# @apiture/accounts-client-sdk@0.37.2
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/accounts-client-sdk@0.37.2 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AccountApi, AccountBeneficiariesApi, AccountOwnersApi, AuthorizedSignersApi, ConfigurationApi, ExternalAccountApi } from "@apiture/accounts-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AccountApi main class passing the configuration object.
    const accountApi = new AccountApi(configuration);

// Instantiate AccountBeneficiariesApi main class passing the configuration object.
    const accountBeneficiariesApi = new AccountBeneficiariesApi(configuration);

// Instantiate AccountOwnersApi main class passing the configuration object.
    const accountOwnersApi = new AccountOwnersApi(configuration);

// Instantiate AuthorizedSignersApi main class passing the configuration object.
    const authorizedSignersApi = new AuthorizedSignersApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);

// Instantiate ExternalAccountApi main class passing the configuration object.
    const externalAccountApi = new ExternalAccountApi(configuration);


// Use the methods to call the apis ( Refer to the Accounts SDK Classes and Methods list ).
  externalAccount.getExternalAccounts().then( response => {
    const getexternalaccountsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ExternalAccountApi main class.
    const externalAccountApi = new ExternalAccountApi();


// Update the accessToken using the class method `setAccessToken`.
    externalAccountApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    externalAccountApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    externalAccountApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ExternalAccounts } from "@apiture/accounts-client-sdk";

  const stronglyTypedObject :ExternalAccounts = { ... };

  // ______ Scoped import

  import * as AccountsTypes from "@apiture/accounts-client-sdk";

  const stronglyTypedObject :AccountsTypes.ExternalAccounts = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/accounts",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Accounts SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document

  `APIApi.getLabels` - Localized Labels



### AccountApi


  `AccountApi.activateAccount` - Activate an account

  `AccountApi.bumpApyRate` - Bump the account&#39;s APY rate

  `AccountApi.closeAccount` - Close an account

  `AccountApi.createAccount` - Create a new account.

  `AccountApi.deactivateAccount` - Deactivate an account

  `AccountApi.deleteAccount` - Delete this account resource

  `AccountApi.freezeAccount` - Freeze an account

  `AccountApi.generateVerificationLetter` - Generate the account verification letter

  `AccountApi.getAccount` - Fetch a representation of this account

  `AccountApi.getAccounts` - Return a collection of accounts

  `AccountApi.patchAccount` - Update this account

  `AccountApi.requestMicroDepositVerification` - Request micro-deposit verification

  `AccountApi.reviewAccount` - The account is under review

  `AccountApi.updateAccountProduct` - Change the account&#39;s product



### AccountBeneficiariesApi


  `AccountBeneficiariesApi.getBeneficiaries` - Fetch the account&#39;s beneficiaries

  `AccountBeneficiariesApi.patchBeneficiaries` - Create or Update the account&#39;s beneficiaries



### AccountOwnersApi


  `AccountOwnersApi.getExternalAccountOwners` - Return a list of external account owners

  `AccountOwnersApi.getOwners` - Fetch the primary and joint owners of an account

  `AccountOwnersApi.updateOwners` - Update the owners of this account



### AuthorizedSignersApi


  `AuthorizedSignersApi.getAuthorizedSigners` - Fetch the business account&#39;s authorized signers

  `AuthorizedSignersApi.updateAuthorizedSigners` - Update the authorized signers of an account



### ConfigurationApi


  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



### ExternalAccountApi


  `ExternalAccountApi.createExternalAccount` - Create a new external account

  `ExternalAccountApi.deleteExternalAccount` - Delete this external account resource

  `ExternalAccountApi.getExternalAccount` - Fetch a representation of this external account

  `ExternalAccountApi.getExternalAccounts` - Return a collection of external accounts

  `ExternalAccountApi.patchExternalAccount` - Update this external account



## About the Accounts API
___
The Accounts API manages banking accounts for bank customers. This API manages two primary types of resources:    * *Accounts* (or _internal_ accounts) are those controlled by the   financial institution (FI). Account holders can perform a various operations   on such accounts: Users may view balances and account details,   open new accounts, lock internal accounts, blocking new banking activity on the account   until they unlock it. Users may also close accounts. The FI can freeze or unfreeze accounts   if they suspect fraudulent or other malicious or suspicious activity.   Users map also transfer money, view transactions, etc. using other Apiture APIs.   * *External Accounts* are accounts controlled by an external   financial institution. These are also known as _linked accounts_.   The user can perform fewer operations on external accounts,   primarily scheduling transfers between and an external account   and an internal account, using other Apiture APIs.   Accounts are instances of a banking _product_ (see the Products API). The product defines the type, rate, terms, attributes, and capabilities of accounts attached to the product. Accounts may be either _personal_ accounts (also known as _retail_ accounts) or _business_ accounts (accounts for businesses, institutions, trusts, non-profits, etc., also known as _commercial accounts_).   A user can list their existing accounts and see the balances of those accounts (based on entitlements) and may have permission to change the account name and label and description. Each account has a _primary user_, which is a bank user (via the Users service). The primary user has full management and entitlements for the account, receives mailings such as statements or tax documents.   For personal (retail) accounts, an account has a primary owner and may have additional joint owners. For business (commercial) accounts, the account owner is the business organization and one or more authorized signers who have account access entitlements.   Because the account number is sensitive data, it is not included by default in account representations. The masked account number is returned in the `accountNumbers` object. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request. The `accountNumbers.full` property is included with the 201 response of creating an account.   This API also manages additional resources which are associated with accounts. For personal accounts, one can get the list of owners (the primary owner and joint owners). The account owner can also view and update the account's beneficiaries. For business accounts, the account holders can view the account's authorized signers: those who have authorization to conduct activity against the account.
