# @apiture/acct-verifications-client-sdk@0.17.2
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/acct-verifications-client-sdk@0.17.2 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AccountVerificationApi, ConfigurationApi, InstitutionsApi, VerificationReportApi } from "@apiture/acct-verifications-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AccountVerificationApi main class passing the configuration object.
    const accountVerificationApi = new AccountVerificationApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);

// Instantiate InstitutionsApi main class passing the configuration object.
    const institutionsApi = new InstitutionsApi(configuration);

// Instantiate VerificationReportApi main class passing the configuration object.
    const verificationReportApi = new VerificationReportApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/accountVerifications",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## External Account Verification SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### AccountVerificationApi


  `AccountVerificationApi.createInstantVerification` - Create a new instant verification resource

  `AccountVerificationApi.createMicroDepositVerification` - Create a new micro-deposit verification resource

  `AccountVerificationApi.getInstantVerification` - Fetch a representation of this instant verification resource

  `AccountVerificationApi.getInstantVerificationAccounts` - Returns a collection of external accounts related to this verification resource

  `AccountVerificationApi.getInstantVerifications` - Return a collection of instant verifications

  `AccountVerificationApi.getMicroDepositVerification` - Fetch a representation of this micro-deposit verification resource

  `AccountVerificationApi.getMicroDepositVerificationAccounts` - Returns a collection of external accounts related to this verification resource

  `AccountVerificationApi.getMicroDepositVerifications` - Return a collection of micro-deposit verification resources

  `AccountVerificationApi.patchMicroDepositVerification` - Update this micro-deposit verification resource

  `AccountVerificationApi.updateInstantVerification` - Update this instant verification resource

  `AccountVerificationApi.verifyMicroDepositAmounts` - Verify micro-deposit amounts



### ConfigurationApi


  `ConfigurationApi.getConfiguration` - Configuration definition for this API

  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



### InstitutionsApi


  `InstitutionsApi.getInstitution` - Fetch a representation of this external financial institution

  `InstitutionsApi.getInstitutionFields` - Return descriptions of the fields required to authenticate with the external institution

  `InstitutionsApi.getInstitutions` - Return a collection of institutions



### VerificationReportApi


  `VerificationReportApi.createVerificationReport` - Create a new verification report resource



## About the External Account Verification API
___
 This API allows financial institutions to verify their customer's external accounts. An external account is defined as a customer's account held at a different financial institution.  Two sets of operations can be utilized to accomplish the verification of an external account: instant verification and micro-deposit. Both operations are asynchronous, which means that upon resource creation the API will return a resource with `state` equal to `pending`. Once the verification completes, the `state` will be updated to `verified` or `failed` to indicate the result of the operation.  ## Instant Account Verification (IAV) This process verifies accounts held at a financial institution within seconds by authenticating via user account credentials with the external financial institution and multi-factor challenges when available.  ## Micro-Deposit Verification (MD) This is an alternative verification method for institutions that don't support IAV. When this verification is initiated, Apiture creates two deposits (typically less than $0.99) to the customer account to be verified, followed by a debit which balances those deposits. Once the transactions post to the user account, the account owner should find the deposits on their external account and submit the two amounts to the micro-deposits resources. This verifies that the user has ownership or access to the external account. Please note that the micro-deposit transactions may take up to two business days to be reflected on the external financial institution.
