# @apiture/applications-client-sdk@0.17.9
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/applications-client-sdk@0.17.9 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AccountApplicationApi, AccountApplicationActionsApi, ConfigurationApi, EnrollmentApi, EnrollmentActionsApi } from "@apiture/applications-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AccountApplicationApi main class passing the configuration object.
    const accountApplicationApi = new AccountApplicationApi(configuration);

// Instantiate AccountApplicationActionsApi main class passing the configuration object.
    const accountApplicationActionsApi = new AccountApplicationActionsApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);

// Instantiate EnrollmentApi main class passing the configuration object.
    const enrollmentApi = new EnrollmentApi(configuration);

// Instantiate EnrollmentActionsApi main class passing the configuration object.
    const enrollmentActionsApi = new EnrollmentActionsApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/accountApplications",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Account Applications SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### AccountApplicationApi


  `AccountApplicationApi.createApplication` - Create a new account application

  `AccountApplicationApi.deleteApplication` - Delete an unused or expired application

  `AccountApplicationApi.getApplication` - Fetch a representation of this account application

  `AccountApplicationApi.getApplications` - Return a collection of account applications

  `AccountApplicationApi.getBlockedApplications` - Return a collection of blocked account applications

  `AccountApplicationApi.getRunningApplications` - Return a collection of active, running account applications

  `AccountApplicationApi.patchApplication` - Update this account application

  `AccountApplicationApi.updateApplication` - Update this account application



### AccountApplicationActionsApi


  `AccountApplicationActionsApi.approveApplication` - Approve an application

  `AccountApplicationActionsApi.cancelApplication` - Cancel an application

  `AccountApplicationActionsApi.expireApplication` - Expire an application

  `AccountApplicationActionsApi.rejectApplication` - Reject an application

  `AccountApplicationActionsApi.startApplication` - Start an application



### ConfigurationApi


  `ConfigurationApi.getConfiguration` - Configuration definition for this API

  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



### EnrollmentApi


  `EnrollmentApi.createEnrollment` - Create a new enrollment

  `EnrollmentApi.deleteEnrollment` - Delete this enrollment resource

  `EnrollmentApi.getEnrollment` - Fetch a representation of this enrollment

  `EnrollmentApi.getEnrollments` - Return a collection of enrollments

  `EnrollmentApi.patchEnrollment` - Update this enrollment

  `EnrollmentApi.updateEnrollment` - Update this enrollment



### EnrollmentActionsApi


  `EnrollmentActionsApi.approveEnrollment` - Approve an enrollment

  `EnrollmentActionsApi.cancelEnrollment` - Cancel an enrollment

  `EnrollmentActionsApi.rejectEnrollment` - Reject an enrollment



## About the Account Applications API
___
This API manages _applications_ to create new accounts. An account application coordinates the following resources necessary to complete the application:   * account applicant(s) and their identity verification status  * banking product for the new account  * documents (required documents, uploaded instances, approvals)  * consents the applicant has given (such as terms and conditions for the banking product, electronic consent)  * external funding account and amount (Transfer)  * business verifications (for business accounts)  * workflow/business process used to perform the application process  * application approval   These individual resources will be nested within in the full representation inside the application resource, but are omitted in the summary application representations that are returned in the `applications` collection. Only the banking product is required to create a new account application. The application retains snapshots of these objects as they existed when the application was reviewed.  An application may be seeded with initial data. This allows \"pre-approved\" applications from external sources. All completed applications (whether `approved` or `rejected`) are retained indefinitely for auditing purposes. Incomplete applications expire after 30 days of inactivity or a period specified by the financial institution in the service configuration.  Each banking product (such as a checking account or money market account) has an association to an _account application workflow definition_ which defines the business process for opening a new account for that product. This workflow is a set of tasks the user must perform in order to open a new account for that product. This service instantiates the workflow, sets the `accountApplication`, `accountApplicant`, `product`, `fundingAccount`, and `organization` properties of the workflow instance, and starts the workflow.  **Note:** A task in the workflow typically performs the actual account creation. A valid account is necessary for an _initial funding_ operation to occur.  Each application maintains a `state` field which indicates the state of that application: `pending`, `running`, `canceled`, `expired`, `rejected`, `approved`. The `pending` state is reserved for future use. The default state when creating a new application is `running`'  Allowed state transitions are:    * `running` &rarr; `canceled` | `expired`  | `approved` | `rejected`   * `blocked` &rarr; `running`  | `canceled` | `expired`  | `approved` | `rejected`   The service will also change an application's state from `blocked` to `running` once the condition that is blocking the application has changed (such as completion of workflow tasks or financial institution approvals.)  This API also manages _enrollments_, which represent a new user enrolling in on-line digital banking. Enrollments consist of collecting personal information (name, address, phone, email, tax ID) and other personal data. Enrollments also support Customer Identification Program regulatory requirements, also known as \"Know Your Customer\", by verifying the user's identity and ensuring they are not involved with fraud or other risk factors. Enrollments are used when new users register in response to invitations to become joint owners or authorized signers on existing accounts. State transitions for enrollments are similar to those for applications. Note: This API uses the base path `/accountApplications` to avoid confusion with _software applications_. 
