// tslint:disable
/**
 * Account Applications
 * This API manages _applications_ to create new accounts. An account application coordinates the following resources necessary to complete the application:   * account applicant(s) and their identity verification status  * banking product for the new account  * documents (required documents, uploaded instances, approvals)  * consents the applicant has given (such as terms and conditions for the banking product, electronic consent)  * external funding account and amount (Transfer)  * business verifications (for business accounts)  * workflow/business process used to perform the application process  * application approval   These individual resources will be nested within in the full representation inside the application resource, but are omitted in the summary application representations that are returned in the `applications` collection. Only the banking product is required to create a new account application. The application retains snapshots of these objects as they existed when the application was reviewed.  An application may be seeded with initial data. This allows \"pre-approved\" applications from external sources. All completed applications (whether `approved` or `rejected`) are retained indefinitely for auditing purposes. Incomplete applications expire after 30 days of inactivity or a period specified by the financial institution in the service configuration.  Each banking product (such as a checking account or money market account) has an association to an _account application workflow definition_ which defines the business process for opening a new account for that product. This workflow is a set of tasks the user must perform in order to open a new account for that product. This service instantiates the workflow, sets the `accountApplication`, `accountApplicant`, `product`, `fundingAccount`, and `organization` properties of the workflow instance, and starts the workflow.  **Note:** A task in the workflow typically performs the actual account creation. A valid account is necessary for an _initial funding_ operation to occur.  Each application maintains a `state` field which indicates the state of that application: `pending`, `running`, `canceled`, `expired`, `rejected`, `approved`. The `pending` state is reserved for future use. The default state when creating a new application is `running`'  Allowed state transitions are:    * `running` &rarr; `canceled` | `expired`  | `approved` | `rejected`   * `blocked` &rarr; `running`  | `canceled` | `expired`  | `approved` | `rejected`   The service will also change an application's state from `blocked` to `running` once the condition that is blocking the application has changed (such as completion of workflow tasks or financial institution approvals.)  This API also manages _enrollments_, which represent a new user enrolling in on-line digital banking. Enrollments consist of collecting personal information (name, address, phone, email, tax ID) and other personal data. Enrollments also support Customer Identification Program regulatory requirements, also known as \"Know Your Customer\", by verifying the user's identity and ensuring they are not involved with fraud or other risk factors. Enrollments are used when new users register in response to invitations to become joint owners or authorized signers on existing accounts. State transitions for enrollments are similar to those for applications. Note: This API uses the base path `/accountApplications` to avoid confusion with _software applications_.
 *
 * OpenAPI spec version: 0.17.9
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
