# @apiture/approvals-client-sdk@0.11.3
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/approvals-client-sdk@0.11.3 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ApprovalApi, ApprovalActionsApi, ApprovalTypeApi } from "@apiture/approvals-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ApprovalApi main class passing the configuration object.
    const approvalApi = new ApprovalApi(configuration);

// Instantiate ApprovalActionsApi main class passing the configuration object.
    const approvalActionsApi = new ApprovalActionsApi(configuration);

// Instantiate ApprovalTypeApi main class passing the configuration object.
    const approvalTypeApi = new ApprovalTypeApi(configuration);


// Use the methods to call the apis ( Refer to the Approvals SDK Classes and Methods list ).
  approvalType.getApprovalTypes().then( response => {
    const getapprovaltypesData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ApprovalTypeApi main class.
    const approvalTypeApi = new ApprovalTypeApi();


// Update the accessToken using the class method `setAccessToken`.
    approvalTypeApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    approvalTypeApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    approvalTypeApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ApprovalTypes } from "@apiture/approvals-client-sdk";

  const stronglyTypedObject :ApprovalTypes = { ... };

  // ______ Scoped import

  import * as ApprovalsTypes from "@apiture/approvals-client-sdk";

  const stronglyTypedObject :ApprovalsTypes.ApprovalTypes = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/approvals",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Approvals SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ApprovalApi


  `ApprovalApi.createApproval` - Create a new approval

  `ApprovalApi.deleteApproval` - Delete this approval resource

  `ApprovalApi.getApproval` - Fetch a representation of this approval

  `ApprovalApi.getApprovals` - Return a collection of approvals

  `ApprovalApi.patchApproval` - Update this approval

  `ApprovalApi.updateApproval` - Update this approval



### ApprovalActionsApi


  `ApprovalActionsApi.approveApproval` - Approve an approval

  `ApprovalActionsApi.cancelApproval` - Cancel an approval

  `ApprovalActionsApi.rejectApproval` - Reject an approval

  `ApprovalActionsApi.returnApproval` - Return an approval

  `ApprovalActionsApi.submitApproval` - Submit an approval

  `ApprovalActionsApi.waiveApproval` - Waive an approval



### ApprovalTypeApi


  `ApprovalTypeApi.createApprovalType` - Create a new approval type

  `ApprovalTypeApi.deleteApprovalType` - Delete this approval type resource

  `ApprovalTypeApi.getApprovalType` - Fetch a representation of this approval type

  `ApprovalTypeApi.getApprovalTypes` - Return a collection of approval types

  `ApprovalTypeApi.patchApprovalType` - Update this approval type

  `ApprovalTypeApi.updateApprovalType` - Update this approval type



## About the Approvals API
___
This API manages state-transition based approvals for Financial Institutions.  Approvals are useful in confirming that part or all of a process is complete. An Approval is a resource which represents something that the financial institution must approve. Examples of approvals may include Identity Verification Document approval or Account Application approval.   Approval States may be one of the following:    * **`open`** Created but not yet ready for review   * **`submitted`** Pending review by approver   * **`approved`** Approval granted   * **`rejected`** Approval denied   * **`waived`** Approval forgiven   * **`returned`** Approver returns approval for modification   * **`canceled`** Approval request withdrawn  Allowed state transitions are:    * `open` -> `submitted`   * `open` -> `waived`   * `submitted` -> `approved`   * `submitted` -> `rejected`   * `submitted` -> `waived`   * `submitted` -> `returned`   * `returned` -> `submitted`   * `open` -> `canceled`   * `submitted` -> `canceled`   * `returned` -> `canceled`   An approval may only be deleted if its `state` is `open` or `canceled`. In order to change the state, use `POST` to the `href` in the corresponding links (`apiture:approve`, `apiture:submit`, `apiture:reject`, etc.) in the approval resource as described fully in the _approval_ schema.  ## Approval type resources  All approval resources contain an _approval type_, a resource that is also managed in this API. Approval types provide financial institutions the ability to track, reconcile and group specific approvals. Some examples of approval types may be specific documents related to new account opening that need to be manually approved, account applications or transfer requests. There can be many approval resources per approval type. In addition, metadata regarding specific types of approvals can be stored on the approval type. Approval types may only be deleted if they are not in use by any existing approvals.   Approval types may also indicate which approval states are not allowed. For example, some approval types disallow `waived` or `returned`. See the `disallowedStates` property.  ## Approval targets  The _target_ of the approval, which may be any resource, is not required but may be provided on the `POST` operation that creates the approval. The target is defined in the `_links` in the request body, with the link relation `apiture:target`. Alternatively, the content to be approved may be embedded within the `attributes` on the approval request. It will also be conveyed in the approval representation in the `GET` operation on the instance and the summary representation in the `/approvals` collection. Examples of targets may include an account application or a document.  ## Approval attributes  An approval or approval type may store additional data in the resource's `attributes` property. Attributes can be modified through `PATCH`. Attributes are _*not*_ copied from the approval type to the approval.
