// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Approvals
 * This API manages state-transition based approvals for Financial Institutions.  Approvals are useful in confirming that part or all of a process is complete. An Approval is a resource which represents something that the financial institution must approve. Examples of approvals may include Identity Verification Document approval or Account Application approval.   Approval States may be one of the following:    * **`open`** Created but not yet ready for review   * **`submitted`** Pending review by approver   * **`approved`** Approval granted   * **`rejected`** Approval denied   * **`waived`** Approval forgiven   * **`returned`** Approver returns approval for modification   * **`canceled`** Approval request withdrawn  Allowed state transitions are:    * `open` -> `submitted`   * `open` -> `waived`   * `submitted` -> `approved`   * `submitted` -> `rejected`   * `submitted` -> `waived`   * `submitted` -> `returned`   * `returned` -> `submitted`   * `open` -> `canceled`   * `submitted` -> `canceled`   * `returned` -> `canceled`   An approval may only be deleted if its `state` is `open` or `canceled`. In order to change the state, use `POST` to the `href` in the corresponding links (`apiture:approve`, `apiture:submit`, `apiture:reject`, etc.) in the approval resource as described fully in the _approval_ schema.  ## Approval type resources  All approval resources contain an _approval type_, a resource that is also managed in this API. Approval types provide financial institutions the ability to track, reconcile and group specific approvals. Some examples of approval types may be specific documents related to new account opening that need to be manually approved, account applications or transfer requests. There can be many approval resources per approval type. In addition, metadata regarding specific types of approvals can be stored on the approval type. Approval types may only be deleted if they are not in use by any existing approvals.   Approval types may also indicate which approval states are not allowed. For example, some approval types disallow `waived` or `returned`. See the `disallowedStates` property.  ## Approval targets  The _target_ of the approval, which may be any resource, is not required but may be provided on the `POST` operation that creates the approval. The target is defined in the `_links` in the request body, with the link relation `apiture:target`. Alternatively, the content to be approved may be embedded within the `attributes` on the approval request. It will also be conveyed in the approval representation in the `GET` operation on the instance and the summary representation in the `/approvals` collection. Examples of targets may include an account application or a document.  ## Approval attributes  An approval or approval type may store additional data in the resource's `attributes` property. Attributes can be modified through `PATCH`. Attributes are _*not*_ copied from the approval type to the approval.
 *
 * OpenAPI spec version: 0.11.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/approvals'.replace(/\/+$/, '');

export const API_VERSION = '0.11.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * An approval represents the _review_ of some process, activity or resource, such as a document or an application. The state of the approval is recorded in its `state` property. The target of the approval is in the link named `apiture:target`; see the _Create Approval_ schema and `createApproval` operation.   Links on an approval convey which state transitions are available. The client should use `POST` to invoke these operations, using the `href` on the named link object. No request body is used on these operations.   The absence of a link indicates that the particular state transition is not available at that time or that the caller is not authorized to make the change. For example, a bank customer may lack permissions to approve a wire transfer they submitted.
 * @export
 * @interface Approval
 */
export interface Approval extends UpdateApproval {
  /**
   * The reason given for the last state change, such as why the approval was approved, rejected, waived, canceled, or returned.
   * @type {string}
   * @memberof Approval
   */
  reason?: string;
  /**
   * The date-time when the approval was created.
   * @type {Date}
   * @memberof Approval
   */
  createdAt?: Date;
  /**
   * The date-time when the approval was updated.
   * @type {Date}
   * @memberof Approval
   */
  updatedAt?: Date;
  /**
   * Embedded objects.
   * @type {ApprovalEmbeddedObjects}
   * @memberof Approval
   */
  _embedded?: ApprovalEmbeddedObjects;
}

/**
 * The objects which participate in this approval.
 * @export
 * @interface ApprovalEmbeddedObjects
 */
export interface ApprovalEmbeddedObjects {
  /**
   * The type of this approval.
   * @type {SummaryApprovalType}
   * @memberof ApprovalEmbeddedObjects
   */
  approvalType?: SummaryApprovalType;
  /**
   * The target of this approval.
   * @type {any}
   * @memberof ApprovalEmbeddedObjects
   */
  target?: any;
}

/**
 * Common fields of the approval resource, used to define other model schemas.
 * @export
 * @interface ApprovalFields
 */
export interface ApprovalFields {
  /**
   * The approval's common name.  If omitted on create request, this will default to the label of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  label?: string;
  /**
   * The approval's description.  If omitted on create request, this will default to the description of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  description?: string;
  /**
   * The state of this approval. This property is derived and immutable. Its value can only be changed by using the corresponding `POST` operations, `submitApproval`, `approveApproval`, `rejectApproval`, `waiveApproval`, `returnApproval`, and `cancelApproval`, if the corresponding links exist on the approval resource, as determined by the existing state of the approval and the allowed states determined by the approval type.
   * @type {ApprovalState}
   * @memberof ApprovalFields
   */
  state?: ApprovalState;
  /**
   * If `done` is true, the approval is in a terminal state and may no longer be acted upon.  Done states include `canceled`, `approved`, `waived` or `rejected`. This property is derived from the `state` field and is immutable.
   * @type {boolean}
   * @memberof ApprovalFields
   */
  done?: boolean;
  /**
   * The name of the Approval Type.  This field is immutable and derived from the name of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  typeName?: string;
  /**
   * The id of the User that reviewed the approval.
   * @type {string}
   * @memberof ApprovalFields
   */
  reviewedBy?: string;
  /**
   * The date-time when the approval was reviewed.
   * @type {Date}
   * @memberof ApprovalFields
   */
  reviewedAt?: Date;
}

/**
 * The approval's state.     * **`open`** Created but pending input subject to approval   * **`submitted`** Pending review by approver   * **`approved`** Approval granted   * **`rejected`** Approval denied   * **`waived`** Approval forgiven   * **`returned`** Approver returns approval for modification   * **`canceled`** Approval request withdrawn   This is an immutable and derived property. Its value can only be changed by using the corresponding `POST` operations, `submitApproval`, `approveApproval`, `rejectApproval`, `waiveApproval`, `returnApproval`, and `cancelApproval`.
 * @export
 * @enum {string}
 */
export enum ApprovalState {
  Open = 'open',
  Submitted = 'submitted',
  Approved = 'approved',
  Rejected = 'rejected',
  Waived = 'waived',
  Returned = 'returned',
  Canceled = 'canceled',
}

/**
 * All Approval resources contain an Approval Type, a resource that is also managed in this API. Approval Types provide Financial Institutions the ability to track, reconcile and group specific Approvals. In addition, metadata regarding specific types of Approvals can be stored on the Approval Type. Approval Types may only be deleted if they are not in use by any existing Approvals. Some examples of Approval Types may be specific documents related to New Account Opening that need  to be manually approved, Account Applications or Transfer requests.
 * @export
 * @interface ApprovalType
 */
export interface ApprovalType extends UpdateApprovalType {
  /**
   * The date-time when the approval was created.
   * @type {Date}
   * @memberof ApprovalType
   */
  createdAt?: Date;
  /**
   * The date-time when the approval was updated
   * @type {Date}
   * @memberof ApprovalType
   */
  updatedAt?: Date;
}

/**
 * Common fields of the approval resource used to build other model schemas.
 * @export
 * @interface ApprovalTypeFields
 */
export interface ApprovalTypeFields {
  /**
   * The approval's name.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  name?: string;
  /**
   * The approval's common name.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  label?: string;
  /**
   * The approval's description.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  description?: string;
  /**
   * A namespace for grouping related resources, to keep them separate from other resources. For example, a department or bank branch may define a domain, and all Approval Type instances  they define will use that domain, so that they can avoid conflicting with Approval Type names in other domains. An API or service may define a domain for new Approval Types that it defines. The combination of `domain` and `name` must be unique within the set of all approval types. It is a best practice to define `domain` with a URI or a URN.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  domain?: string;
  /**
   * An optional array of states that are not allowed for this approval type. If omitted, all state transitions are allowed. The states `open` and `approved` are always allowed, so this enumeration set is a subset of the `approvalState` enumeration on an approval.
   * @type {Array<DisallowedState>}
   * @memberof ApprovalTypeFields
   */
  disallowedStates?: Array<DisallowedState>;
}

/**
 * Collection of approval types. The items in the collection are ordered in the `_embedded.items` array; the `name` is `approvals`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ApprovalTypes
 */
export interface ApprovalTypes extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ApprovalTypes
   */
  _embedded?: any;
}

/**
 * Collection of approvals. The items in the collection are ordered in the `_embedded.items` array; the `name` is `approvals`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Approvals
 */
export interface Approvals extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Approvals
   */
  _embedded?: any;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation used to create a new approval.  A link to an `apiture:approvalType` is required to perform this operation.  An optional `apiture:target` link may also be specified to represent the target resource for the approval. The target can be any resource, for example, an account application or a document.
 * @export
 * @interface CreateApproval
 */
export interface CreateApproval extends AbstractResource, ApprovalFields {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval.
   * @type {any}
   * @memberof CreateApproval
   */
  attributes?: any;
}

/**
 * Representation used to create a new approval type.
 * @export
 * @interface CreateApprovalType
 */
export interface CreateApprovalType extends AbstractResource, ApprovalTypeFields {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval type.
   * @type {any}
   * @memberof CreateApprovalType
   */
  attributes?: any;
}

/**
 * A disallowed state for an approval. Approvals of this type may not be set to any of the states defined by this.
 * @export
 * @enum {string}
 */
export enum DisallowedState {
  Rejected = 'rejected',
  Waived = 'waived',
  Returned = 'returned',
  Canceled = 'canceled',
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Representation used to update or patch an approval type.
 * @export
 * @interface PatchApprovalType
 */
export interface PatchApprovalType extends SummaryApprovalType {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval type.
   * @type {any}
   * @memberof PatchApprovalType
   */
  attributes?: any;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of an approval resource in approvals collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryApproval
 */
export interface SummaryApproval extends AbstractResource, ApprovalFields {
  /**
   * The unique identifier for this approval resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryApproval
   */
  _id?: string;
}

/**
 * Summary representation of an approval type resource in approvals collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryApprovalType
 */
export interface SummaryApprovalType extends AbstractResource, ApprovalTypeFields {
  /**
   * The unique identifier for this approval resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryApprovalType
   */
  _id?: string;
}

/**
 * Representation used to update or patch an approval.  The `state` field is immutable and not updated by this operation, but by the `state transition` POST operations such as `approve` or `reject` (ex. `apiture:approve` and `apiture:reject`).
 * @export
 * @interface UpdateApproval
 */
export interface UpdateApproval extends SummaryApproval {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval.
   * @type {any}
   * @memberof UpdateApproval
   */
  attributes?: any;
}

/**
 * Representation used to update or patch an approval type.
 * @export
 * @interface UpdateApprovalType
 */
export interface UpdateApprovalType extends SummaryApprovalType {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval type.
   * @type {any}
   * @memberof UpdateApprovalType
   */
  attributes?: any;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * ApprovalApi - axios parameter creator
 * @export
 */
export const ApprovalApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval in the approvals collection.  The link to an Approval Type resource is required in order to create a new Approval resource. This link should be passed in the `_links` in the request with an `apiture:approvalType` key. The optional target of an approval may be passed on in either the `_links`  with the link relation `apiture:target`, or in `attributes`.
     * @summary Create a new approval
     * @param {CreateApproval} CreateApproval The data necessary to create a new approval.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(CreateApproval: CreateApproval, options: any = {}): RequestArgs {
      // verify required parameter 'CreateApproval' is not null or undefined
      if (CreateApproval === null || CreateApproval === undefined) {
        throw new RequiredError(
          'CreateApproval',
          'Required parameter CreateApproval was null or undefined when calling createApproval.',
        );
      }
      const localVarPath = `/approvals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateApproval' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateApproval || {})
        : CreateApproval || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this approval resource and any resources that are owned by it. An approval may only be deleted if its state is `open` or `canceled`.
     * @summary Delete this approval resource
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApproval(
      approvalId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalId' is not null or undefined
      if (approvalId === null || approvalId === undefined) {
        throw new RequiredError(
          'approvalId',
          'Required parameter approvalId was null or undefined when calling deleteApproval.',
        );
      }
      const localVarPath = `/approvals/{approvalId}`.replace(
        `{${'approvalId'}}`,
        encodeURIComponent(String(approvalId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource.
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'approvalType' | 'target'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;approvalType&#x60; : include the approval type in the &#x60;_embedded.approvalType&#x60; object. (See the &#x60;approvalEmbeddedObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;target&#x60; : include the approval target.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;approvalType&#x60; and &#x60;target&#x60; for approvals use &#x60;GET .../approval/{approvalId}?embed&#x3D;approvalType,target&#x60;. To embed the target only, use &#x60;GET .../approval/{approvalId}?embed&#x3D;target&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(
      approvalId: string,
      query?: { embed?: Array<'approvalType' | 'target'> },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { embed } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'approvalId' is not null or undefined
      if (approvalId === null || approvalId === undefined) {
        throw new RequiredError(
          'approvalId',
          'Required parameter approvalId was null or undefined when calling getApproval.',
        );
      }
      const localVarPath = `/approvals/{approvalId}`.replace(
        `{${'approvalId'}}`,
        encodeURIComponent(String(approvalId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approvals
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'>} [query.state] Subset the approvals collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;submitted&#x60; matches only items whose &#x60;state&#x60; is &#x60;submitted&#x60;; &#x60;?state&#x3D;rejected|approved&#x60; matches items whose &#x60;state&#x60; is &#x60;rejected&#x60; or &#x60;approved&#x60;. The value or &#x60;|&#x60;-separated values should be from the &#x60;approvalState&#x60; enumeration. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovals(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'
        >;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, label } = query;

      const localVarPath = `/approvals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state) {
        localVarQueryParameter['state'] = state.join(COLLECTION_FORMATS['csv']);
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this approval. Omitted fields are not updated. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalId' is not null or undefined
      if (approvalId === null || approvalId === undefined) {
        throw new RequiredError(
          'approvalId',
          'Required parameter approvalId was null or undefined when calling patchApproval.',
        );
      }
      // verify required parameter 'UpdateApproval' is not null or undefined
      if (UpdateApproval === null || UpdateApproval === undefined) {
        throw new RequiredError(
          'UpdateApproval',
          'Required parameter UpdateApproval was null or undefined when calling patchApproval.',
        );
      }
      const localVarPath = `/approvals/{approvalId}`.replace(
        `{${'approvalId'}}`,
        encodeURIComponent(String(approvalId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateApproval' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateApproval || {})
        : UpdateApproval || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this approval. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalId' is not null or undefined
      if (approvalId === null || approvalId === undefined) {
        throw new RequiredError(
          'approvalId',
          'Required parameter approvalId was null or undefined when calling updateApproval.',
        );
      }
      // verify required parameter 'UpdateApproval' is not null or undefined
      if (UpdateApproval === null || UpdateApproval === undefined) {
        throw new RequiredError(
          'UpdateApproval',
          'Required parameter UpdateApproval was null or undefined when calling updateApproval.',
        );
      }
      const localVarPath = `/approvals/{approvalId}`.replace(
        `{${'approvalId'}}`,
        encodeURIComponent(String(approvalId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateApproval' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateApproval || {})
        : UpdateApproval || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ApprovalApi - functional programming interface
 * @export
 */
export const ApprovalApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval in the approvals collection.  The link to an Approval Type resource is required in order to create a new Approval resource. This link should be passed in the `_links` in the request with an `apiture:approvalType` key. The optional target of an approval may be passed on in either the `_links`  with the link relation `apiture:target`, or in `attributes`.
     * @summary Create a new approval
     * @param {CreateApproval} CreateApproval The data necessary to create a new approval.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(
      CreateApproval: CreateApproval,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).createApproval(
        CreateApproval ? CreateApproval : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this approval resource and any resources that are owned by it. An approval may only be deleted if its state is `open` or `canceled`.
     * @summary Delete this approval resource
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApproval(
      approvalId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).deleteApproval(
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource.
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'approvalType' | 'target'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;approvalType&#x60; : include the approval type in the &#x60;_embedded.approvalType&#x60; object. (See the &#x60;approvalEmbeddedObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;target&#x60; : include the approval target.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;approvalType&#x60; and &#x60;target&#x60; for approvals use &#x60;GET .../approval/{approvalId}?embed&#x3D;approvalType,target&#x60;. To embed the target only, use &#x60;GET .../approval/{approvalId}?embed&#x3D;target&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(
      approvalId: string,
      query?: { embed?: Array<'approvalType' | 'target'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).getApproval(
        approvalId ? approvalId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approvals
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'>} [query.state] Subset the approvals collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;submitted&#x60; matches only items whose &#x60;state&#x60; is &#x60;submitted&#x60;; &#x60;?state&#x3D;rejected|approved&#x60; matches items whose &#x60;state&#x60; is &#x60;rejected&#x60; or &#x60;approved&#x60;. The value or &#x60;|&#x60;-separated values should be from the &#x60;approvalState&#x60; enumeration. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovals(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'
        >;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approvals> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).getApprovals(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this approval. Omitted fields are not updated. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).patchApproval(
        UpdateApproval ? UpdateApproval : null,
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this approval. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalApiAxiosParamCreator(configuration).updateApproval(
        UpdateApproval ? UpdateApproval : null,
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ApprovalApi - factory interface
 * @export
 */
export const ApprovalApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new approval in the approvals collection.  The link to an Approval Type resource is required in order to create a new Approval resource. This link should be passed in the `_links` in the request with an `apiture:approvalType` key. The optional target of an approval may be passed on in either the `_links`  with the link relation `apiture:target`, or in `attributes`.
     * @summary Create a new approval
     * @param {CreateApproval} CreateApproval The data necessary to create a new approval.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(CreateApproval: CreateApproval, options?: any) {
      return ApprovalApiFp(configuration).createApproval(
        CreateApproval ? CreateApproval : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this approval resource and any resources that are owned by it. An approval may only be deleted if its state is `open` or `canceled`.
     * @summary Delete this approval resource
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApproval(approvalId: string, headers?: { If_Match?: string }, options?: any) {
      return ApprovalApiFp(configuration).deleteApproval(
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource.
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'approvalType' | 'target'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;approvalType&#x60; : include the approval type in the &#x60;_embedded.approvalType&#x60; object. (See the &#x60;approvalEmbeddedObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;target&#x60; : include the approval target.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;approvalType&#x60; and &#x60;target&#x60; for approvals use &#x60;GET .../approval/{approvalId}?embed&#x3D;approvalType,target&#x60;. To embed the target only, use &#x60;GET .../approval/{approvalId}?embed&#x3D;target&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(
      approvalId: string,
      query?: { embed?: Array<'approvalType' | 'target'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ApprovalApiFp(configuration).getApproval(
        approvalId ? approvalId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approvals
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'>} [query.state] Subset the approvals collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;submitted&#x60; matches only items whose &#x60;state&#x60; is &#x60;submitted&#x60;; &#x60;?state&#x3D;rejected|approved&#x60; matches items whose &#x60;state&#x60; is &#x60;rejected&#x60; or &#x60;approved&#x60;. The value or &#x60;|&#x60;-separated values should be from the &#x60;approvalState&#x60; enumeration. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovals(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'
        >;
        label?: string;
      },
      options?: any,
    ) {
      return ApprovalApiFp(configuration).getApprovals(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this approval. Omitted fields are not updated. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalApiFp(configuration).patchApproval(
        UpdateApproval ? UpdateApproval : null,
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this approval. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
     * @summary Update this approval
     * @param {UpdateApproval} UpdateApproval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApproval(
      UpdateApproval: UpdateApproval,
      approvalId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalApiFp(configuration).updateApproval(
        UpdateApproval ? UpdateApproval : null,
        approvalId ? approvalId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ApprovalApi - object-oriented interface
 * @export
 * @class ApprovalApi
 * @extends {BaseAPI}
 */
export class ApprovalApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new approval in the approvals collection.  The link to an Approval Type resource is required in order to create a new Approval resource. This link should be passed in the `_links` in the request with an `apiture:approvalType` key. The optional target of an approval may be passed on in either the `_links`  with the link relation `apiture:target`, or in `attributes`.
   * @summary Create a new approval
   * @param {CreateApproval} CreateApproval The data necessary to create a new approval.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalApi
   */
  public createApproval(CreateApproval: CreateApproval, options?: any) {
    return ApprovalApiFp(this.configuration).createApproval(
      CreateApproval ? CreateApproval : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this approval resource and any resources that are owned by it. An approval may only be deleted if its state is `open` or `canceled`.
   * @summary Delete this approval resource
   * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ApprovalApi
   */
  public deleteApproval(approvalId: string, headers?: { If_Match?: string }, options?: any) {
    return ApprovalApiFp(this.configuration).deleteApproval(
      approvalId ? approvalId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource.
   * @summary Fetch a representation of this approval
   * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {Array<'approvalType' | 'target'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;approvalType&#x60; : include the approval type in the &#x60;_embedded.approvalType&#x60; object. (See the &#x60;approvalEmbeddedObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;target&#x60; : include the approval target.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;approvalType&#x60; and &#x60;target&#x60; for approvals use &#x60;GET .../approval/{approvalId}?embed&#x3D;approvalType,target&#x60;. To embed the target only, use &#x60;GET .../approval/{approvalId}?embed&#x3D;target&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalApi
   */
  public getApproval(
    approvalId: string,
    query?: { embed?: Array<'approvalType' | 'target'> },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ApprovalApiFp(this.configuration).getApproval(
      approvalId ? approvalId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of approvals
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first approval item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of approval representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {Array<'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'>} [query.state] Subset the approvals collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;submitted&#x60; matches only items whose &#x60;state&#x60; is &#x60;submitted&#x60;; &#x60;?state&#x3D;rejected|approved&#x60; matches items whose &#x60;state&#x60; is &#x60;rejected&#x60; or &#x60;approved&#x60;. The value or &#x60;|&#x60;-separated values should be from the &#x60;approvalState&#x60; enumeration. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approvals}
   * @memberof ApprovalApi
   */
  public getApprovals(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: Array<
        'open' | 'submitted' | 'approved' | 'rejected' | 'waived' | 'returned' | 'canceled'
      >;
      label?: string;
    },
    options?: any,
  ) {
    return ApprovalApiFp(this.configuration).getApprovals(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this approval. Omitted fields are not updated. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
   * @summary Update this approval
   * @param {UpdateApproval} UpdateApproval
   * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalApi
   */
  public patchApproval(
    UpdateApproval: UpdateApproval,
    approvalId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalApiFp(this.configuration).patchApproval(
      UpdateApproval ? UpdateApproval : null,
      approvalId ? approvalId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this approval. Nested `_embedded` and `_links` are ignored if included. The `state` is not updated by this operation; use the state-change operations described in the `approval` schema.
   * @summary Update this approval
   * @param {UpdateApproval} UpdateApproval
   * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalApi
   */
  public updateApproval(
    UpdateApproval: UpdateApproval,
    approvalId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalApiFp(this.configuration).updateApproval(
      UpdateApproval ? UpdateApproval : null,
      approvalId ? approvalId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ApprovalActionsApi - axios parameter creator
 * @export
 */
export const ApprovalActionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Approve an approval.   Only approvals which are `submitted` may be `approved`.   This operation is invoked from the `apiture:approve` link on a product type when it is eligible to be approved.   This changes the `state` to `approved`.
     * @summary Approve an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be approved. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling approveApproval.',
        );
      }
      const localVarPath = `/approvedApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Cancel an approval. Only approvals which are `open`, `submitted` or `returned` may be `canceled`. This operation is invoked from the `apiture:cancel` link on an approval when it is eligible to be canceled. This changes the `state` to `canceled`.
     * @summary Cancel an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be canceled. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling cancelApproval.',
        );
      }
      // verify required parameter 'approvalUri' is not null or undefined
      if (approvalUri === null || approvalUri === undefined) {
        throw new RequiredError(
          'approvalUri',
          'Required parameter approvalUri was null or undefined when calling cancelApproval.',
        );
      }
      const localVarPath = `/canceledApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Reject an approval. Only approvals which are `submitted` may be `rejected`.  This operation is invoked from the `apiture:reject` link on an approval when it is eligible to be rejected. This changes the `state` to `rejected`.
     * @summary Reject an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be rejected. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling rejectApproval.',
        );
      }
      const localVarPath = `/rejectedApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return an approval. Only approvals which are `submitted` may be `returned`. This operation is invoked from the `apiture:return` link on an approval when it is eligible to be returned. This changes the `state` to `returned`.
     * @summary Return an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be returned. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    returnApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling returnApproval.',
        );
      }
      // verify required parameter 'approvalUri' is not null or undefined
      if (approvalUri === null || approvalUri === undefined) {
        throw new RequiredError(
          'approvalUri',
          'Required parameter approvalUri was null or undefined when calling returnApproval.',
        );
      }
      const localVarPath = `/returnedApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Submit an approval. Only approvals which are `open` or `returned` may be `submitted`. This operation is invoked from the `apiture:submit` link on an approval when it is eligible to be submitted. This changes the `state` to `submitted`.
     * @summary Submit an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be submitted. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling submitApproval.',
        );
      }
      // verify required parameter 'approvalUri' is not null or undefined
      if (approvalUri === null || approvalUri === undefined) {
        throw new RequiredError(
          'approvalUri',
          'Required parameter approvalUri was null or undefined when calling submitApproval.',
        );
      }
      const localVarPath = `/submittedApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Waive an approval. Only approvals which are `open` or `submitted` may be `waived`. This operation is invoked from the `apiture:waive` link on an approval when it is eligible to be waived. This changes the `state` to `waived`.
     * @summary Waive an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be waived. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    waiveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { approval, approvalUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'approval' is not null or undefined
      if (approval === null || approval === undefined) {
        throw new RequiredError(
          'approval',
          'Required parameter approval was null or undefined when calling waiveApproval.',
        );
      }
      // verify required parameter 'approvalUri' is not null or undefined
      if (approvalUri === null || approvalUri === undefined) {
        throw new RequiredError(
          'approvalUri',
          'Required parameter approvalUri was null or undefined when calling waiveApproval.',
        );
      }
      const localVarPath = `/waivedApprovals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (approval !== undefined) {
        localVarQueryParameter['approval'] = approval;
      }

      if (approvalUri !== undefined) {
        localVarQueryParameter['approvalUri'] = approvalUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ApprovalActionsApi - functional programming interface
 * @export
 */
export const ApprovalActionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Approve an approval.   Only approvals which are `submitted` may be `approved`.   This operation is invoked from the `apiture:approve` link on a product type when it is eligible to be approved.   This changes the `state` to `approved`.
     * @summary Approve an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be approved. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).approveApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Cancel an approval. Only approvals which are `open`, `submitted` or `returned` may be `canceled`. This operation is invoked from the `apiture:cancel` link on an approval when it is eligible to be canceled. This changes the `state` to `canceled`.
     * @summary Cancel an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be canceled. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).cancelApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Reject an approval. Only approvals which are `submitted` may be `rejected`.  This operation is invoked from the `apiture:reject` link on an approval when it is eligible to be rejected. This changes the `state` to `rejected`.
     * @summary Reject an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be rejected. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).rejectApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return an approval. Only approvals which are `submitted` may be `returned`. This operation is invoked from the `apiture:return` link on an approval when it is eligible to be returned. This changes the `state` to `returned`.
     * @summary Return an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be returned. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    returnApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).returnApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Submit an approval. Only approvals which are `open` or `returned` may be `submitted`. This operation is invoked from the `apiture:submit` link on an approval when it is eligible to be submitted. This changes the `state` to `submitted`.
     * @summary Submit an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be submitted. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).submitApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Waive an approval. Only approvals which are `open` or `submitted` may be `waived`. This operation is invoked from the `apiture:waive` link on an approval when it is eligible to be waived. This changes the `state` to `waived`.
     * @summary Waive an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be waived. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    waiveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalActionsApiAxiosParamCreator(configuration).waiveApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ApprovalActionsApi - factory interface
 * @export
 */
export const ApprovalActionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Approve an approval.   Only approvals which are `submitted` may be `approved`.   This operation is invoked from the `apiture:approve` link on a product type when it is eligible to be approved.   This changes the `state` to `approved`.
     * @summary Approve an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be approved. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).approveApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Cancel an approval. Only approvals which are `open`, `submitted` or `returned` may be `canceled`. This operation is invoked from the `apiture:cancel` link on an approval when it is eligible to be canceled. This changes the `state` to `canceled`.
     * @summary Cancel an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be canceled. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).cancelApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Reject an approval. Only approvals which are `submitted` may be `rejected`.  This operation is invoked from the `apiture:reject` link on an approval when it is eligible to be rejected. This changes the `state` to `rejected`.
     * @summary Reject an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be rejected. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).rejectApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return an approval. Only approvals which are `submitted` may be `returned`. This operation is invoked from the `apiture:return` link on an approval when it is eligible to be returned. This changes the `state` to `returned`.
     * @summary Return an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be returned. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    returnApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).returnApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Submit an approval. Only approvals which are `open` or `returned` may be `submitted`. This operation is invoked from the `apiture:submit` link on an approval when it is eligible to be submitted. This changes the `state` to `submitted`.
     * @summary Submit an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be submitted. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).submitApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Waive an approval. Only approvals which are `open` or `submitted` may be `waived`. This operation is invoked from the `apiture:waive` link on an approval when it is eligible to be waived. This changes the `state` to `waived`.
     * @summary Waive an approval
     * @param {Object} [query] Query object
     * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
     * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be waived. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    waiveApproval(
      query?: { approval?: string; approvalUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalActionsApiFp(configuration).waiveApproval(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ApprovalActionsApi - object-oriented interface
 * @export
 * @class ApprovalActionsApi
 * @extends {BaseAPI}
 */
export class ApprovalActionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Approve an approval.   Only approvals which are `submitted` may be `approved`.   This operation is invoked from the `apiture:approve` link on a product type when it is eligible to be approved.   This changes the `state` to `approved`.
   * @summary Approve an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be approved. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public approveApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).approveApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Cancel an approval. Only approvals which are `open`, `submitted` or `returned` may be `canceled`. This operation is invoked from the `apiture:cancel` link on an approval when it is eligible to be canceled. This changes the `state` to `canceled`.
   * @summary Cancel an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be canceled. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public cancelApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).cancelApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Reject an approval. Only approvals which are `submitted` may be `rejected`.  This operation is invoked from the `apiture:reject` link on an approval when it is eligible to be rejected. This changes the `state` to `rejected`.
   * @summary Reject an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be rejected. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public rejectApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).rejectApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return an approval. Only approvals which are `submitted` may be `returned`. This operation is invoked from the `apiture:return` link on an approval when it is eligible to be returned. This changes the `state` to `returned`.
   * @summary Return an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be returned. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public returnApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).returnApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Submit an approval. Only approvals which are `open` or `returned` may be `submitted`. This operation is invoked from the `apiture:submit` link on an approval when it is eligible to be submitted. This changes the `state` to `submitted`.
   * @summary Submit an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be submitted. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public submitApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).submitApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Waive an approval. Only approvals which are `open` or `submitted` may be `waived`. This operation is invoked from the `apiture:waive` link on an approval when it is eligible to be waived. This changes the `state` to `waived`.
   * @summary Waive an approval
   * @param {Object} [query] Query object
   * @param {string} [query.approval] A server-generated key which identifies an existing approval resource.
   * @param {string} [query.approvalUri] The URI of an existing approval which is eligible to be waived. Note: This parameter is **deprecated** and will be removed in the next version. Use &#x60;?approval&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalActionsApi
   */
  public waiveApproval(
    query?: { approval?: string; approvalUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalActionsApiFp(this.configuration).waiveApproval(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ApprovalTypeApi - axios parameter creator
 * @export
 */
export const ApprovalTypeApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval type in the approval types collection.
     * @summary Create a new approval type
     * @param {CreateApprovalType} CreateApprovalType The data necessary to create a new approval type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApprovalType(CreateApprovalType: CreateApprovalType, options: any = {}): RequestArgs {
      // verify required parameter 'CreateApprovalType' is not null or undefined
      if (CreateApprovalType === null || CreateApprovalType === undefined) {
        throw new RequiredError(
          'CreateApprovalType',
          'Required parameter CreateApprovalType was null or undefined when calling createApprovalType.',
        );
      }
      const localVarPath = `/approvalTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateApprovalType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateApprovalType || {})
        : CreateApprovalType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this approval type resource and any resources that are owned by it.  Deleting an Approval Type is only allowed if it is not in use by any existing Approvals.
     * @summary Delete this approval type resource
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApprovalType(
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalTypeId' is not null or undefined
      if (approvalTypeId === null || approvalTypeId === undefined) {
        throw new RequiredError(
          'approvalTypeId',
          'Required parameter approvalTypeId was null or undefined when calling deleteApprovalType.',
        );
      }
      const localVarPath = `/approvalTypes/{approvalTypeId}`.replace(
        `{${'approvalTypeId'}}`,
        encodeURIComponent(String(approvalTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval type resource.
     * @summary Fetch a representation of this approval type
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalType(
      approvalTypeId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'approvalTypeId' is not null or undefined
      if (approvalTypeId === null || approvalTypeId === undefined) {
        throw new RequiredError(
          'approvalTypeId',
          'Required parameter approvalTypeId was null or undefined when calling getApprovalType.',
        );
      }
      const localVarPath = `/approvalTypes/{approvalTypeId}`.replace(
        `{${'approvalTypeId'}}`,
        encodeURIComponent(String(approvalTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approval types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval type item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the approvals collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        label?: string;
        name?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, label, name } = query;

      const localVarPath = `/approvalTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this approval type. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this approval type
     * @param {PatchApprovalType} PatchApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApprovalType(
      PatchApprovalType: PatchApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalTypeId' is not null or undefined
      if (approvalTypeId === null || approvalTypeId === undefined) {
        throw new RequiredError(
          'approvalTypeId',
          'Required parameter approvalTypeId was null or undefined when calling patchApprovalType.',
        );
      }
      // verify required parameter 'PatchApprovalType' is not null or undefined
      if (PatchApprovalType === null || PatchApprovalType === undefined) {
        throw new RequiredError(
          'PatchApprovalType',
          'Required parameter PatchApprovalType was null or undefined when calling patchApprovalType.',
        );
      }
      const localVarPath = `/approvalTypes/{approvalTypeId}`.replace(
        `{${'approvalTypeId'}}`,
        encodeURIComponent(String(approvalTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'PatchApprovalType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(PatchApprovalType || {})
        : PatchApprovalType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this approval type.
     * @summary Update this approval type
     * @param {UpdateApprovalType} UpdateApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApprovalType(
      UpdateApprovalType: UpdateApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'approvalTypeId' is not null or undefined
      if (approvalTypeId === null || approvalTypeId === undefined) {
        throw new RequiredError(
          'approvalTypeId',
          'Required parameter approvalTypeId was null or undefined when calling updateApprovalType.',
        );
      }
      // verify required parameter 'UpdateApprovalType' is not null or undefined
      if (UpdateApprovalType === null || UpdateApprovalType === undefined) {
        throw new RequiredError(
          'UpdateApprovalType',
          'Required parameter UpdateApprovalType was null or undefined when calling updateApprovalType.',
        );
      }
      const localVarPath = `/approvalTypes/{approvalTypeId}`.replace(
        `{${'approvalTypeId'}}`,
        encodeURIComponent(String(approvalTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateApprovalType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateApprovalType || {})
        : UpdateApprovalType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ApprovalTypeApi - functional programming interface
 * @export
 */
export const ApprovalTypeApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval type in the approval types collection.
     * @summary Create a new approval type
     * @param {CreateApprovalType} CreateApprovalType The data necessary to create a new approval type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApprovalType(
      CreateApprovalType: CreateApprovalType,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ApprovalType> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).createApprovalType(
        CreateApprovalType ? CreateApprovalType : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this approval type resource and any resources that are owned by it.  Deleting an Approval Type is only allowed if it is not in use by any existing Approvals.
     * @summary Delete this approval type resource
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApprovalType(
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).deleteApprovalType(
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval type resource.
     * @summary Fetch a representation of this approval type
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalType(
      approvalTypeId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ApprovalType> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).getApprovalType(
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approval types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval type item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the approvals collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        label?: string;
        name?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ApprovalTypes> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).getApprovalTypes(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this approval type. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this approval type
     * @param {PatchApprovalType} PatchApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApprovalType(
      PatchApprovalType: PatchApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ApprovalType> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).patchApprovalType(
        PatchApprovalType ? PatchApprovalType : null,
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this approval type.
     * @summary Update this approval type
     * @param {UpdateApprovalType} UpdateApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApprovalType(
      UpdateApprovalType: UpdateApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ApprovalType> {
      const localVarAxiosArgs = ApprovalTypeApiAxiosParamCreator(configuration).updateApprovalType(
        UpdateApprovalType ? UpdateApprovalType : null,
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ApprovalTypeApi - factory interface
 * @export
 */
export const ApprovalTypeApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new approval type in the approval types collection.
     * @summary Create a new approval type
     * @param {CreateApprovalType} CreateApprovalType The data necessary to create a new approval type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApprovalType(CreateApprovalType: CreateApprovalType, options?: any) {
      return ApprovalTypeApiFp(configuration).createApprovalType(
        CreateApprovalType ? CreateApprovalType : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this approval type resource and any resources that are owned by it.  Deleting an Approval Type is only allowed if it is not in use by any existing Approvals.
     * @summary Delete this approval type resource
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApprovalType(approvalTypeId: string, headers?: { If_Match?: string }, options?: any) {
      return ApprovalTypeApiFp(configuration).deleteApprovalType(
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval type resource.
     * @summary Fetch a representation of this approval type
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalType(approvalTypeId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ApprovalTypeApiFp(configuration).getApprovalType(
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of approval types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first approval type item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of approval type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the approvals collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApprovalTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        label?: string;
        name?: string;
      },
      options?: any,
    ) {
      return ApprovalTypeApiFp(configuration).getApprovalTypes(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this approval type. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this approval type
     * @param {PatchApprovalType} PatchApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApprovalType(
      PatchApprovalType: PatchApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalTypeApiFp(configuration).patchApprovalType(
        PatchApprovalType ? PatchApprovalType : null,
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this approval type.
     * @summary Update this approval type
     * @param {UpdateApprovalType} UpdateApprovalType
     * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApprovalType(
      UpdateApprovalType: UpdateApprovalType,
      approvalTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ApprovalTypeApiFp(configuration).updateApprovalType(
        UpdateApprovalType ? UpdateApprovalType : null,
        approvalTypeId ? approvalTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ApprovalTypeApi - object-oriented interface
 * @export
 * @class ApprovalTypeApi
 * @extends {BaseAPI}
 */
export class ApprovalTypeApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new approval type in the approval types collection.
   * @summary Create a new approval type
   * @param {CreateApprovalType} CreateApprovalType The data necessary to create a new approval type.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ApprovalType}
   * @memberof ApprovalTypeApi
   */
  public createApprovalType(CreateApprovalType: CreateApprovalType, options?: any) {
    return ApprovalTypeApiFp(this.configuration).createApprovalType(
      CreateApprovalType ? CreateApprovalType : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this approval type resource and any resources that are owned by it.  Deleting an Approval Type is only allowed if it is not in use by any existing Approvals.
   * @summary Delete this approval type resource
   * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ApprovalTypeApi
   */
  public deleteApprovalType(
    approvalTypeId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalTypeApiFp(this.configuration).deleteApprovalType(
      approvalTypeId ? approvalTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval type resource.
   * @summary Fetch a representation of this approval type
   * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ApprovalType}
   * @memberof ApprovalTypeApi
   */
  public getApprovalType(
    approvalTypeId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ApprovalTypeApiFp(this.configuration).getApprovalType(
      approvalTypeId ? approvalTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of approvals. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of approval types
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first approval type item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of approval type representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.label] Subset the approvals collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the approvals collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ApprovalTypes}
   * @memberof ApprovalTypeApi
   */
  public getApprovalTypes(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      label?: string;
      name?: string;
    },
    options?: any,
  ) {
    return ApprovalTypeApiFp(this.configuration).getApprovalTypes(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this approval type. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this approval type
   * @param {PatchApprovalType} PatchApprovalType
   * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ApprovalType}
   * @memberof ApprovalTypeApi
   */
  public patchApprovalType(
    PatchApprovalType: PatchApprovalType,
    approvalTypeId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalTypeApiFp(this.configuration).patchApprovalType(
      PatchApprovalType ? PatchApprovalType : null,
      approvalTypeId ? approvalTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this approval type.
   * @summary Update this approval type
   * @param {UpdateApprovalType} UpdateApprovalType
   * @param {string} approvalTypeId The unique identifier of this approval type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ApprovalType}
   * @memberof ApprovalTypeApi
   */
  public updateApprovalType(
    UpdateApprovalType: UpdateApprovalType,
    approvalTypeId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ApprovalTypeApiFp(this.configuration).updateApprovalType(
      UpdateApprovalType ? UpdateApprovalType : null,
      approvalTypeId ? approvalTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
