// tslint:disable
/**
 * Approvals
 * This API manages state-transition based approvals for Financial Institutions.  Approvals are useful in confirming that part or all of a process is complete. An Approval is a resource which represents something that the financial institution must approve. Examples of approvals may include Identity Verification Document approval or Account Application approval.   Approval States may be one of the following:    * **`open`** Created but not yet ready for review   * **`submitted`** Pending review by approver   * **`approved`** Approval granted   * **`rejected`** Approval denied   * **`waived`** Approval forgiven   * **`returned`** Approver returns approval for modification   * **`canceled`** Approval request withdrawn  Allowed state transitions are:    * `open` -> `submitted`   * `open` -> `waived`   * `submitted` -> `approved`   * `submitted` -> `rejected`   * `submitted` -> `waived`   * `submitted` -> `returned`   * `returned` -> `submitted`   * `open` -> `canceled`   * `submitted` -> `canceled`   * `returned` -> `canceled`   An approval may only be deleted if its `state` is `open` or `canceled`. In order to change the state, use `POST` to the `href` in the corresponding links (`apiture:approve`, `apiture:submit`, `apiture:reject`, etc.) in the approval resource as described fully in the _approval_ schema.  ## Approval type resources  All approval resources contain an _approval type_, a resource that is also managed in this API. Approval types provide financial institutions the ability to track, reconcile and group specific approvals. Some examples of approval types may be specific documents related to new account opening that need to be manually approved, account applications or transfer requests. There can be many approval resources per approval type. In addition, metadata regarding specific types of approvals can be stored on the approval type. Approval types may only be deleted if they are not in use by any existing approvals.   Approval types may also indicate which approval states are not allowed. For example, some approval types disallow `waived` or `returned`. See the `disallowedStates` property.  ## Approval targets  The _target_ of the approval, which may be any resource, is not required but may be provided on the `POST` operation that creates the approval. The target is defined in the `_links` in the request body, with the link relation `apiture:target`. Alternatively, the content to be approved may be embedded within the `attributes` on the approval request. It will also be conveyed in the approval representation in the `GET` operation on the instance and the summary representation in the `/approvals` collection. Examples of targets may include an account application or a document.  ## Approval attributes  An approval or approval type may store additional data in the resource's `attributes` property. Attributes can be modified through `PATCH`. Attributes are _*not*_ copied from the approval type to the approval.
 *
 * OpenAPI spec version: 0.11.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
