# @apiture/associations-client-sdk@0.7.7
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/associations-client-sdk@0.7.7 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AssociationApi, RoleApi } from "@apiture/associations-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AssociationApi main class passing the configuration object.
    const associationApi = new AssociationApi(configuration);

// Instantiate RoleApi main class passing the configuration object.
    const roleApi = new RoleApi(configuration);


// Use the methods to call the apis ( Refer to the Associations SDK Classes and Methods list ).
  role.getRoles().then( response => {
    const getrolesData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate RoleApi main class.
    const roleApi = new RoleApi();


// Update the accessToken using the class method `setAccessToken`.
    roleApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    roleApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    roleApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Roles } from "@apiture/associations-client-sdk";

  const stronglyTypedObject :Roles = { ... };

  // ______ Scoped import

  import * as AssociationsTypes from "@apiture/associations-client-sdk";

  const stronglyTypedObject :AssociationsTypes.Roles = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/associations",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Associations SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### AssociationApi


  `AssociationApi.createAssociation` - Create a new association

  `AssociationApi.deleteAssociation` - Delete this association resource

  `AssociationApi.getAssociation` - Fetch a representation of this association

  `AssociationApi.getAssociations` - Return a collection of associations.

  `AssociationApi.patchAssociation` - Update this association



### RoleApi


  `RoleApi.createRole` - Create a new role

  `RoleApi.deleteRole` - Delete this role resource

  `RoleApi.getRole` - Fetch a representation of this role

  `RoleApi.getRoles` - Return a collection of roles

  `RoleApi.patchRole` - Update this role

  `RoleApi.updateRole` - Update this role



## About the Associations API
___
The Associations API associates source resources to target resources using association roles.
