// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Associations
 * The Associations API associates source resources to target resources using association roles.
 *
 * OpenAPI spec version: 0.7.6
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/associations'.replace(/\/+$/, '');

export const API_VERSION = '0.7.6';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Representation of an association between two resources. When used to create a new association, the request must contain links to the elements of the association: a role (`apiture:role`) a source resource (`apiture:source`) and a target resource (`apiture:target`). In many cases, the target resource is  a person or user; a source or target may be any resource.
 * @export
 * @interface Association
 */
export interface Association extends UpdateAssociation {
  /**
   * The date-time when the association was created. This is in ISO 8601 format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Association
   */
  createdAt?: Date;
  /**
   * The objects which participate in this association
   * @type {any}
   * @memberof Association
   */
  _embedded?: any;
}

/**
 * Core fields of the association resource used to build other model schema.
 * @export
 * @interface AssociationFields
 */
export interface AssociationFields {
  /**
   * The URI of association source resource.
   * @type {string}
   * @memberof AssociationFields
   */
  sourceUri?: string;
  /**
   * The URI of association role resource.
   * @type {string}
   * @memberof AssociationFields
   */
  roleUri?: string;
  /**
   * The name of the role used to associate two resources. This is a derived value and is ignored on updates.
   * @type {string}
   * @memberof AssociationFields
   */
  roleName?: string;
  /**
   * The URI of association target resource.
   * @type {string}
   * @memberof AssociationFields
   */
  targetUri?: string;
  /**
   * Data attribute associated with the error, such as values or constraints.
   * @type {Attributes}
   * @memberof AssociationFields
   */
  attributes?: Attributes;
}

/**
 * Collection of associations. The items in the collection are ordered in the `_embedded` object with name `items`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Associations
 */
export interface Associations extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Associations
   */
  _embedded?: any;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation used to create a new association.
 * @export
 * @interface CreateAssociation
 */
export interface CreateAssociation extends AssociationFields, AbstractResource {}

/**
 * Representation used to create a new role.
 * @export
 * @interface CreateRole
 */
export interface CreateRole extends SummaryRole {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Representation of a role resource. Roles are used to associate resources. The most common roles may be related to entitlements(users) but can also be applied to organizations or non-users (such as beneficiaries, payees, etc.).
 * @export
 * @interface Role
 */
export interface Role extends UpdateRole {
  /**
   * The date-time when the role was created. This is in ISO 8601 format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Role
   */
  createdAt?: Date;
}

/**
 * Core fields of the role resource used to build other model schema.
 * @export
 * @interface RoleFields
 */
export interface RoleFields {
  /**
   * The name of this role, for identification purposes, such as `primaryOwner`, `beneficiary`, `authorizedSigner`. Some roles have well-known uses in the platform.
   * @type {string}
   * @memberof RoleFields
   */
  name?: string;
  /**
   * The text label for this role, for use in human presentation. This field may be localized.
   * @type {string}
   * @memberof RoleFields
   */
  label?: string;
  /**
   * A fuller description of this role. This field may be localized.
   * @type {string}
   * @memberof RoleFields
   */
  description?: string;
}

/**
 * Collection of roles. The items in the collection are ordered in the `_embedded` object with name `items`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Roles
 */
export interface Roles extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Roles
   */
  _embedded?: any;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of an association resource in associations collections.
 * @export
 * @interface SummaryAssociation
 */
export interface SummaryAssociation extends CreateAssociation {
  /**
   * The unique identifier for this association resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryAssociation
   */
  _id?: string;
}

/**
 * Summary representation of a role resource in roles collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryRole
 */
export interface SummaryRole extends RoleFields, AbstractResource {
  /**
   * The unique identifier for this role resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryRole
   */
  _id?: string;
}

/**
 * Representation used to update or patch an association.
 * @export
 * @interface UpdateAssociation
 */
export interface UpdateAssociation extends AssociationFields, AbstractResource {
  /**
   * The unique identifier for this association resource. This is an immutable opaque string.
   * @type {string}
   * @memberof UpdateAssociation
   */
  _id?: string;
}

/**
 * Representation used to update or patch a role.
 * @export
 * @interface UpdateRole
 */
export interface UpdateRole extends SummaryRole {}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:associations`* : links to the collection of associations held at this financial institution. *`apiture:roles`* : links to the collection of roles held at this financial institution.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:associations`* : links to the collection of associations held at this financial institution. *`apiture:roles`* : links to the collection of roles held at this financial institution.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:associations`* : links to the collection of associations held at this financial institution. *`apiture:roles`* : links to the collection of roles held at this financial institution.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:associations`* : links to the collection of associations held at this financial institution. *`apiture:roles`* : links to the collection of roles held at this financial institution.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AssociationApi - axios parameter creator
 * @export
 */
export const AssociationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new association between two resources. The request must include a valid link (`apiture:source`) to a source resource, (`apiture:role`) to an association role instance and a link (`apiture:target`) to a target resource.
     * @summary Create a new association
     * @param {CreateAssociation} CreateAssociation The data necessary to create a new association.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAssociation(CreateAssociation: CreateAssociation, options: any = {}): RequestArgs {
      // verify required parameter 'CreateAssociation' is not null or undefined
      if (CreateAssociation === null || CreateAssociation === undefined) {
        throw new RequiredError(
          'CreateAssociation',
          'Required parameter CreateAssociation was null or undefined when calling createAssociation.',
        );
      }
      const localVarPath = `/associations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateAssociation' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateAssociation || {})
        : CreateAssociation || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this association resource and any resources that are owned by it.  Deleting an association does not delete the source, role, or target resources.
     * @summary Delete this association resource
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAssociation(
      associationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'associationId' is not null or undefined
      if (associationId === null || associationId === undefined) {
        throw new RequiredError(
          'associationId',
          'Required parameter associationId was null or undefined when calling deleteAssociation.',
        );
      }
      const localVarPath = `/associations/{associationId}`.replace(
        `{${'associationId'}}`,
        encodeURIComponent(String(associationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this association resource.
     * @summary Fetch a representation of this association
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociation(
      associationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'associationId' is not null or undefined
      if (associationId === null || associationId === undefined) {
        throw new RequiredError(
          'associationId',
          'Required parameter associationId was null or undefined when calling getAssociation.',
        );
      }
      const localVarPath = `/associations/{associationId}`.replace(
        `{${'associationId'}}`,
        encodeURIComponent(String(associationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of associations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of associations.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first association item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of association representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the associations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        type?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, name, type, label } = query;

      const localVarPath = `/associations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this association. Fields which are omitted are not updated.
     * @summary Update this association
     * @param {UpdateAssociation} UpdateAssociation
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAssociation(
      UpdateAssociation: UpdateAssociation,
      associationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'associationId' is not null or undefined
      if (associationId === null || associationId === undefined) {
        throw new RequiredError(
          'associationId',
          'Required parameter associationId was null or undefined when calling patchAssociation.',
        );
      }
      // verify required parameter 'UpdateAssociation' is not null or undefined
      if (UpdateAssociation === null || UpdateAssociation === undefined) {
        throw new RequiredError(
          'UpdateAssociation',
          'Required parameter UpdateAssociation was null or undefined when calling patchAssociation.',
        );
      }
      const localVarPath = `/associations/{associationId}`.replace(
        `{${'associationId'}}`,
        encodeURIComponent(String(associationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateAssociation' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateAssociation || {})
        : UpdateAssociation || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AssociationApi - functional programming interface
 * @export
 */
export const AssociationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new association between two resources. The request must include a valid link (`apiture:source`) to a source resource, (`apiture:role`) to an association role instance and a link (`apiture:target`) to a target resource.
     * @summary Create a new association
     * @param {CreateAssociation} CreateAssociation The data necessary to create a new association.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAssociation(
      CreateAssociation: CreateAssociation,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Association> {
      const localVarAxiosArgs = AssociationApiAxiosParamCreator(configuration).createAssociation(
        CreateAssociation ? CreateAssociation : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this association resource and any resources that are owned by it.  Deleting an association does not delete the source, role, or target resources.
     * @summary Delete this association resource
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAssociation(
      associationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AssociationApiAxiosParamCreator(configuration).deleteAssociation(
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this association resource.
     * @summary Fetch a representation of this association
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociation(
      associationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Association> {
      const localVarAxiosArgs = AssociationApiAxiosParamCreator(configuration).getAssociation(
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of associations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of associations.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first association item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of association representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the associations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Associations> {
      const localVarAxiosArgs = AssociationApiAxiosParamCreator(configuration).getAssociations(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this association. Fields which are omitted are not updated.
     * @summary Update this association
     * @param {UpdateAssociation} UpdateAssociation
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAssociation(
      UpdateAssociation: UpdateAssociation,
      associationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Association> {
      const localVarAxiosArgs = AssociationApiAxiosParamCreator(configuration).patchAssociation(
        UpdateAssociation ? UpdateAssociation : null,
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AssociationApi - factory interface
 * @export
 */
export const AssociationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new association between two resources. The request must include a valid link (`apiture:source`) to a source resource, (`apiture:role`) to an association role instance and a link (`apiture:target`) to a target resource.
     * @summary Create a new association
     * @param {CreateAssociation} CreateAssociation The data necessary to create a new association.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAssociation(CreateAssociation: CreateAssociation, options?: any) {
      return AssociationApiFp(configuration).createAssociation(
        CreateAssociation ? CreateAssociation : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this association resource and any resources that are owned by it.  Deleting an association does not delete the source, role, or target resources.
     * @summary Delete this association resource
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAssociation(associationId: string, headers?: { If_Match?: string }, options?: any) {
      return AssociationApiFp(configuration).deleteAssociation(
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this association resource.
     * @summary Fetch a representation of this association
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociation(associationId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AssociationApiFp(configuration).getAssociation(
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of associations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of associations.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first association item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of association representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the associations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAssociations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ) {
      return AssociationApiFp(configuration).getAssociations(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this association. Fields which are omitted are not updated.
     * @summary Update this association
     * @param {UpdateAssociation} UpdateAssociation
     * @param {string} associationId The unique identifier of this association. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAssociation(
      UpdateAssociation: UpdateAssociation,
      associationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AssociationApiFp(configuration).patchAssociation(
        UpdateAssociation ? UpdateAssociation : null,
        associationId ? associationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AssociationApi - object-oriented interface
 * @export
 * @class AssociationApi
 * @extends {BaseAPI}
 */
export class AssociationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new association between two resources. The request must include a valid link (`apiture:source`) to a source resource, (`apiture:role`) to an association role instance and a link (`apiture:target`) to a target resource.
   * @summary Create a new association
   * @param {CreateAssociation} CreateAssociation The data necessary to create a new association.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Association}
   * @memberof AssociationApi
   */
  public createAssociation(CreateAssociation: CreateAssociation, options?: any) {
    return AssociationApiFp(this.configuration).createAssociation(
      CreateAssociation ? CreateAssociation : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this association resource and any resources that are owned by it.  Deleting an association does not delete the source, role, or target resources.
   * @summary Delete this association resource
   * @param {string} associationId The unique identifier of this association. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AssociationApi
   */
  public deleteAssociation(associationId: string, headers?: { If_Match?: string }, options?: any) {
    return AssociationApiFp(this.configuration).deleteAssociation(
      associationId ? associationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this association resource.
   * @summary Fetch a representation of this association
   * @param {string} associationId The unique identifier of this association. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Association}
   * @memberof AssociationApi
   */
  public getAssociation(
    associationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AssociationApiFp(this.configuration).getAssociation(
      associationId ? associationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of associations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of associations.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first association item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of association representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the associations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Associations}
   * @memberof AssociationApi
   */
  public getAssociations(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      name?: string;
      type?: string;
      label?: string;
    },
    options?: any,
  ) {
    return AssociationApiFp(this.configuration).getAssociations(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this association. Fields which are omitted are not updated.
   * @summary Update this association
   * @param {UpdateAssociation} UpdateAssociation
   * @param {string} associationId The unique identifier of this association. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Association}
   * @memberof AssociationApi
   */
  public patchAssociation(
    UpdateAssociation: UpdateAssociation,
    associationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AssociationApiFp(this.configuration).patchAssociation(
      UpdateAssociation ? UpdateAssociation : null,
      associationId ? associationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * RoleApi - axios parameter creator
 * @export
 */
export const RoleApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new role which is used to associate two resources.
     * @summary Create a new role
     * @param {CreateRole} CreateRole The data necessary to create a new role.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createRole(CreateRole: CreateRole, options: any = {}): RequestArgs {
      // verify required parameter 'CreateRole' is not null or undefined
      if (CreateRole === null || CreateRole === undefined) {
        throw new RequiredError(
          'CreateRole',
          'Required parameter CreateRole was null or undefined when calling createRole.',
        );
      }
      const localVarPath = `/roles`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateRole' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateRole || {})
        : CreateRole || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this role resource and any resources that are owned by it.  A role cannot be deleted if it is in use in an association.
     * @summary Delete this role resource
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteRole(roleId: string, headers?: { If_Match?: string }, options: any = {}): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'roleId' is not null or undefined
      if (roleId === null || roleId === undefined) {
        throw new RequiredError(
          'roleId',
          'Required parameter roleId was null or undefined when calling deleteRole.',
        );
      }
      const localVarPath = `/roles/{roleId}`.replace(
        `{${'roleId'}}`,
        encodeURIComponent(String(roleId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this role resource.
     * @summary Fetch a representation of this role
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRole(roleId: string, headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'roleId' is not null or undefined
      if (roleId === null || roleId === undefined) {
        throw new RequiredError(
          'roleId',
          'Required parameter roleId was null or undefined when calling getRole.',
        );
      }
      const localVarPath = `/roles/{roleId}`.replace(
        `{${'roleId'}}`,
        encodeURIComponent(String(roleId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of roles. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of roles
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first role item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of role representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRoles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, name, label } = query;

      const localVarPath = `/roles`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this role. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'roleId' is not null or undefined
      if (roleId === null || roleId === undefined) {
        throw new RequiredError(
          'roleId',
          'Required parameter roleId was null or undefined when calling patchRole.',
        );
      }
      // verify required parameter 'UpdateRole' is not null or undefined
      if (UpdateRole === null || UpdateRole === undefined) {
        throw new RequiredError(
          'UpdateRole',
          'Required parameter UpdateRole was null or undefined when calling patchRole.',
        );
      }
      const localVarPath = `/roles/{roleId}`.replace(
        `{${'roleId'}}`,
        encodeURIComponent(String(roleId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateRole' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateRole || {})
        : UpdateRole || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this role.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'roleId' is not null or undefined
      if (roleId === null || roleId === undefined) {
        throw new RequiredError(
          'roleId',
          'Required parameter roleId was null or undefined when calling updateRole.',
        );
      }
      // verify required parameter 'UpdateRole' is not null or undefined
      if (UpdateRole === null || UpdateRole === undefined) {
        throw new RequiredError(
          'UpdateRole',
          'Required parameter UpdateRole was null or undefined when calling updateRole.',
        );
      }
      const localVarPath = `/roles/{roleId}`.replace(
        `{${'roleId'}}`,
        encodeURIComponent(String(roleId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateRole' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateRole || {})
        : UpdateRole || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * RoleApi - functional programming interface
 * @export
 */
export const RoleApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new role which is used to associate two resources.
     * @summary Create a new role
     * @param {CreateRole} CreateRole The data necessary to create a new role.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createRole(
      CreateRole: CreateRole,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Role> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).createRole(
        CreateRole ? CreateRole : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this role resource and any resources that are owned by it.  A role cannot be deleted if it is in use in an association.
     * @summary Delete this role resource
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteRole(
      roleId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).deleteRole(
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this role resource.
     * @summary Fetch a representation of this role
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRole(
      roleId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Role> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).getRole(
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of roles. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of roles
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first role item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of role representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRoles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Roles> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).getRoles(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this role. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Role> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).patchRole(
        UpdateRole ? UpdateRole : null,
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this role.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Role> {
      const localVarAxiosArgs = RoleApiAxiosParamCreator(configuration).updateRole(
        UpdateRole ? UpdateRole : null,
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * RoleApi - factory interface
 * @export
 */
export const RoleApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new role which is used to associate two resources.
     * @summary Create a new role
     * @param {CreateRole} CreateRole The data necessary to create a new role.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createRole(CreateRole: CreateRole, options?: any) {
      return RoleApiFp(configuration).createRole(
        CreateRole ? CreateRole : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this role resource and any resources that are owned by it.  A role cannot be deleted if it is in use in an association.
     * @summary Delete this role resource
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteRole(roleId: string, headers?: { If_Match?: string }, options?: any) {
      return RoleApiFp(configuration).deleteRole(
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this role resource.
     * @summary Fetch a representation of this role
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRole(roleId: string, headers?: { If_None_Match?: string }, options?: any) {
      return RoleApiFp(configuration).getRole(
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of roles. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of roles
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first role item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of role representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRoles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options?: any,
    ) {
      return RoleApiFp(configuration).getRoles(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this role. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return RoleApiFp(configuration).patchRole(
        UpdateRole ? UpdateRole : null,
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this role.
     * @summary Update this role
     * @param {UpdateRole} UpdateRole
     * @param {string} roleId The unique identifier of this role. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateRole(
      UpdateRole: UpdateRole,
      roleId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return RoleApiFp(configuration).updateRole(
        UpdateRole ? UpdateRole : null,
        roleId ? roleId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * RoleApi - object-oriented interface
 * @export
 * @class RoleApi
 * @extends {BaseAPI}
 */
export class RoleApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new role which is used to associate two resources.
   * @summary Create a new role
   * @param {CreateRole} CreateRole The data necessary to create a new role.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Role}
   * @memberof RoleApi
   */
  public createRole(CreateRole: CreateRole, options?: any) {
    return RoleApiFp(this.configuration).createRole(
      CreateRole ? CreateRole : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this role resource and any resources that are owned by it.  A role cannot be deleted if it is in use in an association.
   * @summary Delete this role resource
   * @param {string} roleId The unique identifier of this role. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof RoleApi
   */
  public deleteRole(roleId: string, headers?: { If_Match?: string }, options?: any) {
    return RoleApiFp(this.configuration).deleteRole(
      roleId ? roleId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this role resource.
   * @summary Fetch a representation of this role
   * @param {string} roleId The unique identifier of this role. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Role}
   * @memberof RoleApi
   */
  public getRole(roleId: string, headers?: { If_None_Match?: string }, options?: any) {
    return RoleApiFp(this.configuration).getRole(
      roleId ? roleId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of roles. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of roles
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first role item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of role representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; matches items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Roles}
   * @memberof RoleApi
   */
  public getRoles(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      name?: string;
      label?: string;
    },
    options?: any,
  ) {
    return RoleApiFp(this.configuration).getRoles(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a partial update of this role. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this role
   * @param {UpdateRole} UpdateRole
   * @param {string} roleId The unique identifier of this role. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Role}
   * @memberof RoleApi
   */
  public patchRole(
    UpdateRole: UpdateRole,
    roleId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return RoleApiFp(this.configuration).patchRole(
      UpdateRole ? UpdateRole : null,
      roleId ? roleId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this role.
   * @summary Update this role
   * @param {UpdateRole} UpdateRole
   * @param {string} roleId The unique identifier of this role. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Role}
   * @memberof RoleApi
   */
  public updateRole(
    UpdateRole: UpdateRole,
    roleId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return RoleApiFp(this.configuration).updateRole(
      UpdateRole ? UpdateRole : null,
      roleId ? roleId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
