# @apiture/audit-client-sdk@0.8.3
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/audit-client-sdk@0.8.3 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AuditRecordApi, AuditRecordTypeApi } from "@apiture/audit-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AuditRecordApi main class passing the configuration object.
    const auditRecordApi = new AuditRecordApi(configuration);

// Instantiate AuditRecordTypeApi main class passing the configuration object.
    const auditRecordTypeApi = new AuditRecordTypeApi(configuration);


// Use the methods to call the apis ( Refer to the Audit SDK Classes and Methods list ).
  auditRecordType.getAuditRecordTypes().then( response => {
    const getauditrecordtypesData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate AuditRecordTypeApi main class.
    const auditRecordTypeApi = new AuditRecordTypeApi();


// Update the accessToken using the class method `setAccessToken`.
    auditRecordTypeApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    auditRecordTypeApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    auditRecordTypeApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { RecordTypes } from "@apiture/audit-client-sdk";

  const stronglyTypedObject :RecordTypes = { ... };

  // ______ Scoped import

  import * as AuditTypes from "@apiture/audit-client-sdk";

  const stronglyTypedObject :AuditTypes.RecordTypes = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/audit",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Audit SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### AuditRecordApi


  `AuditRecordApi.getAuditRecord` - Fetch a representation of this audit record

  `AuditRecordApi.getAuditRecords` - Return audit records



### AuditRecordTypeApi


  `AuditRecordTypeApi.getAuditRecordType` - Fetch a representation of this audit record type

  `AuditRecordTypeApi.getAuditRecordTypes` - Return a collection of audit record types



## About the Audit API
___
 The Audit API provides read-only access to Apiture system audit records, which track user online banking activity. This API is available to administrators only, not bank customers. Only activity processed by Apiture APIs and services is available through this API.   This API manages two primary resources: _audit records_ of user or other activity, and _audit record types_ which are metadata that describe the data in the audit records.   Each audit record contains the `type` of the record, the user who performed the activity, the URI of related resources, a time stamp, and a `data` object containing `type`-specific properties of the activity; see the `record` schema below. Administrator users of this API can filter audit records using most of these values.   The content of each audit record is defined with an _audit record type_ which describes the content of all audit records of that type. The audit record type contains its name, label, description and a JSON schema object which defines the data types and descriptions of the `data` property of an audit record. See the `recordType` schema below.   There is a many-to-one relationship between audit records and audit record types.  ## Audit record queries  The `getAuditRecords` operation supports querying by the fields common to all audit records: `?type=`, `?category=`, `?user=`, `?host=`, `?uri=`, (To filter by date/time, see _Time-bound queries_ below.)  ### Audit records by user  Each audit record contains the `customerId` of the user who performed the auditable action, if it is known. The `customerId` is the unique `customerId` of the user's resource from the Users service. This indicates _who_ performed the audited activity. In some cases, administrators at the financial institution can perform some actions on behalf of users from an administrative application. If this occurs, the audit record's `customerId` will be the ID of the administrator, and the `onBehalfOf` value will be the customer ID of the financial institution customer. The `?user={customerId}` query parameter on `getAuditRecords` matches either the `customerId` property or the `onBehalfOf` property.   The customer ID is not always known. For example, if an administrator reverses a transaction in the core servicing application and that reversal flows into Apiture resources, Apiture may not be able to attribute the activity to a user, but will still create an audit record for the activity. The `customerId` has the value `<system>` for audit records for such operations. Please consult the audit records in the banking core or servicing application to track such activity.  ### Time-bound queries  The audit record views also support time-bounded queries. By default, the `getAuditRecords` and `getAuditRecordsByType` operations return records for the current day (based on the date component of the record's `occurredAt` field), in reverse chronological order.   These date-time bounds can be passed explicitly to override the defaults:    1. Pass the `startAt` _and_ `endAt` to find any records which overlap that date range.      For example, to fetch for the first six days of September 2019, request `?startAt=2019-09-01&period=P6D`.   1. Pass the `startAt` to find audit records beginning at that date      or date-time. The optional `period` determines how many      minutes, hours, or days of data to include in the paginated response.   1. Pass the `endAt` to return audit records which occurred up to specified date or date time.      The optional `period` determines how many minutes, hours,      or days of data to include in the paginated response.      For example, to fetch for the last six days of September 2019, request `?startAt=2019-09-30&period=P6D`.  The default [period](https://en.wikipedia.org/wiki/ISO_8601#Durations) is `P1D`. To fetch records for the last six days, request just `?period=P6D`; use `?period=PT1H` to select just the past one hour of data. This result list of records is sorted in _reverse chronological order_ unless `startAt` is specified. (The default `endAt` is the current instant.) `period` is not allowed if both `startAt` and `endAt` are passed.   To find transfers scheduled in September 2019, specify a `startAt` of September 1 and a `period` of `P1M` (one month):   ```text GET /audit/recordsByType?type=transferScheduled&startAt=2019-09-01&period=P1M ```  `startAt` and `endAt` may be either specific date or date-time values in [RFC 3339](https://tools.ietf.org/html/rfc3339) format (`YYYY-MM-DD` or `YYYY-MM-DDThh:mm:ss.sssZ`). *Caution*: The `occurredAt` time is in UTC time zone; adjust start and end times to account for local time zones.  ## Audit record pagination  The audit records support _cursor-based pagination_ rather than index-based pagination. The `start` property in the collection and the `?start=` query parameter in the `next` link are opaque strings which represent the pagination cursor. The audit record collection uses cursor based pagination because new audit records are likely to be added to the collection while a client is paging, and using index paged pagination is likely to result in visiting the same records again. (For example, the first `GET` returns records 0 to 1000. Before the next GET, 210 new audit records may be added, so an index-based pagination request for the next 1,000 items, `GET /audit/records?start=1000`, will start at record 1,000 instead of the desired 1,210, and the result would contain 210 items that were also in the first page.)   Often, pagination is bounded by the date-time query parameters as described above. For example, for `?startAt=2019-09-01&period=P1M`, the response will only page through audit records for the one month period starting 2019-09-01. If the collection response's `_links` object includes the `apiture:skip` link, that link will skip to the next or previous time period, such as `?startAt=2019-10-01&period=P1M`. When the page parameters use `?startAt=`, the `apiture:skip` link will skip by _adding_ the period to the start date-time. When the page parameters use `?endAt=`, the `apiture:skip` link will skip by _subtracting_ the period from the end date-time. Skip link does not appear if the query includes both `?startAt=` and `?endAt=` query parameters.
