// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Audit
 *  The Audit API provides read-only access to Apiture system audit records, which track user online banking activity. This API is available to administrators only, not bank customers. Only activity processed by Apiture APIs and services is available through this API.   This API manages two primary resources: _audit records_ of user or other activity, and _audit record types_ which are metadata that describe the data in the audit records.   Each audit record contains the `type` of the record, the user who performed the activity, the URI of related resources, a time stamp, and a `data` object containing `type`-specific properties of the activity; see the `record` schema below. Administrator users of this API can filter audit records using most of these values.   The content of each audit record is defined with an _audit record type_ which describes the content of all audit records of that type. The audit record type contains its name, label, description and a JSON schema object which defines the data types and descriptions of the `data` property of an audit record. See the `recordType` schema below.   There is a many-to-one relationship between audit records and audit record types.  ## Audit record queries  The `getAuditRecords` operation supports querying by the fields common to all audit records: `?type=`, `?category=`, `?user=`, `?host=`, `?uri=`, (To filter by date/time, see _Time-bound queries_ below.)  ### Audit records by user  Each audit record contains the `customerId` of the user who performed the auditable action, if it is known. The `customerId` is the unique `customerId` of the user's resource from the Users service. This indicates _who_ performed the audited activity. In some cases, administrators at the financial institution can perform some actions on behalf of users from an administrative application. If this occurs, the audit record's `customerId` will be the ID of the administrator, and the `onBehalfOf` value will be the customer ID of the financial institution customer. The `?user={customerId}` query parameter on `getAuditRecords` matches either the `customerId` property or the `onBehalfOf` property.   The customer ID is not always known. For example, if an administrator reverses a transaction in the core servicing application and that reversal flows into Apiture resources, Apiture may not be able to attribute the activity to a user, but will still create an audit record for the activity. The `customerId` has the value `<system>` for audit records for such operations. Please consult the audit records in the banking core or servicing application to track such activity.  ### Time-bound queries  The audit record views also support time-bounded queries. By default, the `getAuditRecords` and `getAuditRecordsByType` operations return records for the current day (based on the date component of the record's `occurredAt` field), in reverse chronological order.   These date-time bounds can be passed explicitly to override the defaults:    1. Pass the `startAt` _and_ `endAt` to find any records which overlap that date range.      For example, to fetch for the first six days of September 2019, request `?startAt=2019-09-01&period=P6D`.   1. Pass the `startAt` to find audit records beginning at that date      or date-time. The optional `period` determines how many      minutes, hours, or days of data to include in the paginated response.   1. Pass the `endAt` to return audit records which occurred up to specified date or date time.      The optional `period` determines how many minutes, hours,      or days of data to include in the paginated response.      For example, to fetch for the last six days of September 2019, request `?startAt=2019-09-30&period=P6D`.  The default [period](https://en.wikipedia.org/wiki/ISO_8601#Durations) is `P1D`. To fetch records for the last six days, request just `?period=P6D`; use `?period=PT1H` to select just the past one hour of data. This result list of records is sorted in _reverse chronological order_ unless `startAt` is specified. (The default `endAt` is the current instant.) `period` is not allowed if both `startAt` and `endAt` are passed.   To find transfers scheduled in September 2019, specify a `startAt` of September 1 and a `period` of `P1M` (one month):   ```text GET /audit/recordsByType?type=transferScheduled&startAt=2019-09-01&period=P1M ```  `startAt` and `endAt` may be either specific date or date-time values in [RFC 3339](https://tools.ietf.org/html/rfc3339) format (`YYYY-MM-DD` or `YYYY-MM-DDThh:mm:ss.sssZ`). *Caution*: The `occurredAt` time is in UTC time zone; adjust start and end times to account for local time zones.  ## Audit record pagination  The audit records support _cursor-based pagination_ rather than index-based pagination. The `start` property in the collection and the `?start=` query parameter in the `next` link are opaque strings which represent the pagination cursor. The audit record collection uses cursor based pagination because new audit records are likely to be added to the collection while a client is paging, and using index paged pagination is likely to result in visiting the same records again. (For example, the first `GET` returns records 0 to 1000. Before the next GET, 210 new audit records may be added, so an index-based pagination request for the next 1,000 items, `GET /audit/records?start=1000`, will start at record 1,000 instead of the desired 1,210, and the result would contain 210 items that were also in the first page.)   Often, pagination is bounded by the date-time query parameters as described above. For example, for `?startAt=2019-09-01&period=P1M`, the response will only page through audit records for the one month period starting 2019-09-01. If the collection response's `_links` object includes the `apiture:skip` link, that link will skip to the next or previous time period, such as `?startAt=2019-10-01&period=P1M`. When the page parameters use `?startAt=`, the `apiture:skip` link will skip by _adding_ the period to the start date-time. When the page parameters use `?endAt=`, the `apiture:skip` link will skip by _subtracting_ the period from the end date-time. Skip link does not appear if the query includes both `?startAt=` and `?endAt=` query parameters.
 *
 * OpenAPI spec version: 0.8.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/audit'.replace(/\/+$/, '');

export const API_VERSION = '0.8.1';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * A collection of resources, or a page from a larger collection. This is an abstract model schema which is extended to define specific resource collections. Pages are referenced using an opaque string starting point named `start`. The `_links` in the collection may contain [pagination links](https://developer.apiture.com/docs/concepts/pagination):    * the `next` link returns the next page of items. If there is no `next`   link, the collection has been exhausted.   * the `first` link returns to the beginning   of the filtered/sorted collection.   * the `collection` link returns   to the beginning of the default collection with no explicit filter   or sort criteria.  Cursor paged collections can only paginate forwards contiguously (without skipping items or pages), or reset to the beginning of the collection. This pagination works for collections which are likely to change during pagination, such as adding data to the beginning of the collection's natural sort order. Examples include transactions or audit records.
 * @export
 * @interface CursorPagedCollection
 */
export interface CursorPagedCollection extends AbstractResource {
  /**
   * An opaque marker representing the position of the current page in this resource collection. The service will use the `start` and `limit` to compute the `?start=` query parameter for the next page when it provides the `next` link in the collection's `_links`.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  start?: string;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof CursorPagedCollection
   */
  limit?: number;
  /**
   * A name for the items in collection.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  name?: string;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A data record representing an auditable banking activity or action performed by a user. This conveys:   * who did something (`customerId`, `username`, `onBehalfOf`),   * what they did (`type`, `category`),   * when they did it (`occurredAt`),   * where they did it (`host`),   * what they did it to (`primaryUri`, `secondaryUri`)   * additional `data` that is specific to the activity `type`.   The `type` is a key into the set of _audit record types_ (see `getAuditRecordType`, `GET /audit/recordTypes/{type}`). An audit record has a link (`apiture:type`) to the this audit record type resource. The record type contains a JSON schema that describes the data in the record's `data` object.
 * @export
 * @interface Record
 */
export interface Record extends AbstractResource {
  /**
   * The unique identifier for this audit record. This is an immutable opaque string.
   * @type {string}
   * @memberof Record
   */
  _id?: string;
  /**
   * The type of this audit record. This is the key into the set of audit record types.
   * @type {string}
   * @memberof Record
   */
  type?: string;
  /**
   * Multiple record types can all belong to a category of types; this is an identifier for the category, derived from the record type named by `type`. This is a lowerCamelCase string.
   * @type {any}
   * @memberof Record
   */
  category?: any;
  /**
   * The date-time when the action occurred or logged. The time is approximate. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time string.
   * @type {Date}
   * @memberof Record
   */
  occurredAt?: Date;
  /**
   * The customer ID of the user who performed the action. If an administrator is performing the action on behalf of a customer, this is the administrator's ID; see also `onBehalfOf`.
   * @type {string}
   * @memberof Record
   */
  customerId?: string;
  /**
   * If the audit record was generated when an admin was emulating a user, this is the customer ID of the user whom the administrator is acting on behalf of. (`customerId` will be the ID of the administrator user.)
   * @type {string}
   * @memberof Record
   */
  onBehalfOf?: string;
  /**
   * The user name of the user who performed the action. For failed login attempts, this is the `username` that the user _tried_ to authenticate with. For most other operations, this is the `username` of the user. Note that since users may change their username, this is the username that was in effect when the audit record was created. If an administrator is performing the action on behalf of a customer, this is the _administrator's_ user name. This may be `<system>` if the operation was performed by a system process. See also `onBehalfOf`.
   * @type {string}
   * @memberof Record
   */
  username?: string;
  /**
   * The host IP address of client which was used for this activity.
   * @type {string}
   * @memberof Record
   */
  host?: string;
  /**
   * The URI of the primary resource that this activity applies to. For example, if a transfer if scheduled or canceled, this is the URI of the transfer.
   * @type {string}
   * @memberof Record
   */
  primaryUri?: string;
  /**
   * The URI of a secondary resource that this activity applies to.
   * @type {string}
   * @memberof Record
   */
  secondaryUri?: string;
  /**
   * Additional properties of the audit record, represented as a `type`-specific object. The schema of this data is found in the `schema` property of the corresponding `/audit/recordTypes/{type}` resource. The `/records` collection does not support sorting and filtering based on the properties in this `data` object.
   * @type {any}
   * @memberof Record
   */
  data?: any;
}

/**
 * Representation of audit record type resources.
 * @export
 * @interface RecordType
 */
export interface RecordType extends AbstractResource {
  /**
   * The name of this audit record type type. This is a lowerCamelCase string.
   * @type {string}
   * @memberof RecordType
   */
  name?: string;
  /**
   * A short label for this audit record type.
   * @type {string}
   * @memberof RecordType
   */
  label?: string;
  /**
   * Multiple record types can all belong to a category of types; this is an identifier for the category. This is a lowerCamelCase string.
   * @type {any}
   * @memberof RecordType
   */
  category?: any;
  /**
   * A short text label for the `category`.
   * @type {string}
   * @memberof RecordType
   */
  categoryLabel?: string;
  /**
   * The semantic version number of this record type and schema.
   * @type {string}
   * @memberof RecordType
   */
  version?: string;
  /**
   * A longer description of this audit record type.
   * @type {string}
   * @memberof RecordType
   */
  description?: string;
  /**
   * A JSON schema object which defines the data that is associated with all audit records which use this audit record type.
   * @type {any}
   * @memberof RecordType
   */
  schema?: any;
}

/**
 * Collection of audit record types. The items in the collection are listed in the `_embedded.items` array; the `name` is `recordTypes`.
 * @export
 * @interface RecordTypes
 */
export interface RecordTypes extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof RecordTypes
   */
  _embedded?: any;
}

/**
 * Collection of audit records. The items in the collection are ordered in the `_embedded.items` array; the `name` is `records`. The top-level `_links` object may contain pagination links (`self`, `next`, `collection`). This collection is cursor based and only supports paginating forward one page at a time, with no direct index-based access to audit records. The collection is exhausted when there is no `next` link. The response includes an `apiture:skip` link if the query is time-bound (i.e. contains `?startAt=` or `?endAt=` but not both). That link will skip to the next or previous time period.
 * @export
 * @interface Records
 */
export interface Records extends CursorPagedCollection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Records
   */
  _embedded?: any;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AuditRecordApi - axios parameter creator
 * @export
 */
export const AuditRecordApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record resource.
     * @summary Fetch a representation of this audit record
     * @param {string} recordId The unique identifier of this audit record. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecord(
      recordId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'recordId' is not null or undefined
      if (recordId === null || recordId === undefined) {
        throw new RequiredError(
          'recordId',
          'Required parameter recordId was null or undefined when calling getAuditRecord.',
        );
      }
      const localVarPath = `/records/{recordId}`.replace(
        `{${'recordId'}}`,
        encodeURIComponent(String(recordId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', ['admin/read'])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) collection of audit records which satisfy the filtering query parameters. By default, this returns records for the past 24 hours, in reverse chronological order. This result list of records is sorted in _reverse chronological order_ unless `?startAt=` is specified. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links as described in the `records` schema.
     * @summary Return audit records
     * @param {Object} [query] Query object
     * @param {string} [query.type] Restrict audit records to those matching this record type. Multiple types may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.category] Restrict audit records to those matching this record type category. Multiple categories may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.user] Restrict audit records to those where either the &#x60;customerId&#x60; or &#x60;onBehalfOf&#x60; fields match this value.
     * @param {string} [query.host] Restrict audit records to those matching this client host IP address.
     * @param {string} [query.startAt] The start date or date-time of the time-bounded query. May be combined with &#x60;endAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;00:00:00&#x60;. The default &#x60;startAt&#x60; date-time is 24 hours before the current instant. Using &#x60;startAt&#x60; will change the sort order from reverse to forward chronological order.
     * @param {string} [query.endAt] The end date of the time-bounded query. May be combined with &#x60;startAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;24:00:00&#x60;. The default &#x60;endAt&#x60; is the current instant.
     * @param {string} [query.period] The time period for the date-time range, looking backwards from &#x60;endAt&#x60; (or today, if &#x60;endAt&#x60; is omitted), or forward from &#x60;startAt&#x60;. The &#x60;period&#x60; is a [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations). For example, to list audit records for the last 6 days, use &#x60;?period&#x3D;P6D&#x60;. The default is &#x60;P1D&#x60; indicating one day of data. Examples of &#x60;period&#x60; values: &#x60;P1M&#x60; (one month), &#x60;P2W&#x60; (two weeks), &#x60;P5D&#x60; (five days), &#x60;PT12H&#x60; (twelve hours), &#x60;PT30M&#x60; (30 minutes) and &#x60;PT30S&#x60; (30 seconds).
     * @param {string} [query.uri] Restrict audit records to where &#x60;primaryUri&#x60; or &#x60;secondaryUri&#x60; match this URI parameter value. This string is a _relative_ URI only, without the absolute &#x60;https://host&#x60; URL prefix. Example: &#x60;?uri&#x3D;/accounts/account/b6512168-20fc-4a8c-80dd-8670f76ea356&#x60;
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of audit record representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecords(
      query?: {
        type?: string;
        category?: string;
        user?: string;
        host?: string;
        startAt?: Date;
        endAt?: Date;
        period?: string;
        uri?: string;
        start?: string;
        limit?: number;
        sortBy?: string;
      },
      options: any = {},
    ): RequestArgs {
      const {
        type,
        category,
        user,
        host,
        startAt,
        endAt,
        period,
        uri,
        start,
        limit,
        sortBy,
      } = query;

      const localVarPath = `/records`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', ['admin/read'])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (category !== undefined) {
        localVarQueryParameter['category'] = category;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (host !== undefined) {
        localVarQueryParameter['host'] = host;
      }

      if (startAt !== undefined) {
        localVarQueryParameter['startAt'] = (startAt as any).toISOString();
      }

      if (endAt !== undefined) {
        localVarQueryParameter['endAt'] = (endAt as any).toISOString();
      }

      if (period !== undefined) {
        localVarQueryParameter['period'] = period;
      }

      if (uri !== undefined) {
        localVarQueryParameter['uri'] = uri;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AuditRecordApi - functional programming interface
 * @export
 */
export const AuditRecordApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record resource.
     * @summary Fetch a representation of this audit record
     * @param {string} recordId The unique identifier of this audit record. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecord(
      recordId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Record> {
      const localVarAxiosArgs = AuditRecordApiAxiosParamCreator(configuration).getAuditRecord(
        recordId ? recordId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) collection of audit records which satisfy the filtering query parameters. By default, this returns records for the past 24 hours, in reverse chronological order. This result list of records is sorted in _reverse chronological order_ unless `?startAt=` is specified. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links as described in the `records` schema.
     * @summary Return audit records
     * @param {Object} [query] Query object
     * @param {string} [query.type] Restrict audit records to those matching this record type. Multiple types may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.category] Restrict audit records to those matching this record type category. Multiple categories may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.user] Restrict audit records to those where either the &#x60;customerId&#x60; or &#x60;onBehalfOf&#x60; fields match this value.
     * @param {string} [query.host] Restrict audit records to those matching this client host IP address.
     * @param {string} [query.startAt] The start date or date-time of the time-bounded query. May be combined with &#x60;endAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;00:00:00&#x60;. The default &#x60;startAt&#x60; date-time is 24 hours before the current instant. Using &#x60;startAt&#x60; will change the sort order from reverse to forward chronological order.
     * @param {string} [query.endAt] The end date of the time-bounded query. May be combined with &#x60;startAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;24:00:00&#x60;. The default &#x60;endAt&#x60; is the current instant.
     * @param {string} [query.period] The time period for the date-time range, looking backwards from &#x60;endAt&#x60; (or today, if &#x60;endAt&#x60; is omitted), or forward from &#x60;startAt&#x60;. The &#x60;period&#x60; is a [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations). For example, to list audit records for the last 6 days, use &#x60;?period&#x3D;P6D&#x60;. The default is &#x60;P1D&#x60; indicating one day of data. Examples of &#x60;period&#x60; values: &#x60;P1M&#x60; (one month), &#x60;P2W&#x60; (two weeks), &#x60;P5D&#x60; (five days), &#x60;PT12H&#x60; (twelve hours), &#x60;PT30M&#x60; (30 minutes) and &#x60;PT30S&#x60; (30 seconds).
     * @param {string} [query.uri] Restrict audit records to where &#x60;primaryUri&#x60; or &#x60;secondaryUri&#x60; match this URI parameter value. This string is a _relative_ URI only, without the absolute &#x60;https://host&#x60; URL prefix. Example: &#x60;?uri&#x3D;/accounts/account/b6512168-20fc-4a8c-80dd-8670f76ea356&#x60;
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of audit record representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecords(
      query?: {
        type?: string;
        category?: string;
        user?: string;
        host?: string;
        startAt?: Date;
        endAt?: Date;
        period?: string;
        uri?: string;
        start?: string;
        limit?: number;
        sortBy?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Records> {
      const localVarAxiosArgs = AuditRecordApiAxiosParamCreator(configuration).getAuditRecords(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AuditRecordApi - factory interface
 * @export
 */
export const AuditRecordApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record resource.
     * @summary Fetch a representation of this audit record
     * @param {string} recordId The unique identifier of this audit record. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecord(recordId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AuditRecordApiFp(configuration).getAuditRecord(
        recordId ? recordId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) collection of audit records which satisfy the filtering query parameters. By default, this returns records for the past 24 hours, in reverse chronological order. This result list of records is sorted in _reverse chronological order_ unless `?startAt=` is specified. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links as described in the `records` schema.
     * @summary Return audit records
     * @param {Object} [query] Query object
     * @param {string} [query.type] Restrict audit records to those matching this record type. Multiple types may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.category] Restrict audit records to those matching this record type category. Multiple categories may be specified, separated by &#x60;|&#x60;.
     * @param {string} [query.user] Restrict audit records to those where either the &#x60;customerId&#x60; or &#x60;onBehalfOf&#x60; fields match this value.
     * @param {string} [query.host] Restrict audit records to those matching this client host IP address.
     * @param {string} [query.startAt] The start date or date-time of the time-bounded query. May be combined with &#x60;endAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;00:00:00&#x60;. The default &#x60;startAt&#x60; date-time is 24 hours before the current instant. Using &#x60;startAt&#x60; will change the sort order from reverse to forward chronological order.
     * @param {string} [query.endAt] The end date of the time-bounded query. May be combined with &#x60;startAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;24:00:00&#x60;. The default &#x60;endAt&#x60; is the current instant.
     * @param {string} [query.period] The time period for the date-time range, looking backwards from &#x60;endAt&#x60; (or today, if &#x60;endAt&#x60; is omitted), or forward from &#x60;startAt&#x60;. The &#x60;period&#x60; is a [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations). For example, to list audit records for the last 6 days, use &#x60;?period&#x3D;P6D&#x60;. The default is &#x60;P1D&#x60; indicating one day of data. Examples of &#x60;period&#x60; values: &#x60;P1M&#x60; (one month), &#x60;P2W&#x60; (two weeks), &#x60;P5D&#x60; (five days), &#x60;PT12H&#x60; (twelve hours), &#x60;PT30M&#x60; (30 minutes) and &#x60;PT30S&#x60; (30 seconds).
     * @param {string} [query.uri] Restrict audit records to where &#x60;primaryUri&#x60; or &#x60;secondaryUri&#x60; match this URI parameter value. This string is a _relative_ URI only, without the absolute &#x60;https://host&#x60; URL prefix. Example: &#x60;?uri&#x3D;/accounts/account/b6512168-20fc-4a8c-80dd-8670f76ea356&#x60;
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of audit record representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecords(
      query?: {
        type?: string;
        category?: string;
        user?: string;
        host?: string;
        startAt?: Date;
        endAt?: Date;
        period?: string;
        uri?: string;
        start?: string;
        limit?: number;
        sortBy?: string;
      },
      options?: any,
    ) {
      return AuditRecordApiFp(configuration).getAuditRecords(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AuditRecordApi - object-oriented interface
 * @export
 * @class AuditRecordApi
 * @extends {BaseAPI}
 */
export class AuditRecordApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record resource.
   * @summary Fetch a representation of this audit record
   * @param {string} recordId The unique identifier of this audit record. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Record}
   * @memberof AuditRecordApi
   */
  public getAuditRecord(recordId: string, headers?: { If_None_Match?: string }, options?: any) {
    return AuditRecordApiFp(this.configuration).getAuditRecord(
      recordId ? recordId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) collection of audit records which satisfy the filtering query parameters. By default, this returns records for the past 24 hours, in reverse chronological order. This result list of records is sorted in _reverse chronological order_ unless `?startAt=` is specified. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links as described in the `records` schema.
   * @summary Return audit records
   * @param {Object} [query] Query object
   * @param {string} [query.type] Restrict audit records to those matching this record type. Multiple types may be specified, separated by &#x60;|&#x60;.
   * @param {string} [query.category] Restrict audit records to those matching this record type category. Multiple categories may be specified, separated by &#x60;|&#x60;.
   * @param {string} [query.user] Restrict audit records to those where either the &#x60;customerId&#x60; or &#x60;onBehalfOf&#x60; fields match this value.
   * @param {string} [query.host] Restrict audit records to those matching this client host IP address.
   * @param {string} [query.startAt] The start date or date-time of the time-bounded query. May be combined with &#x60;endAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;00:00:00&#x60;. The default &#x60;startAt&#x60; date-time is 24 hours before the current instant. Using &#x60;startAt&#x60; will change the sort order from reverse to forward chronological order.
   * @param {string} [query.endAt] The end date of the time-bounded query. May be combined with &#x60;startAt&#x60; _or_ &#x60;period&#x60; but not both. This may be either a date or date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) *UTC* format (&#x60;YYYY-MM-DD&#x60; or &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;). If only a date is passed, the time of day is &#x60;24:00:00&#x60;. The default &#x60;endAt&#x60; is the current instant.
   * @param {string} [query.period] The time period for the date-time range, looking backwards from &#x60;endAt&#x60; (or today, if &#x60;endAt&#x60; is omitted), or forward from &#x60;startAt&#x60;. The &#x60;period&#x60; is a [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations). For example, to list audit records for the last 6 days, use &#x60;?period&#x3D;P6D&#x60;. The default is &#x60;P1D&#x60; indicating one day of data. Examples of &#x60;period&#x60; values: &#x60;P1M&#x60; (one month), &#x60;P2W&#x60; (two weeks), &#x60;P5D&#x60; (five days), &#x60;PT12H&#x60; (twelve hours), &#x60;PT30M&#x60; (30 minutes) and &#x60;PT30S&#x60; (30 seconds).
   * @param {string} [query.uri] Restrict audit records to where &#x60;primaryUri&#x60; or &#x60;secondaryUri&#x60; match this URI parameter value. This string is a _relative_ URI only, without the absolute &#x60;https://host&#x60; URL prefix. Example: &#x60;?uri&#x3D;/accounts/account/b6512168-20fc-4a8c-80dd-8670f76ea356&#x60;
   * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
   * @param {number} [query.limit] The maximum number of audit record representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Records}
   * @memberof AuditRecordApi
   */
  public getAuditRecords(
    query?: {
      type?: string;
      category?: string;
      user?: string;
      host?: string;
      startAt?: Date;
      endAt?: Date;
      period?: string;
      uri?: string;
      start?: string;
      limit?: number;
      sortBy?: string;
    },
    options?: any,
  ) {
    return AuditRecordApiFp(this.configuration).getAuditRecords(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AuditRecordTypeApi - axios parameter creator
 * @export
 */
export const AuditRecordTypeApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record type resource.
     * @summary Fetch a representation of this audit record type
     * @param {string} recordTypeId The unique identifier of this audit record type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordType(
      recordTypeId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'recordTypeId' is not null or undefined
      if (recordTypeId === null || recordTypeId === undefined) {
        throw new RequiredError(
          'recordTypeId',
          'Required parameter recordTypeId was null or undefined when calling getAuditRecordType.',
        );
      }
      const localVarPath = `/types/{recordTypeId}`.replace(
        `{${'recordTypeId'}}`,
        encodeURIComponent(String(recordTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', ['admin/read'])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a collection of audit record types.
     * @summary Return a collection of audit record types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordTypes(options: any = {}): RequestArgs {
      const localVarPath = `/types`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', ['admin/read'])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AuditRecordTypeApi - functional programming interface
 * @export
 */
export const AuditRecordTypeApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record type resource.
     * @summary Fetch a representation of this audit record type
     * @param {string} recordTypeId The unique identifier of this audit record type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordType(
      recordTypeId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<RecordType> {
      const localVarAxiosArgs = AuditRecordTypeApiAxiosParamCreator(
        configuration,
      ).getAuditRecordType(
        recordTypeId ? recordTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a collection of audit record types.
     * @summary Return a collection of audit record types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordTypes(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<RecordTypes> {
      const localVarAxiosArgs = AuditRecordTypeApiAxiosParamCreator(
        configuration,
      ).getAuditRecordTypes(options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AuditRecordTypeApi - factory interface
 * @export
 */
export const AuditRecordTypeApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record type resource.
     * @summary Fetch a representation of this audit record type
     * @param {string} recordTypeId The unique identifier of this audit record type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordType(recordTypeId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AuditRecordTypeApiFp(configuration).getAuditRecordType(
        recordTypeId ? recordTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a collection of audit record types.
     * @summary Return a collection of audit record types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuditRecordTypes(options?: any) {
      return AuditRecordTypeApiFp(configuration).getAuditRecordTypes(options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * AuditRecordTypeApi - object-oriented interface
 * @export
 * @class AuditRecordTypeApi
 * @extends {BaseAPI}
 */
export class AuditRecordTypeApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this audit record type resource.
   * @summary Fetch a representation of this audit record type
   * @param {string} recordTypeId The unique identifier of this audit record type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {RecordType}
   * @memberof AuditRecordTypeApi
   */
  public getAuditRecordType(
    recordTypeId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AuditRecordTypeApiFp(this.configuration).getAuditRecordType(
      recordTypeId ? recordTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a collection of audit record types.
   * @summary Return a collection of audit record types
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {RecordTypes}
   * @memberof AuditRecordTypeApi
   */
  public getAuditRecordTypes(options?: any) {
    return AuditRecordTypeApiFp(this.configuration).getAuditRecordTypes(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}
