// tslint:disable
/**
 * Auth
 *  The Authentication API is an identity layer based on OpenID Connect (OIDC) and OAuth 2.0. Accessing resources in the Apiture Open platform requires registering an OAuth consumer before making authenticated API requests. ## Discovery The OpenID Connect Discovery metadata can be retrieved by browsing to the `/auth/openid/metadata` URL. The metadata information is public. ## Creating a client Request an OAuth client key and secret by visiting [developer.apiture.com](https://developer.apiture.com), registering your partner organization, defining a new client application, and requesting API keys for that application and a target environment. After submitting the request, Apiture will provision the API keys and the client ID and client secret which allow the client's user to authenticate and request authentication tokens at run time; these authentication tokens and the API key are used to authenticate each API request. See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ## Open ID Connect and OAuth 2.0 Authentication The Authentication API supports OpenID Connect authentication flows and OAuth 2.0:    - Authorization Code Flow (OpenID Connect), for Mobile Applications or Web Applications or apps where a user logs in   - Client Credentials Grant (OAuth 2.0), for back-end service applications in a secure environment  More information about using these flows are in the [`authorize`](#op-authorize) and [`getToken`](#op-getToken) operations below. ### OpenID Connect Authorization Code Flow This interactive flow involves browser redirection to the Apiture Identity Provider URL (the OAuth _authorization server_) for secure user login and consent. After the first redirection, the user is redirected back to the requesting application using the callback URL associated with the client application in the [developer portal](https://developer.apiture.com).    1. The client requests user authentication via the [`authorize`](#op-authorize) operation, passing a unique random `state` value   1. The user authenticates by entering their credentials in the authorization server's form   1. The user may also be prompted to give consent to specific application access   1. If the client request and user authentication are valid, the authorization operation return a 302 response and `Location` header with the client redirect URI, a `code`, and the client `state` value   1. The client redirects to the redirect URI in order to process the response and code. The request handler should ensure the `state` matches the one passed in step #1.   1. If the `state` matches, the client exchanges the code for tokens via the [`getToken`](#op-getToken) operation to complete the flow  See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ### OAuth 2.0 Client Credentials Grant With this authentication method, the client [requests an authentication token](#op-getToken) passing the client ID and client secret that have been provisioned by the [developer portal](https://developer.apiture.com). Theis method does not use user authentication or credentials; hence the access token is not associated with a financial institution customer. This is _only_ suitable for **secure applications**, such as those in a financial institution's data center. Web or mobile applications must not use this method.  See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ## Password reset flow It is possible to reset the user's password from an unauthenticated space by sending the user's key identifying information.    1. Start the process by issuing a [`POST` to `/passwordResetRequests`](#op-passwordResetRequest) with the user's username, taxId   and birthdate. A confirmation code is sent via the preconfigured delivery channel as a result   of this operation.   2. Use the confirmation code as part of a [`POST` request to `/passwordResets`](#op-passwordReset) along with the   user's username and the new desired password. A successful password reset will be acknowledged   with a 202 status code.  ## Changing the user's password To change a user's password, an already authenticated user should [`POST` to `/my/password`[#op-changeUserPassword). The client should encrypt the old and new password using client side encryption obtained from the [`GET /encryptionKeys`]{#op-getEncryptionKeys). ## Using the Tokens Upon successful authentication via the [`authorize`](#op-authorize) operation, use the [`getToken`](#op-getToken) operation to obtain a [`oauthToken`](#schema-oauthToken) response containing an `access_token` that can be used to call secured API endpoints. Each request to a secured endpoint must include the access token (also known a bearer token) as part of the `Authorization` header: `Authorization: Bearer {access_token}`.  The access token has an expiration time in milliseconds in the `expires_in` property in the response, and the the refresh token is in the the `refresh_token` property. To refresh an expiring or expired access tokenm, use the [`/oauth2/token#getToken`](#op-getToken) endpoint with the `grant_type` query parameter set to `refresh_token`, and the `refresh_token` query parameter set to the `refresh_token` obtained when the token was first issued. ## Devices For additional security, this API also manages the devices (such as cell phones, tablets, computers) that the user uses for digital banking. This allows the Apiture platform to notify the user if someone logs onto their account from an unknown device. Each device has a unique device ID.  Device management improves the multi-factor authentication (MFA) experience for users. If SMS-based MFA is enabled, end users must input a security code received via SMS in addition to entering their password during every sign-in . With device management, users can specify that a device is trusted and the authentication service will remember the device as trusted. Trusted devices can serve as a second factor of authentication instead of requiring a security code delivered via SMS.  This feature tracks each device/user combination separately, such as a husband and wife logging onto digital banking on a shared laptop or table. If the husband has chosen to trust the device, he may sign in using the device and not have to use secondary authentication such as an code sent via SMS. If the wife has not marked the device as trusted, when they sign in, they will need to use the secondary authentication such as an code sent via SMS.  A financial institution can disable tracking of trusted devices so that other secondary authentication such as SMS codes or biometrics must be used on each sign in. ## Identity Challenges The Challenges and Authenticator operations support additional user identity verification challenges to allow a user to verify they are who they claim to be, such as entering a code send via email or SMS. A challenge represents a resource for tracking this additional authentication.  For example, in the Users API, when a user tries to change their preferred mailing address, email address, or phone number, the operations may require an additional identity verification challenge. This helps prevent fraudulent use if someone gains access to an account and attempts to take it over without the owner's consent or knowledge by changing the account's contact information. Other APIs which may use the Challenge API include the Transfers API to confirm identity before transferring money higher than some user-level transfer threshold or much higher than historical transfers, or the Accounts API when adding or removing joint owners or authorized signers.  API services initiate challenges when required. If an operation requires a challenge, the initial operation fails with a 401 Unauthorized response with an `_error` object in the response. That [error response](http://developer.apiture.com/docs/concepts/errors) has the error type of `identityChallengeRequired`. The error object contains a `_embedded.challenge` object which describes the challenge (see the `challengeErrorResponse` schema).  A challenge consists of:    * a `contextUri` - the URI of a resource which the challenge is requested (such as the Transfers API,   or the Accounts API), a set of authentication types)   * an array of `authenticators` which the end user can select from   in order to verify their identity   * a `reason` that the service is requesting additional authentication   * the `userId` of the user who is being challenged   * `createdAt`, `verifiedAt`, and `failedAt`, and `redeemedAt` timestamps.   * the `state` of the challenge   * other data for limiting and tracking redemption (use) of a challenge   An authenticator contains   * the authentication `type` such as `sms` or `email`   * the authentication category such as `knowledge`, `biometric`, `device`   * additional authentication details in `attributes`   * a link to a JSON schema that describes the attributes   * a link to the challenge to which it relates   * `createdAt`, `verifiedAt`, and `failedAt` timestamps   * `maximumRetries` limits how many times an authenticator may be retried   For example, a `type` may be `sms` which means the authenticator will send an SMS message to the user's mobile device; the message contains a code (4 to 6 digits) which the user must enter in the application. The schema attached to `sms` will list the preferred mobile device number(s) for the user or account, and perhaps other allowed mobile device phone numbers. Other types include `email` (a similar code is sent to the user at the preferred email address.) Clients must be prepared to handle all the authenticator types.  The client should start the selected authenticators by using a `POST` to their `apiture:start` links (operation [`startAuthenticator`](#op-startAuthenticator). For example, for `sms` and `email` authenticator types, the service will send a code to the user's preferred mobile phone number or email address respectively. The `type` in the authenticator includes a JSON schema which describes the data that should be passed in the authenticator's `attributes`. The client should collect data from the user and then post the authenticator resource (with the user data in the `attributes`) to the `verifyAuthenticator` operation. This validates the data and either completes the authenticator (and challenge) or fails.  After the required authenticators are verified and the challenge has been completed, the client application should retry the initial operation that failed with the 401 error. The client should pass the `_id` of the challenge resource in the `Apiture-Challenge` request header on this operation retry. Operations which participate in the Challenge protocol will document the optional `Apiture-Challenge` request header as one of the operation's parameters.  Challenges and authenticators expire and they are automatically deleted after a delay of several minutes. ## Session Tracking You may use the Authentication API to track user sessions. There are operations to mark the beginning, continuation, and ending of a user session (log on, refresh a user's access token, log off). See the `startUserSession`, `continueUserSession`, `endUserSession` operations.  # Error Types      Error responses in this API may have one of the following `type` values.        <h2 class='errorType' id=\"err-accountAlreadyConfirmed\">accountAlreadyConfirmed</h2>  Description: A user has already confirmed this login account.  Remediation: Your login account is ready for use. You can login or use the Forgot Password option if you have forgotten your username.   <h2 class='errorType' id=\"err-getTokenAccessDenied\">getTokenAccessDenied</h2>  Description: The client is not authorized to generate this token.  Remediation: Make sure the client credentials are valid.   <h2 class='errorType' id=\"err-invalidGrant\">invalidGrant</h2>  Description: The provided code is not valid.  Remediation: Check the provided code.   <h2 class='errorType' id=\"err-postTokenAccessDenied\">postTokenAccessDenied</h2>  Description: The client is not authorized to generate this token.  Remediation: Make sure the client is authorized.   <h2 class='errorType' id=\"err-invalidSymbolForNonEmailUsernameFormat\">invalidSymbolForNonEmailUsernameFormat</h2>  Description: Username cannot contain the ‘@’ symbol.  Remediation: Choose a new username without the ‘@’ symbol.   <h2 class='errorType' id=\"err-usernameRequestConflict\">usernameRequestConflict</h2>  Description: There was a conflict requesting the username.  Remediation: Make sure the supplied information is correct.   <h2 class='errorType' id=\"err-invalidUsernameRequest\">invalidUsernameRequest</h2>  Description: The username request was not processed.  Remediation: Check that the user exists and that the attributes match the request.   <h2 class='errorType' id=\"err-invalidNewPassword\">invalidNewPassword</h2>  Description: The new password is not valid.  Remediation: Check that the new password conforms to password policy.   <h2 class='errorType' id=\"err-dataNotEncrypted\">dataNotEncrypted</h2>  Description: The data in request was not encrypted or it was encrypted with obsolete keys.  Remediation: Encrypt the data using valid encryption keys.   <h2 class='errorType' id=\"err-invalidUsername\">invalidUsername</h2>  Description: For your security, we recommend choosing a more complex username with at least one special character.  Remediation: Choose a new username that satisfies the financial institution's policies or is more complex, such as including special characters.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>specialCharacters</td><td>string</td><td>A string containing recommended special characters.</td></tr> </table>  <h2 class='errorType' id=\"err-challengedNotVerified\">challengedNotVerified</h2>  Description: The challenge has not been verified, has expired, or has been redeemed too many times.  Remediation: Pass a valid and verified challenge resource in the Apiture-Challenge request header.   <h2 class='errorType' id=\"err-accessDenied\">accessDenied</h2>  Description: The credentials supplied in the request are insufficient to grant access.  Remediation: Check the supplied credentials for validity.   <h2 class='errorType' id=\"err-currentPasswordDoesNotMatch\">currentPasswordDoesNotMatch</h2>  Description: The current password does not match.  Remediation: Check that the current password in the request match the user's current password.   <h2 class='errorType' id=\"err-noSuchUser\">noSuchUser</h2>  Description: No users were found for the specified userId.  Remediation: Ensure the supplied userId corresponds to an Apiture user.   <h2 class='errorType' id=\"err-challengeNotFound\">challengeNotFound</h2>  Description: No Challenge was found for the specified challengeId.  Remediation: Ensure the supplied challengeId corresponds to a valid challenge resource.   <h2 class='errorType' id=\"err-authenticatorNotFound\">authenticatorNotFound</h2>  Description: No authenticators were found for the specified authenticatorId and challengeId combination.  Remediation: Ensure the supplied authenticatorId corresponds to a valid authenticator resource.   <h2 class='errorType' id=\"err-noSuchDevice\">noSuchDevice</h2>  Description: No devices were found for the specified userId.  Remediation: Verify that the device exists for the user and resubmit.   <h2 class='errorType' id=\"err-invalidAuthenticatorState\">invalidAuthenticatorState</h2>  Description: The operation is not allowed from the authenticator’s current state.  Remediation: Ensure the supplied authenticatorId corresponds to an Apiture authenticator resource in the correct state.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>currentState</td><td>string</td><td>undefined</td></tr> <tr><td>allowedStates</td><td>array</td><td>undefined</td></tr> </table>  <h2 class='errorType' id=\"err-authenticatorAttemptsExceeded\">authenticatorAttemptsExceeded</h2>  Description: User has exceeded the allowed number of retry attempts.  Remediation: Consider locking this user or device in order to prevent fraud.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>authenticatorId</td><td>string</td><td>undefined</td></tr> <tr><td>maximumRetries</td><td>number</td><td>undefined</td></tr> <tr><td>retryCount</td><td>number</td><td>undefined</td></tr> </table>  <h2 class='errorType' id=\"err-authenticatorTypeInUse\">authenticatorTypeInUse</h2>  Description: An update to the authenticator types omits one or more types that are in use.  Remediation: Include all in-use type names.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>typeNames</td><td>array</td><td>The list of authenticator types that are in use but missing from the request.<br>Example: `sms,email`</td></tr> </table>  <h2 class='errorType' id=\"err-redeemChallengeConflict\">redeemChallengeConflict</h2>  Description: No `Apiture-Challenge` request header was passed when expected, or the challenge has not been verified, has expired, or has been redeemed too many times.  Remediation: Ensure the supplied challengeId corresponds to a valid challenge resource.   <h2 class='errorType' id=\"err-authenticatorNotCompletable\">authenticatorNotCompletable</h2>  Description: The authenticator is not in a state that allows completing.  Remediation: Only verify an authenticator if the `apiture:verify` link exists.   <h2 class='errorType' id=\"err-invalidAuthenticatorAttributes\">invalidAuthenticatorAttributes</h2>  Description: The `attributes` in the authenticator do not conform to the schema for the authenticator type.  Remediation: Pass `attributes` that satisfy the JSON schema for the authenticator's type.   <h2 class='errorType' id=\"err-invalidSession\">invalidSession</h2>  Description: No session was found.  Remediation: Resubmit request with a valid session.   <h2 class='errorType' id=\"err-challengeRefNotFound\">challengeRefNotFound</h2>  Description: There is no challence resource corresponding to the referenced challenge.  Remediation: Pass a reference to a valid challence resource.   <h2 class='errorType' id=\"err-authenticatorRefNotFound\">authenticatorRefNotFound</h2>  Description: There is no authentictor resource corresponding to the referenced authentictor.  Remediation: Pass a reference to a valid authentictor resource.   <h2 class='errorType' id=\"err-missingApitureChallengeHeader\">missingApitureChallengeHeader</h2>  Description: The Apiture-Challenge request header is missing.  Remediation: Pass a reference to a valid challence resource in the Apiture-Challenge header.   <h2 class='errorType' id=\"err-challengedAlreadyRedeemed\">challengedAlreadyRedeemed</h2>  Description: The challenge resource has already been redeemed.  Remediation: Use the most recently issued challenge.   <h2 class='errorType' id=\"err-challengedExpired\">challengedExpired</h2>  Description: The challenge resource has expired.  Remediation: Use the most recently issued challenge and complete the authenticators before the challenge expires.   <h2 class='errorType' id=\"err-postTokenForbidden\">postTokenForbidden</h2>  Description: The client is not authorized to generate a new token.  Remediation: Use the most recently issued challenge.
 *
 * OpenAPI spec version: 0.17.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
