# @apiture/biz-verifications-client-sdk@0.10.2
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/biz-verifications-client-sdk@0.10.2 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ConfigurationApi, VerificationReportApi, VerificationStatusApi } from "@apiture/biz-verifications-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);

// Instantiate VerificationReportApi main class passing the configuration object.
    const verificationReportApi = new VerificationReportApi(configuration);

// Instantiate VerificationStatusApi main class passing the configuration object.
    const verificationStatusApi = new VerificationStatusApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/businessVerifications",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Business Verifications SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ConfigurationApi


  `ConfigurationApi.getConfiguration` - Configuration definition for this API

  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



### VerificationReportApi


  `VerificationReportApi.createVerificationReport` - Create a new verification report

  `VerificationReportApi.getVerificationReport` - Fetch a representation of this verification report

  `VerificationReportApi.getVerificationReports` - Return a collection of verification reports



### VerificationStatusApi


  `VerificationStatusApi.getBusinessVerifications` - Retrieves business verification resources.



## About the Business Verifications API
___
This API manages the set of operations that allow financial institutions to verify business identities as well as the identities of authorized representatives  connected to the business.  Vetting business identites can help financial  institutions standardize and build consistency in decisioning processes. This vetting consists of verifying the business as well as the  authorized signers associated with the business.  **Buisness Identification consists of the following attributes:**   * `businessName` The name of the business  * `addressLine1` Line 1 of the businesses street address  * `addressLine2` Line 2 of the businesses street address  * `city` The businesses city  * `regionCode` The businesses region code  * `postalCode` The businesses postal code  * `countryCode` The businesses country code  * `identification.taxId` The business's tax ID number (Federal Employer Identification Number)  **Authorized Signer Identification consists of the following attributes:**   * `firstName` The legal first name of the authorized signer  * `lastName` The legal last name of the authorized signer  * `identification.taxId` The federal tax ID of the authorized signer  _A verification report accepts an array of authorized signers to allow for verifying  multiple identities associated with a business._  ## Submitting a request to generate a verification report  A _verification report_ can be generated by passing the above data points in a `POST /verificationReports`. The response will contain an *`input`* object which will echo the data that was sent on the POST request.  It will also contain an  *`output`* object which will hold the unique `transactionId` and state for the report as well as any risk factors, risk factor codes and risk factor  descriptions flagged by the report.  It is possible to link an organization resource to a verification report  by passing an `apiture:organization` URI in the `_links` object when calling a `POST /verificationReports`.  If the optional `apiture:organization` link is supplied to the `POST /businessVerifications` call, you can retrieve that organizations verification status by calling `GET /businessVerifications?organizationUri={organizationUri}`.   If `apiture:organization` is not included in this `POST`, results can  be retrieved by calling `GET /verificationReports/{verificationReportId}`  ## Checking the verification status for an organization  If the optional `apiture:organization` link was passed on the `POST /verificationReports`, it is possible to view the verification status of that organization by calling  `GET /businessVerifications?organizationUri=/organization/organization/{organizationId}`. The response from `GET /businessVerifications` will contain an embedded list of of  *`businessVerifications`*, each of which will contain a *`type`*. The two possible values are *`verificationReport`* or *`administratorApproval`*.   A *`verificationReport`* will point back to a verification report resource.   An *`administratorApproval`* will point back to an Approval resource.   The presence of an *`administratorApproval`* record signifies that a member of the  financial institution has made a decision regarding the verification  status of an organization.  This decision acts as an override to any  previous verification report results. If a verification report is run and  successfully verifies the identity of the business, an approval  record will be automatically generated with a `state: 'passed'`.
