# @apiture/check-deposits-client-sdk@0.3.1
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/check-deposits-client-sdk@0.3.1 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, CheckApi, CheckDepositApi, LimitsApi } from "@apiture/check-deposits-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate CheckApi main class passing the configuration object.
    const checkApi = new CheckApi(configuration);

// Instantiate CheckDepositApi main class passing the configuration object.
    const checkDepositApi = new CheckDepositApi(configuration);

// Instantiate LimitsApi main class passing the configuration object.
    const limitsApi = new LimitsApi(configuration);


// Use the methods to call the apis ( Refer to the Check Deposits SDK Classes and Methods list ).
  limits.getLimits().then( response => {
    const getlimitsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate LimitsApi main class.
    const limitsApi = new LimitsApi();


// Update the accessToken using the class method `setAccessToken`.
    limitsApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    limitsApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    limitsApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { CheckDepositLimits } from "@apiture/check-deposits-client-sdk";

  const stronglyTypedObject :CheckDepositLimits = { ... };

  // ______ Scoped import

  import * as Check DepositsTypes from "@apiture/check-deposits-client-sdk";

  const stronglyTypedObject :Check DepositsTypes.CheckDepositLimits = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/checkDeposits",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Check Deposits SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### CheckApi


  `CheckApi.createCheck` - Add a check to the check deposit batch

  `CheckApi.createCheckImageUpload` - Create a new upload uri for the check side image

  `CheckApi.deleteCheck` - Remove a check from the check deposit

  `CheckApi.getCheck` - Fetch a check

  `CheckApi.getCheckImage` - Return the check side image metadata

  `CheckApi.getCheckImageContent` - Return the raw content of the check image side

  `CheckApi.patchCheck` - Modify a check in the deposit

  `CheckApi.processCheck` - Process a check

  `CheckApi.rejectCheck` - Reject a check



### CheckDepositApi


  `CheckDepositApi.createCheckDeposit` - Create a new check deposit

  `CheckDepositApi.deleteCheckDeposit` - Delete this check deposit resource

  `CheckDepositApi.getCheckDeposit` - Fetch a check deposit

  `CheckDepositApi.getCheckDeposits` - Return a collection of check deposits

  `CheckDepositApi.patchCheckDeposit` - Modify this check deposit resource

  `CheckDepositApi.processCheckDeposit` - Process checks in a check deposit

  `CheckDepositApi.submitCheckDeposit` - Submit a check deposit



### LimitsApi


  `LimitsApi.getLimits` - Return the mobile check deposit limits



## About the Check Deposits API
___
The Check Deposits API allows bank customers to use their mobile or web applications to take photographs or scans of endorsed paper checks and submit them for deposit into an existing account.  A check deposit is a batch of one or more checks to be deposited to an account.  To deposit checks, a user can create a check deposit resource and add check resources to it. The `apiture:uploadFrontImage` and `apiture:uploadBackImage` links found on a check can be used to upload JPEG formatted check images. After a check is created and front and back images uploaded, the check must be processed to determine if it is eligible to submit. A check can be processed asyncronously using the `apiture:process` link on the check resource, or all checks with `pending` state in a check deposit can be processed asyncronously by using the `apiture:process` link on the check deposit resource. When processing completes, each check may contain risk warnings, risk errors, or risk rejections.    * `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   * `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   * `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.  All checks in a check deposit must finish processing with `valid` state in order to submit the check deposit.  The **Check Deposit** state may be one of the following:   - `pending` In creation, not yet submitted for deposit. The user can add checks and make modifications to the check deposit.   - `processing` One or more checks in the check deposit are processing.   - `valid` The check deposit is eligible to submit.   - `invalid` The check deposit is not eligible to submit. It has one or more checks that must be corrected.   - `submitted` Submitted and is awaiting FI (Financial Institution) judgement. A `submitted` check deposit is read only.   - `accepted` All checks were approved by the FI and processed for deposit. An `accepted` check deposit is read only.   - `rejected` All checks were rejected by the FI and not processed for deposit. A `rejected` check deposit is read only.   - `acceptedWithRejections` One or more checks in the check deposit were accepted for deposit, but one or more were rejected. An `acceptedWithRejections` check deposit is read only.   The **Check** state may be one of the following:   - `pending` In creation, not submitted yet.   - `processing` Uploaded, awaiting image processing.   - `valid` Check has finished processing and is eligible to submit. The check may contain warnings.   - `invalid` Check has finished processing and is not eligible to submit. It has one or more errors that must be corrected before becoming eligible to submit.   - `submitted`  Check was submitted and is awaiting FI judgement before deposit. A `submitted` check is read only.   - `accepted` Check was accepted by the FI and deposited. Terminal. An `accepted` check is read only.   - `rejected` Check was rejected by the FI and not deposited. Terminal. A `rejected` check is read only.   If a check deposit is eligible to submit, the `apiture:submit` link can be used to submit the batch of checks for deposit. The checks are reviewed by the FI, either through an automated system or an admin. If the FI accepts a check, it is deposited and set to `accepted` state. If the FI rejects a check, it is not deposited and is set to `rejected` state.   # Error Types  Error responses in this API may have one of the `type` values described below. See [Errors](https://developer.apiture.com/docs/concepts/errors) for more information on error responses and error types.    ## <span class='errorType' id=\"err-accessForbidden\">accessForbidden</span>  **Description**: The credentials supplied in the request are insufficient to grant access. <br> **Remediation**: Check the supplied credentials for validity.   ## <span class='errorType' id=\"err-preconditionFailed\">preconditionFailed</span>  **Description**: The supplied `if-Match` header value does not match the most recent `ETag` response header value. The resource has changed in the interim. <br> **Remediation**: Resubmit the operation, supplying the value of the ETag and the most recent state of the resource.   ## <span class='errorType' id=\"err-preconditionRequired\">preconditionRequired</span>  **Description**: Precondition Required. The request did not include the required if-Match header. <br> **Remediation**: Resubmit with the operation, supplying the value of the ETag and the most recent state of the resource.   ## <span class='errorType' id=\"err-internalError\">internalError</span>  **Description**: An unexpected internal server error occurred. <br> **Remediation**: Retry the operation again.   ## <span class='errorType' id=\"err-emptyRequestBody\">emptyRequestBody</span>  **Description**: The supplied request body was empty. <br> **Remediation**: Check to make sure the body is included in your request.   ## <span class='errorType' id=\"err-invalidGroupName\">invalidGroupName</span>  **Description**: No configurationGroup was found for the specified groupName. <br> **Remediation**: Check to make sure that the supplied groupName corresponds to an apiture transfer configuration group resource.   ## <span class='errorType' id=\"err-invalidValueName\">invalidValueName</span>  **Description**: No configurationName was found for the specified valueName. <br> **Remediation**: Check to make sure that the supplied valueName corresponds to an apiture transfer configuration value resource.   ## <span class='errorType' id=\"err-invalidConfigurationGroup\">invalidConfigurationGroup</span>  **Description**: The request body did not conform to the schema for this configuration group. <br> **Remediation**: Check the schema for the configuration group and resubmit the operation.   ## <span class='errorType' id=\"err-invalidConfigurationValue\">invalidConfigurationValue</span>  **Description**: The request body did not conform to the schema for this configuration group value. <br> **Remediation**: Check the schema for the configuration group value and resubmit the operation.   ## <span class='errorType' id=\"err-invalidDepositId\">invalidDepositId</span>  **Description**: No Deposits were found for the specified depositId. <br> **Remediation**: Check to make sure that the supplied depositId corresponds to an apiture deposit resource.   ## <span class='errorType' id=\"err-invalidCheckId\">invalidCheckId</span>  **Description**: No Checks were found for the specified checkId. <br> **Remediation**: Check to make sure that the supplied checkId corresponds to an apiture check resource.   ## <span class='errorType' id=\"err-checkImageNotFound\">checkImageNotFound</span>  **Description**: No image was found for the specified checkId and image type. <br> **Remediation**: Check to make sure the check image has completed uploading and/or processing.   ## <span class='errorType' id=\"err-invalidCheckDepositState\">invalidCheckDepositState</span>  **Description**: Actions on check deposits may only be performed if they are in a valid state. <br> **Remediation**: Check the state of the check deposit and the allowable states for the requested operation.   ## <span class='errorType' id=\"err-invalidCheckState\">invalidCheckState</span>  **Description**: Actions on checks may only be performed if they are in a valid state. <br> **Remediation**: Check the state of the check and the allowable states for the requested operation.   ## <span class='errorType' id=\"err-invalidChecks\">invalidChecks</span>  **Description**: One or more checks are invalid to perform the requested operation. <br> **Remediation**: Verify all of the checks are valid and do not contain errors.   ## <span class='errorType' id=\"err-inProgressCheckDeposit\">inProgressCheckDeposit</span>  **Description**: The user has a check deposit in progress and is not allowed to create another. <br> **Remediation**: Submit or cancel the existing check deposit and try again.   ## <span class='errorType' id=\"err-invalidAccount\">invalidAccount</span>  **Description**: The supplied account reference was malformed. <br> **Remediation**: Check to make sure that the supplied `account` parameter corresponds to an Apiture account resource. 
