// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Check Deposits
 * The Check Deposits API allows bank customers to use their mobile or web applications to take photographs or scans of endorsed paper checks and submit them for deposit into an existing account.  A check deposit is a batch of one or more checks to be deposited to an account.  To deposit checks, a user can create a check deposit resource and add check resources to it. The `apiture:uploadFrontImage` and `apiture:uploadBackImage` links found on a check can be used to upload JPEG formatted check images. After a check is created and front and back images uploaded, the check must be processed to determine if it is eligible to submit. A check can be processed asyncronously using the `apiture:process` link on the check resource, or all checks with `pending` state in a check deposit can be processed asyncronously by using the `apiture:process` link on the check deposit resource. When processing completes, each check may contain risk warnings, risk errors, or risk rejections.    * `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   * `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   * `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.  All checks in a check deposit must finish processing with `valid` state in order to submit the check deposit.  The **Check Deposit** state may be one of the following:   - `pending` In creation, not yet submitted for deposit. The user can add checks and make modifications to the check deposit.   - `processing` One or more checks in the check deposit are processing.   - `valid` The check deposit is eligible to submit.   - `invalid` The check deposit is not eligible to submit. It has one or more checks that must be corrected.   - `submitted` Submitted and is awaiting FI (Financial Institution) judgement. A `submitted` check deposit is read only.   - `accepted` All checks were approved by the FI and processed for deposit. An `accepted` check deposit is read only.   - `rejected` All checks were rejected by the FI and not processed for deposit. A `rejected` check deposit is read only.   - `acceptedWithRejections` One or more checks in the check deposit were accepted for deposit, but one or more were rejected. An `acceptedWithRejections` check deposit is read only.   The **Check** state may be one of the following:   - `pending` In creation, not submitted yet.   - `processing` Uploaded, awaiting image processing.   - `valid` Check has finished processing and is eligible to submit. The check may contain warnings.   - `invalid` Check has finished processing and is not eligible to submit. It has one or more errors that must be corrected before becoming eligible to submit.   - `submitted`  Check was submitted and is awaiting FI judgement before deposit. A `submitted` check is read only.   - `accepted` Check was accepted by the FI and deposited. Terminal. An `accepted` check is read only.   - `rejected` Check was rejected by the FI and not deposited. Terminal. A `rejected` check is read only.   If a check deposit is eligible to submit, the `apiture:submit` link can be used to submit the batch of checks for deposit. The checks are reviewed by the FI, either through an automated system or an admin. If the FI accepts a check, it is deposited and set to `accepted` state. If the FI rejects a check, it is not deposited and is set to `rejected` state.   # Error Types  Error responses in this API may have one of the `type` values described below. See [Errors](https://developer.apiture.com/docs/concepts/errors) for more information on error responses and error types.    ## <span class='errorType' id=\"err-accessForbidden\">accessForbidden</span>  **Description**: The credentials supplied in the request are insufficient to grant access. <br> **Remediation**: Check the supplied credentials for validity.   ## <span class='errorType' id=\"err-preconditionFailed\">preconditionFailed</span>  **Description**: The supplied `if-Match` header value does not match the most recent `ETag` response header value. The resource has changed in the interim. <br> **Remediation**: Resubmit the operation, supplying the value of the ETag and the most recent state of the resource.   ## <span class='errorType' id=\"err-preconditionRequired\">preconditionRequired</span>  **Description**: Precondition Required. The request did not include the required if-Match header. <br> **Remediation**: Resubmit with the operation, supplying the value of the ETag and the most recent state of the resource.   ## <span class='errorType' id=\"err-internalError\">internalError</span>  **Description**: An unexpected internal server error occurred. <br> **Remediation**: Retry the operation again.   ## <span class='errorType' id=\"err-emptyRequestBody\">emptyRequestBody</span>  **Description**: The supplied request body was empty. <br> **Remediation**: Check to make sure the body is included in your request.   ## <span class='errorType' id=\"err-invalidGroupName\">invalidGroupName</span>  **Description**: No configurationGroup was found for the specified groupName. <br> **Remediation**: Check to make sure that the supplied groupName corresponds to an apiture transfer configuration group resource.   ## <span class='errorType' id=\"err-invalidValueName\">invalidValueName</span>  **Description**: No configurationName was found for the specified valueName. <br> **Remediation**: Check to make sure that the supplied valueName corresponds to an apiture transfer configuration value resource.   ## <span class='errorType' id=\"err-invalidConfigurationGroup\">invalidConfigurationGroup</span>  **Description**: The request body did not conform to the schema for this configuration group. <br> **Remediation**: Check the schema for the configuration group and resubmit the operation.   ## <span class='errorType' id=\"err-invalidConfigurationValue\">invalidConfigurationValue</span>  **Description**: The request body did not conform to the schema for this configuration group value. <br> **Remediation**: Check the schema for the configuration group value and resubmit the operation.   ## <span class='errorType' id=\"err-invalidDepositId\">invalidDepositId</span>  **Description**: No Deposits were found for the specified depositId. <br> **Remediation**: Check to make sure that the supplied depositId corresponds to an apiture deposit resource.   ## <span class='errorType' id=\"err-invalidCheckId\">invalidCheckId</span>  **Description**: No Checks were found for the specified checkId. <br> **Remediation**: Check to make sure that the supplied checkId corresponds to an apiture check resource.   ## <span class='errorType' id=\"err-checkImageNotFound\">checkImageNotFound</span>  **Description**: No image was found for the specified checkId and image type. <br> **Remediation**: Check to make sure the check image has completed uploading and/or processing.   ## <span class='errorType' id=\"err-invalidCheckDepositState\">invalidCheckDepositState</span>  **Description**: Actions on check deposits may only be performed if they are in a valid state. <br> **Remediation**: Check the state of the check deposit and the allowable states for the requested operation.   ## <span class='errorType' id=\"err-invalidCheckState\">invalidCheckState</span>  **Description**: Actions on checks may only be performed if they are in a valid state. <br> **Remediation**: Check the state of the check and the allowable states for the requested operation.   ## <span class='errorType' id=\"err-invalidChecks\">invalidChecks</span>  **Description**: One or more checks are invalid to perform the requested operation. <br> **Remediation**: Verify all of the checks are valid and do not contain errors.   ## <span class='errorType' id=\"err-inProgressCheckDeposit\">inProgressCheckDeposit</span>  **Description**: The user has a check deposit in progress and is not allowed to create another. <br> **Remediation**: Submit or cancel the existing check deposit and try again.   ## <span class='errorType' id=\"err-invalidAccount\">invalidAccount</span>  **Description**: The supplied account reference was malformed. <br> **Remediation**: Check to make sure that the supplied `account` parameter corresponds to an Apiture account resource.
 *
 * OpenAPI spec version: 0.3.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/checkDeposits'.replace(/\/+$/, '');

export const API_VERSION = '0.3.1';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Check resource. The `apiture:reject` link invokes the `rejectCheck` operation to reject an invalid check (`POST`); it is present if the `rejectCheck` operation is available for the check.
 * @export
 * @interface Check
 */
export interface Check extends AbstractResource {
  /**
   * The unique identifier for this check deposit resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Check
   */
  _id?: string;
  /**
   * Description for the check.
   * @type {string}
   * @memberof Check
   */
  description?: string;
  /**
   *
   * @type {CheckState}
   * @memberof Check
   */
  state?: CheckState;
  /**
   * Risk factors indicating the check has been rejected and can't be corrected. If a check contains any rejection risk factors, the check must be removed from the check deposit. A check deposit can't be submitted if any of its checks contain rejection risk factors.
   * @type {Array<RiskFactor>}
   * @memberof Check
   */
  riskRejections?: Array<RiskFactor>;
  /**
   * Risk factors indicating the check has errors which must be corrected before the check deposit can be submitted. Modifying the check data and re-processing may resolve errors. A check deposit can't be submitted if any of its checks contain error risk factors.
   * @type {Array<RiskFactor>}
   * @memberof Check
   */
  riskErrors?: Array<RiskFactor>;
  /**
   * Risk factors indicating the check has warnings. Warnings do not prevent a check from being deposited, but are helpful to show the user to catch any potential issues before submission. A check deposit can still be submitted if checks contain warnings.
   * @type {Array<RiskFactor>}
   * @memberof Check
   */
  riskWarnings?: Array<RiskFactor>;
  /**
   * Various additional diagnostic information about the check.
   * @type {Array<RiskFactor>}
   * @memberof Check
   */
  riskInfo?: Array<RiskFactor>;
  /**
   * The USD amount of the check entered by the user. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof Check
   */
  enteredAmount?: string;
  /**
   * The USD amount of the check read by OCR. This value may only be available after processing is complete. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof Check
   */
  scannedAmount?: string;
  /**
   * Indicates the confidence in the accuracy of the `scannedAmount` value, from lowest confidence `0.0` to highest confidence, `1.0`.
   * @type {number}
   * @memberof Check
   */
  scannedAmountConfidence?: number;
  /**
   * The scanned _magnetic ink character recognition_ (MICR) number from the check image. This value encodes the routing number, account number, check number, check amount, and other data from the check. This value is only be available after processing is complete.
   * @type {string}
   * @memberof Check
   */
  scannedMicr?: string;
  /**
   * The number of the check read by OCR. This value may only be available after processing is complete.
   * @type {string}
   * @memberof Check
   */
  scannedCheckNumber?: string;
  /**
   * An optional map of name/value pairs which contains additional dynamic data about the resource.
   * @type {{ [key: string]: AttributeValue; }}
   * @memberof Check
   */
  attributes?: { [key: string]: AttributeValue };
}

/**
 * The limits on check deposit amounts in this time period.
 * @export
 * @interface CheckAmounts
 */
export interface CheckAmounts {
  /**
   * The current total check deposit amount in this time period.
   * @type {string}
   * @memberof CheckAmounts
   */
  current?: string;
  /**
   * The remaining check deposit amount.
   * @type {string}
   * @memberof CheckAmounts
   */
  remaining?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this balance.
   * @type {string}
   * @memberof CheckAmounts
   */
  currency?: string;
}

/**
 * The limits on the number of check deposit in this time period.
 * @export
 * @interface CheckCounts
 */
export interface CheckCounts {
  /**
   * The current number of mobile check deposits in this time period
   * @type {number}
   * @memberof CheckCounts
   */
  current?: number;
  /**
   * The number of check deposits remaining.
   * @type {number}
   * @memberof CheckCounts
   */
  remaining?: number;
}

/**
 * Check deposit resource. Checks are added to this before being deposited. The URI of the account to deposit into will be included in the `apiture:target` link. The `apiture:process` link invokes the operation to process the checks to verify the check contents (`POST`); it is present if the `processCheckDeposit` operation is available for the check deposit. The `apiture:submit` link invokes the `submitCheckDeposit operation to submit the valid checks for deposit (`POST`); it is present if the `submitCheckDeposit` operation is available for the check deposit.
 * @export
 * @interface CheckDeposit
 */
export interface CheckDeposit extends SummaryCheckDeposit {
  /**
   * Checks included in the Check Deposit.
   * @type {Array<Check>}
   * @memberof CheckDeposit
   */
  checks?: Array<Check>;
  /**
   * The confirmation id that the deposit request was received for processing.
   * @type {string}
   * @memberof CheckDeposit
   */
  confirmationId?: string;
}

/**
 * List of check deposit limits and the remaining amounts.
 * @export
 * @interface CheckDepositLimit
 */
export interface CheckDepositLimit extends AbstractResource {
  /**
   * Defines the context of this check deposit limit.
   * @type {CheckDepositLimitContext}
   * @memberof CheckDepositLimit
   */
  context?: CheckDepositLimitContext;
  /**
   * The number of days covered this limit response, backwards from the today.
   * @type {number}
   * @memberof CheckDepositLimit
   */
  days?: number;
  /**
   *
   * @type {CheckCounts}
   * @memberof CheckDepositLimit
   */
  checkCounts?: CheckCounts;
  /**
   *
   * @type {CheckAmounts}
   * @memberof CheckDepositLimit
   */
  checkAmounts?: CheckAmounts;
}

/**
 * The context of a check deposit limit.  <strong><code>checkDepositLimitContext</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named checkDepositLimitContext)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>user</code></strong></td><td>User: User-level check deposit limits.</td>     </tr> <tr>     <td><strong><code>account</code></strong></td><td>Account-level check deposit limits.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum CheckDepositLimitContext {
  User = 'user',
  Account = 'account',
}

/**
 * Collection of check deposit limits and the remaining amounts.
 * @export
 * @interface CheckDepositLimits
 */
export interface CheckDepositLimits extends AbstractResource {
  /**
   * An array containing the limits.
   * @type {Array<CheckDepositLimit>}
   * @memberof CheckDepositLimits
   */
  limits?: Array<CheckDepositLimit>;
}

/**
 * The state of the check deposit. This field is immutable and derived.  <strong><code>checkDepositState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named checkDepositState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending</td>     </tr> <tr>     <td><strong><code>processing</code></strong></td><td>Processing</td>     </tr> <tr>     <td><strong><code>valid</code></strong></td><td>Valid</td>     </tr> <tr>     <td><strong><code>invalid</code></strong></td><td>Invalid</td>     </tr> <tr>     <td><strong><code>submitted</code></strong></td><td>Submitted</td>     </tr> <tr>     <td><strong><code>accepted</code></strong></td><td>Accepted</td>     </tr> <tr>     <td><strong><code>rejected</code></strong></td><td>Rejected</td>     </tr> <tr>     <td><strong><code>acceptedWithRejections</code></strong></td><td>Accepted with Rejections</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum CheckDepositState {
  Pending = 'pending',
  Processing = 'processing',
  Valid = 'valid',
  Invalid = 'invalid',
  Submitted = 'submitted',
  Accepted = 'accepted',
  Rejected = 'rejected',
  AcceptedWithRejections = 'acceptedWithRejections',
}

/**
 * Collection of check deposits. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface CheckDeposits
 */
export interface CheckDeposits extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof CheckDeposits
   */
  _embedded?: any;
}

/**
 * Representation of a check image file. The image may contain an `apiture:uploadUrl` link  within the item's `_links`. The client should next `PUT` the file content to the upload URLs. The file must be an image with JPEG format. If file content has been uploaded, the image may have an `apiture:content` link to access the direct URI of the file's content.
 * @export
 * @interface CheckImage
 */
export interface CheckImage extends AbstractResource {
  /**
   * The file name, for identification purposes. File names may include file extensions such as `.jpeg` for JPEG images, although the system does not validate or ensure that extensions match the file content type. This is limited to 64 characters and may not contain certain special characters such as / or \\\\. If omitted, the system will assign a name.
   * @type {string}
   * @memberof CheckImage
   */
  name?: string;
  /**
   * A description of this file and its contents.
   * @type {string}
   * @memberof CheckImage
   */
  description?: string;
  /**
   * The [media type](https://tools.ietf.org/html/rfc6838) for this file.
   * @type {string}
   * @memberof CheckImage
   */
  contentType?: string;
  /**
   * The file size in bytes. This is a derived property and cannot be modified in updates.
   * @type {number}
   * @memberof CheckImage
   */
  sizeBytes?: number;
  /**
   * The date-time when the image was created or uploaded.
   * @type {Date}
   * @memberof CheckImage
   */
  createdAt?: Date;
}

/**
 * The state of the check. This field is immutable and derived.  <strong><code>checkState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named checkState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending</td>     </tr> <tr>     <td><strong><code>processing</code></strong></td><td>Processing</td>     </tr> <tr>     <td><strong><code>valid</code></strong></td><td>Valid</td>     </tr> <tr>     <td><strong><code>invalid</code></strong></td><td>Invalid</td>     </tr> <tr>     <td><strong><code>submitted</code></strong></td><td>Submitted</td>     </tr> <tr>     <td><strong><code>accepted</code></strong></td><td>Accepted</td>     </tr> <tr>     <td><strong><code>rejected</code></strong></td><td>Rejected</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum CheckState {
  Pending = 'pending',
  Processing = 'processing',
  Valid = 'valid',
  Invalid = 'invalid',
  Submitted = 'submitted',
  Accepted = 'accepted',
  Rejected = 'rejected',
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Create a new check.
 * @export
 * @interface CreateCheck
 */
export interface CreateCheck extends AbstractResource {
  /**
   * The USD amount of the deposit entered by the user. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof CreateCheck
   */
  enteredAmount?: string;
  /**
   * Description for the deposit.
   * @type {string}
   * @memberof CreateCheck
   */
  description?: string;
  /**
   *
   * @type {Device}
   * @memberof CreateCheck
   */
  device?: Device;
}

/**
 * Create a new check deposit. Account URI to deposit into should be included in _links 'apiture:target'.
 * @export
 * @interface CreateCheckDeposit
 */
export interface CreateCheckDeposit extends AbstractResource {
  /**
   * The total USD amount of the deposit entered by the user. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof CreateCheckDeposit
   */
  enteredAmount?: string;
  /**
   * Description for the deposit.
   * @type {string}
   * @memberof CreateCheckDeposit
   */
  description?: string;
  /**
   *
   * @type {Device}
   * @memberof CreateCheckDeposit
   */
  device?: Device;
}

/**
 * Diagnostic information about the client device.
 * @export
 * @interface Device
 */
export interface Device {
  /**
   * Unique identifier of the device originating the request. This can be any unique value to identify the client device.
   * @type {string}
   * @memberof Device
   */
  id?: string;
  /**
   * The type of device originating the request. This is a high level indicator for the type of the client device. iPhone, Android, Web Browser are examples.
   * @type {string}
   * @memberof Device
   */
  type?: string;
  /**
   * The operating system of the device originating the request. iOS, Android, macOS, Windows, Linux are examples.
   * @type {string}
   * @memberof Device
   */
  operatingSystem?: string;
  /**
   * The version of the operating system of the device originating the request.
   * @type {string}
   * @memberof Device
   */
  operatingSystemVersion?: string;
  /**
   * The make of the device originating the request. Apple, Google, Motorola, Dell are examples.
   * @type {string}
   * @memberof Device
   */
  make?: string;
  /**
   * The model of the device originating the request. iPhoneXs, Pixel3, G2qx, MacbookPro13 are examples.
   * @type {string}
   * @memberof Device
   */
  model?: string;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Diagnostic information about the check.
 * @export
 * @interface RiskFactor
 */
export interface RiskFactor extends AbstractResource {
  /**
   * The risk factor type.
   * @type {string}
   * @memberof RiskFactor
   */
  type?: string;
  /**
   * A short label identifying the risk factor.
   * @type {string}
   * @memberof RiskFactor
   */
  label?: string;
  /**
   * A longer description with information about the risk factor. This may include recovery options in the case of warnings or errors.
   * @type {string}
   * @memberof RiskFactor
   */
  description?: string;
  /**
   * Data attribute associated with the risk factor, such as values or constraints.
   * @type {Attributes}
   * @memberof RiskFactor
   */
  attributes?: Attributes;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of check deposit resource in collections.
 * @export
 * @interface SummaryCheckDeposit
 */
export interface SummaryCheckDeposit extends AbstractResource {
  /**
   * The unique identifier for this account resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryCheckDeposit
   */
  _id?: string;
  /**
   *
   * @type {CheckDepositState}
   * @memberof SummaryCheckDeposit
   */
  state?: CheckDepositState;
  /**
   * Description for the deposit.
   * @type {string}
   * @memberof SummaryCheckDeposit
   */
  description?: string;
  /**
   * The total USD amount of the check deposit after it was successfully deposited. This number is immutable and only available after the check deposit was accepted by the FI and has state 'accepted' or 'acceptedWithRejections'. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof SummaryCheckDeposit
   */
  depositedAmount?: string;
  /**
   * The USD amount of the deposit entered by the user. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof SummaryCheckDeposit
   */
  enteredAmount?: string;
  /**
   * The total USD amount of the deposit read by OCR. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof SummaryCheckDeposit
   */
  scannedAmount?: string;
  /**
   * The current count of checks in the deposit batch.
   * @type {number}
   * @memberof SummaryCheckDeposit
   */
  checkCount?: number;
  /**
   * The date-time the check deposit was created. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp.
   * @type {Date}
   * @memberof SummaryCheckDeposit
   */
  createdAt?: Date;
  /**
   * The date-time the check deposit was submitted. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp.
   * @type {Date}
   * @memberof SummaryCheckDeposit
   */
  submittedAt?: Date;
  /**
   * The date-time the check deposit was accepted. This does not mean the checks have cleared, only that the deposit has been posted. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp.
   * @type {Date}
   * @memberof SummaryCheckDeposit
   */
  acceptedAt?: Date;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * CheckApi - axios parameter creator
 * @export
 */
export const CheckApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new check in the check deposit. A check must reside inside a check deposit resource. Checks can only be added to check deposits that have state `pending`, `processing`, `valid`, or `invalid`. Device data may be provided to identify the client device. The device data for each check may be compared to the device data for other checks or the parent check deposit to aid verification. It is recommended to provide as much device data as possible.  The check in the response body will include `apiture:uploadFrontImage` and `apiture:uploadBackImage` links which the client should use to upload check images. Images must be uploaded in JPEG format.  After images have been successfully uploaded, `apiture:frontImageContent` and `apiture:backImageContent` links can be used to download image contents.  A check must be processed by using the `apiture:process` link before it can be submitted. The check must have successfully uploaded front and back images in order to be processed.
     * @summary Add a check to the check deposit batch
     * @param {CreateCheck} CreateCheck The data necessary to create a new check.
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheck(CreateCheck: CreateCheck, depositId: string, options: any = {}): RequestArgs {
      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling createCheck.',
        );
      }
      // verify required parameter 'CreateCheck' is not null or undefined
      if (CreateCheck === null || CreateCheck === undefined) {
        throw new RequiredError(
          'CreateCheck',
          'Required parameter CreateCheck was null or undefined when calling createCheck.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks`.replace(
        `{${'depositId'}}`,
        encodeURIComponent(String(depositId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateCheck' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateCheck || {})
        : CreateCheck || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new upload uri for the check side image. This operation is used if the client needs to replace an uploaded image side, it is not needed for new checks. Upload uris may not be issued if the check has state `submitted`, `accepted`, or `rejected`. The response body will include a `apiture:uploadUri` link which can be used to POST the file content and upload an image. This will replace any existing image. The Content-Type header (or the Content-Type in the multipart form data) must match the contentType of the file resource. JPEG is the only supported image format.  If a check has state `processing`, `valid`, or `invalid`, creating a new image upload uri will invalidate the image analysis, reset the check to `pending`, and the check must be processed again. Valid check side values:   * `front`   * `back`
     * @summary Create a new upload uri for the check side image
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckImageUpload(
      depositId: string,
      checkId: string,
      side: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling createCheckImageUpload.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling createCheckImageUpload.',
        );
      }
      // verify required parameter 'side' is not null or undefined
      if (side === null || side === undefined) {
        throw new RequiredError(
          'side',
          'Required parameter side was null or undefined when calling createCheckImageUpload.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}/images/{side}`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)))
        .replace(`{${'side'}}`, encodeURIComponent(String(side)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Removes the check from the check deposit batch. Checks may not be deleted if they have state `submitted`, `accepted`, or `rejected`.
     * @summary Remove a check from the check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheck(depositId: string, checkId: string, options: any = {}): RequestArgs {
      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling deleteCheck.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling deleteCheck.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a HAL representation of this check resource
     * @summary Fetch a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheck(
      depositId: string,
      checkId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling getCheck.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling getCheck.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return metadata of the image file. Valid check side values:   * `front`   * `back`
     * @summary Return the check side image metadata
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImage(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling getCheckImage.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling getCheckImage.',
        );
      }
      // verify required parameter 'side' is not null or undefined
      if (side === null || side === undefined) {
        throw new RequiredError(
          'side',
          'Required parameter side was null or undefined when calling getCheckImage.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}/images/{side}`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)))
        .replace(`{${'side'}}`, encodeURIComponent(String(side)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the raw content of the image file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available. Valid check side values:   * `front`   * `back`
     * @summary Return the raw content of the check image side
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImageContent(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling getCheckImageContent.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling getCheckImageContent.',
        );
      }
      // verify required parameter 'side' is not null or undefined
      if (side === null || side === undefined) {
        throw new RequiredError(
          'side',
          'Required parameter side was null or undefined when calling getCheckImageContent.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}/images/{side}/content`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)))
        .replace(`{${'side'}}`, encodeURIComponent(String(side)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Modify check data. `enteredAmount` and `description` are the only editable fields.  Checks may not be modified if they have state `submitted`, `accepted`, or `rejected`.  If a check has state `processing`, `valid`, or `invalid`, modifying the check `enteredAmount` will invalidate the image analysis, reset the check to `pending`, and must be processed again.
     * @summary Modify a check in the deposit
     * @param {Check} Check The data to modify a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheck(
      Check: Check,
      depositId: string,
      checkId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling patchCheck.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling patchCheck.',
        );
      }
      // verify required parameter 'Check' is not null or undefined
      if (Check === null || Check === undefined) {
        throw new RequiredError(
          'Check',
          'Required parameter Check was null or undefined when calling patchCheck.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/checks/{checkId}`
        .replace(`{${'depositId'}}`, encodeURIComponent(String(depositId)))
        .replace(`{${'checkId'}}`, encodeURIComponent(String(checkId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Check' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(Check || {}) : Check || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Process a Check to validate data, perform image analysis, and return risk factors. This operation is invoked from the `apiture:process` link on a check. Each check in a check deposit must be processed before the batch can be submitted. Checks may not be processed if they have state `submitted`, `accepted`, or `rejected`.  If the check has not been processed, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If the check has finished processing, the operations returns 200 OK and the response body is the updated check resource.  `riskRejections`, `riskErrors`, `riskWarnings`, and `riskInfo` may contain risk factors after a check has completed processing. Risk factors include diagnostic information about the check, check images, or end user, which indicate if the check is acceptable for deposit.    - `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   - `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   - `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.   - `riskInfo` includes additional diagnostic information about the check.  If a check has finished processing and contains no risk factors, it indicates the check has a high chance of being accepted for deposit.
     * @summary Process a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.checkId] The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheck(depositId: string, query?: { checkId?: string }, options: any = {}): RequestArgs {
      const { checkId } = query;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling processCheck.',
        );
      }
      // verify required parameter 'checkId' is not null or undefined
      if (checkId === null || checkId === undefined) {
        throw new RequiredError(
          'checkId',
          'Required parameter checkId was null or undefined when calling processCheck.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}/processedChecks`.replace(
        `{${'depositId'}}`,
        encodeURIComponent(String(depositId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (checkId !== undefined) {
        localVarQueryParameter['checkId'] = checkId;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Reject a check if it is eligible to be rejected. This operation is invoked from the `apiture:reject` link on a check. The link will only be returned for admins, and only admins can reject a check. There is no request body in this method. Rejecting a check will also reverse the core transaction.
     * @summary Reject a check
     * @param {Object} [query] Query object
     * @param {string} [query.check] A server-generated key which identifies an existing check resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectCheck(query?: { check?: string }, options: any = {}): RequestArgs {
      const { check } = query;

      // verify required parameter 'check' is not null or undefined
      if (check === null || check === undefined) {
        throw new RequiredError(
          'check',
          'Required parameter check was null or undefined when calling rejectCheck.',
        );
      }
      const localVarPath = `/rejectedChecks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (check !== undefined) {
        localVarQueryParameter['check'] = check;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * CheckApi - functional programming interface
 * @export
 */
export const CheckApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new check in the check deposit. A check must reside inside a check deposit resource. Checks can only be added to check deposits that have state `pending`, `processing`, `valid`, or `invalid`. Device data may be provided to identify the client device. The device data for each check may be compared to the device data for other checks or the parent check deposit to aid verification. It is recommended to provide as much device data as possible.  The check in the response body will include `apiture:uploadFrontImage` and `apiture:uploadBackImage` links which the client should use to upload check images. Images must be uploaded in JPEG format.  After images have been successfully uploaded, `apiture:frontImageContent` and `apiture:backImageContent` links can be used to download image contents.  A check must be processed by using the `apiture:process` link before it can be submitted. The check must have successfully uploaded front and back images in order to be processed.
     * @summary Add a check to the check deposit batch
     * @param {CreateCheck} CreateCheck The data necessary to create a new check.
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheck(
      CreateCheck: CreateCheck,
      depositId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Check> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).createCheck(
        CreateCheck ? CreateCheck : null,
        depositId ? depositId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new upload uri for the check side image. This operation is used if the client needs to replace an uploaded image side, it is not needed for new checks. Upload uris may not be issued if the check has state `submitted`, `accepted`, or `rejected`. The response body will include a `apiture:uploadUri` link which can be used to POST the file content and upload an image. This will replace any existing image. The Content-Type header (or the Content-Type in the multipart form data) must match the contentType of the file resource. JPEG is the only supported image format.  If a check has state `processing`, `valid`, or `invalid`, creating a new image upload uri will invalidate the image analysis, reset the check to `pending`, and the check must be processed again. Valid check side values:   * `front`   * `back`
     * @summary Create a new upload uri for the check side image
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckImageUpload(
      depositId: string,
      checkId: string,
      side: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckImage> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).createCheckImageUpload(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Removes the check from the check deposit batch. Checks may not be deleted if they have state `submitted`, `accepted`, or `rejected`.
     * @summary Remove a check from the check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheck(
      depositId: string,
      checkId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).deleteCheck(
        depositId ? depositId : null,
        checkId ? checkId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a HAL representation of this check resource
     * @summary Fetch a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheck(
      depositId: string,
      checkId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Check> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).getCheck(
        depositId ? depositId : null,
        checkId ? checkId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return metadata of the image file. Valid check side values:   * `front`   * `back`
     * @summary Return the check side image metadata
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImage(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckImage> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).getCheckImage(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the raw content of the image file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available. Valid check side values:   * `front`   * `back`
     * @summary Return the raw content of the check image side
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImageContent(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).getCheckImageContent(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Modify check data. `enteredAmount` and `description` are the only editable fields.  Checks may not be modified if they have state `submitted`, `accepted`, or `rejected`.  If a check has state `processing`, `valid`, or `invalid`, modifying the check `enteredAmount` will invalidate the image analysis, reset the check to `pending`, and must be processed again.
     * @summary Modify a check in the deposit
     * @param {Check} Check The data to modify a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheck(
      Check: Check,
      depositId: string,
      checkId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Check> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).patchCheck(
        Check ? Check : null,
        depositId ? depositId : null,
        checkId ? checkId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Process a Check to validate data, perform image analysis, and return risk factors. This operation is invoked from the `apiture:process` link on a check. Each check in a check deposit must be processed before the batch can be submitted. Checks may not be processed if they have state `submitted`, `accepted`, or `rejected`.  If the check has not been processed, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If the check has finished processing, the operations returns 200 OK and the response body is the updated check resource.  `riskRejections`, `riskErrors`, `riskWarnings`, and `riskInfo` may contain risk factors after a check has completed processing. Risk factors include diagnostic information about the check, check images, or end user, which indicate if the check is acceptable for deposit.    - `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   - `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   - `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.   - `riskInfo` includes additional diagnostic information about the check.  If a check has finished processing and contains no risk factors, it indicates the check has a high chance of being accepted for deposit.
     * @summary Process a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.checkId] The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheck(
      depositId: string,
      query?: { checkId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Check> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).processCheck(
        depositId ? depositId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Reject a check if it is eligible to be rejected. This operation is invoked from the `apiture:reject` link on a check. The link will only be returned for admins, and only admins can reject a check. There is no request body in this method. Rejecting a check will also reverse the core transaction.
     * @summary Reject a check
     * @param {Object} [query] Query object
     * @param {string} [query.check] A server-generated key which identifies an existing check resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectCheck(
      query?: { check?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Check> {
      const localVarAxiosArgs = CheckApiAxiosParamCreator(configuration).rejectCheck(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * CheckApi - factory interface
 * @export
 */
export const CheckApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new check in the check deposit. A check must reside inside a check deposit resource. Checks can only be added to check deposits that have state `pending`, `processing`, `valid`, or `invalid`. Device data may be provided to identify the client device. The device data for each check may be compared to the device data for other checks or the parent check deposit to aid verification. It is recommended to provide as much device data as possible.  The check in the response body will include `apiture:uploadFrontImage` and `apiture:uploadBackImage` links which the client should use to upload check images. Images must be uploaded in JPEG format.  After images have been successfully uploaded, `apiture:frontImageContent` and `apiture:backImageContent` links can be used to download image contents.  A check must be processed by using the `apiture:process` link before it can be submitted. The check must have successfully uploaded front and back images in order to be processed.
     * @summary Add a check to the check deposit batch
     * @param {CreateCheck} CreateCheck The data necessary to create a new check.
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheck(CreateCheck: CreateCheck, depositId: string, options?: any) {
      return CheckApiFp(configuration).createCheck(
        CreateCheck ? CreateCheck : null,
        depositId ? depositId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new upload uri for the check side image. This operation is used if the client needs to replace an uploaded image side, it is not needed for new checks. Upload uris may not be issued if the check has state `submitted`, `accepted`, or `rejected`. The response body will include a `apiture:uploadUri` link which can be used to POST the file content and upload an image. This will replace any existing image. The Content-Type header (or the Content-Type in the multipart form data) must match the contentType of the file resource. JPEG is the only supported image format.  If a check has state `processing`, `valid`, or `invalid`, creating a new image upload uri will invalidate the image analysis, reset the check to `pending`, and the check must be processed again. Valid check side values:   * `front`   * `back`
     * @summary Create a new upload uri for the check side image
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckImageUpload(depositId: string, checkId: string, side: string, options?: any) {
      return CheckApiFp(configuration).createCheckImageUpload(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Removes the check from the check deposit batch. Checks may not be deleted if they have state `submitted`, `accepted`, or `rejected`.
     * @summary Remove a check from the check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheck(depositId: string, checkId: string, options?: any) {
      return CheckApiFp(configuration).deleteCheck(
        depositId ? depositId : null,
        checkId ? checkId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a HAL representation of this check resource
     * @summary Fetch a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheck(
      depositId: string,
      checkId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return CheckApiFp(configuration).getCheck(
        depositId ? depositId : null,
        checkId ? checkId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return metadata of the image file. Valid check side values:   * `front`   * `back`
     * @summary Return the check side image metadata
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImage(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return CheckApiFp(configuration).getCheckImage(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the raw content of the image file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available. Valid check side values:   * `front`   * `back`
     * @summary Return the raw content of the check image side
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckImageContent(
      depositId: string,
      checkId: string,
      side: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return CheckApiFp(configuration).getCheckImageContent(
        depositId ? depositId : null,
        checkId ? checkId : null,
        side ? side : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Modify check data. `enteredAmount` and `description` are the only editable fields.  Checks may not be modified if they have state `submitted`, `accepted`, or `rejected`.  If a check has state `processing`, `valid`, or `invalid`, modifying the check `enteredAmount` will invalidate the image analysis, reset the check to `pending`, and must be processed again.
     * @summary Modify a check in the deposit
     * @param {Check} Check The data to modify a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {string} checkId The unique identifier of this check. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheck(
      Check: Check,
      depositId: string,
      checkId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return CheckApiFp(configuration).patchCheck(
        Check ? Check : null,
        depositId ? depositId : null,
        checkId ? checkId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Process a Check to validate data, perform image analysis, and return risk factors. This operation is invoked from the `apiture:process` link on a check. Each check in a check deposit must be processed before the batch can be submitted. Checks may not be processed if they have state `submitted`, `accepted`, or `rejected`.  If the check has not been processed, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If the check has finished processing, the operations returns 200 OK and the response body is the updated check resource.  `riskRejections`, `riskErrors`, `riskWarnings`, and `riskInfo` may contain risk factors after a check has completed processing. Risk factors include diagnostic information about the check, check images, or end user, which indicate if the check is acceptable for deposit.    - `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   - `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   - `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.   - `riskInfo` includes additional diagnostic information about the check.  If a check has finished processing and contains no risk factors, it indicates the check has a high chance of being accepted for deposit.
     * @summary Process a check
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.checkId] The unique identifier of this check. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheck(depositId: string, query?: { checkId?: string }, options?: any) {
      return CheckApiFp(configuration).processCheck(
        depositId ? depositId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Reject a check if it is eligible to be rejected. This operation is invoked from the `apiture:reject` link on a check. The link will only be returned for admins, and only admins can reject a check. There is no request body in this method. Rejecting a check will also reverse the core transaction.
     * @summary Reject a check
     * @param {Object} [query] Query object
     * @param {string} [query.check] A server-generated key which identifies an existing check resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectCheck(query?: { check?: string }, options?: any) {
      return CheckApiFp(configuration).rejectCheck(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * CheckApi - object-oriented interface
 * @export
 * @class CheckApi
 * @extends {BaseAPI}
 */
export class CheckApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new check in the check deposit. A check must reside inside a check deposit resource. Checks can only be added to check deposits that have state `pending`, `processing`, `valid`, or `invalid`. Device data may be provided to identify the client device. The device data for each check may be compared to the device data for other checks or the parent check deposit to aid verification. It is recommended to provide as much device data as possible.  The check in the response body will include `apiture:uploadFrontImage` and `apiture:uploadBackImage` links which the client should use to upload check images. Images must be uploaded in JPEG format.  After images have been successfully uploaded, `apiture:frontImageContent` and `apiture:backImageContent` links can be used to download image contents.  A check must be processed by using the `apiture:process` link before it can be submitted. The check must have successfully uploaded front and back images in order to be processed.
   * @summary Add a check to the check deposit batch
   * @param {CreateCheck} CreateCheck The data necessary to create a new check.
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Check}
   * @memberof CheckApi
   */
  public createCheck(CreateCheck: CreateCheck, depositId: string, options?: any) {
    return CheckApiFp(this.configuration).createCheck(
      CreateCheck ? CreateCheck : null,
      depositId ? depositId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new upload uri for the check side image. This operation is used if the client needs to replace an uploaded image side, it is not needed for new checks. Upload uris may not be issued if the check has state `submitted`, `accepted`, or `rejected`. The response body will include a `apiture:uploadUri` link which can be used to POST the file content and upload an image. This will replace any existing image. The Content-Type header (or the Content-Type in the multipart form data) must match the contentType of the file resource. JPEG is the only supported image format.  If a check has state `processing`, `valid`, or `invalid`, creating a new image upload uri will invalidate the image analysis, reset the check to `pending`, and the check must be processed again. Valid check side values:   * `front`   * `back`
   * @summary Create a new upload uri for the check side image
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckImage}
   * @memberof CheckApi
   */
  public createCheckImageUpload(depositId: string, checkId: string, side: string, options?: any) {
    return CheckApiFp(this.configuration).createCheckImageUpload(
      depositId ? depositId : null,
      checkId ? checkId : null,
      side ? side : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Removes the check from the check deposit batch. Checks may not be deleted if they have state `submitted`, `accepted`, or `rejected`.
   * @summary Remove a check from the check deposit
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof CheckApi
   */
  public deleteCheck(depositId: string, checkId: string, options?: any) {
    return CheckApiFp(this.configuration).deleteCheck(
      depositId ? depositId : null,
      checkId ? checkId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a HAL representation of this check resource
   * @summary Fetch a check
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Check}
   * @memberof CheckApi
   */
  public getCheck(
    depositId: string,
    checkId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return CheckApiFp(this.configuration).getCheck(
      depositId ? depositId : null,
      checkId ? checkId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return metadata of the image file. Valid check side values:   * `front`   * `back`
   * @summary Return the check side image metadata
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckImage}
   * @memberof CheckApi
   */
  public getCheckImage(
    depositId: string,
    checkId: string,
    side: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return CheckApiFp(this.configuration).getCheckImage(
      depositId ? depositId : null,
      checkId ? checkId : null,
      side ? side : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the raw content of the image file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available. Valid check side values:   * `front`   * `back`
   * @summary Return the raw content of the check image side
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {string} side The side of the check. Valid check &#x60;side&#x60; values:   * &#x60;front&#x60;   * &#x60;back&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof CheckApi
   */
  public getCheckImageContent(
    depositId: string,
    checkId: string,
    side: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return CheckApiFp(this.configuration).getCheckImageContent(
      depositId ? depositId : null,
      checkId ? checkId : null,
      side ? side : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Modify check data. `enteredAmount` and `description` are the only editable fields.  Checks may not be modified if they have state `submitted`, `accepted`, or `rejected`.  If a check has state `processing`, `valid`, or `invalid`, modifying the check `enteredAmount` will invalidate the image analysis, reset the check to `pending`, and must be processed again.
   * @summary Modify a check in the deposit
   * @param {Check} Check The data to modify a check
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {string} checkId The unique identifier of this check. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Check}
   * @memberof CheckApi
   */
  public patchCheck(
    Check: Check,
    depositId: string,
    checkId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return CheckApiFp(this.configuration).patchCheck(
      Check ? Check : null,
      depositId ? depositId : null,
      checkId ? checkId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Process a Check to validate data, perform image analysis, and return risk factors. This operation is invoked from the `apiture:process` link on a check. Each check in a check deposit must be processed before the batch can be submitted. Checks may not be processed if they have state `submitted`, `accepted`, or `rejected`.  If the check has not been processed, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If the check has finished processing, the operations returns 200 OK and the response body is the updated check resource.  `riskRejections`, `riskErrors`, `riskWarnings`, and `riskInfo` may contain risk factors after a check has completed processing. Risk factors include diagnostic information about the check, check images, or end user, which indicate if the check is acceptable for deposit.    - `riskWarnings` are not required to be resolved, but may be useful to resolve potential issues.   - `riskErrors` must be resolved in order to submit the check deposit. Errors may be fixed by reuploading images or correcting check data.   - `riskRejections` indicate the check is not suitable for deposit, and the check must be removed from the check deposit.   - `riskInfo` includes additional diagnostic information about the check.  If a check has finished processing and contains no risk factors, it indicates the check has a high chance of being accepted for deposit.
   * @summary Process a check
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.checkId] The unique identifier of this check. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Check}
   * @memberof CheckApi
   */
  public processCheck(depositId: string, query?: { checkId?: string }, options?: any) {
    return CheckApiFp(this.configuration).processCheck(
      depositId ? depositId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Reject a check if it is eligible to be rejected. This operation is invoked from the `apiture:reject` link on a check. The link will only be returned for admins, and only admins can reject a check. There is no request body in this method. Rejecting a check will also reverse the core transaction.
   * @summary Reject a check
   * @param {Object} [query] Query object
   * @param {string} [query.check] A server-generated key which identifies an existing check resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Check}
   * @memberof CheckApi
   */
  public rejectCheck(query?: { check?: string }, options?: any) {
    return CheckApiFp(this.configuration).rejectCheck(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * CheckDepositApi - axios parameter creator
 * @export
 */
export const CheckDepositApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new check deposit to add checks and submit a deposit. A check deposit must be used to submit a deposit, individual check resources can't be submitted.  The `apiture:target` link can be used to specify the account resource the check deposit will be deposited to. This value is not required when creating a check deposit, but is required to submit it.  The user can provide an optional `enteredAmount` when creating a check deposit. This is the expected total batch amount of all checks, and can be used as verification against the check amounts later scanned by OCR (optical character recognition).  Device data may be provided to identify the client device and aid the deposit verification process. It is recommended to provide as much device data as possible.  After creating a check deposit, use the `createCheck` operation (the `apiture:createCheck` link) to add checks to it, then use the `processCheckDeposit` operation (the `apiture:process` link) to process the checks to verify the check contents. If all the checks are valid, follow that with the `submitCheckDeposit` (the `apiture:process` link) operation to submit the valid checks for deposit.
     * @summary Create a new check deposit
     * @param {CreateCheckDeposit} CreateCheckDeposit The data necessary to create a new check deposit.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckDeposit(CreateCheckDeposit: CreateCheckDeposit, options: any = {}): RequestArgs {
      // verify required parameter 'CreateCheckDeposit' is not null or undefined
      if (CreateCheckDeposit === null || CreateCheckDeposit === undefined) {
        throw new RequiredError(
          'CreateCheckDeposit',
          'Required parameter CreateCheckDeposit was null or undefined when calling createCheckDeposit.',
        );
      }
      const localVarPath = `/checkDeposits`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateCheckDeposit' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateCheckDeposit || {})
        : CreateCheckDeposit || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this check deposit resource and any resources that are owned by it. This operation will also delete any checks included in the check deposit. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Delete this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheckDeposit(
      depositId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling deleteCheckDeposit.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}`.replace(
        `{${'depositId'}}`,
        encodeURIComponent(String(depositId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a HAL representation of this check deposit resource.
     * @summary Fetch a check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposit(
      depositId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling getCheckDeposit.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}`.replace(
        `{${'depositId'}}`,
        encodeURIComponent(String(depositId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of check deposits. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of check deposits
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first check deposit item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of check deposit representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections'} [query.state] Subset of the check deposit collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;pending|submitted&#x60; matches items whose &#x60;state&#x60; is &#x60;pending&#x60; or &#x60;submitted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposits(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections';
        filter?: string;
        q?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, state, filter, q } = query;

      const localVarPath = `/checkDeposits`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Modify this check deposit. The `apiture:target` link, `description`, and `enteredAmount` are the only editable fields. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Modify this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheckDeposit(
      depositId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'depositId' is not null or undefined
      if (depositId === null || depositId === undefined) {
        throw new RequiredError(
          'depositId',
          'Required parameter depositId was null or undefined when calling patchCheckDeposit.',
        );
      }
      const localVarPath = `/checkDeposits/{depositId}`.replace(
        `{${'depositId'}}`,
        encodeURIComponent(String(depositId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Process all checks in a check deposit which have state `pending`.  This operation is invoked from the `apiture:process` link on a check deposit. All checks with `pending` state on the check deposit will be processed asyncronously. Checks which are currently being processed or have finished processing with state `valid` or `invalid` will be ignored.  If any checks have not been processed yet, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If all checks have finished processing, the operations returns 200 OK and the response body is the updated check deposit resource.
     * @summary Process checks in a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheckDeposit(query?: { depositId?: string }, options: any = {}): RequestArgs {
      const { depositId } = query;

      const localVarPath = `/processedCheckDeposits`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (depositId !== undefined) {
        localVarQueryParameter['depositId'] = depositId;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Submit a check deposit that is eligible to be submitted. This operation is invoked from the `apiture:submit` link on a check deposit, which only exists if the action is allowed. If successful, this changes the state to `submitted`.    The `apiture:target` link is required to be a valid account resource uri, which will be used to deposit the checks into.  A check deposit can only be submitted to a single target account.
     * @summary Submit a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitCheckDeposit(query?: { depositId?: string }, options: any = {}): RequestArgs {
      const { depositId } = query;

      const localVarPath = `/submittedCheckDeposits`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (depositId !== undefined) {
        localVarQueryParameter['depositId'] = depositId;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * CheckDepositApi - functional programming interface
 * @export
 */
export const CheckDepositApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new check deposit to add checks and submit a deposit. A check deposit must be used to submit a deposit, individual check resources can't be submitted.  The `apiture:target` link can be used to specify the account resource the check deposit will be deposited to. This value is not required when creating a check deposit, but is required to submit it.  The user can provide an optional `enteredAmount` when creating a check deposit. This is the expected total batch amount of all checks, and can be used as verification against the check amounts later scanned by OCR (optical character recognition).  Device data may be provided to identify the client device and aid the deposit verification process. It is recommended to provide as much device data as possible.  After creating a check deposit, use the `createCheck` operation (the `apiture:createCheck` link) to add checks to it, then use the `processCheckDeposit` operation (the `apiture:process` link) to process the checks to verify the check contents. If all the checks are valid, follow that with the `submitCheckDeposit` (the `apiture:process` link) operation to submit the valid checks for deposit.
     * @summary Create a new check deposit
     * @param {CreateCheckDeposit} CreateCheckDeposit The data necessary to create a new check deposit.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckDeposit(
      CreateCheckDeposit: CreateCheckDeposit,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposit> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).createCheckDeposit(
        CreateCheckDeposit ? CreateCheckDeposit : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this check deposit resource and any resources that are owned by it. This operation will also delete any checks included in the check deposit. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Delete this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheckDeposit(
      depositId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).deleteCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a HAL representation of this check deposit resource.
     * @summary Fetch a check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposit(
      depositId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposit> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).getCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of check deposits. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of check deposits
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first check deposit item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of check deposit representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections'} [query.state] Subset of the check deposit collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;pending|submitted&#x60; matches items whose &#x60;state&#x60; is &#x60;pending&#x60; or &#x60;submitted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposits(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections';
        filter?: string;
        q?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposits> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).getCheckDeposits(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Modify this check deposit. The `apiture:target` link, `description`, and `enteredAmount` are the only editable fields. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Modify this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheckDeposit(
      depositId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposit> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).patchCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Process all checks in a check deposit which have state `pending`.  This operation is invoked from the `apiture:process` link on a check deposit. All checks with `pending` state on the check deposit will be processed asyncronously. Checks which are currently being processed or have finished processing with state `valid` or `invalid` will be ignored.  If any checks have not been processed yet, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If all checks have finished processing, the operations returns 200 OK and the response body is the updated check deposit resource.
     * @summary Process checks in a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheckDeposit(
      query?: { depositId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposit> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).processCheckDeposit(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Submit a check deposit that is eligible to be submitted. This operation is invoked from the `apiture:submit` link on a check deposit, which only exists if the action is allowed. If successful, this changes the state to `submitted`.    The `apiture:target` link is required to be a valid account resource uri, which will be used to deposit the checks into.  A check deposit can only be submitted to a single target account.
     * @summary Submit a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitCheckDeposit(
      query?: { depositId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDeposit> {
      const localVarAxiosArgs = CheckDepositApiAxiosParamCreator(configuration).submitCheckDeposit(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * CheckDepositApi - factory interface
 * @export
 */
export const CheckDepositApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new check deposit to add checks and submit a deposit. A check deposit must be used to submit a deposit, individual check resources can't be submitted.  The `apiture:target` link can be used to specify the account resource the check deposit will be deposited to. This value is not required when creating a check deposit, but is required to submit it.  The user can provide an optional `enteredAmount` when creating a check deposit. This is the expected total batch amount of all checks, and can be used as verification against the check amounts later scanned by OCR (optical character recognition).  Device data may be provided to identify the client device and aid the deposit verification process. It is recommended to provide as much device data as possible.  After creating a check deposit, use the `createCheck` operation (the `apiture:createCheck` link) to add checks to it, then use the `processCheckDeposit` operation (the `apiture:process` link) to process the checks to verify the check contents. If all the checks are valid, follow that with the `submitCheckDeposit` (the `apiture:process` link) operation to submit the valid checks for deposit.
     * @summary Create a new check deposit
     * @param {CreateCheckDeposit} CreateCheckDeposit The data necessary to create a new check deposit.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCheckDeposit(CreateCheckDeposit: CreateCheckDeposit, options?: any) {
      return CheckDepositApiFp(configuration).createCheckDeposit(
        CreateCheckDeposit ? CreateCheckDeposit : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this check deposit resource and any resources that are owned by it. This operation will also delete any checks included in the check deposit. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Delete this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteCheckDeposit(depositId: string, headers?: { If_Match?: string }, options?: any) {
      return CheckDepositApiFp(configuration).deleteCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a HAL representation of this check deposit resource.
     * @summary Fetch a check deposit
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposit(depositId: string, headers?: { If_None_Match?: string }, options?: any) {
      return CheckDepositApiFp(configuration).getCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of check deposits. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of check deposits
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first check deposit item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of check deposit representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections'} [query.state] Subset of the check deposit collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;pending|submitted&#x60; matches items whose &#x60;state&#x60; is &#x60;pending&#x60; or &#x60;submitted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getCheckDeposits(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections';
        filter?: string;
        q?: string;
      },
      options?: any,
    ) {
      return CheckDepositApiFp(configuration).getCheckDeposits(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Modify this check deposit. The `apiture:target` link, `description`, and `enteredAmount` are the only editable fields. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
     * @summary Modify this check deposit resource
     * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchCheckDeposit(depositId: string, headers?: { If_Match?: string }, options?: any) {
      return CheckDepositApiFp(configuration).patchCheckDeposit(
        depositId ? depositId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Process all checks in a check deposit which have state `pending`.  This operation is invoked from the `apiture:process` link on a check deposit. All checks with `pending` state on the check deposit will be processed asyncronously. Checks which are currently being processed or have finished processing with state `valid` or `invalid` will be ignored.  If any checks have not been processed yet, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If all checks have finished processing, the operations returns 200 OK and the response body is the updated check deposit resource.
     * @summary Process checks in a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    processCheckDeposit(query?: { depositId?: string }, options?: any) {
      return CheckDepositApiFp(configuration).processCheckDeposit(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Submit a check deposit that is eligible to be submitted. This operation is invoked from the `apiture:submit` link on a check deposit, which only exists if the action is allowed. If successful, this changes the state to `submitted`.    The `apiture:target` link is required to be a valid account resource uri, which will be used to deposit the checks into.  A check deposit can only be submitted to a single target account.
     * @summary Submit a check deposit
     * @param {Object} [query] Query object
     * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    submitCheckDeposit(query?: { depositId?: string }, options?: any) {
      return CheckDepositApiFp(configuration).submitCheckDeposit(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * CheckDepositApi - object-oriented interface
 * @export
 * @class CheckDepositApi
 * @extends {BaseAPI}
 */
export class CheckDepositApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new check deposit to add checks and submit a deposit. A check deposit must be used to submit a deposit, individual check resources can't be submitted.  The `apiture:target` link can be used to specify the account resource the check deposit will be deposited to. This value is not required when creating a check deposit, but is required to submit it.  The user can provide an optional `enteredAmount` when creating a check deposit. This is the expected total batch amount of all checks, and can be used as verification against the check amounts later scanned by OCR (optical character recognition).  Device data may be provided to identify the client device and aid the deposit verification process. It is recommended to provide as much device data as possible.  After creating a check deposit, use the `createCheck` operation (the `apiture:createCheck` link) to add checks to it, then use the `processCheckDeposit` operation (the `apiture:process` link) to process the checks to verify the check contents. If all the checks are valid, follow that with the `submitCheckDeposit` (the `apiture:process` link) operation to submit the valid checks for deposit.
   * @summary Create a new check deposit
   * @param {CreateCheckDeposit} CreateCheckDeposit The data necessary to create a new check deposit.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposit}
   * @memberof CheckDepositApi
   */
  public createCheckDeposit(CreateCheckDeposit: CreateCheckDeposit, options?: any) {
    return CheckDepositApiFp(this.configuration).createCheckDeposit(
      CreateCheckDeposit ? CreateCheckDeposit : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this check deposit resource and any resources that are owned by it. This operation will also delete any checks included in the check deposit. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
   * @summary Delete this check deposit resource
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof CheckDepositApi
   */
  public deleteCheckDeposit(depositId: string, headers?: { If_Match?: string }, options?: any) {
    return CheckDepositApiFp(this.configuration).deleteCheckDeposit(
      depositId ? depositId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a HAL representation of this check deposit resource.
   * @summary Fetch a check deposit
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposit}
   * @memberof CheckDepositApi
   */
  public getCheckDeposit(depositId: string, headers?: { If_None_Match?: string }, options?: any) {
    return CheckDepositApiFp(this.configuration).getCheckDeposit(
      depositId ? depositId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of check deposits. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of check deposits
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first check deposit item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of check deposit representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections'} [query.state] Subset of the check deposit collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;pending|submitted&#x60; matches items whose &#x60;state&#x60; is &#x60;pending&#x60; or &#x60;submitted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposits}
   * @memberof CheckDepositApi
   */
  public getCheckDeposits(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      state?: 'pending' | 'submitted' | 'accepted' | 'rejected' | 'acceptedWithRejections';
      filter?: string;
      q?: string;
    },
    options?: any,
  ) {
    return CheckDepositApiFp(this.configuration).getCheckDeposits(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Modify this check deposit. The `apiture:target` link, `description`, and `enteredAmount` are the only editable fields. The check deposit must have state `pending`, `processing`, `valid`, or `invalid`.
   * @summary Modify this check deposit resource
   * @param {string} depositId The unique identifier of this deposit. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposit}
   * @memberof CheckDepositApi
   */
  public patchCheckDeposit(depositId: string, headers?: { If_Match?: string }, options?: any) {
    return CheckDepositApiFp(this.configuration).patchCheckDeposit(
      depositId ? depositId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Process all checks in a check deposit which have state `pending`.  This operation is invoked from the `apiture:process` link on a check deposit. All checks with `pending` state on the check deposit will be processed asyncronously. Checks which are currently being processed or have finished processing with state `valid` or `invalid` will be ignored.  If any checks have not been processed yet, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds. If all checks have finished processing, the operations returns 200 OK and the response body is the updated check deposit resource.
   * @summary Process checks in a check deposit
   * @param {Object} [query] Query object
   * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposit}
   * @memberof CheckDepositApi
   */
  public processCheckDeposit(query?: { depositId?: string }, options?: any) {
    return CheckDepositApiFp(this.configuration).processCheckDeposit(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Submit a check deposit that is eligible to be submitted. This operation is invoked from the `apiture:submit` link on a check deposit, which only exists if the action is allowed. If successful, this changes the state to `submitted`.    The `apiture:target` link is required to be a valid account resource uri, which will be used to deposit the checks into.  A check deposit can only be submitted to a single target account.
   * @summary Submit a check deposit
   * @param {Object} [query] Query object
   * @param {string} [query.depositId] The unique identifier of this deposit. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDeposit}
   * @memberof CheckDepositApi
   */
  public submitCheckDeposit(query?: { depositId?: string }, options?: any) {
    return CheckDepositApiFp(this.configuration).submitCheckDeposit(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * LimitsApi - axios parameter creator
 * @export
 */
export const LimitsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return the mobile check deposit limits. The response shows the check deposit limits and amounts for the previous 30 days.
     * @summary Return the mobile check deposit limits
     * @param {Object} [query] Query object
     * @param {string} [query.account] Return check deposit limits for the named account. This is the &#x60;_id&#x60; of the account resource. If omitted, the response contains only user limits.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLimits(query?: { account?: string }, options: any = {}): RequestArgs {
      const { account } = query;

      const localVarPath = `/limits`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * LimitsApi - functional programming interface
 * @export
 */
export const LimitsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return the mobile check deposit limits. The response shows the check deposit limits and amounts for the previous 30 days.
     * @summary Return the mobile check deposit limits
     * @param {Object} [query] Query object
     * @param {string} [query.account] Return check deposit limits for the named account. This is the &#x60;_id&#x60; of the account resource. If omitted, the response contains only user limits.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLimits(
      query?: { account?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CheckDepositLimits> {
      const localVarAxiosArgs = LimitsApiAxiosParamCreator(configuration).getLimits(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * LimitsApi - factory interface
 * @export
 */
export const LimitsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return the mobile check deposit limits. The response shows the check deposit limits and amounts for the previous 30 days.
     * @summary Return the mobile check deposit limits
     * @param {Object} [query] Query object
     * @param {string} [query.account] Return check deposit limits for the named account. This is the &#x60;_id&#x60; of the account resource. If omitted, the response contains only user limits.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLimits(query?: { account?: string }, options?: any) {
      return LimitsApiFp(configuration).getLimits(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * LimitsApi - object-oriented interface
 * @export
 * @class LimitsApi
 * @extends {BaseAPI}
 */
export class LimitsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return the mobile check deposit limits. The response shows the check deposit limits and amounts for the previous 30 days.
   * @summary Return the mobile check deposit limits
   * @param {Object} [query] Query object
   * @param {string} [query.account] Return check deposit limits for the named account. This is the &#x60;_id&#x60; of the account resource. If omitted, the response contains only user limits.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CheckDepositLimits}
   * @memberof LimitsApi
   */
  public getLimits(query?: { account?: string }, options?: any) {
    return LimitsApiFp(this.configuration).getLimits(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}
