# @apiture/client-organizations-client-sdk@0.13.2
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/client-organizations-client-sdk@0.13.2 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, PartnerOrganizationApi } from "@apiture/client-organizations-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate PartnerOrganizationApi main class passing the configuration object.
    const partnerOrganizationApi = new PartnerOrganizationApi(configuration);


// Use the methods to call the apis ( Refer to the Partner Organizations SDK Classes and Methods list ).
  partnerOrganization.getOrganizations().then( response => {
    const getorganizationsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate PartnerOrganizationApi main class.
    const partnerOrganizationApi = new PartnerOrganizationApi();


// Update the accessToken using the class method `setAccessToken`.
    partnerOrganizationApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    partnerOrganizationApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    partnerOrganizationApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Organizations } from "@apiture/client-organizations-client-sdk";

  const stronglyTypedObject :Organizations = { ... };

  // ______ Scoped import

  import * as Partner OrganizationsTypes from "@apiture/client-organizations-client-sdk";

  const stronglyTypedObject :Partner OrganizationsTypes.Organizations = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/partners",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Partner Organizations SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document

  `APIApi.getLabels` - Localized Labels



### PartnerOrganizationApi


  `PartnerOrganizationApi.activateOrganization` - Activate a partner organization.

  `PartnerOrganizationApi.createOrganization` - Create a new organization

  `PartnerOrganizationApi.deactivateOrganization` - Deactivate a partner organization.

  `PartnerOrganizationApi.deleteOrganization` - Delete this organization resource

  `PartnerOrganizationApi.getOrganization` - Fetch a representation of this organization

  `PartnerOrganizationApi.getOrganizations` - Return a collection of organizations

  `PartnerOrganizationApi.inviteMembers` - Invite new members

  `PartnerOrganizationApi.patchOrganization` - Update this organization

  `PartnerOrganizationApi.removeOrganization` - Remove a partner organization.

  `PartnerOrganizationApi.updateOrganization` - Update this organization

  `PartnerOrganizationApi.validatePartnerDomain` - Validate a partner domain name



## About the Partner Organizations API
___
Client and partner organizations (businesses, financial institutions etc.) which register on the Apiture Developer portal for API keys.
