// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Partner Organizations
 * Client and partner organizations (businesses, financial institutions etc.) which register on the Apiture Developer portal for API keys.
 *
 * OpenAPI spec version: 0.13.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/partners'.replace(/\/+$/, '');

export const API_VERSION = '0.13.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The type of this address.
   * @type {AddressType}
   * @memberof Address
   */
  type: AddressType;
  /**
   * A text label, suitable for presentation to the end user. This is derived from `type` or from `otherType` if `type` is `other`
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The actual address type if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  otherType?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
  /**
   * An identifier for this address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all addresses within the `addresses` array.
   * @type {string}
   * @memberof Address
   */
  _id?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Representation used to create an invitation to join a partner organization.
 * @export
 * @interface CreateInvitation
 */
export interface CreateInvitation extends AbstractRequest, InvitationFields {}

/**
 * Representation used to create a new organization.
 * @export
 * @interface CreateOrganization
 */
export interface CreateOrganization extends AbstractResource, OrganizationFields {
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof CreateOrganization
   */
  attributes?: any;
}

/**
 * A collection of resources, or a page from a larger collection. This is an abstract model schema which is extended to define specific resource collections. Pages are referenced using an opaque string starting point named `start`. The `_links` in the collection may contain [pagination links](https://developer.apiture.com/docs/concepts/pagination):    * the `next` link returns the next page of items. If there is no `next`   link, the collection has been exhausted.   * the `first` link returns to the beginning   of the filtered/sorted collection.   * the `collection` link returns   to the beginning of the default collection with no explicit filter   or sort criteria.  Cursor paged collections can only paginate forwards contiguously (without skipping items or pages), or reset to the beginning of the collection. This pagination works for collections which are likely to change during pagination, such as adding data to the beginning of the collection's natural sort order. Examples include transactions or audit records.
 * @export
 * @interface CursorPagedCollection
 */
export interface CursorPagedCollection extends AbstractResource {
  /**
   * An opaque marker representing the position of the current page in this resource collection. The service will use the `start` and `limit` to compute the `?start=` query parameter for the next page when it provides the `next` link in the collection's `_links`.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  start?: string;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof CursorPagedCollection
   */
  limit?: number;
  /**
   * A name for the items in collection.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  name?: string;
}

/**
 * The response from validating a partner domain.
 * @export
 * @interface DomainValidation
 */
export interface DomainValidation extends AbstractResource {
  /**
   * `true` if the domain is valid, `false` if not. If `false`, consult the `_error` object.
   * @type {boolean}
   * @memberof DomainValidation
   */
  valid?: boolean;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Partner Organization member invitation.
 * @export
 * @interface Invitation
 */
export interface Invitation extends AbstractResource, InvitationFields {}

/**
 * Fields of a member invitation. This is fragment schema, used to construct other schemas
 * @export
 * @interface InvitationFields
 */
export interface InvitationFields {
  /**
   * An invitation message from the inviter to includ in the invitation email. The message is Markdown which can be formatted with rich text.
   * @type {string}
   * @memberof InvitationFields
   */
  message?: string;
  /**
   * The list of invitees.
   * @type {Array<Invitee>}
   * @memberof InvitationFields
   */
  invitees?: Array<Invitee>;
}

/**
 * Representation of new partner organization member invitee.
 * @export
 * @interface Invitee
 */
export interface Invitee {
  /**
   * The first name of the invitee.
   * @type {string}
   * @memberof Invitee
   */
  firstName: string;
  /**
   * The last name of the invitee.
   * @type {string}
   * @memberof Invitee
   */
  lastName: string;
  /**
   * The email address of the invitee.
   * @type {string}
   * @memberof Invitee
   */
  emailAddress: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A localized label and optional description for localizable content defined in this API. This schema is deprecated; use [`labelItem`](#schema-labelitem) instead.
 * @export
 * @interface LocalizedLabel
 */
export interface LocalizedLabel {
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  label?: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof LocalizedLabel
   */
  description?: string;
  /**
   * The actual natural language tag to which this localized label is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1)
   * @type {string}
   * @memberof LocalizedLabel
   */
  language?: string;
  /**
   * If the localized value is associated with an external standard, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  code?: string;
}

/**
 * A map that defines lables for an enumeration or other item in a JSON schema. This is a map which maps enumeration schema names to an `localizedLabel` object. This schema is deprecated. Use [`labelGroups`](#schema-labelgroups)` instead.
 * @export
 * @interface LocalizedLabels
 */
export interface LocalizedLabels {
  [key: string]: LocalizedLabel;
}

/**
 * Representation of content and descriptive data (mailing addresses, phone numbers, email addresses) for a partner organization. a partner organization may have the following links in the `_links` object:   * **`apiture:activate`** - Activate a new, pending organization.   * **`apiture:deactivate`** - Deactivate a partner organization (if it   is active).   * **`apiture:remove`** - Remove an inactive organization.
 * @export
 * @interface Organization
 */
export interface Organization extends SummaryOrganization {
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof Organization
   */
  attributes?: any;
  /**
   * The date-time when the organization was created.
   * @type {Date}
   * @memberof Organization
   */
  createdAt?: Date;
  /**
   * The date-time when the organization was updated
   * @type {Date}
   * @memberof Organization
   */
  updatedAt?: Date;
}

/**
 * Representation of an organization's address resource.
 * @export
 * @interface OrganizationAddress
 */
export interface OrganizationAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof OrganizationAddress
   */
  state?: ProfileItemState;
}

/**
 * Representation of email address resources. An email address is immutable, although organizations can add new email addresses.
 * @export
 * @interface OrganizationEmailAddress
 */
export interface OrganizationEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof OrganizationEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * Common fields of the organization resource used to build other model schemas.
 * @export
 * @interface OrganizationFields
 */
export interface OrganizationFields extends SimpleOrganization {
  /**
   *
   * @type {OrganizationState}
   * @memberof OrganizationFields
   */
  state?: OrganizationState;
  /**
   * The organization's home page.
   * @type {string}
   * @memberof OrganizationFields
   */
  homeUrl?: string;
}

/**
 * The type and value of the organizations unique identification numbers.
 * @export
 * @interface OrganizationIdentification
 */
export interface OrganizationIdentification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof OrganizationIdentification
   */
  value: string;
  /**
   * The type of this form of identification. `taxId` is the only supported type at this time.
   * @type {OrganizationIdentificationType}
   * @memberof OrganizationIdentification
   */
  type: OrganizationIdentificationType;
  /**
   * The date when this form of identification expires.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiresOn?: string;
  /**
   * The date when this form of identification expires. **Note** This property is deprecated; use `expiresOn`.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiration?: string;
}

/**
 * The type of the form of an organization's identification. `taxId` is the only supported type at this time.
 * @export
 * @enum {string}
 */
export enum OrganizationIdentificationType {
  TaxId = 'taxId',
  DunsNumber = 'dunsNumber',
}

/**
 * Representation of phone number resources.
 * @export
 * @interface OrganizationPhoneNumber
 */
export interface OrganizationPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof OrganizationPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * The state of this partner organization.
 * @export
 * @enum {string}
 */
export enum OrganizationState {
  Pending = 'pending',
  Inactive = 'inactive',
  Active = 'active',
  Removed = 'removed',
}

/**
 * Collection of organizations. The items in the collection are ordered in the `_embedded.items` array; the `name` is `organizations`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Organizations
 */
export interface Organizations extends CursorPagedCollection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Organizations
   */
  _embedded?: any;
}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * The state of an item (address, email address, or phone number) within the organization's profile. New addresses, email addresses, or phone numbers start with the state `pending`, which means approval by the financial institution is pending. After they have been verified, the state becomes `approved`. Some normalizing or sanitizing of the value may occur when this happens (for example, a ZIP code may change to ZIP+4 format). `pending` items may not be assigned as the preferred item.
 * @export
 * @enum {string}
 */
export enum ProfileItemState {
  Pending = 'pending',
  Approved = 'approved',
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * The simplest form of an organization.
 * @export
 * @interface SimpleOrganization
 */
export interface SimpleOrganization {
  /**
   * The organization's official full name
   * @type {string}
   * @memberof SimpleOrganization
   */
  name?: string;
  /**
   * The organization's common name.
   * @type {string}
   * @memberof SimpleOrganization
   */
  label?: string;
  /**
   * Indicates what type of organization this resource represents.   The enumeration values are described by the `organizationType` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  type?: string;
  /**
   * A refinement of the `type`.   The enumeration values are described by the `organizationSubtype` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  subtype?: string;
  /**
   * A collection of official identifying information associated with the organization. This currently only supports government tax ID.
   * @type {Array<OrganizationIdentification>}
   * @memberof SimpleOrganization
   */
  identification?: Array<OrganizationIdentification>;
  /**
   * An array containing address items.
   * @type {Array<OrganizationAddress>}
   * @memberof SimpleOrganization
   */
  addresses?: Array<OrganizationAddress>;
  /**
   * An array of phone numbers associated with the organization. The first item, if present, is the default (preferred) organization phone number.
   * @type {Array<OrganizationPhoneNumber>}
   * @memberof SimpleOrganization
   */
  phones?: Array<OrganizationPhoneNumber>;
  /**
   * An array of email addresses associated with the organization. The first item, if present, is the default (preferred) organization email.
   * @type {Array<OrganizationEmailAddress>}
   * @memberof SimpleOrganization
   */
  emailAddresses?: Array<OrganizationEmailAddress>;
  /**
   * The ID of the organization's preferred email address. This string is the `_id` of an email address in the `emailAddresses` array. This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredEmailAddressId?: string;
  /**
   * The ID of organization's preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredPhoneId?: string;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredMailingAddressId?: string;
  /**
   * The date the organization was established.
   * @type {string}
   * @memberof SimpleOrganization
   */
  establishedDate?: string;
}

/**
 * Summary representation of a partner organization resource in organizations collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryOrganization
 */
export interface SummaryOrganization extends AbstractResource, OrganizationFields {
  /**
   * This partner organization's internet domain name. This is derived from the domain name of email address of the first user that registers with the organizations email domain. The dev portal adds other user's to the partner organization that matches their verified email address domain.
   * @type {string}
   * @memberof SummaryOrganization
   */
  domain?: string;
}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.  The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.  The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: LocalizedLabel }> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.  The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.  The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LocalizedLabel}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * PartnerOrganizationApi - axios parameter creator
 * @export
 */
export const PartnerOrganizationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a partner organization from an inactive state. <p> This operation is invoked from the `apiture:activate` link on an organization resource when that partner resource is eligible to be activated. <p> This changes the `state` to `active`.
     * @summary Activate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling activateOrganization.',
        );
      }
      const localVarPath = `/activeOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(CreateOrganization: CreateOrganization, options: any = {}): RequestArgs {
      // verify required parameter 'CreateOrganization' is not null or undefined
      if (CreateOrganization === null || CreateOrganization === undefined) {
        throw new RequiredError(
          'CreateOrganization',
          'Required parameter CreateOrganization was null or undefined when calling createOrganization.',
        );
      }
      const localVarPath = `/organizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateOrganization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateOrganization || {})
        : CreateOrganization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate a partner organization from an active state. <p> This operation is invoked from the `apiture:deactivate` link on an organization resource when that partner organization is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling deactivateOrganization.',
        );
      }
      const localVarPath = `/inactiveOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this organization resource. Most callers do not have delete access. (Admin users have delete access to all partner organizations.)
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling deleteOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [filterable](https://developer.apiture.com/docs/concepts/filtering) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The result is limited to partner organizations that the caller has access to (usually, their own partner organization) based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the result to match only partner organizations whose &#x60;domain&#x60; property matches this value. This is combined with the &#x60;filter&#x60; query, if any, via and implicit &#x60;and&#x60;. Note that for most users, the collection is already implicitly filtered to their organization.
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use | to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; will match only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; will match items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {Array<'pending' | 'active' | 'inactive' | 'removed'>} [query.state] Subset the resources to only those whose &#x60;state&#x60; matches the query, such as &#x60;?state&#x3D;active&#x60;. The value may be a &#x60;|&#x60; separated list of states, such as &#x60;?state&#x3D;pending|active&#x60; to match all resources whose &#x60;state&#x60; is either &#x60;pending&#x60; _or_ &#x60;active&#x60;. If &#x60;?filter&#x3D;&#x60; is also used, the two are combined with an implicit &#x60;and()&#x60; operation.
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use | to separate multiple values. For example, ?name&#x3D;Bartell will match only items whose name is Bartell; ?name&#x3D;Bartell|kirsten will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: string;
        limit?: number;
        filter?: string;
        domain?: string;
        type?: string;
        state?: Array<'pending' | 'active' | 'inactive' | 'removed'>;
        name?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, filter, domain, type, state, name } = query;

      const localVarPath = `/organizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (state) {
        localVarQueryParameter['state'] = state.join(COLLECTION_FORMATS['pipes']);
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Invite new members to this partner organization. This operation sends the invitees an invitation email. This API does not track which people it has sent invitations to; it unconditionally emails each invitee even if they have been invited in the past or are already registered. When the recipients register on the developer portal with an email address with the same partner `domain`, they are automatically added to the organization.  TODO: Provide API to remove members (i.e. if they leave the organization.)
     * @summary Invite new members
     * @param {CreateInvitation} CreateInvitation The data necessary to invite one or more new members.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    inviteMembers(
      CreateInvitation: CreateInvitation,
      organizationId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling inviteMembers.',
        );
      }
      // verify required parameter 'CreateInvitation' is not null or undefined
      if (CreateInvitation === null || CreateInvitation === undefined) {
        throw new RequiredError(
          'CreateInvitation',
          'Required parameter CreateInvitation was null or undefined when calling inviteMembers.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/memberInvitations`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateInvitation' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateInvitation || {})
        : CreateInvitation || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling patchOrganization.',
        );
      }
      // verify required parameter 'Organization' is not null or undefined
      if (Organization === null || Organization === undefined) {
        throw new RequiredError(
          'Organization',
          'Required parameter Organization was null or undefined when calling patchOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Organization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Organization || {})
        : Organization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove a partner organization by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a organization resource when that resource is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization). <p> This changes the `state` to `removed`.
     * @summary Remove a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling removeOrganization.',
        );
      }
      const localVarPath = `/removedOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this organization. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling updateOrganization.',
        );
      }
      // verify required parameter 'Organization' is not null or undefined
      if (Organization === null || Organization === undefined) {
        throw new RequiredError(
          'Organization',
          'Required parameter Organization was null or undefined when calling updateOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'admin/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Organization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Organization || {})
        : Organization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Check if a partner domain is valid. Some domains are not valid for use in the developer portal, such as those assocated with generic email services (`gmail.com`, `outlook.com`, `yahoo.com`, `aol.com`, and so on). The domain is passed as a query parameter. The 200 response is a JSON object, and the `_error` will be populated if the domain is not valid.
     * @summary Validate a partner domain name
     * @param {Object} [query] Query object
     * @param {string} [query.domain] A candidate partner domain, such as &#x60;example.com&#x60; or &#x60;apiture.com&#x60;. This is typically taked from the user&#39;s email address, following the &#x60;@&#x60; character.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    validatePartnerDomain(query?: { domain?: string }, options: any = {}): RequestArgs {
      const { domain } = query;

      // verify required parameter 'domain' is not null or undefined
      if (domain === null || domain === undefined) {
        throw new RequiredError(
          'domain',
          'Required parameter domain was null or undefined when calling validatePartnerDomain.',
        );
      }
      const localVarPath = `/domainValidations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PartnerOrganizationApi - functional programming interface
 * @export
 */
export const PartnerOrganizationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a partner organization from an inactive state. <p> This operation is invoked from the `apiture:activate` link on an organization resource when that partner resource is eligible to be activated. <p> This changes the `state` to `active`.
     * @summary Activate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).activateOrganization(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(
      CreateOrganization: CreateOrganization,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).createOrganization(
        CreateOrganization ? CreateOrganization : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate a partner organization from an active state. <p> This operation is invoked from the `apiture:deactivate` link on an organization resource when that partner organization is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).deactivateOrganization(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this organization resource. Most callers do not have delete access. (Admin users have delete access to all partner organizations.)
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).deleteOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).getOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [filterable](https://developer.apiture.com/docs/concepts/filtering) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The result is limited to partner organizations that the caller has access to (usually, their own partner organization) based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the result to match only partner organizations whose &#x60;domain&#x60; property matches this value. This is combined with the &#x60;filter&#x60; query, if any, via and implicit &#x60;and&#x60;. Note that for most users, the collection is already implicitly filtered to their organization.
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use | to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; will match only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; will match items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {Array<'pending' | 'active' | 'inactive' | 'removed'>} [query.state] Subset the resources to only those whose &#x60;state&#x60; matches the query, such as &#x60;?state&#x3D;active&#x60;. The value may be a &#x60;|&#x60; separated list of states, such as &#x60;?state&#x3D;pending|active&#x60; to match all resources whose &#x60;state&#x60; is either &#x60;pending&#x60; _or_ &#x60;active&#x60;. If &#x60;?filter&#x3D;&#x60; is also used, the two are combined with an implicit &#x60;and()&#x60; operation.
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use | to separate multiple values. For example, ?name&#x3D;Bartell will match only items whose name is Bartell; ?name&#x3D;Bartell|kirsten will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: string;
        limit?: number;
        filter?: string;
        domain?: string;
        type?: string;
        state?: Array<'pending' | 'active' | 'inactive' | 'removed'>;
        name?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organizations> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).getOrganizations(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Invite new members to this partner organization. This operation sends the invitees an invitation email. This API does not track which people it has sent invitations to; it unconditionally emails each invitee even if they have been invited in the past or are already registered. When the recipients register on the developer portal with an email address with the same partner `domain`, they are automatically added to the organization.  TODO: Provide API to remove members (i.e. if they leave the organization.)
     * @summary Invite new members
     * @param {CreateInvitation} CreateInvitation The data necessary to invite one or more new members.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    inviteMembers(
      CreateInvitation: CreateInvitation,
      organizationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).inviteMembers(
        CreateInvitation ? CreateInvitation : null,
        organizationId ? organizationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).patchOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove a partner organization by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a organization resource when that resource is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization). <p> This changes the `state` to `removed`.
     * @summary Remove a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).removeOrganization(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this organization. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).updateOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Check if a partner domain is valid. Some domains are not valid for use in the developer portal, such as those assocated with generic email services (`gmail.com`, `outlook.com`, `yahoo.com`, `aol.com`, and so on). The domain is passed as a query parameter. The 200 response is a JSON object, and the `_error` will be populated if the domain is not valid.
     * @summary Validate a partner domain name
     * @param {Object} [query] Query object
     * @param {string} [query.domain] A candidate partner domain, such as &#x60;example.com&#x60; or &#x60;apiture.com&#x60;. This is typically taked from the user&#39;s email address, following the &#x60;@&#x60; character.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    validatePartnerDomain(
      query?: { domain?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<DomainValidation> {
      const localVarAxiosArgs = PartnerOrganizationApiAxiosParamCreator(
        configuration,
      ).validatePartnerDomain(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PartnerOrganizationApi - factory interface
 * @export
 */
export const PartnerOrganizationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate a partner organization from an inactive state. <p> This operation is invoked from the `apiture:activate` link on an organization resource when that partner resource is eligible to be activated. <p> This changes the `state` to `active`.
     * @summary Activate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).activateOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(CreateOrganization: CreateOrganization, options?: any) {
      return PartnerOrganizationApiFp(configuration).createOrganization(
        CreateOrganization ? CreateOrganization : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate a partner organization from an active state. <p> This operation is invoked from the `apiture:deactivate` link on an organization resource when that partner organization is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).deactivateOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this organization resource. Most callers do not have delete access. (Admin users have delete access to all partner organizations.)
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(organizationId: string, headers?: { If_Match?: string }, options?: any) {
      return PartnerOrganizationApiFp(configuration).deleteOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(organizationId: string, headers?: { If_None_Match?: string }, options?: any) {
      return PartnerOrganizationApiFp(configuration).getOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [filterable](https://developer.apiture.com/docs/concepts/filtering) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The result is limited to partner organizations that the caller has access to (usually, their own partner organization) based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the result to match only partner organizations whose &#x60;domain&#x60; property matches this value. This is combined with the &#x60;filter&#x60; query, if any, via and implicit &#x60;and&#x60;. Note that for most users, the collection is already implicitly filtered to their organization.
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use | to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; will match only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; will match items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {Array<'pending' | 'active' | 'inactive' | 'removed'>} [query.state] Subset the resources to only those whose &#x60;state&#x60; matches the query, such as &#x60;?state&#x3D;active&#x60;. The value may be a &#x60;|&#x60; separated list of states, such as &#x60;?state&#x3D;pending|active&#x60; to match all resources whose &#x60;state&#x60; is either &#x60;pending&#x60; _or_ &#x60;active&#x60;. If &#x60;?filter&#x3D;&#x60; is also used, the two are combined with an implicit &#x60;and()&#x60; operation.
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use | to separate multiple values. For example, ?name&#x3D;Bartell will match only items whose name is Bartell; ?name&#x3D;Bartell|kirsten will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: string;
        limit?: number;
        filter?: string;
        domain?: string;
        type?: string;
        state?: Array<'pending' | 'active' | 'inactive' | 'removed'>;
        name?: string;
      },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).getOrganizations(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Invite new members to this partner organization. This operation sends the invitees an invitation email. This API does not track which people it has sent invitations to; it unconditionally emails each invitee even if they have been invited in the past or are already registered. When the recipients register on the developer portal with an email address with the same partner `domain`, they are automatically added to the organization.  TODO: Provide API to remove members (i.e. if they leave the organization.)
     * @summary Invite new members
     * @param {CreateInvitation} CreateInvitation The data necessary to invite one or more new members.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    inviteMembers(CreateInvitation: CreateInvitation, organizationId: string, options?: any) {
      return PartnerOrganizationApiFp(configuration).inviteMembers(
        CreateInvitation ? CreateInvitation : null,
        organizationId ? organizationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).patchOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove a partner organization by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a organization resource when that resource is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization). <p> This changes the `state` to `removed`.
     * @summary Remove a partner organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).removeOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this organization. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return PartnerOrganizationApiFp(configuration).updateOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Check if a partner domain is valid. Some domains are not valid for use in the developer portal, such as those assocated with generic email services (`gmail.com`, `outlook.com`, `yahoo.com`, `aol.com`, and so on). The domain is passed as a query parameter. The 200 response is a JSON object, and the `_error` will be populated if the domain is not valid.
     * @summary Validate a partner domain name
     * @param {Object} [query] Query object
     * @param {string} [query.domain] A candidate partner domain, such as &#x60;example.com&#x60; or &#x60;apiture.com&#x60;. This is typically taked from the user&#39;s email address, following the &#x60;@&#x60; character.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    validatePartnerDomain(query?: { domain?: string }, options?: any) {
      return PartnerOrganizationApiFp(configuration).validatePartnerDomain(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PartnerOrganizationApi - object-oriented interface
 * @export
 * @class PartnerOrganizationApi
 * @extends {BaseAPI}
 */
export class PartnerOrganizationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate a partner organization from an inactive state. <p> This operation is invoked from the `apiture:activate` link on an organization resource when that partner resource is eligible to be activated. <p> This changes the `state` to `active`.
   * @summary Activate a partner organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public activateOrganization(
    query?: { organization?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).activateOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new organization in the organizations collection.
   * @summary Create a new organization
   * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public createOrganization(CreateOrganization: CreateOrganization, options?: any) {
    return PartnerOrganizationApiFp(this.configuration).createOrganization(
      CreateOrganization ? CreateOrganization : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate a partner organization from an active state. <p> This operation is invoked from the `apiture:deactivate` link on an organization resource when that partner organization is eligible to be deactivated. <p> This changes the `state` to `inactive`.
   * @summary Deactivate a partner organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public deactivateOrganization(
    query?: { organization?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).deactivateOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this organization resource. Most callers do not have delete access. (Admin users have delete access to all partner organizations.)
   * @summary Delete this organization resource
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof PartnerOrganizationApi
   */
  public deleteOrganization(
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).deleteOrganization(
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
   * @summary Fetch a representation of this organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public getOrganization(
    organizationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).getOrganization(
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [filterable](https://developer.apiture.com/docs/concepts/filtering) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The result is limited to partner organizations that the caller has access to (usually, their own partner organization) based on their email address domain. (Admin users have access to all partner organizations.)
   * @summary Return a collection of organizations
   * @param {Object} [query] Query object
   * @param {string} [query.start] Represents the first record of the page of results. This is supplied by the service when paginating items: the &#x60;next&#x60; link includes a &#x60;?start&#x3D;&#x60; query parameter which refers to beginning of the next page of items.
   * @param {number} [query.limit] The maximum number of organization representations to return in this page.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.domain] Subset the result to match only partner organizations whose &#x60;domain&#x60; property matches this value. This is combined with the &#x60;filter&#x60; query, if any, via and implicit &#x60;and&#x60;. Note that for most users, the collection is already implicitly filtered to their organization.
   * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use | to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; will match only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; will match items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {Array<'pending' | 'active' | 'inactive' | 'removed'>} [query.state] Subset the resources to only those whose &#x60;state&#x60; matches the query, such as &#x60;?state&#x3D;active&#x60;. The value may be a &#x60;|&#x60; separated list of states, such as &#x60;?state&#x3D;pending|active&#x60; to match all resources whose &#x60;state&#x60; is either &#x60;pending&#x60; _or_ &#x60;active&#x60;. If &#x60;?filter&#x3D;&#x60; is also used, the two are combined with an implicit &#x60;and()&#x60; operation.
   * @param {string} [query.name] Subset the organizations collection to those with this name value. Use | to separate multiple values. For example, ?name&#x3D;Bartell will match only items whose name is Bartell; ?name&#x3D;Bartell|kirsten will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organizations}
   * @memberof PartnerOrganizationApi
   */
  public getOrganizations(
    query?: {
      start?: string;
      limit?: number;
      filter?: string;
      domain?: string;
      type?: string;
      state?: Array<'pending' | 'active' | 'inactive' | 'removed'>;
      name?: string;
    },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).getOrganizations(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Invite new members to this partner organization. This operation sends the invitees an invitation email. This API does not track which people it has sent invitations to; it unconditionally emails each invitee even if they have been invited in the past or are already registered. When the recipients register on the developer portal with an email address with the same partner `domain`, they are automatically added to the organization.  TODO: Provide API to remove members (i.e. if they leave the organization.)
   * @summary Invite new members
   * @param {CreateInvitation} CreateInvitation The data necessary to invite one or more new members.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof PartnerOrganizationApi
   */
  public inviteMembers(CreateInvitation: CreateInvitation, organizationId: string, options?: any) {
    return PartnerOrganizationApiFp(this.configuration).inviteMembers(
      CreateInvitation ? CreateInvitation : null,
      organizationId ? organizationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
   * @summary Update this organization
   * @param {Organization} Organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public patchOrganization(
    Organization: Organization,
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).patchOrganization(
      Organization ? Organization : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove a partner organization by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a organization resource when that resource is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization). <p> This changes the `state` to `removed`.
   * @summary Remove a partner organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or a organization URI.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public removeOrganization(
    query?: { organization?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).removeOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this organization. Most callers have access only to their own partner organization, based on their email address domain. (Admin users have access to all partner organizations.)
   * @summary Update this organization
   * @param {Organization} Organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PartnerOrganizationApi
   */
  public updateOrganization(
    Organization: Organization,
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return PartnerOrganizationApiFp(this.configuration).updateOrganization(
      Organization ? Organization : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Check if a partner domain is valid. Some domains are not valid for use in the developer portal, such as those assocated with generic email services (`gmail.com`, `outlook.com`, `yahoo.com`, `aol.com`, and so on). The domain is passed as a query parameter. The 200 response is a JSON object, and the `_error` will be populated if the domain is not valid.
   * @summary Validate a partner domain name
   * @param {Object} [query] Query object
   * @param {string} [query.domain] A candidate partner domain, such as &#x60;example.com&#x60; or &#x60;apiture.com&#x60;. This is typically taked from the user&#39;s email address, following the &#x60;@&#x60; character.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {DomainValidation}
   * @memberof PartnerOrganizationApi
   */
  public validatePartnerDomain(query?: { domain?: string }, options?: any) {
    return PartnerOrganizationApiFp(this.configuration).validatePartnerDomain(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
