# @apiture/common-client-sdk@1.15.4
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/common-client-sdk@1.15.4 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi } from "@apiture/common-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);


// Use the methods to call the apis ( Refer to the Common Apiture Models SDK Classes and Methods list ).
  aPI.getApi().then( response => {
    const getapiData = response.data;
    const headers = response.headers;
  });



// Use the methods to call the apis ( Refer to the Common Apiture Models SDK Classes and Methods list ).
  aPI.getApiDoc().then( response => {
    const getapidocData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate APIApi main class.
    const aPIApi = new APIApi();


// Update the accessToken using the class method `setAccessToken`.
    aPIApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    aPIApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    aPIApi.setApiKey(newApiKey);

// Instantiate APIApi main class.
    const aPIApi = new APIApi();


// Update the accessToken using the class method `setAccessToken`.
    aPIApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    aPIApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    aPIApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Root } from "@apiture/common-client-sdk";

  const stronglyTypedObject :Root = { ... };

  // ______ Scoped import

  import * as Common Apiture ModelsTypes from "@apiture/common-client-sdk";

  const stronglyTypedObject :Common Apiture ModelsTypes.Root = { ... };

  // ______ Individual Import

  import { any } from "@apiture/common-client-sdk";

  const stronglyTypedObject :any = { ... };

  // ______ Scoped import

  import * as Common Apiture ModelsTypes from "@apiture/common-client-sdk";

  const stronglyTypedObject :Common Apiture ModelsTypes.any = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/common",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Common Apiture Models SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



## About the Common Apiture Models API
___
This is a \"psuedo\" OpenAPI document which defines the core models used by Apiture APIs. This does not define an actual API, just the models and some test operations.
