// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Common Apiture Models
 * This is a \"psuedo\" OpenAPI document which defines the core models used by Apiture APIs. This does not define an actual API, just the models and some test operations.
 *
 * OpenAPI spec version: 1.15.4
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from "url";
import { SdkConfiguration } from "./configuration";
import globalAxios, { AxiosPromise, AxiosInstance } from "axios";

const BASE_PATH = "/common".replace(/\/+$/, "");

export const API_VERSION = "1.15.4";

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ",",
  ssv: " ",
  tsv: "\t",
  pipes: "|"
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || "";
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf("http://") < 0 && hostUrl.indexOf("https://") < 0) {
      parsedUrl = "https://" + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || "";
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === "string") {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(
        `Expected string value, received ${newToken}/${typeof newToken}`
      );
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === "string") {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(
        `Expected string value, received ${newKey}/${typeof newKey}`
      );
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === "string") {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(
        `Expected string value, received ${newHost}/${typeof newHost}`
      );
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: "RequiredError" = "RequiredError";
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * A collection of resources, or a page from a larger collection. This is an abstract model schema which is extended to define specific resource collections. Pages are referenced using an opaque string starting point named `start`. The `_links` in the collection may contain [pagination links](https://developer.apiture.com/docs/concepts/pagination):    * the `next` link returns the next page of items. If there is no `next`   link, the collection has been exhausted.   * the `first` link returns to the beginning   of the filtered/sorted collection.   * the `collection` link returns   to the beginning of the default collection with no explicit filter   or sort criteria.  Cursor paged collections can only paginate forwards contiguously (without skipping items or pages), or reset to the beginning of the collection. This pagination works for collections which are likely to change during pagination, such as adding data to the beginning of the collection's natural sort order. Examples include transactions or audit records.
 * @export
 * @interface CursorPagedCollection
 */
export interface CursorPagedCollection extends AbstractResource {
  /**
   * An opaque marker representing the position of the current page in this resource collection. The service will use the `start` and `limit` to compute the `?start=` query parameter for the next page when it provides the `next` link in the collection's `_links`.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  start?: string;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof CursorPagedCollection
   */
  limit?: number;
  /**
   * A name for the items in collection.
   * @type {string}
   * @memberof CursorPagedCollection
   */
  name?: string;
}

/**
 * A rotating public encryption key.
 * @export
 * @interface EncryptionKey
 */
export interface EncryptionKey {
  /**
   * An encryption key name identifies the type of data that the client wishes to encrypt, such as `pii` for personally identifying information, `secret` for passwords or other secret data. The type name is chosen by the client when requesting encryption keys.
   * @type {string}
   * @memberof EncryptionKey
   */
  name?: string;
  /**
   * The ASCII encoded public encryption key that the client uses to encrypt data. This is half of the asymmetric public/private key pair. This is a mult-line string with key bopokends and embedded line breaks.
   * @type {string}
   * @memberof EncryptionKey
   */
  publicKey?: string;
  /**
   * An alias or proxy for the actual rotating key. Keys rotate every few minutes. The alias identifies a specific active public/private key pair. This alias should be used in the `_encryption` metadata (see [`encryptionMetadata`](#schema-encryptionMetadata)). The value of the alias is the concatenation of the `name`, a dash `-`, and some additional characters which identify the specific key rotation.
   * @type {string}
   * @memberof EncryptionKey
   */
  alias?: string;
  /**
   * The date-time when the encryption key was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) date-time format.
   * @type {Date}
   * @memberof EncryptionKey
   */
  createdAt?: Date;
  /**
   * The date-time when the encryption key will expire. If this expiration time has passed or is less than 60 seconds away, the client should fetch updated encryption keys. [RFC 3339](https://tools.ietf.org/html/rfc3339) date-time format.
   * @type {Date}
   * @memberof EncryptionKey
   */
  expiresAt?: Date;
}

/**
 * A set of rotating public encryption keys that the client may use to encrypt sensitive or secret data before sending it to the service. The client only has access to the public key and only the service can decrypt the data. Such keys typically expire after several minutes.
 * @export
 * @interface EncryptionKeys
 */
export interface EncryptionKeys extends AbstractResource {
  /**
   * A map of encryption keys. The map's keys are the key `name`; the values are encryption key objects.
   * @type {{ [key: string]: EncryptionKey; }}
   * @memberof EncryptionKeys
   */
  keys?: { [key: string]: EncryptionKey };
}

/**
 * Metadata about encrypted data within a JSON object in a request body. This `_encryption` object is a peer of the encrypted data. Each nested object that contains encrypted properties has it's own `_encryption` object.   This object is a map of `string` &rarr; `string`. The keys are names of the encrypted property; each value is the `alias` of the rotating public encryption key that the client used to encrypt the named property. For example, for the original request body payload below, the client encrypts the `password` properties with the `secret` key and the `hint` properties with the `sensitive` key.  <code>{</code><br> <code>&nbsp;&nbsp;\"old\" : { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"noise-tube-branch-4183\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"bang nano twig ext\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-01-09T050:00.00Z\"</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp;&nbsp;\"new\" : { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"mile-leave-began-9315\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"1600 take-your \",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-03-09T08:00:00.000Z\"</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp; \"reason\" : \"I forgot my password\"</code><br> <code>}</code>  At the time of the encryption, the `secret` key has the alias `secret-48729783` and the `sensitive` key has the alias `sensitive-47839398`, so the `_encryption` metadata shows those aliases for the `password` and `hint` properties. Other data is not encrypted.  <code>{</code><br> <code>&nbsp;&nbsp;\"old\": { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"E389478492\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"E487903092478\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-01-09T050:00.00Z\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"_encryption\": {</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"password\" : \"secret-48729783\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"hint\" : \"sensitive-47839398\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;}</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp;&nbsp;\"new\": { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"E320480203\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"E489229004\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-03-09T08:00:00.000Z\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"_encryption\": {</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"password\" : \"secret-48729783\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"hint\" : \"sensitive-47839398\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;}</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;</code><br> <code>&nbsp;&nbsp;\"reason\" : \"I forgot my password\"</code><br> <code>}</code>  For brevity, the encrypted data is represented as `\"Ennnn\"` but in reality, encrypted data will be longer ASCII data.
 * @export
 * @interface EncryptionMetadata
 */
export interface EncryptionMetadata {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * A map that defines labels for the items in a group. This is a map from each item *name* &rarr; *a [`labelItem`](#schema-labelitem) object*. For example, consider a JSON response that includes a property named `revenueEstimate`; the values for `revenueEstimate` must be one of the items in the group named `estimatedAnnualRevenue`, with options ranging `under1Million`, to `over100Million`. The item name is used as the selected value in an Apiture representation, such as `{ ..., \"revenueEstimate\" : \"from10to100Million\" , ...}`, and the item with the name `from10to100Million` defines the presentation labels for that item, as well as other metadata about that choice: this is the range `[10000000.00,100000000.00)`.  This allows the client to let the user select a value from a list, such as the following derivde from the labels in the example:    * Unknown   * Under $1M   * $1M to $10M   * $10M to $100M   * $100M or more  Note that the `other` item is hidden from the selection list, as that item is marked as `hidden`. For items which define numeric ranges, a client may instead let the customer *directly* enter their estimated annual revenue as a number, such as 4,500,000.00. The client can then match that number to one of ranges in the items and set the `revenueEstimate` to the corresponding item's name: `{ ..., \"revenueEstimate\" : \"from1to10Million\", ... }`.
 * @export
 * @interface LabelGroup
 */
export interface LabelGroup {
  [key: string]: LabelItem;
}

/**
 * A set of named groups of labels, each of which contains multiple item labels.   The abbreviated example shows two groups, one named `structure` and one named `estimatedAnnualRevenue`. The first has items with names such as `corporation`, `llc` and `soleProprietorship`, with text labels for each in the default and in French. The second has items for estimated revenue *ranges* but no localized labels. For example, the item named `from1to10Million` has the `label` \"$1M to $10M\" and the range `[1000000.00,10000000.00)`.
 * @export
 * @interface LabelGroups
 */
export interface LabelGroups extends AbstractResource {
  /**
   * Groups of localized labels. This maps *group names* &rarr; [*a group of labels*](#schema-labelgroup) within that group.
   * @type {any}
   * @memberof LabelGroups
   */
  groups?: any;
}

/**
 * An item in a [`labelGroup`](#schema-labelgroup), with a set of `variants` which contains different localized labels for the item. Each ([`simpleLabel`](#schema-simpleLabel)) variant defines the presentation text label and optional description for a language. Items may also have a lookup `code` to map to external syststems, a numeric range, and a `hidden` boolean to indicate the item is normally hidden in the UI.
 * @export
 * @interface LabelItem
 */
export interface LabelItem extends SimpleLabel {
  /**
   * The language-specific variants of this label. The keys in this object are [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1) language codes.
   * @type {{ [key: string]: SimpleLabel; }}
   * @memberof LabelItem
   */
  variants?: { [key: string]: SimpleLabel };
  /**
   * If the localized value is associated with an external standard or definition, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LabelItem
   */
  code?: string;
  /**
   * If `true`, this item is normally hidden from the User Interface.
   * @type {boolean}
   * @memberof LabelItem
   */
  hidden?: boolean;
  /**
   * The range of values, if the item describes a bounded numeric value. This is range notation such as `[min,max]`, `(exclusiveMin,max]`, `[min,exclusiveMax)`, or `(exclusiveMin,exclusiveMax)`. For example, `[0,100)` is the range greater than or equal to 0 and less than 100. If the *min* or *max* value are omitted, that end of the range is unbounded. For example, `(,1000.00)` means less than 1000.00 and `[20000.00,]` means 20000.00 or more. The ranges do not overlap or have gaps.
   * @type {string}
   * @memberof LabelItem
   */
  range?: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A localized label and optional description for localizable content defined in this API. This schema is deprecated; use [`labelItem`](#schema-labelitem) instead.
 * @export
 * @interface LocalizedLabel
 */
export interface LocalizedLabel {
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  label?: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof LocalizedLabel
   */
  description?: string;
  /**
   * The actual natural language tag to which this localized label is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1)
   * @type {string}
   * @memberof LocalizedLabel
   */
  language?: string;
  /**
   * If the localized value is associated with an external standard, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  code?: string;
}

/**
 * A map that defines lables for an enumeration or other item in a JSON schema. This is a map which maps enumeration schema names to an `localizedLabel` object. This schema is deprecated. Use [`labelGroups`](#schema-labelgroups)` instead.
 * @export
 * @interface LocalizedLabels
 */
export interface LocalizedLabels {
  [key: string]: LocalizedLabel;
}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * A text label and optional description.
 * @export
 * @interface SimpleLabel
 */
export interface SimpleLabel {
  /**
   * A label or title which may be used as labels or other UI controls which present a value.
   * @type {string}
   * @memberof SimpleLabel
   */
  label: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof SimpleLabel
   */
  description?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(
  configuration?: SdkConfiguration
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign(
        { method: "GET" },
        baseOptions,
        options
      );
      const localVarHeaderParameter =
        baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign(
        {},
        localVarHeaderParameter,
        options.headers
      );

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign(
        { method: "GET" },
        baseOptions,
        options
      );
      const localVarHeaderParameter =
        baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign(
        {},
        localVarHeaderParameter,
        options.headers
      );

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions
      };
    }
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(
      options?: any
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {}
      );
      return (
        axios: AxiosInstance = globalAxios,
        basePath: string = BASE_PATH
      ) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(
      options?: any
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(
        configuration
      ).getApiDoc(options ? options : {});
      return (
        axios: AxiosInstance = globalAxios,
        basePath: string = BASE_PATH
      ) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url
        });
        return axios.request(axiosRequestArgs);
      };
    }
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(
        axios,
        basePath
      );
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(
        axios,
        basePath
      );
    }
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(
      this.axios,
      this.basePath
    );
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath
    );
  }
}
