# @apiture/configurations-client-sdk@0.6.4
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/configurations-client-sdk@0.6.4 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ConfigurationApi } from "@apiture/configurations-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);


// Use the methods to call the apis ( Refer to the Configuration SDK Classes and Methods list ).
  configuration.getConfigurationGroups().then( response => {
    const getconfigurationgroupsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ConfigurationApi main class.
    const configurationApi = new ConfigurationApi();


// Update the accessToken using the class method `setAccessToken`.
    configurationApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    configurationApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    configurationApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ConfigurationGroups } from "@apiture/configurations-client-sdk";

  const stronglyTypedObject :ConfigurationGroups = { ... };

  // ______ Scoped import

  import * as ConfigurationTypes from "@apiture/configurations-client-sdk";

  const stronglyTypedObject :ConfigurationTypes.ConfigurationGroups = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/configurations",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Configuration SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ConfigurationApi


  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



## About the Configuration API
___
The Configuration API manages the discovery and update of service configurations.
