# @apiture/consents-client-sdk@0.6.1
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/consents-client-sdk@0.6.1 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ConsentApi, ConsentTypeNameApi } from "@apiture/consents-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ConsentApi main class passing the configuration object.
    const consentApi = new ConsentApi(configuration);

// Instantiate ConsentTypeNameApi main class passing the configuration object.
    const consentTypeNameApi = new ConsentTypeNameApi(configuration);


// Use the methods to call the apis ( Refer to the Consents SDK Classes and Methods list ).
  consentTypeName.getConsentTypeNames().then( response => {
    const getconsenttypenamesData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ConsentTypeNameApi main class.
    const consentTypeNameApi = new ConsentTypeNameApi();


// Update the accessToken using the class method `setAccessToken`.
    consentTypeNameApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    consentTypeNameApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    consentTypeNameApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ConsentTypeNames } from "@apiture/consents-client-sdk";

  const stronglyTypedObject :ConsentTypeNames = { ... };

  // ______ Scoped import

  import * as ConsentsTypes from "@apiture/consents-client-sdk";

  const stronglyTypedObject :ConsentsTypes.ConsentTypeNames = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/consents",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Consents SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ConsentApi


  `ConsentApi.createConsent` - Create a new consent

  `ConsentApi.getConsent` - Fetch a representation of this consent

  `ConsentApi.getConsents` - Return a collection of consents

  `ConsentApi.getNeededConsents` - Get needed consents

  `ConsentApi.giveConsent` - Give a consent

  `ConsentApi.rescindConsents` - Rescind matching consents

  `ConsentApi.reviseDocument` - Mark a document as revised, rendering corresponding consents as stale

  `ConsentApi.revokeConsent` - Revoke a consent



### ConsentTypeNameApi


  `ConsentTypeNameApi.getConsentTypeNames` - Retrieve the set of consent type names

  `ConsentTypeNameApi.updateConsentTypeNames` - Replace the set of consent type names



## About the Consents API
___
The Consents API tracks a user's consent of financial institution policies and documents such as banking product terms and conditions, electronic consent, and privacy policy.  ## Target Documents  A consent resource holds the URI of a target document (typically, a PDF document). Each consent also has a `type`, such as `privacyPolicy` or `productTermsAndConditions` or `electronicConsent`, which indicates the target document's purpose and hence what kind of consent this is. The consent also holds the document's media type, specific document revision identification string, and the time stamp that the document was last revised (modified). If the document is later revised, any previously given consents for any revision of that document become `stale`; this indicates the user should review and consent to the _revised_ document.  ## Contexts  A consent may be associated with a _context_ in which an application or service is requesting the consent; the context is represented as the URI of some resource. For example, two different banking products (DDA1, DDA2) at a financial institution may share the same terms and conditions document, D0. If the user is opening an account of type DDA1, the client can create a consent for D0 using the product URI for DDA1 as the context. When the user opens a new account for product DDA2, the client can create a new consent for D0 using product DDA2's URI as the context. Because the contexts of the two consents are different, the two consents are independent of each other, indicating that the user must consent to the terms and conditions each time they open an account, even if they have consented to the same document earlier.   The context is optional. For example, for the financial institution's privacy policy, there is no specific context.  ## Life Cycle  When a banking application or service (the requester) wishes a user to agree to or consent to a document, it creates a new consent resource (`POST /consents`) to track the request and the user's response.   The user can consent to a document to indicate that they agree to the terms described in the document. This is typically done when the user checks an \"I agree\" checkbox or other user experience. To record the consent given by the user, the client application which serves as the controller issues a `POST` to the `apiture:give` link on a consent resource. This sets the `state` to `given` and records the date and time on the consent.   When a user gives consent to a document, _all_ consent resources which match the target document, context URI, and user ID are also marked as `given`, although the action can be scoped to just a specific instance.   A client can check for pending or stale consents for a user with the `GET /neededConsents` operation.   Consents are not directly mutable (the `PUT` and `PATCH` verbs are not supported), but other operations described below may update a consent resource to indicate a user has given or revoked consent, that a consent is stale, or that a requester has rescinded a request for consent.   If the user wishes to undo or _revoke_ a specific consent, the client application should `POST` to the `apiture:revoke` link on a consent resource (`/revokedConsents?consent={consentId}`) to reset the consent back to the `pending` state.   If the requester no longer requires the user's consent, it can rescind the request with `POST /rescindedConsents?type={type}?document={documentUri}?context={contextUri}?user=user` This sets the `state` to `rescinded` on the first matching consent. For example, if the user is removed as a joint owner of an account of type DDA2, rescinding the `productTermsAndConditions` consents will match and remove only the first matching consent for DDA2. (The user may be an owner of other accounts on product DDA2, and their consent must be tracked and possibly requested again if the terms and conditions for DDA2 change.)  ## Document revisions  If the document is revised (for example, the financial institution has updated their privacy policy), a client can mark a document as revised via `POST /revisedDocuments`. All consents associated with the older revisions of the document are marked `stale`. A _stale_ consent indicates that the user should consent to the revised document. The client applications should notify the user that the document has changed (such as via email or or via notification at their next login) and present the revised document to the user for them to accept.
