// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Consents
 * The Consents API tracks a user's consent of financial institution policies and documents such as banking product terms and conditions, electronic consent, and privacy policy.  ## Target Documents  A consent resource holds the URI of a target document (typically, a PDF document). Each consent also has a `type`, such as `privacyPolicy` or `productTermsAndConditions` or `electronicConsent`, which indicates the target document's purpose and hence what kind of consent this is. The consent also holds the document's media type, specific document revision identification string, and the time stamp that the document was last revised (modified). If the document is later revised, any previously given consents for any revision of that document become `stale`; this indicates the user should review and consent to the _revised_ document.  ## Contexts  A consent may be associated with a _context_ in which an application or service is requesting the consent; the context is represented as the URI of some resource. For example, two different banking products (DDA1, DDA2) at a financial institution may share the same terms and conditions document, D0. If the user is opening an account of type DDA1, the client can create a consent for D0 using the product URI for DDA1 as the context. When the user opens a new account for product DDA2, the client can create a new consent for D0 using product DDA2's URI as the context. Because the contexts of the two consents are different, the two consents are independent of each other, indicating that the user must consent to the terms and conditions each time they open an account, even if they have consented to the same document earlier.   The context is optional. For example, for the financial institution's privacy policy, there is no specific context.  ## Life Cycle  When a banking application or service (the requester) wishes a user to agree to or consent to a document, it creates a new consent resource (`POST /consents`) to track the request and the user's response.   The user can consent to a document to indicate that they agree to the terms described in the document. This is typically done when the user checks an \"I agree\" checkbox or other user experience. To record the consent given by the user, the client application which serves as the controller issues a `POST` to the `apiture:give` link on a consent resource. This sets the `state` to `given` and records the date and time on the consent.   When a user gives consent to a document, _all_ consent resources which match the target document, context URI, and user ID are also marked as `given`, although the action can be scoped to just a specific instance.   A client can check for pending or stale consents for a user with the `GET /neededConsents` operation.   Consents are not directly mutable (the `PUT` and `PATCH` verbs are not supported), but other operations described below may update a consent resource to indicate a user has given or revoked consent, that a consent is stale, or that a requester has rescinded a request for consent.   If the user wishes to undo or _revoke_ a specific consent, the client application should `POST` to the `apiture:revoke` link on a consent resource (`/revokedConsents?consent={consentId}`) to reset the consent back to the `pending` state.   If the requester no longer requires the user's consent, it can rescind the request with `POST /rescindedConsents?type={type}?document={documentUri}?context={contextUri}?user=user` This sets the `state` to `rescinded` on the first matching consent. For example, if the user is removed as a joint owner of an account of type DDA2, rescinding the `productTermsAndConditions` consents will match and remove only the first matching consent for DDA2. (The user may be an owner of other accounts on product DDA2, and their consent must be tracked and possibly requested again if the terms and conditions for DDA2 change.)  ## Document revisions  If the document is revised (for example, the financial institution has updated their privacy policy), a client can mark a document as revised via `POST /revisedDocuments`. All consents associated with the older revisions of the document are marked `stale`. A _stale_ consent indicates that the user should consent to the revised document. The client applications should notify the user that the document has changed (such as via email or or via notification at their next login) and present the revised document to the user for them to accept.
 *
 * OpenAPI spec version: 0.6.0
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/consents'.replace(/\/+$/, '');

export const API_VERSION = '0.6.0';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation of a consent resource. Users consent or acceptance of a policy or other document.
 * @export
 * @interface Consent
 */
export interface Consent extends SummaryConsent {}

/**
 * Common fields of the consent resource used to build other model schemas.
 * @export
 * @interface ConsentFields
 */
export interface ConsentFields {
  /**
   * Properties of the target document.
   * @type {Document}
   * @memberof ConsentFields
   */
  document?: Document;
  /**
   * Describe what kind of consent this is. This value must be one of the type names in the `/consentTypeNames` resource.
   * @type {string}
   * @memberof ConsentFields
   */
  type?: string;
  /**
   * The URI of a resource that establishes the context in which the user's consent is requested for a specific document. For example, for consent of an account's terms and conditions, the context might be the banking product for that account.
   * @type {string}
   * @memberof ConsentFields
   */
  contextUri?: string;
  /**
   * The user ID of the user who is requested to consent to a document. This is the `_id` of the User resource.
   * @type {string}
   * @memberof ConsentFields
   */
  userId?: string;
}

/**
 * The state of a consent resource.
 * @export
 * @enum {string}
 */
export enum ConsentStates {
  Pending = 'pending',
  Given = 'given',
  Stale = 'stale',
  Rescinded = 'rescinded',
  Revoked = 'revoked',
}

/**
 * A list of allowed consent type names and their labels and descriptions.
 * @export
 * @interface ConsentTypeNames
 */
export interface ConsentTypeNames extends AbstractResource {
  /**
   * An object which maps consent type names to their labels and descriptions.
   * @type {LocalizedLabels}
   * @memberof ConsentTypeNames
   */
  names?: LocalizedLabels;
}

/**
 * Collection of consents. The items in the collection are ordered in the `_embedded.items` array; the `name` is `consents`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Consents
 */
export interface Consents extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Consents
   */
  _embedded?: any;
}

/**
 * Representation used to create a new consent.
 * @export
 * @interface CreateConsent
 */
export interface CreateConsent extends ConsentFields, AbstractResource {}

/**
 * Properties of a target document.
 * @export
 * @interface Document
 */
export interface Document {
  /**
   * The URI of the target document that the user is consenting to. If the document is revised, this consent is marked as `stale`. (Note: This need not be a document in the Apiture vault.)
   * @type {string}
   * @memberof Document
   */
  uri: string;
  /**
   * The [media type](https://tools.ietf.org/html/rfc6838) for the document. For text documents, the content type should include the text encoding; if omitted, the encoding type is assumed to be utf-8.
   * @type {any}
   * @memberof Document
   */
  contentType: any;
  /**
   * The revision identifier of the document revision the user consented to. If the content management system in which the document is stored does not define revision identifiers or tags, this may be omitted and will default to the revision time stamp.
   * @type {string}
   * @memberof Document
   */
  revisionId?: string;
  /**
   * The time stamp when the target document was last revised (modified), in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Document
   */
  revisedAt: Date;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A localized label and optional description for localizable content defined in this API.
 * @export
 * @interface LocalizedLabel
 */
export interface LocalizedLabel {
  /**
   * A localized label or title which may be used to decorate UI controls which present a value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  label?: string;
  /**
   * A more detailed localized description of this label.
   * @type {string}
   * @memberof LocalizedLabel
   */
  description?: string;
  /**
   * The natural language tag to which this localized label is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1). If empty, this item serves as the _default_ label in case no label matches the caller's language.
   * @type {string}
   * @memberof LocalizedLabel
   */
  language?: string;
  /**
   * If the localized value is associated with an external standard, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  code?: string;
}

/**
 * An object that maps a name to an array of labels, descriptions and a language (locale) code for the label and description. The first item in the array should be the default label/description; the remaining items must have a `language`.
 * @export
 * @interface LocalizedLabels
 */
export interface LocalizedLabels {
  [key: string]: Array<LocalizedLabel>;
}

/**
 * Details about a target document that has been revised.
 * @export
 * @interface RevisedDocument
 */
export interface RevisedDocument extends Document, AbstractResource {
  /**
   * The URI of the revised target document, if the document has moved. All matching consents will have their `document.uri` updated to this new document URI.
   * @type {string}
   * @memberof RevisedDocument
   */
  newUri?: string;
  /**
   * The URI of a resource that establishes the context in which the user's consent is requested for a specific document. For example, for consent of an account's terms and conditions, the context might be the banking product for that account.
   * @type {string}
   * @memberof RevisedDocument
   */
  contextUri?: string;
  /**
   * Describe what kind of consent this is. This value must be one of the type names in the `/consentTypeNames` resource.
   * @type {string}
   * @memberof RevisedDocument
   */
  type?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of a consent resource in consents collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryConsent
 */
export interface SummaryConsent extends ConsentFields, AbstractResource {
  /**
   * The unique identifier for this consent resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryConsent
   */
  _id?: string;
  /**
   * The state of this consent.
   * @type {ConsentStates}
   * @memberof SummaryConsent
   */
  state?: ConsentStates;
  /**
   * The time stamp when the user last consented to the document, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). This property is not set if `state` is `pending`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  givenAt?: Date;
  /**
   * The time stamp when the user revoked consent, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). A revoked consent reflects a consent request that the user has previously given but has reversed. Revoking a consent sets the `state` back to `pending` and clears `consentedAt`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  requestRevokedAt?: Date;
  /**
   * The time stamp when the consent _request_ was rescinded by the requester, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). A rescinded consent reflects a consent request that the system or application has issued in the past but no longer requires. For example, if a user is removed as an authorized signer from an account and a consent is pending for that account's terms and conditions, the Accounts service may rescind that consent request. This property is set only if `state` is `rescinded`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  requestRescindedAt?: Date;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * ConsentApi - axios parameter creator
 * @export
 */
export const ConsentApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new consent resource.
     * @summary Create a new consent
     * @param {CreateConsent} CreateConsent The data necessary to create a new consent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createConsent(CreateConsent: CreateConsent, options: any = {}): RequestArgs {
      // verify required parameter 'CreateConsent' is not null or undefined
      if (CreateConsent === null || CreateConsent === undefined) {
        throw new RequiredError(
          'CreateConsent',
          'Required parameter CreateConsent was null or undefined when calling createConsent.',
        );
      }
      const localVarPath = `/consents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateConsent' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateConsent || {})
        : CreateConsent || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this consent resource.
     * @summary Fetch a representation of this consent
     * @param {string} consentId The unique identifier of this consent. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsent(
      consentId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'consentId' is not null or undefined
      if (consentId === null || consentId === undefined) {
        throw new RequiredError(
          'consentId',
          'Required parameter consentId was null or undefined when calling getConsent.',
        );
      }
      const localVarPath = `/consents/{consentId}`.replace(
        `{${'consentId'}}`,
        encodeURIComponent(String(consentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of consents. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Subset the response to those with this &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;termsAndCondition&#x60; matches only items whose &#x60;type&#x60; is &#x60;termsAndCondition&#x60; &#x60;?type&#x3D;privacyPolicy|electronicConsent&#x60; matches items whose type is &#x60;privacyPolicy&#x60; or &#x60;electronicConsent&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the response to those with this &#x60;state&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;given|stale&#x60; matches only items whose &#x60;state&#x60; is &#x60;given&#x60; or &#x60;stale&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.userId] Subset the response to those with this &#x60;userId&#x60; value. Use &#x60;|&#x60; to separate multiple values. This is for administrative use; bank users can only see their own consents.
     * @param {string} [query.contextUri] Subset the response to those with this &#x60;contextUri&#x60; value. Use &#x60;|&#x60; to separate multiple values.
     * @param {number} [query.start] The zero-based index of the first consent item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of consent representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsents(
      query?: {
        type?: string;
        state?: string;
        userId?: string;
        contextUri?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { type, state, userId, contextUri, start, limit, sortBy, filter, q } = query;

      const localVarPath = `/consents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (userId !== undefined) {
        localVarQueryParameter['userId'] = userId;
      }

      if (contextUri !== undefined) {
        localVarQueryParameter['contextUri'] = contextUri;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a list of needed consents (both `pending` and `stale` consents) for a user. If no consents exists for a user ID (including if the user ID is not found), the response is an empty collection.
     * @summary Get needed consents
     * @param {Object} [query] Query object
     * @param {string} [query.userId] The user ID of the user; This is the &#x60;_id&#x60; of the User resource. If omitted, the returned list is the needed consents for the currently authenticated user.
     * @param {boolean} [query.consolidate] If &#x60;true&#x60;, the response body will consolidate two or more duplicate consents that have the same &#x60;type&#x60; and &#x60;targetUri&#x60; such that the result contain only one of them. **Warning**: the client should **not** use &#x60;?matching&#x3D;false&#x60; when the user [gives consent](#op-giveConsent) to consents resources in the consolidated response.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getNeededConsents(
      query?: { userId?: string; consolidate?: boolean },
      options: any = {},
    ): RequestArgs {
      const { userId, consolidate } = query;

      const localVarPath = `/neededConsents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (userId !== undefined) {
        localVarQueryParameter['userId'] = userId;
      }

      if (consolidate !== undefined) {
        localVarQueryParameter['consolidate'] = consolidate;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Indicate that a user has given consent to a document. This marks the the given consent as `given`. If `scope` is matching, _all_ matching needed consents (`pending` or `stale` consents which have the same `type`, `document.uri` and `contextUri`) will also be marked as `given`. This operation may be invoked by using `POST` on the `apiture:giveConsent` link on a consent resource; there is no query parameter.
     * @summary Give a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {'instance' | 'matching'} [query.scope] The scope of the given consent. If &#x60;instance&#x60;, only the consent named in the &#x60;?consent&#x3D;&#x60; query parameter is marked as &#x60;given&#x60;. If &#x60;matching&#x60;, all needed consent matching the named in the &#x60;?consent&#x3D;&#x60; query parameter (&#x60;pending&#x60; or &#x60;stale&#x60; consents which have the same &#x60;type&#x60;, &#x60;document.uri&#x60; and &#x60;contextUri&#x60;) are marked as &#x60;given&#x60;. The default if omitted is &#x60;matching&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    giveConsent(
      query?: { consent?: string; scope?: 'instance' | 'matching' },
      options: any = {},
    ): RequestArgs {
      const { consent, scope } = query;

      // verify required parameter 'consent' is not null or undefined
      if (consent === null || consent === undefined) {
        throw new RequiredError(
          'consent',
          'Required parameter consent was null or undefined when calling giveConsent.',
        );
      }
      const localVarPath = `/givenConsents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (consent !== undefined) {
        localVarQueryParameter['consent'] = consent;
      }

      if (scope !== undefined) {
        localVarQueryParameter['scope'] = scope;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Rescind consent requests which match the specified consent type, context, and user. This action is typically performed by the financial institution to indicate that it no longer requires the user's consent. For example, a service may rescind a consent if a user is removed as an account owner or as an authorized signer, or when an account application expires. changes the `state` property of the matching consents to `rescinded`. The client must pass the `type`, `context`, and `user` in order to find matching consents; if the `document` is also specified, it must also match.  The response is the collection of updated consent resources. If no matching consents were found, the consents collection response will have an empty `items` array.
     * @summary Rescind matching consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Specify the consent &#x60;type&#x60; to rescind.
     * @param {string} [query.context] The URI of the consent context.
     * @param {string} [query.user] Rescind all matching consents for the user with this user ID.
     * @param {string} [query.document] The URI of the target document. This is not _required_ but if passed, the &#x60;document.uri&#x60; must match as well as the other required query parameters.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rescindConsents(
      query?: { type?: string; context?: string; user?: string; document?: string },
      options: any = {},
    ): RequestArgs {
      const { type, context, user, document } = query;

      // verify required parameter 'type' is not null or undefined
      if (type === null || type === undefined) {
        throw new RequiredError(
          'type',
          'Required parameter type was null or undefined when calling rescindConsents.',
        );
      }
      // verify required parameter 'context' is not null or undefined
      if (context === null || context === undefined) {
        throw new RequiredError(
          'context',
          'Required parameter context was null or undefined when calling rescindConsents.',
        );
      }
      // verify required parameter 'user' is not null or undefined
      if (user === null || user === undefined) {
        throw new RequiredError(
          'user',
          'Required parameter user was null or undefined when calling rescindConsents.',
        );
      }
      const localVarPath = `/rescindedConsents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (context !== undefined) {
        localVarQueryParameter['context'] = context;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (document !== undefined) {
        localVarQueryParameter['document'] = document;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Mark a document as revised. All `given` consents related to that document, document type, and the optional context are marked as `stale`, indicating that the user should be presented the document and asked to consent to the terms of the revised document. The newly `stale` consents will now be listed in the result of `GET /neededConsents`. This operation is restricted to financial institution administrators or service applications. Any `given` consents which already match the document and time stamp (and, optionally, document revision) are not marked stale.
     * @summary Mark a document as revised, rendering corresponding consents as stale
     * @param {RevisedDocument} RevisedDocument The details of the revised document.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviseDocument(RevisedDocument: RevisedDocument, options: any = {}): RequestArgs {
      // verify required parameter 'RevisedDocument' is not null or undefined
      if (RevisedDocument === null || RevisedDocument === undefined) {
        throw new RequiredError(
          'RevisedDocument',
          'Required parameter RevisedDocument was null or undefined when calling reviseDocument.',
        );
      }
      const localVarPath = `/revisedDocuments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'RevisedDocument' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(RevisedDocument || {})
        : RevisedDocument || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * A user has revoked a previously given consent. This operation updates a consent by adding it to the set of revoked consents. This changes the `state` property of the consent to `revoked`. This operation is available via the `apiture:revoke` link on the consent resource, if and only if the consent is eligible for the revoke operation. The responses is the updated representation of the consent.  The `If-Match` request header, if present, must match the current entity tag value of the consent.
     * @summary Revoke a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeConsent(
      query?: { consent?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { consent } = query;
      const { If_Match } = headers;

      // verify required parameter 'consent' is not null or undefined
      if (consent === null || consent === undefined) {
        throw new RequiredError(
          'consent',
          'Required parameter consent was null or undefined when calling revokeConsent.',
        );
      }
      const localVarPath = `/revokedConsents`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (consent !== undefined) {
        localVarQueryParameter['consent'] = consent;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConsentApi - functional programming interface
 * @export
 */
export const ConsentApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new consent resource.
     * @summary Create a new consent
     * @param {CreateConsent} CreateConsent The data necessary to create a new consent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createConsent(
      CreateConsent: CreateConsent,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consent> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).createConsent(
        CreateConsent ? CreateConsent : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this consent resource.
     * @summary Fetch a representation of this consent
     * @param {string} consentId The unique identifier of this consent. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsent(
      consentId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consent> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).getConsent(
        consentId ? consentId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of consents. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Subset the response to those with this &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;termsAndCondition&#x60; matches only items whose &#x60;type&#x60; is &#x60;termsAndCondition&#x60; &#x60;?type&#x3D;privacyPolicy|electronicConsent&#x60; matches items whose type is &#x60;privacyPolicy&#x60; or &#x60;electronicConsent&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the response to those with this &#x60;state&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;given|stale&#x60; matches only items whose &#x60;state&#x60; is &#x60;given&#x60; or &#x60;stale&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.userId] Subset the response to those with this &#x60;userId&#x60; value. Use &#x60;|&#x60; to separate multiple values. This is for administrative use; bank users can only see their own consents.
     * @param {string} [query.contextUri] Subset the response to those with this &#x60;contextUri&#x60; value. Use &#x60;|&#x60; to separate multiple values.
     * @param {number} [query.start] The zero-based index of the first consent item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of consent representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsents(
      query?: {
        type?: string;
        state?: string;
        userId?: string;
        contextUri?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consents> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).getConsents(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a list of needed consents (both `pending` and `stale` consents) for a user. If no consents exists for a user ID (including if the user ID is not found), the response is an empty collection.
     * @summary Get needed consents
     * @param {Object} [query] Query object
     * @param {string} [query.userId] The user ID of the user; This is the &#x60;_id&#x60; of the User resource. If omitted, the returned list is the needed consents for the currently authenticated user.
     * @param {boolean} [query.consolidate] If &#x60;true&#x60;, the response body will consolidate two or more duplicate consents that have the same &#x60;type&#x60; and &#x60;targetUri&#x60; such that the result contain only one of them. **Warning**: the client should **not** use &#x60;?matching&#x3D;false&#x60; when the user [gives consent](#op-giveConsent) to consents resources in the consolidated response.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getNeededConsents(
      query?: { userId?: string; consolidate?: boolean },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consents> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).getNeededConsents(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Indicate that a user has given consent to a document. This marks the the given consent as `given`. If `scope` is matching, _all_ matching needed consents (`pending` or `stale` consents which have the same `type`, `document.uri` and `contextUri`) will also be marked as `given`. This operation may be invoked by using `POST` on the `apiture:giveConsent` link on a consent resource; there is no query parameter.
     * @summary Give a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {'instance' | 'matching'} [query.scope] The scope of the given consent. If &#x60;instance&#x60;, only the consent named in the &#x60;?consent&#x3D;&#x60; query parameter is marked as &#x60;given&#x60;. If &#x60;matching&#x60;, all needed consent matching the named in the &#x60;?consent&#x3D;&#x60; query parameter (&#x60;pending&#x60; or &#x60;stale&#x60; consents which have the same &#x60;type&#x60;, &#x60;document.uri&#x60; and &#x60;contextUri&#x60;) are marked as &#x60;given&#x60;. The default if omitted is &#x60;matching&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    giveConsent(
      query?: { consent?: string; scope?: 'instance' | 'matching' },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consent> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).giveConsent(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Rescind consent requests which match the specified consent type, context, and user. This action is typically performed by the financial institution to indicate that it no longer requires the user's consent. For example, a service may rescind a consent if a user is removed as an account owner or as an authorized signer, or when an account application expires. changes the `state` property of the matching consents to `rescinded`. The client must pass the `type`, `context`, and `user` in order to find matching consents; if the `document` is also specified, it must also match.  The response is the collection of updated consent resources. If no matching consents were found, the consents collection response will have an empty `items` array.
     * @summary Rescind matching consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Specify the consent &#x60;type&#x60; to rescind.
     * @param {string} [query.context] The URI of the consent context.
     * @param {string} [query.user] Rescind all matching consents for the user with this user ID.
     * @param {string} [query.document] The URI of the target document. This is not _required_ but if passed, the &#x60;document.uri&#x60; must match as well as the other required query parameters.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rescindConsents(
      query?: { type?: string; context?: string; user?: string; document?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consents> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).rescindConsents(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Mark a document as revised. All `given` consents related to that document, document type, and the optional context are marked as `stale`, indicating that the user should be presented the document and asked to consent to the terms of the revised document. The newly `stale` consents will now be listed in the result of `GET /neededConsents`. This operation is restricted to financial institution administrators or service applications. Any `given` consents which already match the document and time stamp (and, optionally, document revision) are not marked stale.
     * @summary Mark a document as revised, rendering corresponding consents as stale
     * @param {RevisedDocument} RevisedDocument The details of the revised document.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviseDocument(
      RevisedDocument: RevisedDocument,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<RevisedDocument> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).reviseDocument(
        RevisedDocument ? RevisedDocument : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * A user has revoked a previously given consent. This operation updates a consent by adding it to the set of revoked consents. This changes the `state` property of the consent to `revoked`. This operation is available via the `apiture:revoke` link on the consent resource, if and only if the consent is eligible for the revoke operation. The responses is the updated representation of the consent.  The `If-Match` request header, if present, must match the current entity tag value of the consent.
     * @summary Revoke a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeConsent(
      query?: { consent?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Consent> {
      const localVarAxiosArgs = ConsentApiAxiosParamCreator(configuration).revokeConsent(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConsentApi - factory interface
 * @export
 */
export const ConsentApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new consent resource.
     * @summary Create a new consent
     * @param {CreateConsent} CreateConsent The data necessary to create a new consent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createConsent(CreateConsent: CreateConsent, options?: any) {
      return ConsentApiFp(configuration).createConsent(
        CreateConsent ? CreateConsent : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this consent resource.
     * @summary Fetch a representation of this consent
     * @param {string} consentId The unique identifier of this consent. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsent(consentId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConsentApiFp(configuration).getConsent(
        consentId ? consentId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of consents. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Subset the response to those with this &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;termsAndCondition&#x60; matches only items whose &#x60;type&#x60; is &#x60;termsAndCondition&#x60; &#x60;?type&#x3D;privacyPolicy|electronicConsent&#x60; matches items whose type is &#x60;privacyPolicy&#x60; or &#x60;electronicConsent&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the response to those with this &#x60;state&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;given|stale&#x60; matches only items whose &#x60;state&#x60; is &#x60;given&#x60; or &#x60;stale&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.userId] Subset the response to those with this &#x60;userId&#x60; value. Use &#x60;|&#x60; to separate multiple values. This is for administrative use; bank users can only see their own consents.
     * @param {string} [query.contextUri] Subset the response to those with this &#x60;contextUri&#x60; value. Use &#x60;|&#x60; to separate multiple values.
     * @param {number} [query.start] The zero-based index of the first consent item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of consent representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsents(
      query?: {
        type?: string;
        state?: string;
        userId?: string;
        contextUri?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ) {
      return ConsentApiFp(configuration).getConsents(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a list of needed consents (both `pending` and `stale` consents) for a user. If no consents exists for a user ID (including if the user ID is not found), the response is an empty collection.
     * @summary Get needed consents
     * @param {Object} [query] Query object
     * @param {string} [query.userId] The user ID of the user; This is the &#x60;_id&#x60; of the User resource. If omitted, the returned list is the needed consents for the currently authenticated user.
     * @param {boolean} [query.consolidate] If &#x60;true&#x60;, the response body will consolidate two or more duplicate consents that have the same &#x60;type&#x60; and &#x60;targetUri&#x60; such that the result contain only one of them. **Warning**: the client should **not** use &#x60;?matching&#x3D;false&#x60; when the user [gives consent](#op-giveConsent) to consents resources in the consolidated response.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getNeededConsents(query?: { userId?: string; consolidate?: boolean }, options?: any) {
      return ConsentApiFp(configuration).getNeededConsents(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Indicate that a user has given consent to a document. This marks the the given consent as `given`. If `scope` is matching, _all_ matching needed consents (`pending` or `stale` consents which have the same `type`, `document.uri` and `contextUri`) will also be marked as `given`. This operation may be invoked by using `POST` on the `apiture:giveConsent` link on a consent resource; there is no query parameter.
     * @summary Give a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {'instance' | 'matching'} [query.scope] The scope of the given consent. If &#x60;instance&#x60;, only the consent named in the &#x60;?consent&#x3D;&#x60; query parameter is marked as &#x60;given&#x60;. If &#x60;matching&#x60;, all needed consent matching the named in the &#x60;?consent&#x3D;&#x60; query parameter (&#x60;pending&#x60; or &#x60;stale&#x60; consents which have the same &#x60;type&#x60;, &#x60;document.uri&#x60; and &#x60;contextUri&#x60;) are marked as &#x60;given&#x60;. The default if omitted is &#x60;matching&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    giveConsent(query?: { consent?: string; scope?: 'instance' | 'matching' }, options?: any) {
      return ConsentApiFp(configuration).giveConsent(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Rescind consent requests which match the specified consent type, context, and user. This action is typically performed by the financial institution to indicate that it no longer requires the user's consent. For example, a service may rescind a consent if a user is removed as an account owner or as an authorized signer, or when an account application expires. changes the `state` property of the matching consents to `rescinded`. The client must pass the `type`, `context`, and `user` in order to find matching consents; if the `document` is also specified, it must also match.  The response is the collection of updated consent resources. If no matching consents were found, the consents collection response will have an empty `items` array.
     * @summary Rescind matching consents
     * @param {Object} [query] Query object
     * @param {string} [query.type] Specify the consent &#x60;type&#x60; to rescind.
     * @param {string} [query.context] The URI of the consent context.
     * @param {string} [query.user] Rescind all matching consents for the user with this user ID.
     * @param {string} [query.document] The URI of the target document. This is not _required_ but if passed, the &#x60;document.uri&#x60; must match as well as the other required query parameters.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rescindConsents(
      query?: { type?: string; context?: string; user?: string; document?: string },
      options?: any,
    ) {
      return ConsentApiFp(configuration).rescindConsents(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Mark a document as revised. All `given` consents related to that document, document type, and the optional context are marked as `stale`, indicating that the user should be presented the document and asked to consent to the terms of the revised document. The newly `stale` consents will now be listed in the result of `GET /neededConsents`. This operation is restricted to financial institution administrators or service applications. Any `given` consents which already match the document and time stamp (and, optionally, document revision) are not marked stale.
     * @summary Mark a document as revised, rendering corresponding consents as stale
     * @param {RevisedDocument} RevisedDocument The details of the revised document.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviseDocument(RevisedDocument: RevisedDocument, options?: any) {
      return ConsentApiFp(configuration).reviseDocument(
        RevisedDocument ? RevisedDocument : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * A user has revoked a previously given consent. This operation updates a consent by adding it to the set of revoked consents. This changes the `state` property of the consent to `revoked`. This operation is available via the `apiture:revoke` link on the consent resource, if and only if the consent is eligible for the revoke operation. The responses is the updated representation of the consent.  The `If-Match` request header, if present, must match the current entity tag value of the consent.
     * @summary Revoke a consent
     * @param {Object} [query] Query object
     * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeConsent(query?: { consent?: string }, headers?: { If_Match?: string }, options?: any) {
      return ConsentApiFp(configuration).revokeConsent(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConsentApi - object-oriented interface
 * @export
 * @class ConsentApi
 * @extends {BaseAPI}
 */
export class ConsentApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new consent resource.
   * @summary Create a new consent
   * @param {CreateConsent} CreateConsent The data necessary to create a new consent.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consent}
   * @memberof ConsentApi
   */
  public createConsent(CreateConsent: CreateConsent, options?: any) {
    return ConsentApiFp(this.configuration).createConsent(
      CreateConsent ? CreateConsent : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this consent resource.
   * @summary Fetch a representation of this consent
   * @param {string} consentId The unique identifier of this consent. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consent}
   * @memberof ConsentApi
   */
  public getConsent(consentId: string, headers?: { If_None_Match?: string }, options?: any) {
    return ConsentApiFp(this.configuration).getConsent(
      consentId ? consentId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of consents. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of consents
   * @param {Object} [query] Query object
   * @param {string} [query.type] Subset the response to those with this &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;termsAndCondition&#x60; matches only items whose &#x60;type&#x60; is &#x60;termsAndCondition&#x60; &#x60;?type&#x3D;privacyPolicy|electronicConsent&#x60; matches items whose type is &#x60;privacyPolicy&#x60; or &#x60;electronicConsent&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.state] Subset the response to those with this &#x60;state&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;given|stale&#x60; matches only items whose &#x60;state&#x60; is &#x60;given&#x60; or &#x60;stale&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.userId] Subset the response to those with this &#x60;userId&#x60; value. Use &#x60;|&#x60; to separate multiple values. This is for administrative use; bank users can only see their own consents.
   * @param {string} [query.contextUri] Subset the response to those with this &#x60;contextUri&#x60; value. Use &#x60;|&#x60; to separate multiple values.
   * @param {number} [query.start] The zero-based index of the first consent item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of consent representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consents}
   * @memberof ConsentApi
   */
  public getConsents(
    query?: {
      type?: string;
      state?: string;
      userId?: string;
      contextUri?: string;
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
    },
    options?: any,
  ) {
    return ConsentApiFp(this.configuration).getConsents(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a list of needed consents (both `pending` and `stale` consents) for a user. If no consents exists for a user ID (including if the user ID is not found), the response is an empty collection.
   * @summary Get needed consents
   * @param {Object} [query] Query object
   * @param {string} [query.userId] The user ID of the user; This is the &#x60;_id&#x60; of the User resource. If omitted, the returned list is the needed consents for the currently authenticated user.
   * @param {boolean} [query.consolidate] If &#x60;true&#x60;, the response body will consolidate two or more duplicate consents that have the same &#x60;type&#x60; and &#x60;targetUri&#x60; such that the result contain only one of them. **Warning**: the client should **not** use &#x60;?matching&#x3D;false&#x60; when the user [gives consent](#op-giveConsent) to consents resources in the consolidated response.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consents}
   * @memberof ConsentApi
   */
  public getNeededConsents(query?: { userId?: string; consolidate?: boolean }, options?: any) {
    return ConsentApiFp(this.configuration).getNeededConsents(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Indicate that a user has given consent to a document. This marks the the given consent as `given`. If `scope` is matching, _all_ matching needed consents (`pending` or `stale` consents which have the same `type`, `document.uri` and `contextUri`) will also be marked as `given`. This operation may be invoked by using `POST` on the `apiture:giveConsent` link on a consent resource; there is no query parameter.
   * @summary Give a consent
   * @param {Object} [query] Query object
   * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
   * @param {'instance' | 'matching'} [query.scope] The scope of the given consent. If &#x60;instance&#x60;, only the consent named in the &#x60;?consent&#x3D;&#x60; query parameter is marked as &#x60;given&#x60;. If &#x60;matching&#x60;, all needed consent matching the named in the &#x60;?consent&#x3D;&#x60; query parameter (&#x60;pending&#x60; or &#x60;stale&#x60; consents which have the same &#x60;type&#x60;, &#x60;document.uri&#x60; and &#x60;contextUri&#x60;) are marked as &#x60;given&#x60;. The default if omitted is &#x60;matching&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consent}
   * @memberof ConsentApi
   */
  public giveConsent(query?: { consent?: string; scope?: 'instance' | 'matching' }, options?: any) {
    return ConsentApiFp(this.configuration).giveConsent(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Rescind consent requests which match the specified consent type, context, and user. This action is typically performed by the financial institution to indicate that it no longer requires the user's consent. For example, a service may rescind a consent if a user is removed as an account owner or as an authorized signer, or when an account application expires. changes the `state` property of the matching consents to `rescinded`. The client must pass the `type`, `context`, and `user` in order to find matching consents; if the `document` is also specified, it must also match.  The response is the collection of updated consent resources. If no matching consents were found, the consents collection response will have an empty `items` array.
   * @summary Rescind matching consents
   * @param {Object} [query] Query object
   * @param {string} [query.type] Specify the consent &#x60;type&#x60; to rescind.
   * @param {string} [query.context] The URI of the consent context.
   * @param {string} [query.user] Rescind all matching consents for the user with this user ID.
   * @param {string} [query.document] The URI of the target document. This is not _required_ but if passed, the &#x60;document.uri&#x60; must match as well as the other required query parameters.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consents}
   * @memberof ConsentApi
   */
  public rescindConsents(
    query?: { type?: string; context?: string; user?: string; document?: string },
    options?: any,
  ) {
    return ConsentApiFp(this.configuration).rescindConsents(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Mark a document as revised. All `given` consents related to that document, document type, and the optional context are marked as `stale`, indicating that the user should be presented the document and asked to consent to the terms of the revised document. The newly `stale` consents will now be listed in the result of `GET /neededConsents`. This operation is restricted to financial institution administrators or service applications. Any `given` consents which already match the document and time stamp (and, optionally, document revision) are not marked stale.
   * @summary Mark a document as revised, rendering corresponding consents as stale
   * @param {RevisedDocument} RevisedDocument The details of the revised document.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {RevisedDocument}
   * @memberof ConsentApi
   */
  public reviseDocument(RevisedDocument: RevisedDocument, options?: any) {
    return ConsentApiFp(this.configuration).reviseDocument(
      RevisedDocument ? RevisedDocument : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * A user has revoked a previously given consent. This operation updates a consent by adding it to the set of revoked consents. This changes the `state` property of the consent to `revoked`. This operation is available via the `apiture:revoke` link on the consent resource, if and only if the consent is eligible for the revoke operation. The responses is the updated representation of the consent.  The `If-Match` request header, if present, must match the current entity tag value of the consent.
   * @summary Revoke a consent
   * @param {Object} [query] Query object
   * @param {string} [query.consent] A string which uniquely identifies a consent which is to added to the given consents resource set. This may be the unique &#x60;consentId&#x60; or the URI of the consent.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Consent}
   * @memberof ConsentApi
   */
  public revokeConsent(
    query?: { consent?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConsentApiFp(this.configuration).revokeConsent(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ConsentTypeNameApi - axios parameter creator
 * @export
 */
export const ConsentTypeNameApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return the set of reserved consent type names. The `name` property of a consent must be one of these reserved names. This list may be updated by the financial institution via the `updateConsentTypeNames` operation. The default list includes the following names:    * `productTermsAndConditions`   * `privacyPolicy`   * `electronicConsent`
     * @summary Retrieve the set of consent type names
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsentTypeNames(options: any = {}): RequestArgs {
      const localVarPath = `/consentTypeNames`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * A financial institution can use this operation to register additional types of consent that they may request from their users. The `type` property of a consent must be one of these reserved names. This operation completely replaces the set of reserved consent type names, so it should include all items from the `getConsentTypeNames` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of consent type names
     * @param {ConsentTypeNames} ConsentTypeNames The set of consent type names
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConsentTypeNames(
      ConsentTypeNames: ConsentTypeNames,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'ConsentTypeNames' is not null or undefined
      if (ConsentTypeNames === null || ConsentTypeNames === undefined) {
        throw new RequiredError(
          'ConsentTypeNames',
          'Required parameter ConsentTypeNames was null or undefined when calling updateConsentTypeNames.',
        );
      }
      const localVarPath = `/consentTypeNames`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ConsentTypeNames' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ConsentTypeNames || {})
        : ConsentTypeNames || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConsentTypeNameApi - functional programming interface
 * @export
 */
export const ConsentTypeNameApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return the set of reserved consent type names. The `name` property of a consent must be one of these reserved names. This list may be updated by the financial institution via the `updateConsentTypeNames` operation. The default list includes the following names:    * `productTermsAndConditions`   * `privacyPolicy`   * `electronicConsent`
     * @summary Retrieve the set of consent type names
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsentTypeNames(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConsentTypeNames> {
      const localVarAxiosArgs = ConsentTypeNameApiAxiosParamCreator(
        configuration,
      ).getConsentTypeNames(options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * A financial institution can use this operation to register additional types of consent that they may request from their users. The `type` property of a consent must be one of these reserved names. This operation completely replaces the set of reserved consent type names, so it should include all items from the `getConsentTypeNames` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of consent type names
     * @param {ConsentTypeNames} ConsentTypeNames The set of consent type names
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConsentTypeNames(
      ConsentTypeNames: ConsentTypeNames,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConsentTypeNames> {
      const localVarAxiosArgs = ConsentTypeNameApiAxiosParamCreator(
        configuration,
      ).updateConsentTypeNames(
        ConsentTypeNames ? ConsentTypeNames : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConsentTypeNameApi - factory interface
 * @export
 */
export const ConsentTypeNameApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return the set of reserved consent type names. The `name` property of a consent must be one of these reserved names. This list may be updated by the financial institution via the `updateConsentTypeNames` operation. The default list includes the following names:    * `productTermsAndConditions`   * `privacyPolicy`   * `electronicConsent`
     * @summary Retrieve the set of consent type names
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConsentTypeNames(options?: any) {
      return ConsentTypeNameApiFp(configuration).getConsentTypeNames(options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * A financial institution can use this operation to register additional types of consent that they may request from their users. The `type` property of a consent must be one of these reserved names. This operation completely replaces the set of reserved consent type names, so it should include all items from the `getConsentTypeNames` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of consent type names
     * @param {ConsentTypeNames} ConsentTypeNames The set of consent type names
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConsentTypeNames(
      ConsentTypeNames: ConsentTypeNames,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConsentTypeNameApiFp(configuration).updateConsentTypeNames(
        ConsentTypeNames ? ConsentTypeNames : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConsentTypeNameApi - object-oriented interface
 * @export
 * @class ConsentTypeNameApi
 * @extends {BaseAPI}
 */
export class ConsentTypeNameApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return the set of reserved consent type names. The `name` property of a consent must be one of these reserved names. This list may be updated by the financial institution via the `updateConsentTypeNames` operation. The default list includes the following names:    * `productTermsAndConditions`   * `privacyPolicy`   * `electronicConsent`
   * @summary Retrieve the set of consent type names
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConsentTypeNames}
   * @memberof ConsentTypeNameApi
   */
  public getConsentTypeNames(options?: any) {
    return ConsentTypeNameApiFp(this.configuration).getConsentTypeNames(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * A financial institution can use this operation to register additional types of consent that they may request from their users. The `type` property of a consent must be one of these reserved names. This operation completely replaces the set of reserved consent type names, so it should include all items from the `getConsentTypeNames` that are in use. This operation is only available to financial institution administrators.
   * @summary Replace the set of consent type names
   * @param {ConsentTypeNames} ConsentTypeNames The set of consent type names
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConsentTypeNames}
   * @memberof ConsentTypeNameApi
   */
  public updateConsentTypeNames(
    ConsentTypeNames: ConsentTypeNames,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConsentTypeNameApiFp(this.configuration).updateConsentTypeNames(
      ConsentTypeNames ? ConsentTypeNames : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
