# @apiture/contacts-client-sdk@0.18.9
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/contacts-client-sdk@0.18.9 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ContactApi } from "@apiture/contacts-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ContactApi main class passing the configuration object.
    const contactApi = new ContactApi(configuration);


// Use the methods to call the apis ( Refer to the Contacts SDK Classes and Methods list ).
  contact.getContacts().then( response => {
    const getcontactsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ContactApi main class.
    const contactApi = new ContactApi();


// Update the accessToken using the class method `setAccessToken`.
    contactApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    contactApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    contactApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Contacts } from "@apiture/contacts-client-sdk";

  const stronglyTypedObject :Contacts = { ... };

  // ______ Scoped import

  import * as ContactsTypes from "@apiture/contacts-client-sdk";

  const stronglyTypedObject :ContactsTypes.Contacts = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/contacts",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Contacts SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document

  `APIApi.getLabels` - Localized Labels



### ContactApi


  `ContactApi.activateContact` - Activate a contact.

  `ContactApi.createContact` - Create a new contact

  `ContactApi.deactivateContact` - Deactivate a contact.

  `ContactApi.getContact` - Fetch a representation of this contact

  `ContactApi.getContacts` - Return a collection of contacts

  `ContactApi.patchContact` - Update this contact

  `ContactApi.removeContact` - Remove a contact.

  `ContactApi.updateContact` - Update this contact



## About the Contacts API
___
Contacts manages contact information for people within the Apiture Banking APIs.
