// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Contacts
 * Contacts manages contact information for people within the Apiture Banking APIs.
 *
 * OpenAPI spec version: 0.18.9
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/contacts'.replace(/\/+$/, '');

export const API_VERSION = '0.18.9';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The type of this address.
   * @type {AddressType}
   * @memberof Address
   */
  type: AddressType;
  /**
   * A text label, suitable for presentation to the end user. This is derived from `type` or from `otherType` if `type` is `other`
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The actual address type if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  otherType?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
  /**
   * An identifier for this address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all addresses within the `addresses` array.
   * @type {string}
   * @memberof Address
   */
  _id?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A list of postal addresses and the preferred mailing address.
 * @export
 * @interface Addresses
 */
export interface Addresses {
  /**
   * An array of postal/mailing addresses.
   * @type {Array<Address>}
   * @memberof Addresses
   */
  addresses?: Array<Address>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array.
   * @type {string}
   * @memberof Addresses
   */
  preferredMailingAddressId?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Represents a person authorized for account access. This object contains key identification information for the person and the type of access or role that the person has in relation to the banking account or organization.
 * @export
 * @interface Authorization
 */
export interface Authorization extends IndividualIdentification {
  /**
   * The unique ID of the user. This is the `_id` value of the user resource from the Users API.
   * @type {string}
   * @memberof Authorization
   */
  userId?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof Authorization
   */
  customerId?: string;
  /**
   * The type of this account access authorization.  * *`primary`* the `contact` is the primary owner of a personal account. There may be only one  primary owner. The target of the authorization is a single personal account.  * *`joint`* the `contact` is a non-primary joint owner of a  personal account. The target of the authorization is a single personal account.  * *`authorizedSigner`* the `contact` is an authorized signer  for a business account. The target of the authorization is an  all business accounts owned by the organization.
   * @type {AuthorizationType}
   * @memberof Authorization
   */
  type?: AuthorizationType;
  /**
   * The person's role at the organization. This attribute is required when the authorization type is authorizedSigner.
   * @type {string}
   * @memberof Authorization
   */
  role?: string;
}

/**
 * The type of this account access authorization.  * *`primary`* the person is the primary owner of a personal account.  There may be only one primary owner.  * *`joint`* the person is a non-primary joint owner of a  personal account.  * *`authorizedSigner`* the person is an authorized signer  for all business accounts owned by the organization.
 * @export
 * @enum {string}
 */
export enum AuthorizationType {
  Primary = 'primary',
  Joint = 'joint',
  AuthorizedSigner = 'authorizedSigner',
}

/**
 * Citizenship or nationality status.
 * @export
 * @interface Citizenship
 */
export interface Citizenship {}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation of a contact resource. Contact data (mailing addresses, phone numbers, email addresses) for an individual.
 * @export
 * @interface Contact
 */
export interface Contact extends SummaryContact {
  /**
   * An optional map of name/value pairs which provide additional metadata about the contact.
   * @type {any}
   * @memberof Contact
   */
  attributes?: any;
  /**
   * The date-time when the contact was created.
   * @type {Date}
   * @memberof Contact
   */
  createdAt?: Date;
  /**
   * The date-time when the contact was updated
   * @type {Date}
   * @memberof Contact
   */
  updatedAt?: Date;
}

/**
 * @export
 * @namespace Contact
 */
export namespace Contact {}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * The state of this person. The values are described in the `contactState` text via the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum ContactState {
  Inactive = 'inactive',
  Active = 'active',
  Merged = 'merged',
  Removed = 'removed',
}

/**
 * Common fields of the contact resource used to build other model schemas for people who hold bank accounts.
 * @export
 * @interface ContactVerificationFields
 */
export interface ContactVerificationFields {
  /**
   * An object that contains the answers to Know Your Customer (KYC) questions. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {any}
   * @memberof ContactVerificationFields
   */
  kycAnswers?: any;
  /**
   * Use the `state` of `identityVerification`. The identity verification status for this person.  This field is read-only and is derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {string}
   * @memberof ContactVerificationFields
   */
  identityVerificationStatus?: ContactVerificationFields.IdentityVerificationStatusEnum;
  /**
   * The identity verification data for this person.  These fields are derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {IdentityVerification}
   * @memberof ContactVerificationFields
   */
  identityVerification?: IdentityVerification;
}

/**
 * @export
 * @namespace ContactVerificationFields
 */
export namespace ContactVerificationFields {
  /**
   * @export
   * @enum {string}
   */
  export enum IdentityVerificationStatusEnum {
    Verified = 'verified',
    Unverified = 'unverified',
  }
}

/**
 * Collection of contacts. The items in the collection are ordered in the `_embedded.items` array; the `name` is `contacts`.  The top-level `_links` object may contain pagination links such  as `self`, `next`, `prev`, `first`, `last`, `collection`.
 * @export
 * @interface Contacts
 */
export interface Contacts extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Contacts
   */
  _embedded?: any;
}

/**
 * The object representation of a newly created authorization. The fields listed will assist in the information needed to gain access to a bank account or organization. A link to the user must be passed in _links as `apiture:user` for implementations of this object as it explains the direct association.
 * @export
 * @interface CreateAuthorization
 */
export interface CreateAuthorization extends AbstractResource, Authorization {}

/**
 * Representation used to create a new contact.
 * @export
 * @interface CreateContact
 */
export interface CreateContact
  extends ContactVerificationFields,
    IdentifiedContact,
    AbstractResource {
  /**
   * An optional map of name/value pairs which provide additional metadata about the contact.
   * @type {any}
   * @memberof CreateContact
   */
  attributes?: any;
}

/**
 * @export
 * @namespace CreateContact
 */
export namespace CreateContact {}

/**
 * A list of email addresses and the preferred email address.
 * @export
 * @interface EmailAddresses
 */
export interface EmailAddresses {
  /**
   * An array of email addresses.
   * @type {Array<TypedEmailAddress>}
   * @memberof EmailAddresses
   */
  emailAddresses?: Array<TypedEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.
   * @type {string}
   * @memberof EmailAddresses
   */
  preferredEmailAddressId?: string;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The employment status of a contact, located in `kycAnswers`.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `employmentStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmploymentStatus {
  Unknown = 'unknown',
  FullTime = 'fullTime',
  PartTime = 'partTime',
  PaidLeave = 'paidLeave',
  Retired = 'retired',
  Unemployed = 'unemployed',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Official identifying information associated with the contact.
 * @export
 * @interface Identification
 */
export interface Identification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof Identification
   */
  value: string;
  /**
   * The type of this form of identification.
   * @type {string}
   * @memberof Identification
   */
  type: Identification.TypeEnum;
  /**
   * The date when the form of identification expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` format.
   * @type {string}
   * @memberof Identification
   */
  expiration?: string;
}

/**
 * @export
 * @namespace Identification
 */
export namespace Identification {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    TaxId = 'taxId',
    PassportNumber = 'passportNumber',
  }
}

/**
 * A contact with additional personally identifiable information data.
 * @export
 * @interface IdentifiedContact
 */
export interface IdentifiedContact extends SimpleContact, IdentifiedContactFields {}

/**
 * Properties which provide additional identification of a person.
 * @export
 * @interface IdentifiedContactFields
 */
export interface IdentifiedContactFields {
  /**
   * The contact's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  birthdate?: string;
  /**
   * This individual's citizenship or nationality status.
   * @type {Citizenship}
   * @memberof IdentifiedContactFields
   */
  citizenship?: Citizenship;
  /**
   * This individual's residency status.
   * @type {ResidencyStatus}
   * @memberof IdentifiedContactFields
   */
  residencyStatus?: ResidencyStatus;
  /**
   * The occupation of this individual.
   * @type {Occupation}
   * @memberof IdentifiedContactFields
   */
  occupation?: Occupation;
  /**
   * The actual occupation of this individual if their `occupation` is `other`. This is ignored if `occupation` is not `other`.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  otherOccupation?: string;
  /**
   * The number of years the person has been at their present home address.
   * @type {YearsAtAddress}
   * @memberof IdentifiedContactFields
   */
  yearsAtAddress?: YearsAtAddress;
}

/**
 * Data points on the identity verification process that tells if a user has passed, failed or expired the identity check.
 * @export
 * @interface IdentityVerification
 */
export interface IdentityVerification {
  /**
   * The name of the identity verification provider.
   * @type {string}
   * @memberof IdentityVerification
   */
  provider?: string;
  /**
   * The unique id for a session of the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  sessionId?: string;
  /**
   * The date-time when the provider ran identity verification. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp.
   * @type {Date}
   * @memberof IdentityVerification
   */
  scoredAt?: Date;
  /**
   * The indication if the contact has passed or failed the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  score?: IdentityVerification.ScoreEnum;
  /**
   * The identity verification status for this person.  This field is read-only and is derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record.
   * @type {string}
   * @memberof IdentityVerification
   */
  state?: IdentityVerification.StateEnum;
}

/**
 * @export
 * @namespace IdentityVerification
 */
export namespace IdentityVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum ScoreEnum {
    Passed = 'passed',
    Failed = 'failed',
    Expired = 'expired',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Verified = 'verified',
    Unverified = 'unverified',
  }
}

/**
 * This object contains key identification information for a person associated with digital banking.
 * @export
 * @interface IndividualIdentification
 */
export interface IndividualIdentification extends ContactName, Addresses {
  /**
   * Official government identification (tax ID) for this person.
   * @type {string}
   * @memberof IndividualIdentification
   */
  taxId?: string;
  /**
   * Indicates if the person is a (US) citizen.
   * @type {boolean}
   * @memberof IndividualIdentification
   */
  citizen?: boolean;
  /**
   * Optional email address.
   * @type {string}
   * @memberof IndividualIdentification
   */
  emailAddress?: string;
}

/**
 * Answers to 'Know Your Customer' questions which allow financial institutions to conform to a customer identification program.
 * @export
 * @interface KycAnswers
 */
export interface KycAnswers {
  /**
   * `true` if the person is a foreign senior political figure.
   * @type {boolean}
   * @memberof KycAnswers
   */
  foreignPoliticalFigure?: boolean;
  /**
   * If the person is a foreign senior political figure, this is the foreign country ISO 3166-1 country code. This field is omitted if `foreignPoliticalFigure` is `false`.
   * @type {string}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureCountry?: string;
  /**
   * The type of association to a foreign political figure.
   * @type {string}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureAssociation?: KycAnswers.ForeignPoliticalFigureAssociationEnum;
}

/**
 * @export
 * @namespace KycAnswers
 */
export namespace KycAnswers {
  /**
   * @export
   * @enum {string}
   */
  export enum ForeignPoliticalFigureAssociationEnum {
    Unknown = 'unknown',
    CloseAssociate = 'closeAssociate',
    FamilyMember = 'familyMember',
    None = 'none',
    Other = 'other',
    NotApplicable = 'notApplicable',
  }
}

/**
 * A map that defines labels for the items in a group. This is a map from each item *name* &rarr; *a [`labelItem`](#schema-labelitem) object*. For example, consider a JSON response that includes a property named `revenueEstimate`; the values for `revenueEstimate` must be one of the items in the group named `estimatedAnnualRevenue`, with options ranging `under1Million`, to `over100Million`. The item name is used as the selected value in an Apiture representation, such as `{ ..., \"revenueEstimate\" : \"from10to100Million\" , ...}`, and the item with the name `from10to100Million` defines the presentation labels for that item, as well as other metadata about that choice: this is the range `[10000000.00,100000000.00)`.  This allows the client to let the user select a value from a list, such as the following derivde from the labels in the example:    * Unknown   * Under $1M   * $1M to $10M   * $10M to $100M   * $100M or more  Note that the `other` item is hidden from the selection list, as that item is marked as `hidden`. For items which define numeric ranges, a client may instead let the customer *directly* enter their estimated annual revenue as a number, such as 4,500,000.00. The client can then match that number to one of ranges in the items and set the `revenueEstimate` to the corresponding item's name: `{ ..., \"revenueEstimate\" : \"from1to10Million\", ... }`.
 * @export
 * @interface LabelGroup
 */
export interface LabelGroup {
  [key: string]: LabelItem;
}

/**
 * A set of named groups of labels, each of which contains multiple item labels.   The abbreviated example shows two groups, one named `structure` and one named `estimatedAnnualRevenue`. The first has items with names such as `corporation`, `llc` and `soleProprietorship`, with text labels for each in the default and in French. The second has items for estimated revenue *ranges* but no localized labels. For example, the item named `from1to10Million` has the `label` \"$1M to $10M\" and the range `[1000000.00,10000000.00)`.
 * @export
 * @interface LabelGroups
 */
export interface LabelGroups extends AbstractResource {
  /**
   * Groups of localized labels. This maps *group names* &rarr; [*a group of labels*](#schema-labelgroup) within that group.
   * @type {any}
   * @memberof LabelGroups
   */
  groups?: any;
}

/**
 * An item in a [`labelGroup`](#schema-labelgroup), with a set of `variants` which contains different localized labels for the item. Each ([`simpleLabel`](#schema-simpleLabel)) variant defines the presentation text label and optional description for a language. Items may also have a lookup `code` to map to external syststems, a numeric range, and a `hidden` boolean to indicate the item is normally hidden in the UI.
 * @export
 * @interface LabelItem
 */
export interface LabelItem extends SimpleLabel {
  /**
   * The language-specific variants of this label. The keys in this object are [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1) language codes.
   * @type {{ [key: string]: SimpleLabel; }}
   * @memberof LabelItem
   */
  variants?: { [key: string]: SimpleLabel };
  /**
   * If the localized value is associated with an external standard or definition, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LabelItem
   */
  code?: string;
  /**
   * If `true`, this item is normally hidden from the User Interface.
   * @type {boolean}
   * @memberof LabelItem
   */
  hidden?: boolean;
  /**
   * The range of values, if the item describes a bounded numeric value. This is range notation such as `[min,max]`, `(exclusiveMin,max]`, `[min,exclusiveMax)`, or `(exclusiveMin,exclusiveMax)`. For example, `[0,100)` is the range greater than or equal to 0 and less than 100. If the *min* or *max* value are omitted, that end of the range is unbounded. For example, `(,1000.00)` means less than 1000.00 and `[20000.00,]` means 20000.00 or more. The ranges do not overlap or have gaps.
   * @type {string}
   * @memberof LabelItem
   */
  range?: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * The person's occupation.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `occupation` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum Occupation {
  Unknown = 'unknown',
  ArchitectureAndEngineering = 'architectureAndEngineering',
  ArtsDesignEntertainmentSportsAndMedia = 'artsDesignEntertainmentSportsAndMedia',
  BuildingAndGroundsCleaningAndMaintenance = 'buildingAndGroundsCleaningAndMaintenance',
  BusinessAndFinancialOperations = 'businessAndFinancialOperations',
  CommunityAndSocialService = 'communityAndSocialService',
  ComputerAndMathematical = 'computerAndMathematical',
  ConstructionAndExtraction = 'constructionAndExtraction',
  EducationTrainingAndLibrary = 'educationTrainingAndLibrary',
  FarmingFishingAndForestry = 'farmingFishingAndForestry',
  FoodPreparationAndServingRelated = 'foodPreparationAndServingRelated',
  HealthcarePractitionersAndTechnical = 'healthcarePractitionersAndTechnical',
  HealthcareSupport = 'healthcareSupport',
  InstallationMaintenanceAndRepair = 'installationMaintenanceAndRepair',
  Legal = 'legal',
  LifePhysicalAndSciences = 'lifePhysicalAndSciences',
  Management = 'management',
  MilitarySpecific = 'militarySpecific',
  OfficeAndAdministrativeSupport = 'officeAndAdministrativeSupport',
  PersonalCareAndService = 'personalCareAndService',
  Production = 'production',
  ProtectiveServices = 'protectiveServices',
  SalesAndRelated = 'salesAndRelated',
  TransportationAndMaterialMoving = 'transportationAndMaterialMoving',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * A list of phone numbers and the preferred phone number.
 * @export
 * @interface PhoneNumbers
 */
export interface PhoneNumbers {
  /**
   * An array of phone numbers.
   * @type {Array<PhoneNumber>}
   * @memberof PhoneNumbers
   */
  phones?: Array<PhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array.
   * @type {string}
   * @memberof PhoneNumbers
   */
  preferredPhoneId?: string;
}

/**
 * The contact's preferred method of communication.
 * @export
 * @enum {string}
 */
export enum PreferredContactMethod {
  Unknown = 'unknown',
  Sms = 'sms',
  Email = 'email',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Residency status.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `residencyStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum ResidencyStatus {
  Unknown = 'unknown',
  Resident = 'resident',
  Nonresident = 'nonresident',
  ResidentAlien = 'residentAlien',
  NonresidentAlien = 'nonresidentAlien',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Basic contact and identification information for a person, consisting of the name, mailing address, phone numbers, email addresses, and government identification.
 * @export
 * @interface SimpleContact
 */
export interface SimpleContact
  extends ContactName,
    Addresses,
    EmailAddresses,
    PhoneNumbers,
    SimpleContactFields {}

/**
 * Additional properties for a person or contact.
 * @export
 * @interface SimpleContactFields
 */
export interface SimpleContactFields {
  /**
   * A title or honorific prefix such as Dr. or Fr.
   * @type {string}
   * @memberof SimpleContactFields
   */
  prefix?: string;
  /**
   * A title or honorific suffix such as PhD or DDS.
   * @type {string}
   * @memberof SimpleContactFields
   */
  suffix?: string;
  /**
   * The contact's preferred name. This is how the contact's name is presented to the user in the interface. The default is the contact's `firstName`.
   * @type {string}
   * @memberof SimpleContactFields
   */
  preferredName?: string;
  /**
   * A collection of official identifying information associated with the contact.
   * @type {Array<Identification>}
   * @memberof SimpleContactFields
   */
  identification?: Array<Identification>;
  /**
   * The contact's preferred method of communication.
   * @type {PreferredContactMethod}
   * @memberof SimpleContactFields
   */
  preferredContactMethod?: PreferredContactMethod;
}

/**
 * A text label and optional description.
 * @export
 * @interface SimpleLabel
 */
export interface SimpleLabel {
  /**
   * A label or title which may be used as labels or other UI controls which present a value.
   * @type {string}
   * @memberof SimpleLabel
   */
  label: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof SimpleLabel
   */
  description?: string;
}

/**
 * Summary representation of a contact resource in contacts collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryContact
 */
export interface SummaryContact
  extends ContactVerificationFields,
    IdentifiedContact,
    AbstractResource {
  /**
   * The state of this person's record.
   * @type {ContactState}
   * @memberof SummaryContact
   */
  state?: ContactState;
  /**
   * The unique identifier for this contact resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryContact
   */
  _id?: string;
}

/**
 * @export
 * @namespace SummaryContact
 */
export namespace SummaryContact {}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * Categories for how long the person has been at their present home address.
 * @export
 * @enum {string}
 */
export enum YearsAtAddress {
  Unknown = 'unknown',
  OneOrFewer = 'oneOrFewer',
  Two = 'two',
  Three = 'three',
  FourOrMore = 'fourOrMore',
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API provides the following links in the `_links` object:   * **`apiture:contacts`** -- links to the `contacts` collection   * **`apiture:createContact`** -- links to a POST operation to create a new contact
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API provides the following links in the `_links` object:   * **`apiture:contacts`** -- links to the `contacts` collection   * **`apiture:createContact`** -- links to a POST operation to create a new contact
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<LabelGroups> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API provides the following links in the `_links` object:   * **`apiture:contacts`** -- links to the `contacts` collection   * **`apiture:createContact`** -- links to a POST operation to create a new contact
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. This API provides the following links in the `_links` object:   * **`apiture:contacts`** -- links to the `contacts` collection   * **`apiture:createContact`** -- links to a POST operation to create a new contact
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LabelGroups}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * ContactApi - axios parameter creator
 * @export
 */
export const ContactApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a contact from an inactive state. <p> This operation is invoked from the `apiture:activate` link on a contact resource when that contact is eligible to be activated. This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `active`.
     * @summary Activate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { contact, contactUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'contact' is not null or undefined
      if (contact === null || contact === undefined) {
        throw new RequiredError(
          'contact',
          'Required parameter contact was null or undefined when calling activateContact.',
        );
      }
      const localVarPath = `/activeContacts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (contact !== undefined) {
        localVarQueryParameter['contact'] = contact;
      }

      if (contactUri !== undefined) {
        localVarQueryParameter['contactUri'] = contactUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new contact in the contacts collection.
     * @summary Create a new contact
     * @param {CreateContact} CreateContact The data necessary to create a new contact.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createContact(CreateContact: CreateContact, options: any = {}): RequestArgs {
      // verify required parameter 'CreateContact' is not null or undefined
      if (CreateContact === null || CreateContact === undefined) {
        throw new RequiredError(
          'CreateContact',
          'Required parameter CreateContact was null or undefined when calling createContact.',
        );
      }
      const localVarPath = `/contacts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateContact' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateContact || {})
        : CreateContact || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate a contact from an active state. <p> This operation is invoked from the `apiture:deactivate` link on a contact resource when that contact is eligible to be deactivated. This operation is only allowed if the state is `active`. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { contact, contactUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'contact' is not null or undefined
      if (contact === null || contact === undefined) {
        throw new RequiredError(
          'contact',
          'Required parameter contact was null or undefined when calling deactivateContact.',
        );
      }
      const localVarPath = `/inactiveContacts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (contact !== undefined) {
        localVarQueryParameter['contact'] = contact;
      }

      if (contactUri !== undefined) {
        localVarQueryParameter['contactUri'] = contactUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this contact resource.
     * @summary Fetch a representation of this contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContact(
      contactId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'contactId' is not null or undefined
      if (contactId === null || contactId === undefined) {
        throw new RequiredError(
          'contactId',
          'Required parameter contactId was null or undefined when calling getContact.',
        );
      }
      const localVarPath = `/contacts/{contactId}`.replace(
        `{${'contactId'}}`,
        encodeURIComponent(String(contactId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of contacts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of contacts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first contact item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of contact representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'active' | 'inactive' | 'removed'} [query.state] Subset the contacts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'unknown' | 'architectureAndEngineering' | 'artsDesignEntertainmentSportsAndMedia' | 'buildingAndGroundsCleaningAndMaintenance' | 'businessAndFinancialOperations' | 'communityAndSocialService' | 'computerAndMathematical' | 'constructionAndExtraction' | 'educationTrainingAndLibrary' | 'farmingFishingAndForestry' | 'foodPreparationAndServingRelated' | 'healthcarePractitionersAndTechnical' | 'healthcareSupport' | 'installationMaintenanceAndRepair' | 'legal' | 'lifePhysicalAndSciences' | 'management' | 'militarySpecific' | 'officeAndAdministrativeSupport' | 'personalCareAndService' | 'production' | 'protectiveServices' | 'salesAndRelated' | 'transportationAndMaterialMoving' | 'other' | 'notApplicable'} [query.occupation] Subset the contacts collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?occupation&#x3D;officeAndAdministrativeSupport&#x60; matches only items whose occupation is &#x60;officeAndAdministrativeSupport&#x60;; &#x60;?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving&#x60; matches items whose occupation is &#x60;officeAndAdministrativeSupport&#x60; or &#x60;transportationAndMaterialMoving&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering). The values are derived from the &#x60;occupation&#x60; label group from the result of the [&#x60;getLabels&#x60;](#op-getLabels) operation. &lt;br&gt; **Note:** The enum list will be removed in future update to the API.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContacts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed';
        occupation?:
          | 'unknown'
          | 'architectureAndEngineering'
          | 'artsDesignEntertainmentSportsAndMedia'
          | 'buildingAndGroundsCleaningAndMaintenance'
          | 'businessAndFinancialOperations'
          | 'communityAndSocialService'
          | 'computerAndMathematical'
          | 'constructionAndExtraction'
          | 'educationTrainingAndLibrary'
          | 'farmingFishingAndForestry'
          | 'foodPreparationAndServingRelated'
          | 'healthcarePractitionersAndTechnical'
          | 'healthcareSupport'
          | 'installationMaintenanceAndRepair'
          | 'legal'
          | 'lifePhysicalAndSciences'
          | 'management'
          | 'militarySpecific'
          | 'officeAndAdministrativeSupport'
          | 'personalCareAndService'
          | 'production'
          | 'protectiveServices'
          | 'salesAndRelated'
          | 'transportationAndMaterialMoving'
          | 'other'
          | 'notApplicable';
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, occupation } = query;

      const localVarPath = `/contacts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (occupation !== undefined) {
        localVarQueryParameter['occupation'] = occupation;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this contact. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'contactId' is not null or undefined
      if (contactId === null || contactId === undefined) {
        throw new RequiredError(
          'contactId',
          'Required parameter contactId was null or undefined when calling patchContact.',
        );
      }
      // verify required parameter 'Contact' is not null or undefined
      if (Contact === null || Contact === undefined) {
        throw new RequiredError(
          'Contact',
          'Required parameter Contact was null or undefined when calling patchContact.',
        );
      }
      const localVarPath = `/contacts/{contactId}`.replace(
        `{${'contactId'}}`,
        encodeURIComponent(String(contactId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Contact' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Contact || {})
        : Contact || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove a contact by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a contact resource when that contact is eligible to be removed. The contact must not be in use (there may not be any active associations to the contact). This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `removed`.
     * @summary Remove a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { contact, contactUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'contact' is not null or undefined
      if (contact === null || contact === undefined) {
        throw new RequiredError(
          'contact',
          'Required parameter contact was null or undefined when calling removeContact.',
        );
      }
      const localVarPath = `/removedContacts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (contact !== undefined) {
        localVarQueryParameter['contact'] = contact;
      }

      if (contactUri !== undefined) {
        localVarQueryParameter['contactUri'] = contactUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this contact.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'contactId' is not null or undefined
      if (contactId === null || contactId === undefined) {
        throw new RequiredError(
          'contactId',
          'Required parameter contactId was null or undefined when calling updateContact.',
        );
      }
      // verify required parameter 'Contact' is not null or undefined
      if (Contact === null || Contact === undefined) {
        throw new RequiredError(
          'Contact',
          'Required parameter Contact was null or undefined when calling updateContact.',
        );
      }
      const localVarPath = `/contacts/{contactId}`.replace(
        `{${'contactId'}}`,
        encodeURIComponent(String(contactId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Contact' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Contact || {})
        : Contact || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ContactApi - functional programming interface
 * @export
 */
export const ContactApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a contact from an inactive state. <p> This operation is invoked from the `apiture:activate` link on a contact resource when that contact is eligible to be activated. This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `active`.
     * @summary Activate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).activateContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new contact in the contacts collection.
     * @summary Create a new contact
     * @param {CreateContact} CreateContact The data necessary to create a new contact.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createContact(
      CreateContact: CreateContact,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).createContact(
        CreateContact ? CreateContact : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate a contact from an active state. <p> This operation is invoked from the `apiture:deactivate` link on a contact resource when that contact is eligible to be deactivated. This operation is only allowed if the state is `active`. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).deactivateContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this contact resource.
     * @summary Fetch a representation of this contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContact(
      contactId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).getContact(
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of contacts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of contacts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first contact item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of contact representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'active' | 'inactive' | 'removed'} [query.state] Subset the contacts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'unknown' | 'architectureAndEngineering' | 'artsDesignEntertainmentSportsAndMedia' | 'buildingAndGroundsCleaningAndMaintenance' | 'businessAndFinancialOperations' | 'communityAndSocialService' | 'computerAndMathematical' | 'constructionAndExtraction' | 'educationTrainingAndLibrary' | 'farmingFishingAndForestry' | 'foodPreparationAndServingRelated' | 'healthcarePractitionersAndTechnical' | 'healthcareSupport' | 'installationMaintenanceAndRepair' | 'legal' | 'lifePhysicalAndSciences' | 'management' | 'militarySpecific' | 'officeAndAdministrativeSupport' | 'personalCareAndService' | 'production' | 'protectiveServices' | 'salesAndRelated' | 'transportationAndMaterialMoving' | 'other' | 'notApplicable'} [query.occupation] Subset the contacts collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?occupation&#x3D;officeAndAdministrativeSupport&#x60; matches only items whose occupation is &#x60;officeAndAdministrativeSupport&#x60;; &#x60;?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving&#x60; matches items whose occupation is &#x60;officeAndAdministrativeSupport&#x60; or &#x60;transportationAndMaterialMoving&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering). The values are derived from the &#x60;occupation&#x60; label group from the result of the [&#x60;getLabels&#x60;](#op-getLabels) operation. &lt;br&gt; **Note:** The enum list will be removed in future update to the API.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContacts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed';
        occupation?:
          | 'unknown'
          | 'architectureAndEngineering'
          | 'artsDesignEntertainmentSportsAndMedia'
          | 'buildingAndGroundsCleaningAndMaintenance'
          | 'businessAndFinancialOperations'
          | 'communityAndSocialService'
          | 'computerAndMathematical'
          | 'constructionAndExtraction'
          | 'educationTrainingAndLibrary'
          | 'farmingFishingAndForestry'
          | 'foodPreparationAndServingRelated'
          | 'healthcarePractitionersAndTechnical'
          | 'healthcareSupport'
          | 'installationMaintenanceAndRepair'
          | 'legal'
          | 'lifePhysicalAndSciences'
          | 'management'
          | 'militarySpecific'
          | 'officeAndAdministrativeSupport'
          | 'personalCareAndService'
          | 'production'
          | 'protectiveServices'
          | 'salesAndRelated'
          | 'transportationAndMaterialMoving'
          | 'other'
          | 'notApplicable';
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contacts> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).getContacts(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this contact. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).patchContact(
        Contact ? Contact : null,
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove a contact by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a contact resource when that contact is eligible to be removed. The contact must not be in use (there may not be any active associations to the contact). This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `removed`.
     * @summary Remove a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).removeContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this contact.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Contact> {
      const localVarAxiosArgs = ContactApiAxiosParamCreator(configuration).updateContact(
        Contact ? Contact : null,
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ContactApi - factory interface
 * @export
 */
export const ContactApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate a contact from an inactive state. <p> This operation is invoked from the `apiture:activate` link on a contact resource when that contact is eligible to be activated. This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `active`.
     * @summary Activate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ContactApiFp(configuration).activateContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new contact in the contacts collection.
     * @summary Create a new contact
     * @param {CreateContact} CreateContact The data necessary to create a new contact.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createContact(CreateContact: CreateContact, options?: any) {
      return ContactApiFp(configuration).createContact(
        CreateContact ? CreateContact : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate a contact from an active state. <p> This operation is invoked from the `apiture:deactivate` link on a contact resource when that contact is eligible to be deactivated. This operation is only allowed if the state is `active`. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ContactApiFp(configuration).deactivateContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this contact resource.
     * @summary Fetch a representation of this contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContact(contactId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ContactApiFp(configuration).getContact(
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of contacts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of contacts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first contact item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of contact representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'active' | 'inactive' | 'removed'} [query.state] Subset the contacts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'unknown' | 'architectureAndEngineering' | 'artsDesignEntertainmentSportsAndMedia' | 'buildingAndGroundsCleaningAndMaintenance' | 'businessAndFinancialOperations' | 'communityAndSocialService' | 'computerAndMathematical' | 'constructionAndExtraction' | 'educationTrainingAndLibrary' | 'farmingFishingAndForestry' | 'foodPreparationAndServingRelated' | 'healthcarePractitionersAndTechnical' | 'healthcareSupport' | 'installationMaintenanceAndRepair' | 'legal' | 'lifePhysicalAndSciences' | 'management' | 'militarySpecific' | 'officeAndAdministrativeSupport' | 'personalCareAndService' | 'production' | 'protectiveServices' | 'salesAndRelated' | 'transportationAndMaterialMoving' | 'other' | 'notApplicable'} [query.occupation] Subset the contacts collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?occupation&#x3D;officeAndAdministrativeSupport&#x60; matches only items whose occupation is &#x60;officeAndAdministrativeSupport&#x60;; &#x60;?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving&#x60; matches items whose occupation is &#x60;officeAndAdministrativeSupport&#x60; or &#x60;transportationAndMaterialMoving&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering). The values are derived from the &#x60;occupation&#x60; label group from the result of the [&#x60;getLabels&#x60;](#op-getLabels) operation. &lt;br&gt; **Note:** The enum list will be removed in future update to the API.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContacts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed';
        occupation?:
          | 'unknown'
          | 'architectureAndEngineering'
          | 'artsDesignEntertainmentSportsAndMedia'
          | 'buildingAndGroundsCleaningAndMaintenance'
          | 'businessAndFinancialOperations'
          | 'communityAndSocialService'
          | 'computerAndMathematical'
          | 'constructionAndExtraction'
          | 'educationTrainingAndLibrary'
          | 'farmingFishingAndForestry'
          | 'foodPreparationAndServingRelated'
          | 'healthcarePractitionersAndTechnical'
          | 'healthcareSupport'
          | 'installationMaintenanceAndRepair'
          | 'legal'
          | 'lifePhysicalAndSciences'
          | 'management'
          | 'militarySpecific'
          | 'officeAndAdministrativeSupport'
          | 'personalCareAndService'
          | 'production'
          | 'protectiveServices'
          | 'salesAndRelated'
          | 'transportationAndMaterialMoving'
          | 'other'
          | 'notApplicable';
      },
      options?: any,
    ) {
      return ContactApiFp(configuration).getContacts(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this contact. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ContactApiFp(configuration).patchContact(
        Contact ? Contact : null,
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove a contact by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a contact resource when that contact is eligible to be removed. The contact must not be in use (there may not be any active associations to the contact). This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `removed`.
     * @summary Remove a contact.
     * @param {Object} [query] Query object
     * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
     * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeContact(
      query?: { contact?: string; contactUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ContactApiFp(configuration).removeContact(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this contact.
     * @summary Update this contact
     * @param {Contact} Contact
     * @param {string} contactId The unique identifier of this contact. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateContact(
      Contact: Contact,
      contactId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ContactApiFp(configuration).updateContact(
        Contact ? Contact : null,
        contactId ? contactId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ContactApi - object-oriented interface
 * @export
 * @class ContactApi
 * @extends {BaseAPI}
 */
export class ContactApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate a contact from an inactive state. <p> This operation is invoked from the `apiture:activate` link on a contact resource when that contact is eligible to be activated. This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `active`.
   * @summary Activate a contact.
   * @param {Object} [query] Query object
   * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
   * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public activateContact(
    query?: { contact?: string; contactUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).activateContact(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new contact in the contacts collection.
   * @summary Create a new contact
   * @param {CreateContact} CreateContact The data necessary to create a new contact.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public createContact(CreateContact: CreateContact, options?: any) {
    return ContactApiFp(this.configuration).createContact(
      CreateContact ? CreateContact : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate a contact from an active state. <p> This operation is invoked from the `apiture:deactivate` link on a contact resource when that contact is eligible to be deactivated. This operation is only allowed if the state is `active`. <p> This changes the `state` to `inactive`.
   * @summary Deactivate a contact.
   * @param {Object} [query] Query object
   * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
   * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public deactivateContact(
    query?: { contact?: string; contactUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).deactivateContact(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this contact resource.
   * @summary Fetch a representation of this contact
   * @param {string} contactId The unique identifier of this contact. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public getContact(contactId: string, headers?: { If_None_Match?: string }, options?: any) {
    return ContactApiFp(this.configuration).getContact(
      contactId ? contactId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of contacts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of contacts
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first contact item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of contact representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'active' | 'inactive' | 'removed'} [query.state] Subset the contacts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {'unknown' | 'architectureAndEngineering' | 'artsDesignEntertainmentSportsAndMedia' | 'buildingAndGroundsCleaningAndMaintenance' | 'businessAndFinancialOperations' | 'communityAndSocialService' | 'computerAndMathematical' | 'constructionAndExtraction' | 'educationTrainingAndLibrary' | 'farmingFishingAndForestry' | 'foodPreparationAndServingRelated' | 'healthcarePractitionersAndTechnical' | 'healthcareSupport' | 'installationMaintenanceAndRepair' | 'legal' | 'lifePhysicalAndSciences' | 'management' | 'militarySpecific' | 'officeAndAdministrativeSupport' | 'personalCareAndService' | 'production' | 'protectiveServices' | 'salesAndRelated' | 'transportationAndMaterialMoving' | 'other' | 'notApplicable'} [query.occupation] Subset the contacts collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?occupation&#x3D;officeAndAdministrativeSupport&#x60; matches only items whose occupation is &#x60;officeAndAdministrativeSupport&#x60;; &#x60;?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving&#x60; matches items whose occupation is &#x60;officeAndAdministrativeSupport&#x60; or &#x60;transportationAndMaterialMoving&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering). The values are derived from the &#x60;occupation&#x60; label group from the result of the [&#x60;getLabels&#x60;](#op-getLabels) operation. &lt;br&gt; **Note:** The enum list will be removed in future update to the API.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contacts}
   * @memberof ContactApi
   */
  public getContacts(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: 'pending' | 'active' | 'inactive' | 'removed';
      occupation?:
        | 'unknown'
        | 'architectureAndEngineering'
        | 'artsDesignEntertainmentSportsAndMedia'
        | 'buildingAndGroundsCleaningAndMaintenance'
        | 'businessAndFinancialOperations'
        | 'communityAndSocialService'
        | 'computerAndMathematical'
        | 'constructionAndExtraction'
        | 'educationTrainingAndLibrary'
        | 'farmingFishingAndForestry'
        | 'foodPreparationAndServingRelated'
        | 'healthcarePractitionersAndTechnical'
        | 'healthcareSupport'
        | 'installationMaintenanceAndRepair'
        | 'legal'
        | 'lifePhysicalAndSciences'
        | 'management'
        | 'militarySpecific'
        | 'officeAndAdministrativeSupport'
        | 'personalCareAndService'
        | 'production'
        | 'protectiveServices'
        | 'salesAndRelated'
        | 'transportationAndMaterialMoving'
        | 'other'
        | 'notApplicable';
    },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).getContacts(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a partial update of this contact. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this contact
   * @param {Contact} Contact
   * @param {string} contactId The unique identifier of this contact. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public patchContact(
    Contact: Contact,
    contactId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).patchContact(
      Contact ? Contact : null,
      contactId ? contactId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove a contact by setting its state to `removed`. <p> This operation is invoked from the `apiture:remove` link on a contact resource when that contact is eligible to be removed. The contact must not be in use (there may not be any active associations to the contact). This operation is only allowed if the state is `inactive`. <p> This changes the `state` to `removed`.
   * @summary Remove a contact.
   * @param {Object} [query] Query object
   * @param {string} [query.contact] A string which identifies an existing contact to activate, deactivate, or remove by &#x60;POST&#x60;ing it to the corresponding resource set. The server supplies this value in a link within the representation of a contact. The value may be a &#x60;{contactId}&#x60; or a contact URI.
   * @param {string} [query.contactUri] The URI of an existing contact which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?contact&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public removeContact(
    query?: { contact?: string; contactUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).removeContact(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this contact.
   * @summary Update this contact
   * @param {Contact} Contact
   * @param {string} contactId The unique identifier of this contact. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Contact}
   * @memberof ContactApi
   */
  public updateContact(
    Contact: Contact,
    contactId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ContactApiFp(this.configuration).updateContact(
      Contact ? Contact : null,
      contactId ? contactId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
