// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Dates
 * The Dates API provides various operations relating to calendars and dates. For example, the `/eventDates` method can be used to find upcoming events given one or more schedules and a calendar of exclusions.
 *
 * OpenAPI spec version: 0.7.0
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/dates'.replace(/\/+$/, '');

export const API_VERSION = '0.7.0';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A definition of a calendar.
 * @export
 * @interface Calendar
 */
export interface Calendar {
  /**
   * A collection of dates on which events cannot occur.  These dates should be in the [RFC 3339](https://tools.ietf.org/html/rfc3339) format, `yyyy-mm-dd`.
   * @type {Array<string>}
   * @memberof Calendar
   */
  holidays: Array<string>;
  /**
   * A collection of days of the week on which events cannot occur.
   * @type {Array<string>}
   * @memberof Calendar
   */
  unprocessableDays: Array<Calendar.UnprocessableDaysEnum>;
}

/**
 * @export
 * @namespace Calendar
 */
export namespace Calendar {
  /**
   * @export
   * @enum {string}
   */
  export enum UnprocessableDaysEnum {
    Sunday = 'sunday',
    Monday = 'monday',
    Tuesday = 'tuesday',
    Wednesday = 'wednesday',
    Thursday = 'thursday',
    Friday = 'friday',
    Saturday = 'saturday',
  }
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * A date and one or more events that occur on that date. The `labels` property will reference the associated schedules.
 * @export
 * @interface EventDate
 */
export interface EventDate {
  /**
   * The text `label` for this event, suitable for presentation to the client.  This label references the one or more associated schedules.
   * @type {Array<string>}
   * @memberof EventDate
   */
  labels: Array<string>;
  /**
   * This date is in the [ISO 8601 Date](https://en.wikipedia.org/wiki/ISO_8601#Calendar_dates) format, `yyyy-mm-dd`.
   * @type {string}
   * @memberof EventDate
   */
  date: string;
}

/**
 * Collection of event dates. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`). These pagination links require using `POST` and should pass the same Event Dates Request object as described in the `findEventsDate` operation.
 * @export
 * @interface EventDates
 */
export interface EventDates extends Collection {
  /**
   * The start date of events on this page.
   * @type {string}
   * @memberof EventDates
   */
  startDate?: string;
  /**
   * The length of time used to paginate event date results.
   * @type {string}
   * @memberof EventDates
   */
  period?: string;
  /**
   * Embedded objects.
   * @type {any}
   * @memberof EventDates
   */
  _embedded?: any;
}

/**
 * The request body for invoking `/eventDates`.  Contains an array of scheduled events and a calendar representing excluded dates.
 * @export
 * @interface EventDatesRequest
 */
export interface EventDatesRequest {
  /**
   * A list of one or more schedules for the event.
   * @type {Array<Schedule>}
   * @memberof EventDatesRequest
   */
  schedules: Array<Schedule>;
  /**
   *
   * @type {Calendar}
   * @memberof EventDatesRequest
   */
  exclusions?: Calendar;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * A definition for a one-time or recurring scheduled event.
 * @export
 * @interface Schedule
 */
export interface Schedule {
  /**
   * The text `label` for this schedule, suitable for presentation to the client.  Events will use this label to reference a schedule.
   * @type {string}
   * @memberof Schedule
   */
  label: string;
  /**
   * When the event occurs, or when a recurring event begins. This is a date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) `yyyy-mm-ddTHH:MM:SSZ` format. If present, the time portion is a _hint_; the financial institution  may not be able to schedule events at specific times. If `start` is not provided, the current date will be used. If `start` is after the end of processing for the current day, the event may be scheduled for the next processing day.
   * @type {Date}
   * @memberof Schedule
   */
  start?: Date;
  /**
   * The `every` period indicates the interval at which the event recurs, such as every week, every month, every 3 months. If omitted or empty, this event is a one-time event.  `every` is **required** if either `maximumCount` is greater than 1 or if `end` is greater than `start`. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the number of years/months/days between events. For example, use `P7D` to schedule every week, `P2M` to schedule every other month, `P4Y` to schedule every four years on the anniversary set by `start`. Time values in `every` are ignored but may be honored in the future. (That is, it is not possible to schedule an event every 8 hours; the minimum is `P1D`). To specify semi-monthly or semi-annually, use `P0.5M` or `P0.5Y`.  Fractional values are only allowed for month and year, and `0.5`  is the only allowed fractional value. Some financial institutions may limit recurring events such that the period must be a year (`P1Y`, 'P12M`, 'P365D`) or less. Scheduling may adjust event dates if `start` occurs near boundary dates which do occur not every year/month, such as `start: \"2019-01-31\", every: \"P1M\"`. For example, the next event may occur on the 30th for months which have only 30 days (Apr, Jun, Sep, Nov), or 29th or 28th for February. Actual event dates may also be adjusted to account for holidays or other days when processing does not occur.
   * @type {string}
   * @memberof Schedule
   */
  every?: string;
  /**
   * For a recurring event, this is the number of events which have occurred. It is a derived value and ignored on updates.
   * @type {number}
   * @memberof Schedule
   */
  count?: number;
  /**
   * For a recurring event, this is the number of events which have been skipped, either because a processing date passed when a recurring event had a value of `true` for `skipNext`, or a recurring event was suspended. It is a derived value and ignored on updates.
   * @type {number}
   * @memberof Schedule
   */
  skippedCount?: number;
  /**
   * The maximum number of events to schedule for a recurring event. (Events in the recurrence will stop if the current date is beyond that set by `end, even if fewer than `maximumCount` events have occurred.) The `every` period is required if `maximumCount` or `end` is set. It is an error (422) if `maximumCount` is anything other than 0 or 1 and `every` is not set.  If a schedule contains both `end` and `maximumCount`, the _earliest_ will determine when the recurrence ends.
   * @type {number}
   * @memberof Schedule
   */
  maximumCount?: number;
  /**
   * This field is *ignored* for one-time events. If true for recurring schedules, skip (do not schedule) the next event. After that instance is skipped, this field is reset to false (only one instance may be skipped).
   * @type {boolean}
   * @memberof Schedule
   */
  skipNext?: boolean;
  /**
   * The optional date when the recurring event ends (inclusive). Events recur until the `maximumCount` of events are met _or_ the next scheduled event is _after_ the `end` date. (The earliest of `maximumCount` or `end` wins). If specified, `end` must be no earlier than `start`. This is a date in [RFC 3339](https://tools.ietf.org/html/rfc3339) `yyyy-mm-dd` format.   When scheduling an event, the request should contain either `maximumCount` or `end`, but not both. The other field will be computed.
   * @type {string}
   * @memberof Schedule
   */
  end?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:findEventDates`* - a `POST` operation for finding dates corresponding to recurring scheduled events
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:findEventDates`* - a `POST` operation for finding dates corresponding to recurring scheduled events
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:findEventDates`* - a `POST` operation for finding dates corresponding to recurring scheduled events
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:findEventDates`* - a `POST` operation for finding dates corresponding to recurring scheduled events
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * EventDatesApi - axios parameter creator
 * @export
 */
export const EventDatesApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Finds upcoming event dates given one or more schedules of events and exclusions.  Available parameters include `start`, `limit`, `startDate`, and `period`. There are two modes of pagination available:   * Indexed pages defined by a `start` index and a `limit`  * `period` based pagination beginning at `startDate`   Only one mode of pagination can be used at a time and the default mode is `period` with a value of `P1Y`.  To obtain the next page of results, use the `next` link in the response (if it exists) with a `POST` verb. Pass the same request body as passed to this operation (this operation is fully stateless). If there is no `next` link, the collection has been exhausted. Note that some queries may not have a terminating collection (for example, if the schedule does not have a start date). The service will update the query parameters in the link to access the next page, according to the type of pagination in use. Thait is, it will increment the `start` if initially invoked with indexed-based pagination, or it will adjust the `startDate` if initially invoked with period-based pagination. The `limit` passed to this operation will also be passed to the `next` page.
     * @summary Return a collection of event dates
     * @param {EventDatesRequest} EventDatesRequest The data necessary to find event dates.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first event date item to include in this page. The default 0 denotes the beginning of the collection.  If &#x60;startDate&#x60; is also provided &#x60;start&#x60; will be ignored.
     * @param {number} [query.limit] The maximum number of event dates to return in this page. If &#x60;period&#x60; is also provided, &#x60;limit&#x60; will be ignored.
     * @param {string} [query.startDate] The start date of the period in which to look for events. If &#x60;period&#x60; pagination mode is being used and no &#x60;startDate&#x60; is provided, the current date will be used. &#x60;startDate&#x60; will override &#x60;start&#x60; if both are provided.
     * @param {string} [query.period] The length of time used to paginate event date results. &#x60;period&#x60; will override &#x60;limit&#x60; if both are provided. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form &#x60;P[n]Y[n]M[n]D&#x60; to specify the number of years/months/days between dates. For example, use &#x60;P7D&#x60; to paginate by weeks, &#x60;P2M&#x60; to paginate by 2 months.  Time values in &#x60;period&#x60; are ignored but may be honored in the future.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    findEventDates(
      EventDatesRequest: EventDatesRequest,
      query?: { start?: number; limit?: number; startDate?: Date; period?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, startDate, period } = query;

      // verify required parameter 'EventDatesRequest' is not null or undefined
      if (EventDatesRequest === null || EventDatesRequest === undefined) {
        throw new RequiredError(
          'EventDatesRequest',
          'Required parameter EventDatesRequest was null or undefined when calling findEventDates.',
        );
      }
      const localVarPath = `/eventDates`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (startDate !== undefined) {
        localVarQueryParameter['startDate'] = (startDate as any).toISOString();
      }

      if (period !== undefined) {
        localVarQueryParameter['period'] = period;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'EventDatesRequest' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(EventDatesRequest || {})
        : EventDatesRequest || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EventDatesApi - functional programming interface
 * @export
 */
export const EventDatesApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Finds upcoming event dates given one or more schedules of events and exclusions.  Available parameters include `start`, `limit`, `startDate`, and `period`. There are two modes of pagination available:   * Indexed pages defined by a `start` index and a `limit`  * `period` based pagination beginning at `startDate`   Only one mode of pagination can be used at a time and the default mode is `period` with a value of `P1Y`.  To obtain the next page of results, use the `next` link in the response (if it exists) with a `POST` verb. Pass the same request body as passed to this operation (this operation is fully stateless). If there is no `next` link, the collection has been exhausted. Note that some queries may not have a terminating collection (for example, if the schedule does not have a start date). The service will update the query parameters in the link to access the next page, according to the type of pagination in use. Thait is, it will increment the `start` if initially invoked with indexed-based pagination, or it will adjust the `startDate` if initially invoked with period-based pagination. The `limit` passed to this operation will also be passed to the `next` page.
     * @summary Return a collection of event dates
     * @param {EventDatesRequest} EventDatesRequest The data necessary to find event dates.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first event date item to include in this page. The default 0 denotes the beginning of the collection.  If &#x60;startDate&#x60; is also provided &#x60;start&#x60; will be ignored.
     * @param {number} [query.limit] The maximum number of event dates to return in this page. If &#x60;period&#x60; is also provided, &#x60;limit&#x60; will be ignored.
     * @param {string} [query.startDate] The start date of the period in which to look for events. If &#x60;period&#x60; pagination mode is being used and no &#x60;startDate&#x60; is provided, the current date will be used. &#x60;startDate&#x60; will override &#x60;start&#x60; if both are provided.
     * @param {string} [query.period] The length of time used to paginate event date results. &#x60;period&#x60; will override &#x60;limit&#x60; if both are provided. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form &#x60;P[n]Y[n]M[n]D&#x60; to specify the number of years/months/days between dates. For example, use &#x60;P7D&#x60; to paginate by weeks, &#x60;P2M&#x60; to paginate by 2 months.  Time values in &#x60;period&#x60; are ignored but may be honored in the future.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    findEventDates(
      EventDatesRequest: EventDatesRequest,
      query?: { start?: number; limit?: number; startDate?: Date; period?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<EventDates> {
      const localVarAxiosArgs = EventDatesApiAxiosParamCreator(configuration).findEventDates(
        EventDatesRequest ? EventDatesRequest : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EventDatesApi - factory interface
 * @export
 */
export const EventDatesApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Finds upcoming event dates given one or more schedules of events and exclusions.  Available parameters include `start`, `limit`, `startDate`, and `period`. There are two modes of pagination available:   * Indexed pages defined by a `start` index and a `limit`  * `period` based pagination beginning at `startDate`   Only one mode of pagination can be used at a time and the default mode is `period` with a value of `P1Y`.  To obtain the next page of results, use the `next` link in the response (if it exists) with a `POST` verb. Pass the same request body as passed to this operation (this operation is fully stateless). If there is no `next` link, the collection has been exhausted. Note that some queries may not have a terminating collection (for example, if the schedule does not have a start date). The service will update the query parameters in the link to access the next page, according to the type of pagination in use. Thait is, it will increment the `start` if initially invoked with indexed-based pagination, or it will adjust the `startDate` if initially invoked with period-based pagination. The `limit` passed to this operation will also be passed to the `next` page.
     * @summary Return a collection of event dates
     * @param {EventDatesRequest} EventDatesRequest The data necessary to find event dates.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first event date item to include in this page. The default 0 denotes the beginning of the collection.  If &#x60;startDate&#x60; is also provided &#x60;start&#x60; will be ignored.
     * @param {number} [query.limit] The maximum number of event dates to return in this page. If &#x60;period&#x60; is also provided, &#x60;limit&#x60; will be ignored.
     * @param {string} [query.startDate] The start date of the period in which to look for events. If &#x60;period&#x60; pagination mode is being used and no &#x60;startDate&#x60; is provided, the current date will be used. &#x60;startDate&#x60; will override &#x60;start&#x60; if both are provided.
     * @param {string} [query.period] The length of time used to paginate event date results. &#x60;period&#x60; will override &#x60;limit&#x60; if both are provided. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form &#x60;P[n]Y[n]M[n]D&#x60; to specify the number of years/months/days between dates. For example, use &#x60;P7D&#x60; to paginate by weeks, &#x60;P2M&#x60; to paginate by 2 months.  Time values in &#x60;period&#x60; are ignored but may be honored in the future.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    findEventDates(
      EventDatesRequest: EventDatesRequest,
      query?: { start?: number; limit?: number; startDate?: Date; period?: string },
      options?: any,
    ) {
      return EventDatesApiFp(configuration).findEventDates(
        EventDatesRequest ? EventDatesRequest : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EventDatesApi - object-oriented interface
 * @export
 * @class EventDatesApi
 * @extends {BaseAPI}
 */
export class EventDatesApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Finds upcoming event dates given one or more schedules of events and exclusions.  Available parameters include `start`, `limit`, `startDate`, and `period`. There are two modes of pagination available:   * Indexed pages defined by a `start` index and a `limit`  * `period` based pagination beginning at `startDate`   Only one mode of pagination can be used at a time and the default mode is `period` with a value of `P1Y`.  To obtain the next page of results, use the `next` link in the response (if it exists) with a `POST` verb. Pass the same request body as passed to this operation (this operation is fully stateless). If there is no `next` link, the collection has been exhausted. Note that some queries may not have a terminating collection (for example, if the schedule does not have a start date). The service will update the query parameters in the link to access the next page, according to the type of pagination in use. Thait is, it will increment the `start` if initially invoked with indexed-based pagination, or it will adjust the `startDate` if initially invoked with period-based pagination. The `limit` passed to this operation will also be passed to the `next` page.
   * @summary Return a collection of event dates
   * @param {EventDatesRequest} EventDatesRequest The data necessary to find event dates.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first event date item to include in this page. The default 0 denotes the beginning of the collection.  If &#x60;startDate&#x60; is also provided &#x60;start&#x60; will be ignored.
   * @param {number} [query.limit] The maximum number of event dates to return in this page. If &#x60;period&#x60; is also provided, &#x60;limit&#x60; will be ignored.
   * @param {string} [query.startDate] The start date of the period in which to look for events. If &#x60;period&#x60; pagination mode is being used and no &#x60;startDate&#x60; is provided, the current date will be used. &#x60;startDate&#x60; will override &#x60;start&#x60; if both are provided.
   * @param {string} [query.period] The length of time used to paginate event date results. &#x60;period&#x60; will override &#x60;limit&#x60; if both are provided. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form &#x60;P[n]Y[n]M[n]D&#x60; to specify the number of years/months/days between dates. For example, use &#x60;P7D&#x60; to paginate by weeks, &#x60;P2M&#x60; to paginate by 2 months.  Time values in &#x60;period&#x60; are ignored but may be honored in the future.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {EventDates}
   * @memberof EventDatesApi
   */
  public findEventDates(
    EventDatesRequest: EventDatesRequest,
    query?: { start?: number; limit?: number; startDate?: Date; period?: string },
    options?: any,
  ) {
    return EventDatesApiFp(this.configuration).findEventDates(
      EventDatesRequest ? EventDatesRequest : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
