# @apiture/identity-client-sdk@0.7.3
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/identity-client-sdk@0.7.3 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ApprovalsApi, FraudRiskReportsApi, QuizzesApi, VerifyApi } from "@apiture/identity-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ApprovalsApi main class passing the configuration object.
    const approvalsApi = new ApprovalsApi(configuration);

// Instantiate FraudRiskReportsApi main class passing the configuration object.
    const fraudRiskReportsApi = new FraudRiskReportsApi(configuration);

// Instantiate QuizzesApi main class passing the configuration object.
    const quizzesApi = new QuizzesApi(configuration);

// Instantiate VerifyApi main class passing the configuration object.
    const verifyApi = new VerifyApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/identity",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Identity SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ApprovalsApi


  `ApprovalsApi.createApproval` - Create a new approval resource

  `ApprovalsApi.getApproval` - Fetch a representation of this approval



### FraudRiskReportsApi


  `FraudRiskReportsApi.createFraudRiskReport` - Create a new fraud-risk analysis report

  `FraudRiskReportsApi.getFraudRiskReport` - Fetch a representation of this fraud-risk report

  `FraudRiskReportsApi.getFraudRiskReports` - Returns a collection of fraud-risk analysis results



### QuizzesApi


  `QuizzesApi.createQuiz` - Create a new quiz

  `QuizzesApi.createQuizQuestions` - Generate the questions for a quiz

  `QuizzesApi.getQuiz` - Fetch a representation of this quiz

  `QuizzesApi.getQuizzes` - Returns a collection of quizzes

  `QuizzesApi.scoreQuiz` - Submit the answers to a quiz



### VerifyApi


  `VerifyApi.getContactVerification` - Retrieves contact verification resource.



## About the Identity API
___
This API manages the set of actions that allow financial institutions to verify the identity of their customers and applicants. 'Identity' is defined as a set of personally identifiable information (PII) that can potentially identify a specific individual.   PII consists of the following attributes:    * `taxId` The identity's tax or government ID   * `firstName` The identity's first name   * `lastName`  The identity's last name   * `address1` Line 1 of the identity's street address   * `address2` Line 2 of the identity's street address   * `city` The identity's city   * `region` The identity's region   * `postalCode` The identity's postal code   * `phone` The identity's phone   * `birthdate` The identity's birth date in `yyyy-mm-dd` format.   * `email` The identity's email address   * `ipAddress` The identity's IP address  There are two major steps to the identity verification process - fraud-risk analysis and knowledge-base authentication (KBA) quizzes.   A _fraud-risk report_ can be generated by specifying the PII associated with an individual.  The report will contain a state indicating the result  of the operation as well as an optional list of fraud risk factors associated with that identity. A `passed` state indicates that the provided PII was located and contains no risk factors. A `passedWithRiskFactors` state means that the provided PII matches an identity but contains risk factors. A `failed` state means that the provided PII does not match any identity records.   In order to generate a report, submit the PII via `POST` to `/fraudRiskReports`. This will return a `201` response containing a new `fraudRiskReport` resource which includes `outputs` with a collection of `fraudRiskCategories`. These categories are:    * `personalInfoDoesNotMatch` The retrieved identity does not match the provided PII.   * `addressIsPOBoxOrNonApproved` The provided address is a PO Box or other non-approved address   * `addressIsHighRisk` The provided address is considered high-risk   * `identityOnGovernmentWatchlist` The provided identity is located on one or more government watchlists   * `identityOnAlertList` The provided identity is located on one or more alert lists   * `ipRestricted` The provided IP address is restricted   * `emailRestricted` The provided email address is restricted   * `ageRestricted` The provided identity does not meet the required age. Example: US COPPA laws forbid conducting e-commerce with people under 14 years of age.   * `nonStandardTaxId` The provided taxId is non-standard. Example: The provided SSN is an ITIN (Individual Taxpayer Identification Number)   A _quiz_ containing a list of questions and their possible answers can be generated with a set of PII.  This information can be used to assist in the verification of the identity, by presenting the  customer or applicant with the questions and prompting them to choose the appropriate answers.  These answers can then be submitted to verify their correctness, confirming the identity.   In order to generate a quiz, submit the PII via `POST` to `/quizzes`. This will return a `201` response containing a new `quiz` resource with a state of `pending`. You can then `POST` to `/quizzes/{quizId}/questions` by following the `apiture:getQuestions` link to generate one-time-use (transient) set of questions. When you have collected the answers to these questions you can submit them to `/quizzes/{quizId}/answers` via `POST` by following the `apiture:score` link. This will return the quiz resource with an updated state, either  `passed`, `failed` or `expired`.
