// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Identity
 * This API manages the set of actions that allow financial institutions to verify the identity of their customers and applicants. 'Identity' is defined as a set of personally identifiable information (PII) that can potentially identify a specific individual.   PII consists of the following attributes:    * `taxId` The identity's tax or government ID   * `firstName` The identity's first name   * `lastName`  The identity's last name   * `address1` Line 1 of the identity's street address   * `address2` Line 2 of the identity's street address   * `city` The identity's city   * `region` The identity's region   * `postalCode` The identity's postal code   * `phone` The identity's phone   * `birthdate` The identity's birth date in `yyyy-mm-dd` format.   * `email` The identity's email address   * `ipAddress` The identity's IP address  There are two major steps to the identity verification process - fraud-risk analysis and knowledge-base authentication (KBA) quizzes.   A _fraud-risk report_ can be generated by specifying the PII associated with an individual.  The report will contain a state indicating the result  of the operation as well as an optional list of fraud risk factors associated with that identity. A `passed` state indicates that the provided PII was located and contains no risk factors. A `passedWithRiskFactors` state means that the provided PII matches an identity but contains risk factors. A `failed` state means that the provided PII does not match any identity records.   In order to generate a report, submit the PII via `POST` to `/fraudRiskReports`. This will return a `201` response containing a new `fraudRiskReport` resource which includes `outputs` with a collection of `fraudRiskCategories`. These categories are:    * `personalInfoDoesNotMatch` The retrieved identity does not match the provided PII.   * `addressIsPOBoxOrNonApproved` The provided address is a PO Box or other non-approved address   * `addressIsHighRisk` The provided address is considered high-risk   * `identityOnGovernmentWatchlist` The provided identity is located on one or more government watchlists   * `identityOnAlertList` The provided identity is located on one or more alert lists   * `ipRestricted` The provided IP address is restricted   * `emailRestricted` The provided email address is restricted   * `ageRestricted` The provided identity does not meet the required age. Example: US COPPA laws forbid conducting e-commerce with people under 14 years of age.   * `nonStandardTaxId` The provided taxId is non-standard. Example: The provided SSN is an ITIN (Individual Taxpayer Identification Number)   A _quiz_ containing a list of questions and their possible answers can be generated with a set of PII.  This information can be used to assist in the verification of the identity, by presenting the  customer or applicant with the questions and prompting them to choose the appropriate answers.  These answers can then be submitted to verify their correctness, confirming the identity.   In order to generate a quiz, submit the PII via `POST` to `/quizzes`. This will return a `201` response containing a new `quiz` resource with a state of `pending`. You can then `POST` to `/quizzes/{quizId}/questions` by following the `apiture:getQuestions` link to generate one-time-use (transient) set of questions. When you have collected the answers to these questions you can submit them to `/quizzes/{quizId}/answers` via `POST` by following the `apiture:score` link. This will return the quiz resource with an updated state, either  `passed`, `failed` or `expired`.
 *
 * OpenAPI spec version: 0.7.3
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/identity'.replace(/\/+$/, '');

export const API_VERSION = '0.7.3';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The core representation of an Approval resource. This represents a manual approval and would typically be created by an FI admin when a Contact fails one or more steps of the identity verification workflow.
 * @export
 * @interface Approval
 */
export interface Approval extends AbstractResource, IdentityVerification {}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * The contact's verification history and status.
 * @export
 * @interface ContactVerification
 */
export interface ContactVerification extends AbstractResource {
  /**
   * The history of this contact's identity verifications.
   * @type {Array<IdentityHistoryItem>}
   * @memberof ContactVerification
   */
  verifications?: Array<IdentityHistoryItem>;
}

/**
 * An answer to a quiz question.
 * @export
 * @interface CoreAnswer
 */
export interface CoreAnswer {
  /**
   * The ID corresponding to the question in the quiz.
   * @type {string}
   * @memberof CoreAnswer
   */
  questionId: string;
  /**
   * The answer to the question.
   * @type {string}
   * @memberof CoreAnswer
   */
  answer: string;
}

/**
 * A collection of answers to a quiz.
 * @export
 * @interface CoreQuizAnswers
 */
export interface CoreQuizAnswers {
  /**
   * The list of answers the contact gave to the quiz questions.
   * @type {Array<CoreAnswer>}
   * @memberof CoreQuizAnswers
   */
  answers?: Array<CoreAnswer>;
}

/**
 * A question of a quiz.
 * @export
 * @interface CoreQuizQuestion
 */
export interface CoreQuizQuestion {
  /**
   * The identifier for this question. A quiz answer is associated with the question via the `questionId`.
   * @type {string}
   * @memberof CoreQuizQuestion
   */
  id: string;
  /**
   * The question text.
   * @type {string}
   * @memberof CoreQuizQuestion
   */
  question: string;
  /**
   * An array containing a page of quiz question choice items.
   * @type {Array<string>}
   * @memberof CoreQuizQuestion
   */
  choices?: Array<string>;
}

/**
 * The questions of a quiz.
 * @export
 * @interface CoreQuizQuestions
 */
export interface CoreQuizQuestions {
  /**
   * An array containing a page of quiz question items.
   * @type {Array<CoreQuizQuestion>}
   * @memberof CoreQuizQuestions
   */
  questions?: Array<CoreQuizQuestion>;
}

/**
 * Representation used to create a new fraud-risk analysis report.
 * @export
 * @interface CreateFraudRiskReport
 */
export interface CreateFraudRiskReport extends AbstractRequest, Identity {}

/**
 * Representation used to create a new quiz.
 * @export
 * @interface CreateQuiz
 */
export interface CreateQuiz extends Identity, AbstractRequest {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Representation of a fraud-risk category.
 * @export
 * @interface FraudRiskCategory
 */
export interface FraudRiskCategory {
  /**
   *
   * @type {FraudRiskCategoryType}
   * @memberof FraudRiskCategory
   */
  type?: FraudRiskCategoryType;
  /**
   * The description of the fraud.
   * @type {string}
   * @memberof FraudRiskCategory
   */
  description?: string;
  /**
   * The original result message that was received from the identity verification provider.
   * @type {string}
   * @memberof FraudRiskCategory
   */
  message?: string;
}

/**
 * Represents the possible types of fraud-risk.
 * @export
 * @enum {string}
 */
export enum FraudRiskCategoryType {
  IpRestricted = 'ipRestricted',
  IdentityOnGovernmentWatchlist = 'identityOnGovernmentWatchlist',
  IdentityOnAlertList = 'identityOnAlertList',
  AddressIsPOBoxOrNonApproved = 'addressIsPOBoxOrNonApproved',
  AddressIsHighRisk = 'addressIsHighRisk',
  AgeRestricted = 'ageRestricted',
  NonStandardTaxId = 'nonStandardTaxId',
  PersonalInfoDoesNotMatch = 'personalInfoDoesNotMatch',
  EmailRestricted = 'emailRestricted',
}

/**
 * The result of running a fraud-risk analysys.
 * @export
 * @interface FraudRiskReport
 */
export interface FraudRiskReport extends AbstractResource, IdentityVerification {
  /**
   *
   * @type {FraudRiskReportInputs}
   * @memberof FraudRiskReport
   */
  inputs?: FraudRiskReportInputs;
  /**
   *
   * @type {FraudRiskReportOutputs}
   * @memberof FraudRiskReport
   */
  outputs?: FraudRiskReportOutputs;
}

/**
 * The inputs of a fraud-risk report.
 * @export
 * @interface FraudRiskReportInputs
 */
export interface FraudRiskReportInputs {
  /**
   *
   * @type {Identity}
   * @memberof FraudRiskReportInputs
   */
  identity?: Identity;
}

/**
 * The outputs of a fraud-risk report.
 * @export
 * @interface FraudRiskReportOutputs
 */
export interface FraudRiskReportOutputs extends Outputs {
  /**
   * External identity provider report Id.
   * @type {string}
   * @memberof FraudRiskReportOutputs
   */
  providerReportId?: string;
  /**
   *
   * @type {FraudRiskReportState}
   * @memberof FraudRiskReportOutputs
   */
  state?: FraudRiskReportState;
  /**
   * A list of categories in this report.
   * @type {Array<FraudRiskCategory>}
   * @memberof FraudRiskReportOutputs
   */
  fraudRiskCategories?: Array<FraudRiskCategory>;
}

/**
 * The state of a fraud report. `passed` indicates that the provided personally identifiable information (PII) was located and contains no risk factors. `passedWithRiskFactors` means that the provided PII matches an identity but contains risk factors. `failed` means that the provided PII does not match any identity records.
 * @export
 * @enum {string}
 */
export enum FraudRiskReportState {
  Passed = 'passed',
  PassedWithRiskFactors = 'passedWithRiskFactors',
  Failed = 'failed',
}

/**
 * The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination  links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface FraudRiskReports
 */
export interface FraudRiskReports extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof FraudRiskReports
   */
  _embedded?: any;
}

/**
 * Information that describes the identity.
 * @export
 * @interface Identity
 */
export interface Identity {
  /**
   * The identity's tax or government ID.
   * @type {string}
   * @memberof Identity
   */
  taxId: string;
  /**
   * The identity's first name.
   * @type {string}
   * @memberof Identity
   */
  firstName: string;
  /**
   * The identity's last name.
   * @type {string}
   * @memberof Identity
   */
  lastName: string;
  /**
   * Line 1 of the identity's street address.
   * @type {string}
   * @memberof Identity
   */
  address1: string;
  /**
   * Line 2 of the identity's street address.
   * @type {string}
   * @memberof Identity
   */
  address2?: string;
  /**
   * The identity's city.
   * @type {string}
   * @memberof Identity
   */
  city: string;
  /**
   * The identity's region.
   * @type {string}
   * @memberof Identity
   */
  region: string;
  /**
   * The identity's postal code.
   * @type {string}
   * @memberof Identity
   */
  postalCode: string;
  /**
   * The identity's phone.
   * @type {string}
   * @memberof Identity
   */
  phone: string;
  /**
   * The identity's birth date in `yyyy-mm-dd` format.
   * @type {string}
   * @memberof Identity
   */
  birthdate: string;
  /**
   * The identity's email address.
   * @type {string}
   * @memberof Identity
   */
  email?: string;
  /**
   * The identity's IP address.
   * @type {string}
   * @memberof Identity
   */
  ipAddress?: string;
}

/**
 * One verification record for a contact's history of verifications. This may contain a link to the contact in the link `apiture:contact`.
 * @export
 * @interface IdentityHistoryItem
 */
export interface IdentityHistoryItem {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof IdentityHistoryItem
   */
  _links?: { [key: string]: Link };
  /**
   *
   * @type {IdentityVerificationState}
   * @memberof IdentityHistoryItem
   */
  state: IdentityVerificationState;
  /**
   *
   * @type {IdentityVerificationType}
   * @memberof IdentityHistoryItem
   */
  type?: IdentityVerificationType;
  /**
   * The date-time when the verification occurred or completed. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityHistoryItem
   */
  createdAt: Date;
  /**
   * The date-time when the verification expired. This is only set if the `state` is `expired`. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityHistoryItem
   */
  expiredAt?: Date;
}

/**
 * The core representation of an identity verification resource.
 * @export
 * @interface IdentityVerification
 */
export interface IdentityVerification extends AbstractResource {
  /**
   * A unique identifier for this resource instance. This is is an opaque string.
   * @type {string}
   * @memberof IdentityVerification
   */
  _id?: string;
  /**
   *
   * @type {IdentityVerificationType}
   * @memberof IdentityVerification
   */
  type?: IdentityVerificationType;
  /**
   * The date-time when the resource was created. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityVerification
   */
  createdAt?: Date;
  /**
   * The date-time when the resource expires. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityVerification
   */
  expiresAt?: Date;
}

/**
 * The type of the historical verification.
 * @export
 * @enum {string}
 */
export enum IdentityVerificationState {
  Passed = 'passed',
  Failed = 'failed',
  PassedWithRiskFactors = 'passedWithRiskFactors',
  Pending = 'pending',
  Asked = 'asked',
  IdentityServiceFailure = 'identityServiceFailure',
  Scoring = 'scoring',
  Expired = 'expired',
}

/**
 * Describes how the identity verification was performed.
 * @export
 * @enum {string}
 */
export enum IdentityVerificationType {
  FraudRiskReport = 'fraudRiskReport',
  Quiz = 'quiz',
  AdminApproval = 'adminApproval',
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Base model schema for identity verification operations outputs.
 * @export
 * @interface Outputs
 */
export interface Outputs extends VerificationToken {}

/**
 * A quiz containing a collection of questions and their possible answers. These questions can be used to present a multiple-choice quiz in order to verify the identity.
 * @export
 * @interface Quiz
 */
export interface Quiz extends AbstractResource, IdentityVerification {
  /**
   *
   * @type {QuizInputs}
   * @memberof Quiz
   */
  inputs?: QuizInputs;
  /**
   *
   * @type {QuizOutputs}
   * @memberof Quiz
   */
  outputs?: QuizOutputs;
}

/**
 * The inputs of a quiz.
 * @export
 * @interface QuizInputs
 */
export interface QuizInputs {
  /**
   *
   * @type {Identity}
   * @memberof QuizInputs
   */
  identity?: Identity;
}

/**
 * The outputs of a quiz. Used for workflow.
 * @export
 * @interface QuizOutputs
 */
export interface QuizOutputs extends Outputs {
  /**
   *
   * @type {IdentityVerificationState}
   * @memberof QuizOutputs
   */
  state?: IdentityVerificationState;
}

/**
 * Representation used to create a new set of questions.
 * @export
 * @interface QuizQuestions
 */
export interface QuizQuestions extends AbstractResource, CoreQuizQuestions, VerificationToken {}

/**
 * Collection of quizzes.
 * @export
 * @interface Quizzes
 */
export interface Quizzes extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Quizzes
   */
  _embedded?: any;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Representation used to provide answers to a quiz.
 * @export
 * @interface ScoreQuizAnswers
 */
export interface ScoreQuizAnswers extends CoreQuizAnswers {}

/**
 * The token used to validate and track a contact for identity verification purposes.
 * @export
 * @interface VerificationToken
 */
export interface VerificationToken {
  /**
   * An opaque string that conveys the state of the contact's identity verification.
   * @type {string}
   * @memberof VerificationToken
   */
  token?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * ApprovalsApi - axios parameter creator
 * @export
 */
export const ApprovalsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval resource for the specified Contact. The following links may be included in a successful response under the `_links` property:    * `self`: URI of the created approval resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Create a new approval resource
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(query?: { contactUri?: string; type?: string }, options: any = {}): RequestArgs {
      const { contactUri, type } = query;

      // verify required parameter 'contactUri' is not null or undefined
      if (contactUri === null || contactUri === undefined) {
        throw new RequiredError(
          'contactUri',
          'Required parameter contactUri was null or undefined when calling createApproval.',
        );
      }
      const localVarPath = `/approvals`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (contactUri !== undefined) {
        localVarQueryParameter['contactUri'] = contactUri;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(approvalId: string, options: any = {}): RequestArgs {
      // verify required parameter 'approvalId' is not null or undefined
      if (approvalId === null || approvalId === undefined) {
        throw new RequiredError(
          'approvalId',
          'Required parameter approvalId was null or undefined when calling getApproval.',
        );
      }
      const localVarPath = `/approvals/{approvalId}`.replace(
        `{${'approvalId'}}`,
        encodeURIComponent(String(approvalId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ApprovalsApi - functional programming interface
 * @export
 */
export const ApprovalsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new approval resource for the specified Contact. The following links may be included in a successful response under the `_links` property:    * `self`: URI of the created approval resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Create a new approval resource
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(
      query?: { contactUri?: string; type?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalsApiAxiosParamCreator(configuration).createApproval(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(
      approvalId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Approval> {
      const localVarAxiosArgs = ApprovalsApiAxiosParamCreator(configuration).getApproval(
        approvalId ? approvalId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ApprovalsApi - factory interface
 * @export
 */
export const ApprovalsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new approval resource for the specified Contact. The following links may be included in a successful response under the `_links` property:    * `self`: URI of the created approval resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Create a new approval resource
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApproval(query?: { contactUri?: string; type?: string }, options?: any) {
      return ApprovalsApiFp(configuration).createApproval(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Fetch a representation of this approval
     * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApproval(approvalId: string, options?: any) {
      return ApprovalsApiFp(configuration).getApproval(
        approvalId ? approvalId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ApprovalsApi - object-oriented interface
 * @export
 * @class ApprovalsApi
 * @extends {BaseAPI}
 */
export class ApprovalsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new approval resource for the specified Contact. The following links may be included in a successful response under the `_links` property:    * `self`: URI of the created approval resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
   * @summary Create a new approval resource
   * @param {Object} [query] Query object
   * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
   * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalsApi
   */
  public createApproval(query?: { contactUri?: string; type?: string }, options?: any) {
    return ApprovalsApiFp(this.configuration).createApproval(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this approval resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/approvals/{approvalId}`   * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
   * @summary Fetch a representation of this approval
   * @param {string} approvalId The unique identifier of this approval. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Approval}
   * @memberof ApprovalsApi
   */
  public getApproval(approvalId: string, options?: any) {
    return ApprovalsApiFp(this.configuration).getApproval(
      approvalId ? approvalId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * FraudRiskReportsApi - axios parameter creator
 * @export
 */
export const FraudRiskReportsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new fraud-risk analysis report in the fraud-risk analysis reports collection. If an `apiture:contact` link is specified in the request a verification token will be  returned in the response. If an `apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new fraud-risk analysis report
     * @param {CreateFraudRiskReport} CreateFraudRiskReport The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFraudRiskReport(
      CreateFraudRiskReport: CreateFraudRiskReport,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'CreateFraudRiskReport' is not null or undefined
      if (CreateFraudRiskReport === null || CreateFraudRiskReport === undefined) {
        throw new RequiredError(
          'CreateFraudRiskReport',
          'Required parameter CreateFraudRiskReport was null or undefined when calling createFraudRiskReport.',
        );
      }
      const localVarPath = `/fraudRiskReports`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateFraudRiskReport' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateFraudRiskReport || {})
        : CreateFraudRiskReport || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this fraud-risk analysis report resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this fraud-risk report
     * @param {string} fraudRiskReportId The unique identifier of this fraud-risk report. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReport(fraudRiskReportId: string, options: any = {}): RequestArgs {
      // verify required parameter 'fraudRiskReportId' is not null or undefined
      if (fraudRiskReportId === null || fraudRiskReportId === undefined) {
        throw new RequiredError(
          'fraudRiskReportId',
          'Required parameter fraudRiskReportId was null or undefined when calling getFraudRiskReport.',
        );
      }
      const localVarPath = `/fraudRiskReports/{fraudRiskReportId}`.replace(
        `{${'fraudRiskReportId'}}`,
        encodeURIComponent(String(fraudRiskReportId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of fraud-risk analysis reports.The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of fraud-risk analysis results
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first fraud-risk analysis report in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of fraud-risk analysis report representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'fraudRiskReport' | 'quiz' | 'adminApproval'} [query.type] Subset the fraud reports collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment&#x60; Account matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReports(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: 'fraudRiskReport' | 'quiz' | 'adminApproval';
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, type } = query;

      const localVarPath = `/fraudRiskReports`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * FraudRiskReportsApi - functional programming interface
 * @export
 */
export const FraudRiskReportsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new fraud-risk analysis report in the fraud-risk analysis reports collection. If an `apiture:contact` link is specified in the request a verification token will be  returned in the response. If an `apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new fraud-risk analysis report
     * @param {CreateFraudRiskReport} CreateFraudRiskReport The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFraudRiskReport(
      CreateFraudRiskReport: CreateFraudRiskReport,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<FraudRiskReport> {
      const localVarAxiosArgs = FraudRiskReportsApiAxiosParamCreator(
        configuration,
      ).createFraudRiskReport(
        CreateFraudRiskReport ? CreateFraudRiskReport : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this fraud-risk analysis report resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this fraud-risk report
     * @param {string} fraudRiskReportId The unique identifier of this fraud-risk report. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReport(
      fraudRiskReportId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<FraudRiskReport> {
      const localVarAxiosArgs = FraudRiskReportsApiAxiosParamCreator(
        configuration,
      ).getFraudRiskReport(
        fraudRiskReportId ? fraudRiskReportId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of fraud-risk analysis reports.The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of fraud-risk analysis results
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first fraud-risk analysis report in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of fraud-risk analysis report representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'fraudRiskReport' | 'quiz' | 'adminApproval'} [query.type] Subset the fraud reports collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment&#x60; Account matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReports(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: 'fraudRiskReport' | 'quiz' | 'adminApproval';
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<FraudRiskReports> {
      const localVarAxiosArgs = FraudRiskReportsApiAxiosParamCreator(
        configuration,
      ).getFraudRiskReports(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * FraudRiskReportsApi - factory interface
 * @export
 */
export const FraudRiskReportsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new fraud-risk analysis report in the fraud-risk analysis reports collection. If an `apiture:contact` link is specified in the request a verification token will be  returned in the response. If an `apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new fraud-risk analysis report
     * @param {CreateFraudRiskReport} CreateFraudRiskReport The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFraudRiskReport(CreateFraudRiskReport: CreateFraudRiskReport, options?: any) {
      return FraudRiskReportsApiFp(configuration).createFraudRiskReport(
        CreateFraudRiskReport ? CreateFraudRiskReport : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this fraud-risk analysis report resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this fraud-risk report
     * @param {string} fraudRiskReportId The unique identifier of this fraud-risk report. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReport(fraudRiskReportId: string, options?: any) {
      return FraudRiskReportsApiFp(configuration).getFraudRiskReport(
        fraudRiskReportId ? fraudRiskReportId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of fraud-risk analysis reports.The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of fraud-risk analysis results
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first fraud-risk analysis report in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of fraud-risk analysis report representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'fraudRiskReport' | 'quiz' | 'adminApproval'} [query.type] Subset the fraud reports collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment&#x60; Account matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFraudRiskReports(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: 'fraudRiskReport' | 'quiz' | 'adminApproval';
      },
      options?: any,
    ) {
      return FraudRiskReportsApiFp(configuration).getFraudRiskReports(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * FraudRiskReportsApi - object-oriented interface
 * @export
 * @class FraudRiskReportsApi
 * @extends {BaseAPI}
 */
export class FraudRiskReportsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new fraud-risk analysis report in the fraud-risk analysis reports collection. If an `apiture:contact` link is specified in the request a verification token will be  returned in the response. If an `apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
   * @summary Create a new fraud-risk analysis report
   * @param {CreateFraudRiskReport} CreateFraudRiskReport The identity
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {FraudRiskReport}
   * @memberof FraudRiskReportsApi
   */
  public createFraudRiskReport(CreateFraudRiskReport: CreateFraudRiskReport, options?: any) {
    return FraudRiskReportsApiFp(this.configuration).createFraudRiskReport(
      CreateFraudRiskReport ? CreateFraudRiskReport : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this fraud-risk analysis report resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this fraud-risk report resource - `/fraudRiskReports/{fraudRiskReportId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
   * @summary Fetch a representation of this fraud-risk report
   * @param {string} fraudRiskReportId The unique identifier of this fraud-risk report. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {FraudRiskReport}
   * @memberof FraudRiskReportsApi
   */
  public getFraudRiskReport(fraudRiskReportId: string, options?: any) {
    return FraudRiskReportsApiFp(this.configuration).getFraudRiskReport(
      fraudRiskReportId ? fraudRiskReportId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of fraud-risk analysis reports.The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Returns a collection of fraud-risk analysis results
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first fraud-risk analysis report in this page. The default, 0, represents the first report in the collection.
   * @param {number} [query.limit] The maximum number of fraud-risk analysis report representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'fraudRiskReport' | 'quiz' | 'adminApproval'} [query.type] Subset the fraud reports collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment&#x60; Account matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {FraudRiskReports}
   * @memberof FraudRiskReportsApi
   */
  public getFraudRiskReports(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      type?: 'fraudRiskReport' | 'quiz' | 'adminApproval';
    },
    options?: any,
  ) {
    return FraudRiskReportsApiFp(this.configuration).getFraudRiskReports(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * QuizzesApi - axios parameter creator
 * @export
 */
export const QuizzesApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new quiz in the quizzes collection for the specified identity. `state` defaults to `pending` If the apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new quiz
     * @param {CreateQuiz} CreateQuiz The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuiz(CreateQuiz: CreateQuiz, options: any = {}): RequestArgs {
      // verify required parameter 'CreateQuiz' is not null or undefined
      if (CreateQuiz === null || CreateQuiz === undefined) {
        throw new RequiredError(
          'CreateQuiz',
          'Required parameter CreateQuiz was null or undefined when calling createQuiz.',
        );
      }
      const localVarPath = `/quizzes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateQuiz' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateQuiz || {})
        : CreateQuiz || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Generates the a set of questions for the quiz. Questions can only be generated if the state of the resource is `pending`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:score`: URI of the `/quizzes/{quizId}/answers` endpoint   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Generate the questions for a quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuizQuestions(quizId: string, options: any = {}): RequestArgs {
      // verify required parameter 'quizId' is not null or undefined
      if (quizId === null || quizId === undefined) {
        throw new RequiredError(
          'quizId',
          'Required parameter quizId was null or undefined when calling createQuizQuestions.',
        );
      }
      const localVarPath = `/quizzes/{quizId}/questions`.replace(
        `{${'quizId'}}`,
        encodeURIComponent(String(quizId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this quiz resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuiz(quizId: string, options: any = {}): RequestArgs {
      // verify required parameter 'quizId' is not null or undefined
      if (quizId === null || quizId === undefined) {
        throw new RequiredError(
          'quizId',
          'Required parameter quizId was null or undefined when calling getQuiz.',
        );
      }
      const localVarPath = `/quizzes/{quizId}`.replace(
        `{${'quizId'}}`,
        encodeURIComponent(String(quizId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of quizzes. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of quizzes
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first quiz in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of quiz representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuizzes(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/quizzes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Submits the answers for scoring and returns the quiz with a state of `passed`,  `failed`, `scoring` or `expired`. Can only be processed if state is `asked`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Submit the answers to a quiz
     * @param {ScoreQuizAnswers} ScoreQuizAnswers The identity
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    scoreQuiz(ScoreQuizAnswers: ScoreQuizAnswers, quizId: string, options: any = {}): RequestArgs {
      // verify required parameter 'quizId' is not null or undefined
      if (quizId === null || quizId === undefined) {
        throw new RequiredError(
          'quizId',
          'Required parameter quizId was null or undefined when calling scoreQuiz.',
        );
      }
      // verify required parameter 'ScoreQuizAnswers' is not null or undefined
      if (ScoreQuizAnswers === null || ScoreQuizAnswers === undefined) {
        throw new RequiredError(
          'ScoreQuizAnswers',
          'Required parameter ScoreQuizAnswers was null or undefined when calling scoreQuiz.',
        );
      }
      const localVarPath = `/quizzes/{quizId}/answers`.replace(
        `{${'quizId'}}`,
        encodeURIComponent(String(quizId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ScoreQuizAnswers' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ScoreQuizAnswers || {})
        : ScoreQuizAnswers || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * QuizzesApi - functional programming interface
 * @export
 */
export const QuizzesApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new quiz in the quizzes collection for the specified identity. `state` defaults to `pending` If the apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new quiz
     * @param {CreateQuiz} CreateQuiz The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuiz(
      CreateQuiz: CreateQuiz,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Quiz> {
      const localVarAxiosArgs = QuizzesApiAxiosParamCreator(configuration).createQuiz(
        CreateQuiz ? CreateQuiz : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Generates the a set of questions for the quiz. Questions can only be generated if the state of the resource is `pending`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:score`: URI of the `/quizzes/{quizId}/answers` endpoint   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Generate the questions for a quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuizQuestions(
      quizId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<QuizQuestions> {
      const localVarAxiosArgs = QuizzesApiAxiosParamCreator(configuration).createQuizQuestions(
        quizId ? quizId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this quiz resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuiz(
      quizId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Quiz> {
      const localVarAxiosArgs = QuizzesApiAxiosParamCreator(configuration).getQuiz(
        quizId ? quizId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of quizzes. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of quizzes
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first quiz in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of quiz representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuizzes(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Quizzes> {
      const localVarAxiosArgs = QuizzesApiAxiosParamCreator(configuration).getQuizzes(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Submits the answers for scoring and returns the quiz with a state of `passed`,  `failed`, `scoring` or `expired`. Can only be processed if state is `asked`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Submit the answers to a quiz
     * @param {ScoreQuizAnswers} ScoreQuizAnswers The identity
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    scoreQuiz(
      ScoreQuizAnswers: ScoreQuizAnswers,
      quizId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Quiz> {
      const localVarAxiosArgs = QuizzesApiAxiosParamCreator(configuration).scoreQuiz(
        ScoreQuizAnswers ? ScoreQuizAnswers : null,
        quizId ? quizId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * QuizzesApi - factory interface
 * @export
 */
export const QuizzesApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new quiz in the quizzes collection for the specified identity. `state` defaults to `pending` If the apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Create a new quiz
     * @param {CreateQuiz} CreateQuiz The identity
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuiz(CreateQuiz: CreateQuiz, options?: any) {
      return QuizzesApiFp(configuration).createQuiz(
        CreateQuiz ? CreateQuiz : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Generates the a set of questions for the quiz. Questions can only be generated if the state of the resource is `pending`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:score`: URI of the `/quizzes/{quizId}/answers` endpoint   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Generate the questions for a quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createQuizQuestions(quizId: string, options?: any) {
      return QuizzesApiFp(configuration).createQuizQuestions(
        quizId ? quizId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this quiz resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
     * @summary Fetch a representation of this quiz
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuiz(quizId: string, options?: any) {
      return QuizzesApiFp(configuration).getQuiz(
        quizId ? quizId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of quizzes. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Returns a collection of quizzes
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first quiz in this page. The default, 0, represents the first report in the collection.
     * @param {number} [query.limit] The maximum number of quiz representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getQuizzes(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return QuizzesApiFp(configuration).getQuizzes(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Submits the answers for scoring and returns the quiz with a state of `passed`,  `failed`, `scoring` or `expired`. Can only be processed if state is `asked`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
     * @summary Submit the answers to a quiz
     * @param {ScoreQuizAnswers} ScoreQuizAnswers The identity
     * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    scoreQuiz(ScoreQuizAnswers: ScoreQuizAnswers, quizId: string, options?: any) {
      return QuizzesApiFp(configuration).scoreQuiz(
        ScoreQuizAnswers ? ScoreQuizAnswers : null,
        quizId ? quizId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * QuizzesApi - object-oriented interface
 * @export
 * @class QuizzesApi
 * @extends {BaseAPI}
 */
export class QuizzesApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new quiz in the quizzes collection for the specified identity. `state` defaults to `pending` If the apiture:contact` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the created quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
   * @summary Create a new quiz
   * @param {CreateQuiz} CreateQuiz The identity
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Quiz}
   * @memberof QuizzesApi
   */
  public createQuiz(CreateQuiz: CreateQuiz, options?: any) {
    return QuizzesApiFp(this.configuration).createQuiz(
      CreateQuiz ? CreateQuiz : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Generates the a set of questions for the quiz. Questions can only be generated if the state of the resource is `pending`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:score`: URI of the `/quizzes/{quizId}/answers` endpoint   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
   * @summary Generate the questions for a quiz
   * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {QuizQuestions}
   * @memberof QuizzesApi
   */
  public createQuizQuestions(quizId: string, options?: any) {
    return QuizzesApiFp(this.configuration).createQuizQuestions(
      quizId ? quizId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this quiz resource. The following links will be included in a successful response under the `_links` property:    * `self`: URI of the this quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with an `apiture:contact` a link to the specified resource will be present
   * @summary Fetch a representation of this quiz
   * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Quiz}
   * @memberof QuizzesApi
   */
  public getQuiz(quizId: string, options?: any) {
    return QuizzesApiFp(this.configuration).getQuiz(
      quizId ? quizId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of quizzes. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Returns a collection of quizzes
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first quiz in this page. The default, 0, represents the first report in the collection.
   * @param {number} [query.limit] The maximum number of quiz representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Quizzes}
   * @memberof QuizzesApi
   */
  public getQuizzes(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return QuizzesApiFp(this.configuration).getQuizzes(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Submits the answers for scoring and returns the quiz with a state of `passed`,  `failed`, `scoring` or `expired`. Can only be processed if state is `asked`. The following links will be included in a successful response under the `_links` property:    * `up`: URI of the quiz resource - `/quizzes/{quizId}`   * `apiture:contact`: If the resource was created with a `apiture:contact` a link to the specified resource will be present
   * @summary Submit the answers to a quiz
   * @param {ScoreQuizAnswers} ScoreQuizAnswers The identity
   * @param {string} quizId The unique identifier of this quiz. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Quiz}
   * @memberof QuizzesApi
   */
  public scoreQuiz(ScoreQuizAnswers: ScoreQuizAnswers, quizId: string, options?: any) {
    return QuizzesApiFp(this.configuration).scoreQuiz(
      ScoreQuizAnswers ? ScoreQuizAnswers : null,
      quizId ? quizId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * VerifyApi - axios parameter creator
 * @export
 */
export const VerifyApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Retrieves the contact verification status. If the `contactUri` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the _links property:    * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Retrieves contact verification resource.
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContactVerification(
      query?: { contactUri?: string; type?: string },
      options: any = {},
    ): RequestArgs {
      const { contactUri, type } = query;

      // verify required parameter 'contactUri' is not null or undefined
      if (contactUri === null || contactUri === undefined) {
        throw new RequiredError(
          'contactUri',
          'Required parameter contactUri was null or undefined when calling getContactVerification.',
        );
      }
      const localVarPath = `/contactVerification`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (contactUri !== undefined) {
        localVarQueryParameter['contactUri'] = contactUri;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * VerifyApi - functional programming interface
 * @export
 */
export const VerifyApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Retrieves the contact verification status. If the `contactUri` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the _links property:    * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Retrieves contact verification resource.
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContactVerification(
      query?: { contactUri?: string; type?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ContactVerification> {
      const localVarAxiosArgs = VerifyApiAxiosParamCreator(configuration).getContactVerification(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * VerifyApi - factory interface
 * @export
 */
export const VerifyApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Retrieves the contact verification status. If the `contactUri` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the _links property:    * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
     * @summary Retrieves contact verification resource.
     * @param {Object} [query] Query object
     * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
     * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getContactVerification(query?: { contactUri?: string; type?: string }, options?: any) {
      return VerifyApiFp(configuration).getContactVerification(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * VerifyApi - object-oriented interface
 * @export
 * @class VerifyApi
 * @extends {BaseAPI}
 */
export class VerifyApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Retrieves the contact verification status. If the `contactUri` link is invalid a 400 Bad Request response will be returned. The following links will be included in a successful response under the _links property:    * `apiture:contact`: If the specified contactUri param refers to a Contact resource a link to it will be present
   * @summary Retrieves contact verification resource.
   * @param {Object} [query] Query object
   * @param {string} [query.contactUri] The &#x60;apiture:contact&#x60; URI.
   * @param {string} [query.type] The identity method type. Possible values are &#x60;fraudRiskReport&#x60;, &#x60;quiz&#x60; or &#x60;adminApproval&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ContactVerification}
   * @memberof VerifyApi
   */
  public getContactVerification(query?: { contactUri?: string; type?: string }, options?: any) {
    return VerifyApiFp(this.configuration).getContactVerification(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
