// tslint:disable
/**
 * Identity
 * This API manages the set of actions that allow financial institutions to verify the identity of their customers and applicants. 'Identity' is defined as a set of personally identifiable information (PII) that can potentially identify a specific individual.   PII consists of the following attributes:    * `taxId` The identity's tax or government ID   * `firstName` The identity's first name   * `lastName`  The identity's last name   * `address1` Line 1 of the identity's street address   * `address2` Line 2 of the identity's street address   * `city` The identity's city   * `region` The identity's region   * `postalCode` The identity's postal code   * `phone` The identity's phone   * `birthdate` The identity's birth date in `yyyy-mm-dd` format.   * `email` The identity's email address   * `ipAddress` The identity's IP address  There are two major steps to the identity verification process - fraud-risk analysis and knowledge-base authentication (KBA) quizzes.   A _fraud-risk report_ can be generated by specifying the PII associated with an individual.  The report will contain a state indicating the result  of the operation as well as an optional list of fraud risk factors associated with that identity. A `passed` state indicates that the provided PII was located and contains no risk factors. A `passedWithRiskFactors` state means that the provided PII matches an identity but contains risk factors. A `failed` state means that the provided PII does not match any identity records.   In order to generate a report, submit the PII via `POST` to `/fraudRiskReports`. This will return a `201` response containing a new `fraudRiskReport` resource which includes `outputs` with a collection of `fraudRiskCategories`. These categories are:    * `personalInfoDoesNotMatch` The retrieved identity does not match the provided PII.   * `addressIsPOBoxOrNonApproved` The provided address is a PO Box or other non-approved address   * `addressIsHighRisk` The provided address is considered high-risk   * `identityOnGovernmentWatchlist` The provided identity is located on one or more government watchlists   * `identityOnAlertList` The provided identity is located on one or more alert lists   * `ipRestricted` The provided IP address is restricted   * `emailRestricted` The provided email address is restricted   * `ageRestricted` The provided identity does not meet the required age. Example: US COPPA laws forbid conducting e-commerce with people under 14 years of age.   * `nonStandardTaxId` The provided taxId is non-standard. Example: The provided SSN is an ITIN (Individual Taxpayer Identification Number)   A _quiz_ containing a list of questions and their possible answers can be generated with a set of PII.  This information can be used to assist in the verification of the identity, by presenting the  customer or applicant with the questions and prompting them to choose the appropriate answers.  These answers can then be submitted to verify their correctness, confirming the identity.   In order to generate a quiz, submit the PII via `POST` to `/quizzes`. This will return a `201` response containing a new `quiz` resource with a state of `pending`. You can then `POST` to `/quizzes/{quizId}/questions` by following the `apiture:getQuestions` link to generate one-time-use (transient) set of questions. When you have collected the answers to these questions you can submit them to `/quizzes/{quizId}/answers` via `POST` by following the `apiture:score` link. This will return the quiz resource with an updated state, either  `passed`, `failed` or `expired`.
 *
 * OpenAPI spec version: 0.7.3
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
