# @apiture/invitations-client-sdk@0.2.2
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/invitations-client-sdk@0.2.2 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, InvitationApi, VerificationApi } from "@apiture/invitations-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate InvitationApi main class passing the configuration object.
    const invitationApi = new InvitationApi(configuration);

// Instantiate VerificationApi main class passing the configuration object.
    const verificationApi = new VerificationApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/invitations",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Invitations SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### InvitationApi


  `InvitationApi.completeInvitation` - Complete an Invitation

  `InvitationApi.createInvitation` - Create a new invitation

  `InvitationApi.deleteInvitation` - Delete this invitation resource

  `InvitationApi.getInvitation` - Fetch a representation of this invitation

  `InvitationApi.getInvitations` - Return a collection of invitations

  `InvitationApi.revokeInvitation` - Revoke an Invitation

  `InvitationApi.sendInvitation` - Send an Invitation



### VerificationApi


  `VerificationApi.verifyInvitation` - Verify an Invitation



## About the Invitations API
___
This API allows digital banking customers to send invitations to other people to become joint owners on personal accounts or to become authorized signers of business organizations.  When a user creates a new invitation (`createInvitation` below), the service sends an email, on behalf of the financial institution, to the invitee's email address with instructions to accept the invitation by visiting a web page. The link in the generated email includes parameters that describe the invitation resource, including but not limited to `invitationId`.  The `invitationId` is required on the `verifyInvitation` operation below.  The \"shared secret\" is a string the invitee shares the inviter to verify their identity.  See (`sharedSecret` below)  Invitation States may be one of the following:    * **`sent`** Invitation sent to invitee   * **`accepted`** Invitation accepted by invitee   * **`completed`** Invitee has been added to their invited role   * **`revoked`** Invitation revoked by inviter   * **`expired`** Invitation expired  The invitation also references the account or organization they are being invited to join, depending on the `type` of the invitation. For joint owner invitations, other existing joint owners on the account can see outstanding invitations for the account. For authorized signer invitation, other existing joint owners can see outstanding invitations for the business organization.  The Inviter should share the secret with the invitee through another secure channel (such as face to face or in a phone conversation) so that unauthorized people cannot accept the invitation.  The Inviter can `revoke` an invitation if the state of the invitation is `sent`.  When the invitee visits the web form listed in their invitation email, they enter the `sharedSecret` to accept. The client can use the `verifyInvitation` operation below to determine if the invitee entered the secret correctly. If they enter the data correctly, the invitation is `accepted`.  If not already users, invitees must register as users on the financial institution's digital banking platform in order to assume these roles. Unverified users must also execute the financial institution's identity verification process before they are added as a joint user or authorized signer.  Once added as a joint user or authorized signer, the invitation is `completed`.  Inviters can update an invitation's shared secret. Inviters can also request an invitation be resent, or they can revoke an invitation. Unaccepted invitations expire after some time (such as 30 or 45 days).
