// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Invitations
 * This API allows digital banking customers to send invitations to other people to become joint owners on personal accounts or to become authorized signers of business organizations.  When a user creates a new invitation (`createInvitation` below), the service sends an email, on behalf of the financial institution, to the invitee's email address with instructions to accept the invitation by visiting a web page. The link in the generated email includes parameters that describe the invitation resource, including but not limited to `invitationId`.  The `invitationId` is required on the `verifyInvitation` operation below.  The \"shared secret\" is a string the invitee shares the inviter to verify their identity.  See (`sharedSecret` below)  Invitation States may be one of the following:    * **`sent`** Invitation sent to invitee   * **`accepted`** Invitation accepted by invitee   * **`completed`** Invitee has been added to their invited role   * **`revoked`** Invitation revoked by inviter   * **`expired`** Invitation expired  The invitation also references the account or organization they are being invited to join, depending on the `type` of the invitation. For joint owner invitations, other existing joint owners on the account can see outstanding invitations for the account. For authorized signer invitation, other existing joint owners can see outstanding invitations for the business organization.  The Inviter should share the secret with the invitee through another secure channel (such as face to face or in a phone conversation) so that unauthorized people cannot accept the invitation.  The Inviter can `revoke` an invitation if the state of the invitation is `sent`.  When the invitee visits the web form listed in their invitation email, they enter the `sharedSecret` to accept. The client can use the `verifyInvitation` operation below to determine if the invitee entered the secret correctly. If they enter the data correctly, the invitation is `accepted`.  If not already users, invitees must register as users on the financial institution's digital banking platform in order to assume these roles. Unverified users must also execute the financial institution's identity verification process before they are added as a joint user or authorized signer.  Once added as a joint user or authorized signer, the invitation is `completed`.  Inviters can update an invitation's shared secret. Inviters can also request an invitation be resent, or they can revoke an invitation. Unaccepted invitations expire after some time (such as 30 or 45 days).
 *
 * OpenAPI spec version: 0.3.3
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/invitations'.replace(/\/+$/, '');

export const API_VERSION = '0.3.3';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation used to create a new Invitation.
 * @export
 * @interface CreateInvitation
 */
export interface CreateInvitation extends InvitationFields, AbstractRequest {}

/**
 * @export
 * @namespace CreateInvitation
 */
export namespace CreateInvitation {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Representation of invitation resources.
 * @export
 * @interface Invitation
 */
export interface Invitation extends InvitationFields, AbstractResource {
  /**
   * The unique identifier for this organization resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Invitation
   */
  _id?: string;
  /**
   * The derived state of invitation.
   * @type {string}
   * @memberof Invitation
   */
  state?: Invitation.StateEnum;
  /**
   * The date-time when the invitation was created. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339)format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Invitation
   */
  createdAt?: Date;
  /**
   * The date-time when the invitation was last updated. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339)format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Invitation
   */
  updatedAt?: Date;
  /**
   * The date-time when the invitation will expire. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339)format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Invitation
   */
  expiresAt?: Date;
  /**
   * The derived core Customer Id of the person who created the Invitation.
   * @type {string}
   * @memberof Invitation
   */
  customerId?: string;
  /**
   * The derived core Customer group of the person who created the Invitation.
   * @type {string}
   * @memberof Invitation
   */
  customerGroup?: string;
  /**
   * The derived count of attempted verifications of this invitation.
   * @type {number}
   * @memberof Invitation
   */
  verificationCount?: number;
  /**
   * The unique User Id of the person who created the Invitation. This is derived and immutable.
   * @type {string}
   * @memberof Invitation
   */
  createdBy?: string;
}

/**
 * @export
 * @namespace Invitation
 */
export namespace Invitation {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Sent = 'sent',
    Accepted = 'accepted',
    Completed = 'completed',
    Revoked = 'revoked',
    Expired = 'expired',
  }
}

/**
 * Representation of invitation resources.
 * @export
 * @interface InvitationFields
 */
export interface InvitationFields {
  /**
   * The first name of the invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof InvitationFields
   */
  firstName?: string;
  /**
   * The lastName name of the invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof InvitationFields
   */
  lastName?: string;
  /**
   * The last 4 digits of the government ID (SSN or other ID) of invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof InvitationFields
   */
  identification?: string;
  /**
   * A string shared by the inviter with the invitee to verify their identity.
   * @type {string}
   * @memberof InvitationFields
   */
  sharedSecret?: string;
  /**
   * The email address of the invitee.
   * @type {string}
   * @memberof InvitationFields
   */
  emailAddress?: string;
  /**
   * The type of invitation.
   * @type {string}
   * @memberof InvitationFields
   */
  type?: InvitationFields.TypeEnum;
  /**
   * If `type` is `joint`, this is the uri of the account the invitee is being invited to.
   * @type {string}
   * @memberof InvitationFields
   */
  accountUri?: string;
  /**
   * If `type` is `authorizedSigner`, this is the uri of the organization the invitee is being invited to.
   * @type {string}
   * @memberof InvitationFields
   */
  organizationUri?: string;
  /**
   * If `type` is `authorizedSigner`, this is the role of the invitee at the organization is being invited to.
   * @type {string}
   * @memberof InvitationFields
   */
  role?: string;
  /**
   * The full name of the user sending the invitation.
   * @type {string}
   * @memberof InvitationFields
   */
  inviterFullName?: string;
}

/**
 * @export
 * @namespace InvitationFields
 */
export namespace InvitationFields {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    Joint = 'joint',
    AuthorizedSigner = 'authorizedSigner',
  }
}

/**
 * Collection of invitations. The items in the collection are ordered in the `_embedded.items` array; the `name` is `invitations`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`.)
 * @export
 * @interface Invitations
 */
export interface Invitations extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Invitations
   */
  _embedded?: any;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A localized label and optional description for localizable content defined in this API.
 * @export
 * @interface LocalizedLabel
 */
export interface LocalizedLabel {
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  label?: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof LocalizedLabel
   */
  description?: string;
  /**
   * The actual natural language tag to which this localized label is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1)
   * @type {string}
   * @memberof LocalizedLabel
   */
  language?: string;
  /**
   * If the localized value is associated with an external standard, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  code?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Representation of verification resources.
 * @export
 * @interface Verification
 */
export interface Verification extends AbstractResource {
  /**
   * The first name of the invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof Verification
   */
  firstName?: string;
  /**
   * The lastName name of the invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof Verification
   */
  lastName?: string;
  /**
   * The last 4 digits of the government ID (SSN or other ID) of invitee. **Warning**: This property is deprecated and no longer used in invitation verification.
   * @type {string}
   * @memberof Verification
   */
  identification?: string;
  /**
   * A string shared by the inviter with the invitee to verify their identity.
   * @type {string}
   * @memberof Verification
   */
  sharedSecret?: string;
  /**
   * A optional id of an invitation resource.  If included, the service will compare the key data against this invitation only.
   * @type {string}
   * @memberof Verification
   */
  invitationId?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * InvitationApi - axios parameter creator
 * @export
 */
export const InvitationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Complete an invitation that is eligible to be completed.  Only Invitations which are `accepted` can be completed.  This admin operation is invoked from the `apiture:complete` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `completed`. `Completed` means the desired result (user added as joint owner or authorized signer) has been completed.
     * @summary Complete an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    completeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { invitation } = query;
      const { If_Match } = headers;

      // verify required parameter 'invitation' is not null or undefined
      if (invitation === null || invitation === undefined) {
        throw new RequiredError(
          'invitation',
          'Required parameter invitation was null or undefined when calling completeInvitation.',
        );
      }
      const localVarPath = `/completed`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (invitation !== undefined) {
        localVarQueryParameter['invitation'] = invitation;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new invitation resource and send the invitation email to the invitee.
     * @summary Create a new invitation
     * @param {CreateInvitation} CreateInvitation The data necessary to create a new invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInvitation(CreateInvitation: CreateInvitation, options: any = {}): RequestArgs {
      // verify required parameter 'CreateInvitation' is not null or undefined
      if (CreateInvitation === null || CreateInvitation === undefined) {
        throw new RequiredError(
          'CreateInvitation',
          'Required parameter CreateInvitation was null or undefined when calling createInvitation.',
        );
      }
      const localVarPath = `/invitations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateInvitation' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateInvitation || {})
        : CreateInvitation || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this invitation resource and any resources that are owned by it.
     * @summary Delete this invitation resource
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteInvitation(invitationId: string, options: any = {}): RequestArgs {
      // verify required parameter 'invitationId' is not null or undefined
      if (invitationId === null || invitationId === undefined) {
        throw new RequiredError(
          'invitationId',
          'Required parameter invitationId was null or undefined when calling deleteInvitation.',
        );
      }
      const localVarPath = `/invitations/{invitationId}`.replace(
        `{${'invitationId'}}`,
        encodeURIComponent(String(invitationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this invitation resource.
     * @summary Fetch a representation of this invitation
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitation(
      invitationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'invitationId' is not null or undefined
      if (invitationId === null || invitationId === undefined) {
        throw new RequiredError(
          'invitationId',
          'Required parameter invitationId was null or undefined when calling getInvitation.',
        );
      }
      const localVarPath = `/invitations/{invitationId}`.replace(
        `{${'invitationId'}}`,
        encodeURIComponent(String(invitationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of invitations. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of invitations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first invitation item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of invitation representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.pendingInvitations] Subset the invitations collection to those pending invitations for the currently authenticated user.  These are invitations that have been verified by the authenticated user but still require some user action to complete the invitation process. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.accountUri] Subset the invitations collection to those with this &#x60;accountUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?accountUri&#x3D;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;accountUri&#x60; is &#x60;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.organizationUri] Subset the invitations collection to those with this &#x60;organizationUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example,&#x60; ?organizationUri&#x3D;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;organizationUri&#x60; is &#x60;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'sent' | 'accepted' | 'completed' | 'revoked' | 'expired'} [query.state] Subset the invitations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;sent&#x60; matches only items whose &#x60;state&#x60; is &#x60;sent&#x60;; &#x60;?state&#x3D;sent|accepted&#x60; matches items whose &#x60;state&#x60; is &#x60;sent&#x60; or &#x60;accepted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'joint' | 'authorizedSigner'} [query.type] Subset the invitations collection to those whose &#x60;type&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;joint&#x60; matches only items whose &#x60;type&#x60; is &#x60;joint&#x60;; &#x60;?state&#x3D;joint|authorizedSigner&#x60; matches items whose &#x60;type&#x60; is &#x60;joint&#x60; or &#x60;authorizedSigner&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.emailAddress] Subset the invitations collection to those with this &#x60;emailAddress&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?emailAddress&#x3D;johnsmith@email.com&#x60; matches only items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60;; &#x60;?emailAddress&#x3D;johnsmith@email.com|tomjones@email.com&#x60; will match items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60; or &#x60;tomjones@email.com&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        pendingInvitations?: boolean;
        accountUri?: string;
        organizationUri?: string;
        state?: 'sent' | 'accepted' | 'completed' | 'revoked' | 'expired';
        type?: 'joint' | 'authorizedSigner';
        emailAddress?: string;
      },
      options: any = {},
    ): RequestArgs {
      const {
        start,
        limit,
        sortBy,
        filter,
        q,
        pendingInvitations,
        accountUri,
        organizationUri,
        state,
        type,
        emailAddress,
      } = query;

      const localVarPath = `/invitations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (pendingInvitations !== undefined) {
        localVarQueryParameter['pendingInvitations'] = pendingInvitations;
      }

      if (accountUri !== undefined) {
        localVarQueryParameter['accountUri'] = accountUri;
      }

      if (organizationUri !== undefined) {
        localVarQueryParameter['organizationUri'] = organizationUri;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (emailAddress !== undefined) {
        localVarQueryParameter['emailAddress'] = emailAddress;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Revoke an invitation that is eligible to be revoked.  Only Invitations which are `sent` can be revoked.  This operation is invoked from the `apiture:revoke` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `revoked`.
     * @summary Revoke an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { invitation } = query;
      const { If_Match } = headers;

      // verify required parameter 'invitation' is not null or undefined
      if (invitation === null || invitation === undefined) {
        throw new RequiredError(
          'invitation',
          'Required parameter invitation was null or undefined when calling revokeInvitation.',
        );
      }
      const localVarPath = `/revoked`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (invitation !== undefined) {
        localVarQueryParameter['invitation'] = invitation;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This action will re-send an already `sent` invitation to the invitee. Only Invitations which are already `sent` can be re-sent.  This operation is invoked from  the `apiture:send` link on an Invitation, which only exists if the action is allowed.  There is a configurable limit of times that an invitation can be re-sent.
     * @summary Send an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    sendInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { invitation } = query;
      const { If_Match } = headers;

      // verify required parameter 'invitation' is not null or undefined
      if (invitation === null || invitation === undefined) {
        throw new RequiredError(
          'invitation',
          'Required parameter invitation was null or undefined when calling sendInvitation.',
        );
      }
      const localVarPath = `/sent`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (invitation !== undefined) {
        localVarQueryParameter['invitation'] = invitation;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * InvitationApi - functional programming interface
 * @export
 */
export const InvitationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Complete an invitation that is eligible to be completed.  Only Invitations which are `accepted` can be completed.  This admin operation is invoked from the `apiture:complete` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `completed`. `Completed` means the desired result (user added as joint owner or authorized signer) has been completed.
     * @summary Complete an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    completeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).completeInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new invitation resource and send the invitation email to the invitee.
     * @summary Create a new invitation
     * @param {CreateInvitation} CreateInvitation The data necessary to create a new invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInvitation(
      CreateInvitation: CreateInvitation,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).createInvitation(
        CreateInvitation ? CreateInvitation : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this invitation resource and any resources that are owned by it.
     * @summary Delete this invitation resource
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteInvitation(
      invitationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).deleteInvitation(
        invitationId ? invitationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this invitation resource.
     * @summary Fetch a representation of this invitation
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitation(
      invitationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).getInvitation(
        invitationId ? invitationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of invitations. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of invitations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first invitation item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of invitation representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.pendingInvitations] Subset the invitations collection to those pending invitations for the currently authenticated user.  These are invitations that have been verified by the authenticated user but still require some user action to complete the invitation process. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.accountUri] Subset the invitations collection to those with this &#x60;accountUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?accountUri&#x3D;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;accountUri&#x60; is &#x60;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.organizationUri] Subset the invitations collection to those with this &#x60;organizationUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example,&#x60; ?organizationUri&#x3D;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;organizationUri&#x60; is &#x60;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'sent' | 'accepted' | 'completed' | 'revoked' | 'expired'} [query.state] Subset the invitations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;sent&#x60; matches only items whose &#x60;state&#x60; is &#x60;sent&#x60;; &#x60;?state&#x3D;sent|accepted&#x60; matches items whose &#x60;state&#x60; is &#x60;sent&#x60; or &#x60;accepted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'joint' | 'authorizedSigner'} [query.type] Subset the invitations collection to those whose &#x60;type&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;joint&#x60; matches only items whose &#x60;type&#x60; is &#x60;joint&#x60;; &#x60;?state&#x3D;joint|authorizedSigner&#x60; matches items whose &#x60;type&#x60; is &#x60;joint&#x60; or &#x60;authorizedSigner&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.emailAddress] Subset the invitations collection to those with this &#x60;emailAddress&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?emailAddress&#x3D;johnsmith@email.com&#x60; matches only items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60;; &#x60;?emailAddress&#x3D;johnsmith@email.com|tomjones@email.com&#x60; will match items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60; or &#x60;tomjones@email.com&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        pendingInvitations?: boolean;
        accountUri?: string;
        organizationUri?: string;
        state?: 'sent' | 'accepted' | 'completed' | 'revoked' | 'expired';
        type?: 'joint' | 'authorizedSigner';
        emailAddress?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitations> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).getInvitations(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Revoke an invitation that is eligible to be revoked.  Only Invitations which are `sent` can be revoked.  This operation is invoked from the `apiture:revoke` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `revoked`.
     * @summary Revoke an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).revokeInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This action will re-send an already `sent` invitation to the invitee. Only Invitations which are already `sent` can be re-sent.  This operation is invoked from  the `apiture:send` link on an Invitation, which only exists if the action is allowed.  There is a configurable limit of times that an invitation can be re-sent.
     * @summary Send an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    sendInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Invitation> {
      const localVarAxiosArgs = InvitationApiAxiosParamCreator(configuration).sendInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * InvitationApi - factory interface
 * @export
 */
export const InvitationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Complete an invitation that is eligible to be completed.  Only Invitations which are `accepted` can be completed.  This admin operation is invoked from the `apiture:complete` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `completed`. `Completed` means the desired result (user added as joint owner or authorized signer) has been completed.
     * @summary Complete an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    completeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return InvitationApiFp(configuration).completeInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new invitation resource and send the invitation email to the invitee.
     * @summary Create a new invitation
     * @param {CreateInvitation} CreateInvitation The data necessary to create a new invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInvitation(CreateInvitation: CreateInvitation, options?: any) {
      return InvitationApiFp(configuration).createInvitation(
        CreateInvitation ? CreateInvitation : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this invitation resource and any resources that are owned by it.
     * @summary Delete this invitation resource
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteInvitation(invitationId: string, options?: any) {
      return InvitationApiFp(configuration).deleteInvitation(
        invitationId ? invitationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this invitation resource.
     * @summary Fetch a representation of this invitation
     * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitation(invitationId: string, headers?: { If_None_Match?: string }, options?: any) {
      return InvitationApiFp(configuration).getInvitation(
        invitationId ? invitationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of invitations. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of invitations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first invitation item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of invitation representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.pendingInvitations] Subset the invitations collection to those pending invitations for the currently authenticated user.  These are invitations that have been verified by the authenticated user but still require some user action to complete the invitation process. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.accountUri] Subset the invitations collection to those with this &#x60;accountUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?accountUri&#x3D;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;accountUri&#x60; is &#x60;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.organizationUri] Subset the invitations collection to those with this &#x60;organizationUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example,&#x60; ?organizationUri&#x3D;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;organizationUri&#x60; is &#x60;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'sent' | 'accepted' | 'completed' | 'revoked' | 'expired'} [query.state] Subset the invitations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;sent&#x60; matches only items whose &#x60;state&#x60; is &#x60;sent&#x60;; &#x60;?state&#x3D;sent|accepted&#x60; matches items whose &#x60;state&#x60; is &#x60;sent&#x60; or &#x60;accepted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'joint' | 'authorizedSigner'} [query.type] Subset the invitations collection to those whose &#x60;type&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;joint&#x60; matches only items whose &#x60;type&#x60; is &#x60;joint&#x60;; &#x60;?state&#x3D;joint|authorizedSigner&#x60; matches items whose &#x60;type&#x60; is &#x60;joint&#x60; or &#x60;authorizedSigner&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.emailAddress] Subset the invitations collection to those with this &#x60;emailAddress&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?emailAddress&#x3D;johnsmith@email.com&#x60; matches only items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60;; &#x60;?emailAddress&#x3D;johnsmith@email.com|tomjones@email.com&#x60; will match items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60; or &#x60;tomjones@email.com&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInvitations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        pendingInvitations?: boolean;
        accountUri?: string;
        organizationUri?: string;
        state?: 'sent' | 'accepted' | 'completed' | 'revoked' | 'expired';
        type?: 'joint' | 'authorizedSigner';
        emailAddress?: string;
      },
      options?: any,
    ) {
      return InvitationApiFp(configuration).getInvitations(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Revoke an invitation that is eligible to be revoked.  Only Invitations which are `sent` can be revoked.  This operation is invoked from the `apiture:revoke` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `revoked`.
     * @summary Revoke an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    revokeInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return InvitationApiFp(configuration).revokeInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This action will re-send an already `sent` invitation to the invitee. Only Invitations which are already `sent` can be re-sent.  This operation is invoked from  the `apiture:send` link on an Invitation, which only exists if the action is allowed.  There is a configurable limit of times that an invitation can be re-sent.
     * @summary Send an Invitation
     * @param {Object} [query] Query object
     * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    sendInvitation(
      query?: { invitation?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return InvitationApiFp(configuration).sendInvitation(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * InvitationApi - object-oriented interface
 * @export
 * @class InvitationApi
 * @extends {BaseAPI}
 */
export class InvitationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Complete an invitation that is eligible to be completed.  Only Invitations which are `accepted` can be completed.  This admin operation is invoked from the `apiture:complete` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `completed`. `Completed` means the desired result (user added as joint owner or authorized signer) has been completed.
   * @summary Complete an Invitation
   * @param {Object} [query] Query object
   * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof InvitationApi
   */
  public completeInvitation(
    query?: { invitation?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return InvitationApiFp(this.configuration).completeInvitation(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new invitation resource and send the invitation email to the invitee.
   * @summary Create a new invitation
   * @param {CreateInvitation} CreateInvitation The data necessary to create a new invitation.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof InvitationApi
   */
  public createInvitation(CreateInvitation: CreateInvitation, options?: any) {
    return InvitationApiFp(this.configuration).createInvitation(
      CreateInvitation ? CreateInvitation : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this invitation resource and any resources that are owned by it.
   * @summary Delete this invitation resource
   * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof InvitationApi
   */
  public deleteInvitation(invitationId: string, options?: any) {
    return InvitationApiFp(this.configuration).deleteInvitation(
      invitationId ? invitationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this invitation resource.
   * @summary Fetch a representation of this invitation
   * @param {string} invitationId The unique identifier of this invitation. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof InvitationApi
   */
  public getInvitation(invitationId: string, headers?: { If_None_Match?: string }, options?: any) {
    return InvitationApiFp(this.configuration).getInvitation(
      invitationId ? invitationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of invitations. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of invitations
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first invitation item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of invitation representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
   * @param {boolean} [query.pendingInvitations] Subset the invitations collection to those pending invitations for the currently authenticated user.  These are invitations that have been verified by the authenticated user but still require some user action to complete the invitation process. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.accountUri] Subset the invitations collection to those with this &#x60;accountUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?accountUri&#x3D;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;accountUri&#x60; is &#x60;https://api.apiture.com/accounts/accounts/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.organizationUri] Subset the invitations collection to those with this &#x60;organizationUri&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example,&#x60; ?organizationUri&#x3D;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60; matches only items whose &#x60;organizationUri&#x60; is &#x60;https://api.apiture.com/organizations/organizations/0399abed-fd3d-4830-a88b-30f38b8a365c&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {'sent' | 'accepted' | 'completed' | 'revoked' | 'expired'} [query.state] Subset the invitations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;sent&#x60; matches only items whose &#x60;state&#x60; is &#x60;sent&#x60;; &#x60;?state&#x3D;sent|accepted&#x60; matches items whose &#x60;state&#x60; is &#x60;sent&#x60; or &#x60;accepted&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {'joint' | 'authorizedSigner'} [query.type] Subset the invitations collection to those whose &#x60;type&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;joint&#x60; matches only items whose &#x60;type&#x60; is &#x60;joint&#x60;; &#x60;?state&#x3D;joint|authorizedSigner&#x60; matches items whose &#x60;type&#x60; is &#x60;joint&#x60; or &#x60;authorizedSigner&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.emailAddress] Subset the invitations collection to those with this &#x60;emailAddress&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?emailAddress&#x3D;johnsmith@email.com&#x60; matches only items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60;; &#x60;?emailAddress&#x3D;johnsmith@email.com|tomjones@email.com&#x60; will match items whose &#x60;emailAddress&#x60; is &#x60;johnsmith@email.com&#x60; or &#x60;tomjones@email.com&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitations}
   * @memberof InvitationApi
   */
  public getInvitations(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      pendingInvitations?: boolean;
      accountUri?: string;
      organizationUri?: string;
      state?: 'sent' | 'accepted' | 'completed' | 'revoked' | 'expired';
      type?: 'joint' | 'authorizedSigner';
      emailAddress?: string;
    },
    options?: any,
  ) {
    return InvitationApiFp(this.configuration).getInvitations(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Revoke an invitation that is eligible to be revoked.  Only Invitations which are `sent` can be revoked.  This operation is invoked from the `apiture:revoke` link on an Invitation, which only exists if the action is allowed.  This changes the `state` to `revoked`.
   * @summary Revoke an Invitation
   * @param {Object} [query] Query object
   * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof InvitationApi
   */
  public revokeInvitation(
    query?: { invitation?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return InvitationApiFp(this.configuration).revokeInvitation(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This action will re-send an already `sent` invitation to the invitee. Only Invitations which are already `sent` can be re-sent.  This operation is invoked from  the `apiture:send` link on an Invitation, which only exists if the action is allowed.  There is a configurable limit of times that an invitation can be re-sent.
   * @summary Send an Invitation
   * @param {Object} [query] Query object
   * @param {string} [query.invitation] A server-supplied value which identifies the invitation instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Invitation}
   * @memberof InvitationApi
   */
  public sendInvitation(
    query?: { invitation?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return InvitationApiFp(this.configuration).sendInvitation(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * VerificationApi - axios parameter creator
 * @export
 */
export const VerificationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Verify an Invitation that is eligible to be verified. Only Invitations in a state of `sent` can be verified. `sharedSecret` and `invitationId` are required. This operation increases the `verificationCount` of the invitation identified by `invitationId`. Invitations that are `revoked` or `expired` are not processed. This operation does not verify invitations with a state of `revoked` or `expired`.
     * @summary Verify an Invitation
     * @param {Verification} Verification The data necessary to verify an invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyInvitation(Verification: Verification, options: any = {}): RequestArgs {
      // verify required parameter 'Verification' is not null or undefined
      if (Verification === null || Verification === undefined) {
        throw new RequiredError(
          'Verification',
          'Required parameter Verification was null or undefined when calling verifyInvitation.',
        );
      }
      const localVarPath = `/verifications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Verification' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Verification || {})
        : Verification || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * VerificationApi - functional programming interface
 * @export
 */
export const VerificationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Verify an Invitation that is eligible to be verified. Only Invitations in a state of `sent` can be verified. `sharedSecret` and `invitationId` are required. This operation increases the `verificationCount` of the invitation identified by `invitationId`. Invitations that are `revoked` or `expired` are not processed. This operation does not verify invitations with a state of `revoked` or `expired`.
     * @summary Verify an Invitation
     * @param {Verification} Verification The data necessary to verify an invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyInvitation(
      Verification: Verification,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Verification> {
      const localVarAxiosArgs = VerificationApiAxiosParamCreator(configuration).verifyInvitation(
        Verification ? Verification : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * VerificationApi - factory interface
 * @export
 */
export const VerificationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Verify an Invitation that is eligible to be verified. Only Invitations in a state of `sent` can be verified. `sharedSecret` and `invitationId` are required. This operation increases the `verificationCount` of the invitation identified by `invitationId`. Invitations that are `revoked` or `expired` are not processed. This operation does not verify invitations with a state of `revoked` or `expired`.
     * @summary Verify an Invitation
     * @param {Verification} Verification The data necessary to verify an invitation.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyInvitation(Verification: Verification, options?: any) {
      return VerificationApiFp(configuration).verifyInvitation(
        Verification ? Verification : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * VerificationApi - object-oriented interface
 * @export
 * @class VerificationApi
 * @extends {BaseAPI}
 */
export class VerificationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Verify an Invitation that is eligible to be verified. Only Invitations in a state of `sent` can be verified. `sharedSecret` and `invitationId` are required. This operation increases the `verificationCount` of the invitation identified by `invitationId`. Invitations that are `revoked` or `expired` are not processed. This operation does not verify invitations with a state of `revoked` or `expired`.
   * @summary Verify an Invitation
   * @param {Verification} Verification The data necessary to verify an invitation.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Verification}
   * @memberof VerificationApi
   */
  public verifyInvitation(Verification: Verification, options?: any) {
    return VerificationApiFp(this.configuration).verifyInvitation(
      Verification ? Verification : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}
