# @apiture/organizations-client-sdk@0.26.4
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/organizations-client-sdk@0.26.4 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AddressApi, AuthorizedSignersApi, BeneficialOwnersApi, EmailAddressApi, EntityAuthorizationFormApi, OrganizationApi, PhoneNumberApi } from "@apiture/organizations-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AddressApi main class passing the configuration object.
    const addressApi = new AddressApi(configuration);

// Instantiate AuthorizedSignersApi main class passing the configuration object.
    const authorizedSignersApi = new AuthorizedSignersApi(configuration);

// Instantiate BeneficialOwnersApi main class passing the configuration object.
    const beneficialOwnersApi = new BeneficialOwnersApi(configuration);

// Instantiate EmailAddressApi main class passing the configuration object.
    const emailAddressApi = new EmailAddressApi(configuration);

// Instantiate EntityAuthorizationFormApi main class passing the configuration object.
    const entityAuthorizationFormApi = new EntityAuthorizationFormApi(configuration);

// Instantiate OrganizationApi main class passing the configuration object.
    const organizationApi = new OrganizationApi(configuration);

// Instantiate PhoneNumberApi main class passing the configuration object.
    const phoneNumberApi = new PhoneNumberApi(configuration);

```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript

```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/organizations",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Organizations SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document

  `APIApi.getLabels` - Localized Labels



### AddressApi


  `AddressApi.createAddress` - Create a new address.

  `AddressApi.deleteAddress` - Delete this address resource

  `AddressApi.getAddress` - Fetch a representation of this address

  `AddressApi.getAddresses` - Get an organization&#39;s addresses

  `AddressApi.setPreferredAddress` - Set Preferred mailing Address



### AuthorizedSignersApi


  `AuthorizedSignersApi.createAuthorizedSigner` - Create a new authorized signer and associate it to an organization.

  `AuthorizedSignersApi.getAuthorizedSigners` - Fetch the organization&#39;s authorized signers



### BeneficialOwnersApi


  `BeneficialOwnersApi.getBeneficialOwners` - Fetch the organization&#39;s beneficial owners

  `BeneficialOwnersApi.updateBeneficialOwners` - Update the beneficial owners of an account



### EmailAddressApi


  `EmailAddressApi.createEmailAddress` - Create a new email address

  `EmailAddressApi.deleteEmailAddress` - Delete this email address resource

  `EmailAddressApi.getEmailAddress` - Fetch a representation of this email address

  `EmailAddressApi.getEmailAddresses` - Get organization&#39;s email addresses

  `EmailAddressApi.setPreferredEmailAddress` - Set Preferred Email Address



### EntityAuthorizationFormApi


  `EntityAuthorizationFormApi.generateEntityAuthorizationForm` - Generate an entity authorization Form



### OrganizationApi


  `OrganizationApi.activateOrganization` - Activate an organization.

  `OrganizationApi.createOrganization` - Create a new organization

  `OrganizationApi.deactivateOrganization` - Deactivate an organization.

  `OrganizationApi.deleteOrganization` - Delete this organization resource

  `OrganizationApi.getOrganization` - Fetch a representation of this organization

  `OrganizationApi.getOrganizations` - Return a collection of organizations

  `OrganizationApi.patchOrganization` - Update this organization

  `OrganizationApi.removeOrganization` - Remove an organization.

  `OrganizationApi.updateOrganization` - Update this organization



### PhoneNumberApi


  `PhoneNumberApi.createPhoneNumber` - Create a new phone number

  `PhoneNumberApi.deletePhoneNumber` - Delete this phone number resource

  `PhoneNumberApi.getPhoneNumber` - Fetch a representation of this phone number

  `PhoneNumberApi.getPhoneNumbers` - Get organization&#39;s phone numbers

  `PhoneNumberApi.setPreferredPhoneNumber` - Set Preferred Phone Number



## About the Organizations API
___
Contact information for organizations (businesses, non-profits, trusts, etc.) within the Apiture Banking APIs. This API manages business names, addresses, phone numbers, and email addresses of organizations. This API also tracks additional regulatory information for organizations which conduct banking and own business accounts at the financial institution. This API also manages authorized signers for the accounts owned by the organization as well as the organization's beneficial owners, which are people who own at least 25% of the business.
