# @apiture/products-client-sdk@0.16.1
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/products-client-sdk@0.16.1 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, AccountVerificationLetterTemplateApi, ProductApi, ProductTypeApi } from "@apiture/products-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate AccountVerificationLetterTemplateApi main class passing the configuration object.
    const accountVerificationLetterTemplateApi = new AccountVerificationLetterTemplateApi(configuration);

// Instantiate ProductApi main class passing the configuration object.
    const productApi = new ProductApi(configuration);

// Instantiate ProductTypeApi main class passing the configuration object.
    const productTypeApi = new ProductTypeApi(configuration);


// Use the methods to call the apis ( Refer to the Banking Products SDK Classes and Methods list ).
  productType.getProductTypes().then( response => {
    const getproducttypesData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ProductTypeApi main class.
    const productTypeApi = new ProductTypeApi();


// Update the accessToken using the class method `setAccessToken`.
    productTypeApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    productTypeApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    productTypeApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ProductTypes } from "@apiture/products-client-sdk";

  const stronglyTypedObject :ProductTypes = { ... };

  // ______ Scoped import

  import * as Banking ProductsTypes from "@apiture/products-client-sdk";

  const stronglyTypedObject :Banking ProductsTypes.ProductTypes = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/products",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Banking Products SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document

  `APIApi.getLabels` - Localized Labels



### AccountVerificationLetterTemplateApi


  `AccountVerificationLetterTemplateApi.getVerificationLetterTemplate` - Fetch an account verification letter template

  `AccountVerificationLetterTemplateApi.updateVerificationLetterTemplate` - Update this account verification letter template



### ProductApi


  `ProductApi.activateProduct` - Activate a product

  `ProductApi.createProduct` - Create a new product

  `ProductApi.deactivateProduct` - Deactivate a product

  `ProductApi.deleteProduct` - Delete this product resource

  `ProductApi.getProduct` - Fetch a representation of this product

  `ProductApi.getProductRevision` - Fetch a representation of an immutable revision of this product

  `ProductApi.getProductRevisions` - Return a collection of product revisions

  `ProductApi.getProducts` - Return a collection of products

  `ProductApi.lockProduct` - Marks an active product as ineligible for new account opening

  `ProductApi.patchProduct` - Update this product

  `ProductApi.removeProduct` - Remove a product

  `ProductApi.unlockProduct` - Marks an active product as eligible for new account opening

  `ProductApi.updateProduct` - Update this product



### ProductTypeApi


  `ProductTypeApi.activateProductType` - Activate a product type

  `ProductTypeApi.createProductType` - Create a new product type

  `ProductTypeApi.deactivateProductType` - Deactivate a product type

  `ProductTypeApi.deleteProductType` - Delete this product type resource

  `ProductTypeApi.getProductType` - Fetch a representation of this product type.

  `ProductTypeApi.getProductTypes` - Return a collection of product types

  `ProductTypeApi.patchProductType` - Update this product type

  `ProductTypeApi.removeProductType` - Remove a product type

  `ProductTypeApi.updateProductType` - Update this product type



## About the Banking Products API
___
This API manages the set of banking products that a financial institution offers to its customers. Each bank _account_ is associated with a _product_. <p> Examples of products are a personal savings account product or a business checking account product. Each product also has a _product type_ (for example, DDA for a checking or demand deposit account) and a _subtype_ which is a more specific type, such as 'Interest Checking'. <p> Each account is attached to the product instance that was effective and active when account was created. Product types may also have subtypes, although subtypes may not have deeper subtypes. When the terms and conditions of a product changes, this constititutes a new _revision_ of the product. Business rules (which are not part of this service) dictate whether all accounts which are attached to the product remain attached to the previous revision of the product or are attached to the newer revision or when and how this occurs. Similarly, business rules and other services may provide notification to users of changes in terms of use, etc. Products and product types each have a `name`, a `description` a `label`, and a `state`. <p> The state may be one of the following:    * *`pending`* In creation, not yet used or available for use.   Only pending items may be deleted.   * *`active`* Active and in use or available for use   * *`inactive`* Not available for use (deactivated)   * *`removed`* Removed and archived. Removed items are not eligible to be activated.   When an account is removed, its name is changed so that the name   may be used for new products or product types. <p> After creating a product type or product subtype, which by default leaves the resource in the `pending` state, the caller should also activate it via the `apiture:activate` link in the response. Pending resources which have not been activated may be deleted after an expiration period. <p> Allowed state transitions are:    * `pending -> active`   * `pending -> inactive`   * `active -> inactive`   * `inactive -> active`   * `active -> removed`   * `inactive -> removed` <p> A product or product type may only be deleted if its `state` is `pending`. A product or type may only change to `inactive` if it is not currently in use by active accounts or active products. Products and product types include links which convey the allowed POST operations, such as `apiture:activate`, `apiture:deactivate`, or `apiture:remove`. <p> In addition, a product has `newAccountAvailability` which indicates if that product is available for opening new accounts. **TODO** The `newAccountAvailability` in the product resource is currently mutable but it will become immutable and derived only. The value is derived from the existence of the product in the `unlockedProducts` collection. <p> This resource is a copy of the banking product resources in the bank core. In some cases, the Apiture platform does not have programmatic access to that core, so when  when a financial institution updates the banking products in the core, they must *also* use this API to update the Apiture copy.  # Error Types      Error responses in this API may have one of the following `type` values.        <h2 class='errorType' id=\"err-accessDenied\">accessDenied</h2>  Description: The credentials supplied in the request are insufficient to grant access.  Remediation: Check the supplied credentials for validity.   <h2 class='errorType' id=\"err-invalidProductId\">invalidProductId</h2>  Description: No Products were found for the specified productId.  Remediation: Check to make sure that the supplied productId corresponds to an apiture product resource.   <h2 class='errorType' id=\"err-invalidProductTypeId\">invalidProductTypeId</h2>  Description: No product types were found for the specified productTypeId.  Remediation: Check to make sure that the supplied productType corresponds to an apiture product type resource.   <h2 class='errorType' id=\"err-ifMatchHeaderMissing\">ifMatchHeaderMissing</h2>  Description: Precondition Required. The request did not include the required if-Match header.  Remediation: Resubmit with the operation, supplying the value of the ETag and the most recent state of the resource.   <h2 class='errorType' id=\"err-ifMatchHeaderDoesntMatch\">ifMatchHeaderDoesntMatch</h2>  Description: The supplied `if-Match` header value does not match the most recent `ETag` response header value. The resource has changed in the interim.  Remediation: Resubmit the operation, supplying the value of the ETag and the most recent state of the resource.   <h2 class='errorType' id=\"err-malformedProduct\">malformedProduct</h2>  Description: The supplied product was malformed.  Remediation: Check to make sure that the supplied product parameter corresponds to an apiture product resource.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>product</td><td>string</td><td>The URI or the ID of an existing product</td></tr> </table>  <h2 class='errorType' id=\"err-malformedProductType\">malformedProductType</h2>  Description: The supplied productType was malformed.  Remediation: Check to make sure that the supplied productType corresponds to an apiture productType resource.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>productType</td><td>string</td><td>The invalid product type URI.</td></tr> </table>  <h2 class='errorType' id=\"err-malformedRequestBody\">malformedRequestBody</h2>  Description: The supplied request body was malformed.  Remediation: Check to make sure that your request body exists and that it does not contain syntax errors.   <h2 class='errorType' id=\"err-malformedCreateProductBody\">malformedCreateProductBody</h2>  Description: The supplied request body to create a product did not contain a description or label.  Remediation: Resubmit the request with a description and label in the body.   <h2 class='errorType' id=\"err-canOnlyLockUnlockActive\">canOnlyLockUnlockActive</h2>  Description: You can only lock or unlock a product if its state is `active`.  Remediation: Activate the product and resubmit the operation.   <h2 class='errorType' id=\"err-invalidProductState\">invalidProductState</h2>  Description: The supplied product state is invalid.  Remediation: Resubmit the operation, supplying a valid product state.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>validStates</td><td>array</td><td>The required states for this operation</td></tr> </table>  <h2 class='errorType' id=\"err-invalidAccountAvailability\">invalidAccountAvailability</h2>  Description: The product new account availability is not valid.  Remediation: Resubmit the operation and supply a valid product new account availability value.   <h2 class='errorType' id=\"err-invalidTransactionTypes\">invalidTransactionTypes</h2>  Description: The given transaction type is not valid.  Remediation: Resubmit the operation and supply a valid transaction type.   <h2 class='errorType' id=\"err-invalidConstraintMaxFundingAmount\">invalidConstraintMaxFundingAmount</h2>  Description: The given maximumFundingAmount value is not valid.  Remediation: Check to make sure the maximumFundingAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMaxTransferAmount\">invalidConstraintMaxTransferAmount</h2>  Description: The given maximumTransferAmount value is not valid.  Remediation: Check to make sure the maximumTransferAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinBalance\">invalidConstraintMinBalance</h2>  Description: The given minimumBalance value is not valid.  Remediation: Check to make sure the minimumBalance is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinFundingAmount\">invalidConstraintMinFundingAmount</h2>  Description: The given minimumFundingAmount value is not valid.  Remediation: Check to make sure the minimumFundingAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinTransferAmount\">invalidConstraintMinTransferAmount</h2>  Description: The given minimumTransferAmount value is not valid.  Remediation: Check to make sure the minimumTransferAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintItemAmount\">invalidConstraintItemAmount</h2>  Description: The given fees item amount value is not valid.  Remediation: Check to make sure the fees item amount is a valid numerical value. Also make sure the value is greater than 0.   <h2 class='errorType' id=\"err-invalidProductLinkToSubType\">invalidProductLinkToSubType</h2>  Description: A link to apiture:productSubtype is missing or is invalid.  Remediation: Check to make sure the product has a valid subtype or that the subtype exists.   <h2 class='errorType' id=\"err-invalidRateValues\">invalidRateValues</h2>  Description: The rate object contains invalid values.  Remediation: Check the values of the rate object and resubmit.   <h2 class='errorType' id=\"err-invalidFeesType\">invalidFeesType</h2>  Description: The fee must be an array.  Remediation: Check the type of the fee field and resubmit.   <h2 class='errorType' id=\"err-cannotPatchProductFields\">cannotPatchProductFields</h2>  Description: A products _id and newAccountAvailability cannot be patched.  Remediation: Remove the _id and newAccountAvailability from the request body and try again.   <h2 class='errorType' id=\"err-activateProductInvalidState\">activateProductInvalidState</h2>  Description: Products may only be activated if they are in an inactive or pending state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-removeProductInvalidState\">removeProductInvalidState</h2>  Description: Products may only be removed if they are in an inactive or active state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-deactivateProductInvalidState\">deactivateProductInvalidState</h2>  Description: Products may only be deactivated if they are in a pending or active state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-deleteProductInvalidState\">deleteProductInvalidState</h2>  Description: Products may only be deleted if they are in a pending state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-cannotChangeRateType\">cannotChangeRateType</h2>  Description: The products rate type may not be changed once created.  Remediation: Remove the product and recreate it with the desired rate type or create a new product.   <h2 class='errorType' id=\"err-productStateCannotBeAltered\">productStateCannotBeAltered</h2>  Description: A products state cannot be altered using the PATCH operation.  Remediation: Check the API documentation for the /activeProducts, /inactiveProducts, /removedProducts, /lockedProducts, and /unlockedProducts endpoints.   <h2 class='errorType' id=\"err-productNameInUse\">productNameInUse</h2>  Description: The given product name is currently in use, and cannot be reused.  Remediation: Delete the product with the specified name, or use a different name.   <h2 class='errorType' id=\"err-productCodeInUse\">productCodeInUse</h2>  Description: The given product code is currently in use, and cannot be reused.  Remediation: Delete the product with the specified code, or use a different code.   <h2 class='errorType' id=\"err-activateProductSubTypeInvalidState\">activateProductSubTypeInvalidState</h2>  Description: The state of the resource may not be changed to active or inactive when the product type or subtype is still `pending`.  Remediation: Check the state of your product type and subtype and ensure it is not pending.   <h2 class='errorType' id=\"err-productTypeDoesNotExist\">productTypeDoesNotExist</h2>  Description: The given product type does not exist.  Remediation: Verify that the product type exists for the subtype or parent type and resubmit.   <h2 class='errorType' id=\"err-deleteProductTypeInvalidState\">deleteProductTypeInvalidState</h2>  Description: A product type may not be deleted if the state is anything other than pending, or if the type is used by a pending product.  Remediation: Check the state of the productType and ensure it is not pending. Also ensure that any products using the productType are not pending.   <h2 class='errorType' id=\"err-removeProductTypeInvalidState\">removeProductTypeInvalidState</h2>  Description: A product type may not be updated if the state is removed.  Remediation: Check the state of the productType and ensure it not removed.   <h2 class='errorType' id=\"err-updateProductTypeInvalidState\">updateProductTypeInvalidState</h2>  Description: A product type may not be removed if the state is anything other than inactive.  Remediation: Check the state of the productType and ensure it is inactive.   <h2 class='errorType' id=\"err-cannotChangeRemovedProductTypeState\">cannotChangeRemovedProductTypeState</h2>  Description: The state of a removed productType may not be changed.  Remediation: Check the state of the productType and ensure it is not removed.   <h2 class='errorType' id=\"err-cannotUpdateProductTypeState\">cannotUpdateProductTypeState</h2>  Description: The state of a productType cannot be changed using a PUT method.  Remediation: Check the API documentation for the /activeProductTypes, /inactiveProductTypes, and /removedProductTypes endpoints.   <h2 class='errorType' id=\"err-invalidQueryParameterCombination\">invalidQueryParameterCombination</h2>  Description: Do not use mutually exclusive query parameters.  Remediation: Use one or the other, but not both.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>type</td><td>undefined</td><td>undefined</td></tr> <tr><td>mutuallyExclusiveQueryParameters</td><td>array</td><td>undefined<br>Example: `state,openable`</td></tr> </table>
