# @apiture/statements-client-sdk@0.7.0
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/statements-client-sdk@0.7.0 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, StatementApi } from "@apiture/statements-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate StatementApi main class passing the configuration object.
    const statementApi = new StatementApi(configuration);


// Use the methods to call the apis ( Refer to the Statements SDK Classes and Methods list ).
  statement.getStatements().then( response => {
    const getstatementsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate StatementApi main class.
    const statementApi = new StatementApi();


// Update the accessToken using the class method `setAccessToken`.
    statementApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    statementApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    statementApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Statements } from "@apiture/statements-client-sdk";

  const stronglyTypedObject :Statements = { ... };

  // ______ Scoped import

  import * as StatementsTypes from "@apiture/statements-client-sdk";

  const stronglyTypedObject :StatementsTypes.Statements = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/statements",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Statements SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### StatementApi


  `StatementApi.getStatement` - Fetch a representation of this statement

  `StatementApi.getStatements` - Return a collection of statements



## About the Statements API
___
**Warning: The Statements API is deprecated.** The features of this API are now available in the Documents API via the `getStatements` operation. **This API will be removed by July 1, 2020.**   This API provides access to monthly statements for accounts. The user can query this API to list statements for one or more accounts. Statements may also be queried based on time intervals:     * the start and end date    * a start or end date and a period, such as statements for the first 6 months of a year    * an end date and a period, such as statements for the last 6 months.   Each statement resource includes summary properties which describe the account, and contains a link (`apiture:statement`) to the downloadable statement document, typically PDF.
