// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Text
 * Manage localizable and customizable text strings for client applications.   The Text API is a repository for customizable and localizable text strings which the financial institution may wish to customize in order to change their user experience. The primary consumer of this API is client applications.   Example of customizable text includes:    * page or form titles   * field labels   * hover tips   * URLs (for images or other resources)   * icon references in image icon sets   * instructions or other in-line help   * larger text blocks such as Markdown text blocks.   The Text API manages only static text that is part of the UX or clients, not dynamic changing text _data_ (such as an banking product names, document names, description) provided by the services or the users.  ## Text Strings and Text String Groups  Text is organized into named _groups_ of related strings. These groups often correspond to client application features, such as banking, transfers, or digital account opening. The special group name `common` represents content that is \"common\" to (or shared with) all other groups. Groups names may be nested logically. For example, the group `common.fi` is for text related to the financial institution within the `common` group.   Text strings may include references to other strings, including strings in other groups. For example, consider the message string   `Contact {{common.fi.name}} customer support at {{common.fi.supportNumber}} or {{common.fi.supportLink_url}}`   This template resolve to a string result such as   `Contact 3rd Party Bank customer support at 555-555-1234 or [Support](https://www3rdparty.bank/support)`   `{{common.fi.supportNumber}}` is an example of a string reference by a _key_ which consists of a group name (`common.fi`) and string name (`supportNumber`). Unresolved references are left unexpanded. For example, if there is no string named `support_url` in the `common.fi` group, the above text string request returns   `Contact 3rd Party Bank customer support at 555-555-1234 or {{common.fi.supportLink_url}}`   The reserved group name `_` is an alias for the current group. This allows text strings to easily reference other text strings in the group in a more concise manner. For example, if the text string   `Contact {{common.fi.name}} customer support at {{common.fi.supportNumber}} or {{common.fi.supportLink_url}}`   exists in the `common.fi` group, it could be coded as   `Contact {{_.name}} customer support at {{_.supportNumber}} or {{_.supportLink_url}}`   By convention, string references without group names (that is, those with the format `{{name}}`) are not expanded by the Text service and are left for client-side expansion using a client-supplied environment map of name/value pairs. The same is true for references {{groupId.textStringId}} where the named group or string are not defined.)   Text strings are referenced by a string ID, which must be a simple name:   `name = [ letter | \"_\" ] ( letter | digit | \"_\" | \"$\" )*`<br> `textStringId = name`   Text string names may end with a `_` and a _suffix_ which indicates the purpose or use of the text string. The Text API supports the following suffixes:    * `_label` - labels for UI fields; allows Markdown (125)   * `_tip` - tool tips, hover tips; allows Markdown (250)   * `_md` - Markdown formatted text blocks, such as instructions. Possibly multi-line. (4000)   * `_url` - URLs of other resources, such as images. Example: `backgroundImage_url` (250)   * `_help` - Short on-screen Markdown help for `(?)` or `(i)` icons or _Explain this_ buttons. (1000)  The maximum length of a text string is determined by the suffix (shown in parentheses above).   Client applications must render [Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text values before presenting `*_label`, `*_md` and `*_help` text strings to the user. Web applications may format Markdown to HTML for example.   A group ID is a simple name or `.`-separated names for two- or three-level names such as `level1.level2.level3`.   `groupId = name ( \".\" name ) {0,2}`   The concatenation of the group ID  and a period and the string ID is the string's ***key***.  ## Customization access controls  Different text groups are customizable by different audiences. Only Apiture Engineering may customize some text groups; Only Apiture Professional Services may customize some text groups; financial institutions may customize all other text groups.  ## Natural Language Support  Each text string can have different natural language variants, access by a language code. For example, a text string `preferredAddressOption_label` may have values for the [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers `es-MX`, `es-SP`, `fr`, `de`, `en-GB` and `en-US`. The client specifies the preferred language when requesting text strings and The service follows locale inheritance rules when resolving the request. (See the [ `GET /resolved` (`getResolvedText`)](#op-getresolved) operation below.)   For example, when asking for resolved text for `es-MX`, if a text string `preferredAddressOption_label` is not defined for `es-MX`, the service looks for a value for `es`, and if not defined for `es`, the service returns the value defined for the default locale. The default locale is `en-US`. The default locale-independent value for each text string _must_ be defined when adding groups and text strings.  ## Presentation Format/Form Factors  Text also supports content that is specific to a _format_ which represents different user experience form factors. A mobile app with a smaller screen format may require a different set of labels than those used for web or larger tablets. The service will also fall back from format-specific to format-agnostic labels.   The language and format are examples of optional text parameters.   The client can request text either by the URL path GET `/groups/{groupId}/strings/{textStringId}` or by requesting all text strings in one or more groups via `GET /text/resolved?group=group1|group2|...|groupN` or for all groups, `GET /text/resolved`. These operations support parameterization of the response with the `format=` query parameter and/or the `?languages=` query parameter. Note that unlike many other Apiture APIs, the identifiers for groups and strings (`groupId` and `textStringId`) are _names_, not opaque resource IDs. Clients may use `PUT` to _create_ or _update_ new groups and new text strings within groups with client-supplied names rather than using `POST` to create resources and have the service generate the IDs.
 *
 * OpenAPI spec version: 0.7.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/text'.replace(/\/+$/, '');

export const API_VERSION = '0.7.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Representation of text format resources. Text formats represent client-side presentation formats, such as `small` for a display with limited screen real estate, or `large` for a display with generous screen real estate. The text service supports `small` and `large`, and `small` is the default format.
 * @export
 * @interface Format
 */
export interface Format extends AbstractResource {
  /**
   * The name of this text format. This is the format ID. Names are case sensitive. type: string
   * @type {any}
   * @memberof Format
   */
  name?: any;
  /**
   * The description of this text string format.
   * @type {string}
   * @memberof Format
   */
  description?: string;
}

/**
 * Collection of text formats. The items in the collection are ordered in the `_embedded.items` array; the `name` is `formats`. This collection is small and thus does not support pagination links.
 * @export
 * @interface Formats
 */
export interface Formats extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Formats
   */
  _embedded?: any;
}

/**
 * A text group is a named set of related text strings.
 * @export
 * @interface Group
 */
export interface Group extends AbstractResource {
  /**
   * The name of this text group. This is the group ID. The name of a group is a simple identifier name such as `common` (up to 16 alphanumeric characters) or a two- or three-level name such as `common.fi` or `address.line1Label` where each level name is a simple identifier of 1 to 16 alphanumeric characters. Group names are case sensitive
   * @type {string}
   * @memberof Group
   */
  name?: string;
  /**
   * The description of this text string format.
   * @type {string}
   * @memberof Group
   */
  description?: string;
  /**
   * This group is immutable.
   * @type {boolean}
   * @memberof Group
   */
  immutable?: boolean;
  /**
   * The date-time when this group (or any text strings in it) was last modified. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC format.
   * @type {Date}
   * @memberof Group
   */
  updatedAt?: Date;
}

/**
 * Collection of text groups. The items in the collection are ordered in the `_embedded.items` array; the `name` is `groups`.
 * @export
 * @interface Groups
 */
export interface Groups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Groups
   */
  _embedded?: any;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A resolved group of text string values for a specific language or set of languages and format. The keys in this object are group IDs such as `common`, `common.fi`, or `checkDeposit`. The values map string IDs to simple strings objects, with  any resolvable text string references replaced by their values. In the example below, there is no text string `user.preferredName` so it is left unresolved.
 * @export
 * @interface ResolvedGroup
 */
export interface ResolvedGroup {
  [key: string]: string;
}

/**
 * Resolved text string items for a specific language or set of languages and format. This contains `groups` which is a map of maps. The outer map has group names as keys and inner maps as values; the inner maps have text string names as keys and raw string values as the values. These are very light-weight representations if groups and text strings.
 * @export
 * @interface ResolvedStrings
 */
export interface ResolvedStrings extends AbstractResource {
  /**
   * The value of the `format` query parameter (or the default) used when requesting the resolved text.
   * @type {string}
   * @memberof ResolvedStrings
   */
  format?: string;
  /**
   * The language(s) from which the returned text strings are resolved.
   * @type {Array<string>}
   * @memberof ResolvedStrings
   */
  languages?: Array<string>;
  /**
   * The map of group IDs to resolved strings in that group.
   * @type {any}
   * @memberof ResolvedStrings
   */
  groups?: any;
  /**
   * A list of string keys (`groupId` + `.` + `textStringId`) which were referenced in `groups` strings but which are not resolved either because the `groupId` was not defined, or the `textStringId` was not defined in the group named by the key.
   * @type {Array<string>}
   * @memberof ResolvedStrings
   */
  unresolvedKeys?: Array<string>;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * A named text string within a group. Each text string contains one or more `values`, parameterized by an optional `language` code and `format` code. Items without a `language` and `format` serve as default values which are used if no item matches the requested language and format. The text string's `values` must include exactly one default item with no `language` and `format`. No two values may have the same `format` and `language`.
 * @export
 * @interface TextString
 */
export interface TextString extends AbstractResource, TextStringFields {}

/**
 * Properties of a text string object. (This is a fragment schema, used to define other schemas.)
 * @export
 * @interface TextStringFields
 */
export interface TextStringFields {
  /**
   * The name of this text string. The name must be unique within the group.
   * @type {string}
   * @memberof TextStringFields
   */
  name?: string;
  /**
   * String values for each combination of format and language.
   * @type {Array<TextStringItem>}
   * @memberof TextStringFields
   */
  values?: Array<TextStringItem>;
  /**
   * The date-time when this text string was last modified. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC format.
   * @type {Date}
   * @memberof TextStringFields
   */
  updatedAt?: Date;
}

/**
 * A since string value, corresponding to a `textStringId`, language code, and a format code. One or more text string items form a `textString` object with a shared `textStringId`.
 * @export
 * @interface TextStringItem
 */
export interface TextStringItem {
  /**
   * The text value of this string.
   * @type {string}
   * @memberof TextStringItem
   */
  value: string;
  /**
   * The [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifier for this string item. If omitted on this instance, this is a _default_ text string item to be used if no other items match a request. Language codes are case insensitive.
   * @type {string}
   * @memberof TextStringItem
   */
  language?: string;
  /**
   * The name of a format (or form factor) of the client user experience that this string item best matches. If omitted, this is a default string item to be used if no other items match a request. If specified, this must be the ID of a format resource at `/text/formats/{formatId}`, such as `small` or `large`.
   * @type {string}
   * @memberof TextStringItem
   */
  format?: string;
}

/**
 * Collection of text strings. The items in the collection are ordered in the `_embedded.items` array; the `name` is `strings`.
 * @export
 * @interface TextStrings
 */
export interface TextStrings extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof TextStrings
   */
  _embedded?: any;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * TextApi - axios parameter creator
 * @export
 */
export const TextApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return all text groups and text strings for the specified (or default) language and the specified (or default) client format. The strings are _resolved_  by replacing string references (references have the form `{{key}}`) to other text strings with their corresponding values.  This operation is the primary operation that clients use to load the text strings to present to one end user, based on that user's preferred language and their device format.
     * @param {Object} [query] Query object
     * @param {string} [query.format] Return text strings that match the named or default format (form factor). If no text for the requested format exists for a &#x60;textStringId&#x60;, the default text for that &#x60;textStringId&#x60; is returned.
     * @param {Array<string>} [query.languages] Return text strings that match the search priority of the given language tag(s). The array is ordered by highest to lowest preference. For example, for &#x60;?languages&#x3D;es-MX,en-GB&#x60;, the response will include text strings based on the following search priority: &#x60;es-MX&#x60; &amp;rArr; &#x60;es&#x60; &amp;rArr; &#x60;en-GB&#x60; &amp;rArr; &#x60;en&#x60; &amp;rArr; &#x60;&#x60; (_default_) &lt;br&gt; Items are [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers. If used, &#x60;Accept-Language&#x60; header is ignored. Language codes are case insensitive.
     * @param {Array<string>} [query.groups] Subset the response to only text in the group or groups named in this parameter. Each item in the comma-separated list is a one-, two-, or three-level group name. Group names are case sensitive. The default is &#x60;?groups&#x3D;common&#x60;. Example: &#x60;&amp;groups&#x3D;common,help,features.x,feature.y&#x60;
     * @param {Date} [query.since] Return only text strings whose &#x60;updatedAt&#x60; time-stamp are newer than the &#x60;since&#x60; date-time. If omitted, return all text strings The value is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp in &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60; format.
     * @param {boolean} [query.resolve] If &#x60;?resolve&#x3D;false&#x60;, this operation does not resolve embedded &#x60;{{key}}&#x60; text string references.
     * @param {boolean} [query.subgroups] If &#x60;true&#x60;, the response includes all subgroups of each group named in &#x60;groups&#x60;. This example may return the groups &#x60;common&#x60; and &#x60;common.fi&#x60;, &#x60;common.print&#x60;, and &#x60;web.responsive&#x60; but not the groups &#x60;commonTrust&#x60; or &#x60;helpless&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] An [HTTP &#x60;Accept-Language&#x60;](https://tools.ietf.org/html/rfc7231#section-5.3.5) request header which specifies one or more languages with weights. The response will include one string for each combination of group name and string name. This is ignored if &#x60;?languages&#x3D;&#x60; query parameter is used. &#x60;Accept-Language&#x60; is processed in a similar way as the &#x60;language&#x60; query parameter.
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getResolvedText(
      query?: {
        format?: string;
        languages?: Array<string>;
        groups?: Array<string>;
        since?: Date;
        resolve?: boolean;
        subgroups?: boolean;
      },
      headers?: { Accept_Language?: string; If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { format, languages, groups, since, resolve, subgroups } = query;
      const { Accept_Language, If_None_Match } = headers;

      const localVarPath = `/resolved`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (format !== undefined) {
        localVarQueryParameter['format'] = format;
      }

      if (languages) {
        localVarQueryParameter['languages'] = languages.join(COLLECTION_FORMATS['csv']);
      }

      if (groups) {
        localVarQueryParameter['groups'] = groups.join(COLLECTION_FORMATS['csv']);
      }

      if (since !== undefined) {
        localVarQueryParameter['since'] = (since as any).toISOString();
      }

      if (resolve !== undefined) {
        localVarQueryParameter['resolve'] = resolve;
      }

      if (subgroups !== undefined) {
        localVarQueryParameter['subgroups'] = subgroups;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TextApi - functional programming interface
 * @export
 */
export const TextApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return all text groups and text strings for the specified (or default) language and the specified (or default) client format. The strings are _resolved_  by replacing string references (references have the form `{{key}}`) to other text strings with their corresponding values.  This operation is the primary operation that clients use to load the text strings to present to one end user, based on that user's preferred language and their device format.
     * @param {Object} [query] Query object
     * @param {string} [query.format] Return text strings that match the named or default format (form factor). If no text for the requested format exists for a &#x60;textStringId&#x60;, the default text for that &#x60;textStringId&#x60; is returned.
     * @param {Array<string>} [query.languages] Return text strings that match the search priority of the given language tag(s). The array is ordered by highest to lowest preference. For example, for &#x60;?languages&#x3D;es-MX,en-GB&#x60;, the response will include text strings based on the following search priority: &#x60;es-MX&#x60; &amp;rArr; &#x60;es&#x60; &amp;rArr; &#x60;en-GB&#x60; &amp;rArr; &#x60;en&#x60; &amp;rArr; &#x60;&#x60; (_default_) &lt;br&gt; Items are [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers. If used, &#x60;Accept-Language&#x60; header is ignored. Language codes are case insensitive.
     * @param {Array<string>} [query.groups] Subset the response to only text in the group or groups named in this parameter. Each item in the comma-separated list is a one-, two-, or three-level group name. Group names are case sensitive. The default is &#x60;?groups&#x3D;common&#x60;. Example: &#x60;&amp;groups&#x3D;common,help,features.x,feature.y&#x60;
     * @param {Date} [query.since] Return only text strings whose &#x60;updatedAt&#x60; time-stamp are newer than the &#x60;since&#x60; date-time. If omitted, return all text strings The value is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp in &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60; format.
     * @param {boolean} [query.resolve] If &#x60;?resolve&#x3D;false&#x60;, this operation does not resolve embedded &#x60;{{key}}&#x60; text string references.
     * @param {boolean} [query.subgroups] If &#x60;true&#x60;, the response includes all subgroups of each group named in &#x60;groups&#x60;. This example may return the groups &#x60;common&#x60; and &#x60;common.fi&#x60;, &#x60;common.print&#x60;, and &#x60;web.responsive&#x60; but not the groups &#x60;commonTrust&#x60; or &#x60;helpless&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] An [HTTP &#x60;Accept-Language&#x60;](https://tools.ietf.org/html/rfc7231#section-5.3.5) request header which specifies one or more languages with weights. The response will include one string for each combination of group name and string name. This is ignored if &#x60;?languages&#x3D;&#x60; query parameter is used. &#x60;Accept-Language&#x60; is processed in a similar way as the &#x60;language&#x60; query parameter.
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getResolvedText(
      query?: {
        format?: string;
        languages?: Array<string>;
        groups?: Array<string>;
        since?: Date;
        resolve?: boolean;
        subgroups?: boolean;
      },
      headers?: { Accept_Language?: string; If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ResolvedStrings> {
      const localVarAxiosArgs = TextApiAxiosParamCreator(configuration).getResolvedText(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TextApi - factory interface
 * @export
 */
export const TextApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return all text groups and text strings for the specified (or default) language and the specified (or default) client format. The strings are _resolved_  by replacing string references (references have the form `{{key}}`) to other text strings with their corresponding values.  This operation is the primary operation that clients use to load the text strings to present to one end user, based on that user's preferred language and their device format.
     * @param {Object} [query] Query object
     * @param {string} [query.format] Return text strings that match the named or default format (form factor). If no text for the requested format exists for a &#x60;textStringId&#x60;, the default text for that &#x60;textStringId&#x60; is returned.
     * @param {Array<string>} [query.languages] Return text strings that match the search priority of the given language tag(s). The array is ordered by highest to lowest preference. For example, for &#x60;?languages&#x3D;es-MX,en-GB&#x60;, the response will include text strings based on the following search priority: &#x60;es-MX&#x60; &amp;rArr; &#x60;es&#x60; &amp;rArr; &#x60;en-GB&#x60; &amp;rArr; &#x60;en&#x60; &amp;rArr; &#x60;&#x60; (_default_) &lt;br&gt; Items are [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers. If used, &#x60;Accept-Language&#x60; header is ignored. Language codes are case insensitive.
     * @param {Array<string>} [query.groups] Subset the response to only text in the group or groups named in this parameter. Each item in the comma-separated list is a one-, two-, or three-level group name. Group names are case sensitive. The default is &#x60;?groups&#x3D;common&#x60;. Example: &#x60;&amp;groups&#x3D;common,help,features.x,feature.y&#x60;
     * @param {Date} [query.since] Return only text strings whose &#x60;updatedAt&#x60; time-stamp are newer than the &#x60;since&#x60; date-time. If omitted, return all text strings The value is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp in &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60; format.
     * @param {boolean} [query.resolve] If &#x60;?resolve&#x3D;false&#x60;, this operation does not resolve embedded &#x60;{{key}}&#x60; text string references.
     * @param {boolean} [query.subgroups] If &#x60;true&#x60;, the response includes all subgroups of each group named in &#x60;groups&#x60;. This example may return the groups &#x60;common&#x60; and &#x60;common.fi&#x60;, &#x60;common.print&#x60;, and &#x60;web.responsive&#x60; but not the groups &#x60;commonTrust&#x60; or &#x60;helpless&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] An [HTTP &#x60;Accept-Language&#x60;](https://tools.ietf.org/html/rfc7231#section-5.3.5) request header which specifies one or more languages with weights. The response will include one string for each combination of group name and string name. This is ignored if &#x60;?languages&#x3D;&#x60; query parameter is used. &#x60;Accept-Language&#x60; is processed in a similar way as the &#x60;language&#x60; query parameter.
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getResolvedText(
      query?: {
        format?: string;
        languages?: Array<string>;
        groups?: Array<string>;
        since?: Date;
        resolve?: boolean;
        subgroups?: boolean;
      },
      headers?: { Accept_Language?: string; If_None_Match?: string },
      options?: any,
    ) {
      return TextApiFp(configuration).getResolvedText(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TextApi - object-oriented interface
 * @export
 * @class TextApi
 * @extends {BaseAPI}
 */
export class TextApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return all text groups and text strings for the specified (or default) language and the specified (or default) client format. The strings are _resolved_  by replacing string references (references have the form `{{key}}`) to other text strings with their corresponding values.  This operation is the primary operation that clients use to load the text strings to present to one end user, based on that user's preferred language and their device format.
   * @param {Object} [query] Query object
   * @param {string} [query.format] Return text strings that match the named or default format (form factor). If no text for the requested format exists for a &#x60;textStringId&#x60;, the default text for that &#x60;textStringId&#x60; is returned.
   * @param {Array<string>} [query.languages] Return text strings that match the search priority of the given language tag(s). The array is ordered by highest to lowest preference. For example, for &#x60;?languages&#x3D;es-MX,en-GB&#x60;, the response will include text strings based on the following search priority: &#x60;es-MX&#x60; &amp;rArr; &#x60;es&#x60; &amp;rArr; &#x60;en-GB&#x60; &amp;rArr; &#x60;en&#x60; &amp;rArr; &#x60;&#x60; (_default_) &lt;br&gt; Items are [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers. If used, &#x60;Accept-Language&#x60; header is ignored. Language codes are case insensitive.
   * @param {Array<string>} [query.groups] Subset the response to only text in the group or groups named in this parameter. Each item in the comma-separated list is a one-, two-, or three-level group name. Group names are case sensitive. The default is &#x60;?groups&#x3D;common&#x60;. Example: &#x60;&amp;groups&#x3D;common,help,features.x,feature.y&#x60;
   * @param {Date} [query.since] Return only text strings whose &#x60;updatedAt&#x60; time-stamp are newer than the &#x60;since&#x60; date-time. If omitted, return all text strings The value is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp in &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60; format.
   * @param {boolean} [query.resolve] If &#x60;?resolve&#x3D;false&#x60;, this operation does not resolve embedded &#x60;{{key}}&#x60; text string references.
   * @param {boolean} [query.subgroups] If &#x60;true&#x60;, the response includes all subgroups of each group named in &#x60;groups&#x60;. This example may return the groups &#x60;common&#x60; and &#x60;common.fi&#x60;, &#x60;common.print&#x60;, and &#x60;web.responsive&#x60; but not the groups &#x60;commonTrust&#x60; or &#x60;helpless&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] An [HTTP &#x60;Accept-Language&#x60;](https://tools.ietf.org/html/rfc7231#section-5.3.5) request header which specifies one or more languages with weights. The response will include one string for each combination of group name and string name. This is ignored if &#x60;?languages&#x3D;&#x60; query parameter is used. &#x60;Accept-Language&#x60; is processed in a similar way as the &#x60;language&#x60; query parameter.
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ResolvedStrings}
   * @memberof TextApi
   */
  public getResolvedText(
    query?: {
      format?: string;
      languages?: Array<string>;
      groups?: Array<string>;
      since?: Date;
      resolve?: boolean;
      subgroups?: boolean;
    },
    headers?: { Accept_Language?: string; If_None_Match?: string },
    options?: any,
  ) {
    return TextApiFp(this.configuration).getResolvedText(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * TextFormatApi - axios parameter creator
 * @export
 */
export const TextFormatApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text format resource.
     * @summary Fetch a representation of this text format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormat(
      formatId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'formatId' is not null or undefined
      if (formatId === null || formatId === undefined) {
        throw new RequiredError(
          'formatId',
          'Required parameter formatId was null or undefined when calling getFormat.',
        );
      }
      const localVarPath = `/formats/{formatId}`.replace(
        `{${'formatId'}}`,
        encodeURIComponent(String(formatId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a collection of text formats. The Text service has default formats named `small` and `large`.
     * @summary Return a collection of text formats
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormats(headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      const localVarPath = `/formats`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this text format.
     * @summary Update or create a text format
     * @param {Format} Format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setFormat(
      Format: Format,
      formatId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'formatId' is not null or undefined
      if (formatId === null || formatId === undefined) {
        throw new RequiredError(
          'formatId',
          'Required parameter formatId was null or undefined when calling setFormat.',
        );
      }
      // verify required parameter 'Format' is not null or undefined
      if (Format === null || Format === undefined) {
        throw new RequiredError(
          'Format',
          'Required parameter Format was null or undefined when calling setFormat.',
        );
      }
      const localVarPath = `/formats/{formatId}`.replace(
        `{${'formatId'}}`,
        encodeURIComponent(String(formatId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'admin/write',
                'admin/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Format' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Format || {})
        : Format || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TextFormatApi - functional programming interface
 * @export
 */
export const TextFormatApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text format resource.
     * @summary Fetch a representation of this text format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormat(
      formatId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Format> {
      const localVarAxiosArgs = TextFormatApiAxiosParamCreator(configuration).getFormat(
        formatId ? formatId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a collection of text formats. The Text service has default formats named `small` and `large`.
     * @summary Return a collection of text formats
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormats(
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Formats> {
      const localVarAxiosArgs = TextFormatApiAxiosParamCreator(configuration).getFormats(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this text format.
     * @summary Update or create a text format
     * @param {Format} Format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setFormat(
      Format: Format,
      formatId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Format> {
      const localVarAxiosArgs = TextFormatApiAxiosParamCreator(configuration).setFormat(
        Format ? Format : null,
        formatId ? formatId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TextFormatApi - factory interface
 * @export
 */
export const TextFormatApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text format resource.
     * @summary Fetch a representation of this text format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormat(formatId: string, headers?: { If_None_Match?: string }, options?: any) {
      return TextFormatApiFp(configuration).getFormat(
        formatId ? formatId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a collection of text formats. The Text service has default formats named `small` and `large`.
     * @summary Return a collection of text formats
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFormats(headers?: { If_None_Match?: string }, options?: any) {
      return TextFormatApiFp(configuration).getFormats(
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this text format.
     * @summary Update or create a text format
     * @param {Format} Format
     * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setFormat(Format: Format, formatId: string, headers?: { If_Match?: string }, options?: any) {
      return TextFormatApiFp(configuration).setFormat(
        Format ? Format : null,
        formatId ? formatId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TextFormatApi - object-oriented interface
 * @export
 * @class TextFormatApi
 * @extends {BaseAPI}
 */
export class TextFormatApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text format resource.
   * @summary Fetch a representation of this text format
   * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Format}
   * @memberof TextFormatApi
   */
  public getFormat(formatId: string, headers?: { If_None_Match?: string }, options?: any) {
    return TextFormatApiFp(this.configuration).getFormat(
      formatId ? formatId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a collection of text formats. The Text service has default formats named `small` and `large`.
   * @summary Return a collection of text formats
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Formats}
   * @memberof TextFormatApi
   */
  public getFormats(headers?: { If_None_Match?: string }, options?: any) {
    return TextFormatApiFp(this.configuration).getFormats(
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this text format.
   * @summary Update or create a text format
   * @param {Format} Format
   * @param {string} formatId The unique identifier (&#x60;name&#x60;) of this text format.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Format}
   * @memberof TextFormatApi
   */
  public setFormat(
    Format: Format,
    formatId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TextFormatApiFp(this.configuration).setFormat(
      Format ? Format : null,
      formatId ? formatId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * TextGroupApi - axios parameter creator
 * @export
 */
export const TextGroupApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete this text group resource and any resources that are owned by it.
     * @summary Delete this text group resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteGroup(groupId: string, options: any = {}): RequestArgs {
      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling deleteGroup.',
        );
      }
      const localVarPath = `/groups/{groupId}`.replace(
        `{${'groupId'}}`,
        encodeURIComponent(String(groupId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'admin/write',
                'admin/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text group resource.
     * @summary Fetch a representation of this text group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroup(
      groupId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling getGroup.',
        );
      }
      const localVarPath = `/groups/{groupId}`.replace(
        `{${'groupId'}}`,
        encodeURIComponent(String(groupId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the collection of text groups. Since the number of groups is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text groups
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroups(headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      const localVarPath = `/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a text group, or update an existing text group's properties.
     * @summary Create or update a text group
     * @param {Group} Group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setGroup(
      Group: Group,
      groupId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling setGroup.',
        );
      }
      // verify required parameter 'Group' is not null or undefined
      if (Group === null || Group === undefined) {
        throw new RequiredError(
          'Group',
          'Required parameter Group was null or undefined when calling setGroup.',
        );
      }
      const localVarPath = `/groups/{groupId}`.replace(
        `{${'groupId'}}`,
        encodeURIComponent(String(groupId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'admin/write',
                'admin/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Group' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(Group || {}) : Group || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TextGroupApi - functional programming interface
 * @export
 */
export const TextGroupApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete this text group resource and any resources that are owned by it.
     * @summary Delete this text group resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteGroup(
      groupId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = TextGroupApiAxiosParamCreator(configuration).deleteGroup(
        groupId ? groupId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text group resource.
     * @summary Fetch a representation of this text group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroup(
      groupId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Group> {
      const localVarAxiosArgs = TextGroupApiAxiosParamCreator(configuration).getGroup(
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the collection of text groups. Since the number of groups is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text groups
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroups(
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Groups> {
      const localVarAxiosArgs = TextGroupApiAxiosParamCreator(configuration).getGroups(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a text group, or update an existing text group's properties.
     * @summary Create or update a text group
     * @param {Group} Group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setGroup(
      Group: Group,
      groupId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Group> {
      const localVarAxiosArgs = TextGroupApiAxiosParamCreator(configuration).setGroup(
        Group ? Group : null,
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TextGroupApi - factory interface
 * @export
 */
export const TextGroupApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Delete this text group resource and any resources that are owned by it.
     * @summary Delete this text group resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteGroup(groupId: string, options?: any) {
      return TextGroupApiFp(configuration).deleteGroup(
        groupId ? groupId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text group resource.
     * @summary Fetch a representation of this text group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroup(groupId: string, headers?: { If_None_Match?: string }, options?: any) {
      return TextGroupApiFp(configuration).getGroup(
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the collection of text groups. Since the number of groups is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text groups
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getGroups(headers?: { If_None_Match?: string }, options?: any) {
      return TextGroupApiFp(configuration).getGroups(
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a text group, or update an existing text group's properties.
     * @summary Create or update a text group
     * @param {Group} Group
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setGroup(Group: Group, groupId: string, headers?: { If_Match?: string }, options?: any) {
      return TextGroupApiFp(configuration).setGroup(
        Group ? Group : null,
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TextGroupApi - object-oriented interface
 * @export
 * @class TextGroupApi
 * @extends {BaseAPI}
 */
export class TextGroupApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Delete this text group resource and any resources that are owned by it.
   * @summary Delete this text group resource
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof TextGroupApi
   */
  public deleteGroup(groupId: string, options?: any) {
    return TextGroupApiFp(this.configuration).deleteGroup(
      groupId ? groupId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text group resource.
   * @summary Fetch a representation of this text group
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Group}
   * @memberof TextGroupApi
   */
  public getGroup(groupId: string, headers?: { If_None_Match?: string }, options?: any) {
    return TextGroupApiFp(this.configuration).getGroup(
      groupId ? groupId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the collection of text groups. Since the number of groups is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
   * @summary Return a collection of text groups
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Groups}
   * @memberof TextGroupApi
   */
  public getGroups(headers?: { If_None_Match?: string }, options?: any) {
    return TextGroupApiFp(this.configuration).getGroups(
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a text group, or update an existing text group's properties.
   * @summary Create or update a text group
   * @param {Group} Group
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Group}
   * @memberof TextGroupApi
   */
  public setGroup(Group: Group, groupId: string, headers?: { If_Match?: string }, options?: any) {
    return TextGroupApiFp(this.configuration).setGroup(
      Group ? Group : null,
      groupId ? groupId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * TextStringApi - axios parameter creator
 * @export
 */
export const TextStringApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete this text string resource and any resources that are owned by it. This operation is limited to administrative use.
     * @summary Delete this text string resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteString(groupId: string, textStringId: string, options: any = {}): RequestArgs {
      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling deleteString.',
        );
      }
      // verify required parameter 'textStringId' is not null or undefined
      if (textStringId === null || textStringId === undefined) {
        throw new RequiredError(
          'textStringId',
          'Required parameter textStringId was null or undefined when calling deleteString.',
        );
      }
      const localVarPath = `/groups/{groupId}/strings/{textStringId}`
        .replace(`{${'groupId'}}`, encodeURIComponent(String(groupId)))
        .replace(`{${'textStringId'}}`, encodeURIComponent(String(textStringId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'admin/write',
                'admin/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text string resource.
     * @summary Fetch a representation of this text string
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getString(
      groupId: string,
      textStringId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling getString.',
        );
      }
      // verify required parameter 'textStringId' is not null or undefined
      if (textStringId === null || textStringId === undefined) {
        throw new RequiredError(
          'textStringId',
          'Required parameter textStringId was null or undefined when calling getString.',
        );
      }
      const localVarPath = `/groups/{groupId}/strings/{textStringId}`
        .replace(`{${'groupId'}}`, encodeURIComponent(String(groupId)))
        .replace(`{${'textStringId'}}`, encodeURIComponent(String(textStringId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a collection of text strings within the group. Since the number of text strings in a group is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text strings
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getStrings(
      groupId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling getStrings.',
        );
      }
      const localVarPath = `/groups/{groupId}/strings`.replace(
        `{${'groupId'}}`,
        encodeURIComponent(String(groupId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new text with the `textStringId` name if one did not already exist, or update the properties of an existing text string. This operation is limited to administrative use.
     * @summary Create or update a text string
     * @param {TextString} TextString A text string and variants for different languages and client formats.
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setString(
      TextString: TextString,
      groupId: string,
      textStringId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupId' is not null or undefined
      if (groupId === null || groupId === undefined) {
        throw new RequiredError(
          'groupId',
          'Required parameter groupId was null or undefined when calling setString.',
        );
      }
      // verify required parameter 'textStringId' is not null or undefined
      if (textStringId === null || textStringId === undefined) {
        throw new RequiredError(
          'textStringId',
          'Required parameter textStringId was null or undefined when calling setString.',
        );
      }
      // verify required parameter 'TextString' is not null or undefined
      if (TextString === null || TextString === undefined) {
        throw new RequiredError(
          'TextString',
          'Required parameter TextString was null or undefined when calling setString.',
        );
      }
      const localVarPath = `/groups/{groupId}/strings/{textStringId}`
        .replace(`{${'groupId'}}`, encodeURIComponent(String(groupId)))
        .replace(`{${'textStringId'}}`, encodeURIComponent(String(textStringId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'admin/write',
                'admin/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'TextString' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(TextString || {})
        : TextString || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TextStringApi - functional programming interface
 * @export
 */
export const TextStringApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete this text string resource and any resources that are owned by it. This operation is limited to administrative use.
     * @summary Delete this text string resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteString(
      groupId: string,
      textStringId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = TextStringApiAxiosParamCreator(configuration).deleteString(
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text string resource.
     * @summary Fetch a representation of this text string
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getString(
      groupId: string,
      textStringId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<TextString> {
      const localVarAxiosArgs = TextStringApiAxiosParamCreator(configuration).getString(
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a collection of text strings within the group. Since the number of text strings in a group is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text strings
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getStrings(
      groupId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<TextStrings> {
      const localVarAxiosArgs = TextStringApiAxiosParamCreator(configuration).getStrings(
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new text with the `textStringId` name if one did not already exist, or update the properties of an existing text string. This operation is limited to administrative use.
     * @summary Create or update a text string
     * @param {TextString} TextString A text string and variants for different languages and client formats.
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setString(
      TextString: TextString,
      groupId: string,
      textStringId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<TextString> {
      const localVarAxiosArgs = TextStringApiAxiosParamCreator(configuration).setString(
        TextString ? TextString : null,
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TextStringApi - factory interface
 * @export
 */
export const TextStringApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Delete this text string resource and any resources that are owned by it. This operation is limited to administrative use.
     * @summary Delete this text string resource
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteString(groupId: string, textStringId: string, options?: any) {
      return TextStringApiFp(configuration).deleteString(
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text string resource.
     * @summary Fetch a representation of this text string
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getString(
      groupId: string,
      textStringId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return TextStringApiFp(configuration).getString(
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a collection of text strings within the group. Since the number of text strings in a group is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
     * @summary Return a collection of text strings
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getStrings(groupId: string, headers?: { If_None_Match?: string }, options?: any) {
      return TextStringApiFp(configuration).getStrings(
        groupId ? groupId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new text with the `textStringId` name if one did not already exist, or update the properties of an existing text string. This operation is limited to administrative use.
     * @summary Create or update a text string
     * @param {TextString} TextString A text string and variants for different languages and client formats.
     * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
     * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setString(
      TextString: TextString,
      groupId: string,
      textStringId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return TextStringApiFp(configuration).setString(
        TextString ? TextString : null,
        groupId ? groupId : null,
        textStringId ? textStringId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TextStringApi - object-oriented interface
 * @export
 * @class TextStringApi
 * @extends {BaseAPI}
 */
export class TextStringApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Delete this text string resource and any resources that are owned by it. This operation is limited to administrative use.
   * @summary Delete this text string resource
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof TextStringApi
   */
  public deleteString(groupId: string, textStringId: string, options?: any) {
    return TextStringApiFp(this.configuration).deleteString(
      groupId ? groupId : null,
      textStringId ? textStringId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this text string resource.
   * @summary Fetch a representation of this text string
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {TextString}
   * @memberof TextStringApi
   */
  public getString(
    groupId: string,
    textStringId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return TextStringApiFp(this.configuration).getString(
      groupId ? groupId : null,
      textStringId ? textStringId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a collection of text strings within the group. Since the number of text strings in a group is relatively small, this operation does not implement pagination, sorting, filtering, or searching.
   * @summary Return a collection of text strings
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {TextStrings}
   * @memberof TextStringApi
   */
  public getStrings(groupId: string, headers?: { If_None_Match?: string }, options?: any) {
    return TextStringApiFp(this.configuration).getStrings(
      groupId ? groupId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new text with the `textStringId` name if one did not already exist, or update the properties of an existing text string. This operation is limited to administrative use.
   * @summary Create or update a text string
   * @param {TextString} TextString A text string and variants for different languages and client formats.
   * @param {string} groupId The unique identifier (&#x60;name&#x60;) of this text group.
   * @param {string} textStringId The unique identifier (&#x60;name&#x60;) of this text string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {TextString}
   * @memberof TextStringApi
   */
  public setString(
    TextString: TextString,
    groupId: string,
    textStringId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TextStringApiFp(this.configuration).setString(
      TextString ? TextString : null,
      groupId ? groupId : null,
      textStringId ? textStringId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
