// tslint:disable
/**
 * Text
 * Manage localizable and customizable text strings for client applications.   The Text API is a repository for customizable and localizable text strings which the financial institution may wish to customize in order to change their user experience. The primary consumer of this API is client applications.   Example of customizable text includes:    * page or form titles   * field labels   * hover tips   * URLs (for images or other resources)   * icon references in image icon sets   * instructions or other in-line help   * larger text blocks such as Markdown text blocks.   The Text API manages only static text that is part of the UX or clients, not dynamic changing text _data_ (such as an banking product names, document names, description) provided by the services or the users.  ## Text Strings and Text String Groups  Text is organized into named _groups_ of related strings. These groups often correspond to client application features, such as banking, transfers, or digital account opening. The special group name `common` represents content that is \"common\" to (or shared with) all other groups. Groups names may be nested logically. For example, the group `common.fi` is for text related to the financial institution within the `common` group.   Text strings may include references to other strings, including strings in other groups. For example, consider the message string   `Contact {{common.fi.name}} customer support at {{common.fi.supportNumber}} or {{common.fi.supportLink_url}}`   This template resolve to a string result such as   `Contact 3rd Party Bank customer support at 555-555-1234 or [Support](https://www3rdparty.bank/support)`   `{{common.fi.supportNumber}}` is an example of a string reference by a _key_ which consists of a group name (`common.fi`) and string name (`supportNumber`). Unresolved references are left unexpanded. For example, if there is no string named `support_url` in the `common.fi` group, the above text string request returns   `Contact 3rd Party Bank customer support at 555-555-1234 or {{common.fi.supportLink_url}}`   The reserved group name `_` is an alias for the current group. This allows text strings to easily reference other text strings in the group in a more concise manner. For example, if the text string   `Contact {{common.fi.name}} customer support at {{common.fi.supportNumber}} or {{common.fi.supportLink_url}}`   exists in the `common.fi` group, it could be coded as   `Contact {{_.name}} customer support at {{_.supportNumber}} or {{_.supportLink_url}}`   By convention, string references without group names (that is, those with the format `{{name}}`) are not expanded by the Text service and are left for client-side expansion using a client-supplied environment map of name/value pairs. The same is true for references {{groupId.textStringId}} where the named group or string are not defined.)   Text strings are referenced by a string ID, which must be a simple name:   `name = [ letter | \"_\" ] ( letter | digit | \"_\" | \"$\" )*`<br> `textStringId = name`   Text string names may end with a `_` and a _suffix_ which indicates the purpose or use of the text string. The Text API supports the following suffixes:    * `_label` - labels for UI fields; allows Markdown (125)   * `_tip` - tool tips, hover tips; allows Markdown (250)   * `_md` - Markdown formatted text blocks, such as instructions. Possibly multi-line. (4000)   * `_url` - URLs of other resources, such as images. Example: `backgroundImage_url` (250)   * `_help` - Short on-screen Markdown help for `(?)` or `(i)` icons or _Explain this_ buttons. (1000)  The maximum length of a text string is determined by the suffix (shown in parentheses above).   Client applications must render [Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text values before presenting `*_label`, `*_md` and `*_help` text strings to the user. Web applications may format Markdown to HTML for example.   A group ID is a simple name or `.`-separated names for two- or three-level names such as `level1.level2.level3`.   `groupId = name ( \".\" name ) {0,2}`   The concatenation of the group ID  and a period and the string ID is the string's ***key***.  ## Customization access controls  Different text groups are customizable by different audiences. Only Apiture Engineering may customize some text groups; Only Apiture Professional Services may customize some text groups; financial institutions may customize all other text groups.  ## Natural Language Support  Each text string can have different natural language variants, access by a language code. For example, a text string `preferredAddressOption_label` may have values for the [RFC 3066](https://tools.ietf.org/html/rfc3066) language identifiers `es-MX`, `es-SP`, `fr`, `de`, `en-GB` and `en-US`. The client specifies the preferred language when requesting text strings and The service follows locale inheritance rules when resolving the request. (See the [ `GET /resolved` (`getResolvedText`)](#op-getresolved) operation below.)   For example, when asking for resolved text for `es-MX`, if a text string `preferredAddressOption_label` is not defined for `es-MX`, the service looks for a value for `es`, and if not defined for `es`, the service returns the value defined for the default locale. The default locale is `en-US`. The default locale-independent value for each text string _must_ be defined when adding groups and text strings.  ## Presentation Format/Form Factors  Text also supports content that is specific to a _format_ which represents different user experience form factors. A mobile app with a smaller screen format may require a different set of labels than those used for web or larger tablets. The service will also fall back from format-specific to format-agnostic labels.   The language and format are examples of optional text parameters.   The client can request text either by the URL path GET `/groups/{groupId}/strings/{textStringId}` or by requesting all text strings in one or more groups via `GET /text/resolved?group=group1|group2|...|groupN` or for all groups, `GET /text/resolved`. These operations support parameterization of the response with the `format=` query parameter and/or the `?languages=` query parameter. Note that unlike many other Apiture APIs, the identifiers for groups and strings (`groupId` and `textStringId`) are _names_, not opaque resource IDs. Clients may use `PUT` to _create_ or _update_ new groups and new text strings within groups with client-supplied names rather than using `POST` to create resources and have the service generate the IDs.
 *
 * OpenAPI spec version: 0.7.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
