# @apiture/transactions-client-sdk@0.11.6
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/transactions-client-sdk@0.11.6 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, HistoryApi, PendingTransactionsApi, TransactionsApi } from "@apiture/transactions-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate HistoryApi main class passing the configuration object.
    const historyApi = new HistoryApi(configuration);

// Instantiate PendingTransactionsApi main class passing the configuration object.
    const pendingTransactionsApi = new PendingTransactionsApi(configuration);

// Instantiate TransactionsApi main class passing the configuration object.
    const transactionsApi = new TransactionsApi(configuration);


// Use the methods to call the apis ( Refer to the Transactions SDK Classes and Methods list ).
  transactions.getTransactions().then( response => {
    const gettransactionsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate TransactionsApi main class.
    const transactionsApi = new TransactionsApi();


// Update the accessToken using the class method `setAccessToken`.
    transactionsApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    transactionsApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    transactionsApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Transactions } from "@apiture/transactions-client-sdk";

  const stronglyTypedObject :Transactions = { ... };

  // ______ Scoped import

  import * as TransactionsTypes from "@apiture/transactions-client-sdk";

  const stronglyTypedObject :TransactionsTypes.Transactions = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/transactions",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Transactions SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### HistoryApi


  `HistoryApi.getHistory` - Return a collection of past transactions



### PendingTransactionsApi


  `PendingTransactionsApi.getPendingTransactions` - Return a collection of pending transactions



### TransactionsApi


  `TransactionsApi.getTransaction` - Fetch a representation of this transaction

  `TransactionsApi.getTransactions` - Return a collection of pending and completed transactions.



## About the Transactions API
___
The Transactions API manages banking account transactions for bank customers.  The Transactions API can view account transaction history for accounts held at the current financial institution. The `/transactions` collection lists all transactions, both pending and completed. For accounts with transaction history, the user can view those transactions via the `/history` endpoint (the `getHistory` operation). Pending transactions are managed in a separate collection, under `/pendingTransactions` (via the `getPendingTransactions` operation).  Note that the queries to filter transactions do not use the actual account numbers: ```    GET /transactions/history?account=0399abed-fd3d-4830-a88b-30f38b8a365c ``` For security, these queries only filter based on the opaque account resource ID, which is decoupled from the account number. Thus, account numbers do not appear in the request URLs or in web traffic logs.
