// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Transactions
 * The Transactions API manages banking account transactions for bank customers.  The Transactions API can view account transaction history for accounts held at the current financial institution. The `/transactions` collection lists all transactions, both pending and completed. For accounts with transaction history, the user can view those transactions via the `/history` endpoint (the `getHistory` operation). Pending transactions are managed in a separate collection, under `/pendingTransactions` (via the `getPendingTransactions` operation).  Note that the queries to filter transactions do not use the actual account numbers: ```    GET /transactions/history?account=0399abed-fd3d-4830-a88b-30f38b8a365c ``` For security, these queries only filter based on the opaque account resource ID, which is decoupled from the account number. Thus, account numbers do not appear in the request URLs or in web traffic logs.
 *
 * OpenAPI spec version: 0.11.6
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/transactions'.replace(/\/+$/, '');

export const API_VERSION = '0.11.6';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * Representation of an automated clearing house transfer.
 * @export
 * @interface Ach
 */
export interface Ach {
  /**
   * ACH Trace ID (threadId).
   * @type {string}
   * @memberof Ach
   */
  traceId?: string;
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The ISO 3166-1 country code.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * The balance of the account. This is derived data and not mutable through the API. Balances may be negative, indicating a deficit or loan balance.
 * @export
 * @interface Balance
 */
export interface Balance {
  /**
   * The string representation of the current account balance. This is an exact decimal representation of the numeric balance value. The current balance does not include pending transactions.
   * @type {string}
   * @memberof Balance
   */
  current?: string;
  /**
   * The current balance. **Note**: This property is deprecated. Use `balance.current` instead. This property will be removed in the next release of this service.
   * @type {string}
   * @memberof Balance
   */
  value?: string;
  /**
   * The string representation of the exact decimal available balance. For deposit accounts, this reflects the amount that may be used for withdrawals or transfers. This field does not apply to debit accounts such as loans.
   * @type {string}
   * @memberof Balance
   */
  available?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this balance.
   * @type {string}
   * @memberof Balance
   */
  currency?: string;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation of an electronic funds transfer.
 * @export
 * @interface ElectronicFundsTransfer
 */
export interface ElectronicFundsTransfer {
  /**
   * The amount in which the buyer receives cash at the time of purchase.
   * @type {Money}
   * @memberof ElectronicFundsTransfer
   */
  cashBackAmount?: Money;
  /**
   * Fees (if applicable).
   * @type {string}
   * @memberof ElectronicFundsTransfer
   */
  fee?: string;
  /**
   * Merchant's full address.
   * @type {Address}
   * @memberof ElectronicFundsTransfer
   */
  merchantAddress?: Address;
  /**
   * Indicates how the primary account number (PAN) was entered into the system.  This value encodes [ISO 8583 point of service PAN entry modes](https://en.wikipedia.org/wiki/ISO_8583#Point_of_service_entry_modes).
   * @type {string}
   * @memberof ElectronicFundsTransfer
   */
  panEntryMode?: ElectronicFundsTransfer.PanEntryModeEnum;
}

/**
 * @export
 * @namespace ElectronicFundsTransfer
 */
export namespace ElectronicFundsTransfer {
  /**
   * @export
   * @enum {string}
   */
  export enum PanEntryModeEnum {
    Unknown = 'unknown',
    Manual = 'manual',
    MagneticStripe = 'magneticStripe',
    BarCode = 'barCode',
    Ocr = 'ocr',
    IccCvv = 'iccCvv',
    ContactlessEmv = 'contactlessEmv',
    FallbackFromIcc = 'fallbackFromIcc',
    MagneticStripeTrackTwo = 'magneticStripeTrackTwo',
    ContactlessMagneticStripe = 'contactlessMagneticStripe',
    IccNoCvv = 'iccNoCvv',
    SameAsOriginalTransaction = 'sameAsOriginalTransaction',
  }
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Indicates the hold state of the transaction. the `holdState` will be `none` if no hold is associated to the transaction; otherwise, the `holdState` will indicate if the hold is currently `active` or has `expired`.
 * @export
 * @enum {string}
 */
export enum HoldState {
  Active = 'active',
  Expired = 'expired',
  None = 'none',
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * An amount of money in a specific currency.
 * @export
 * @interface Money
 */
export interface Money {
  /**
   * The net monetary value. A negative amount denotes a debit; a positive amount a credit. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof Money
   */
  value?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII. Note: ISO 4217 defines three-character codes. However, ISO 4217 does not account for cryptocurrencies. Of note, DASH uses 4 characters.
   * @type {string}
   * @memberof Money
   */
  currency?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * The account numbers necessary to link an target account.
 * @export
 * @interface TargetAccountNumbers
 */
export interface TargetAccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation.  It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof TargetAccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when ?unmasked=true is passed on the get request.  Not included in the summary representation of the  account that is included in account collection responses.
   * @type {string}
   * @memberof TargetAccountNumbers
   */
  full?: string;
}

/**
 * An financial transaction, such as a deposit, a check payment, interest, fees, transaction reversals, etc.
 * @export
 * @interface Transaction
 */
export interface Transaction extends AbstractResource {
  /**
   * The unique identifier for this transaction resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Transaction
   */
  _id?: string;
  /**
   * The amount of the transaction.
   * @type {Money}
   * @memberof Transaction
   */
  amount: Money;
  /**
   * The account's running balance as of this transaction. This property is optional and is omitted if not computable.
   * @type {Balance}
   * @memberof Transaction
   */
  balance?: Balance;
  /**
   *
   * @type {TransactionState}
   * @memberof Transaction
   */
  state: TransactionState;
  /**
   *
   * @type {TransactionType}
   * @memberof Transaction
   */
  type: TransactionType;
  /**
   * A subtype, more specific transaction type.
   * @type {string}
   * @memberof Transaction
   */
  subtype?: string;
  /**
   * Human readable version of the transaction description.
   * @type {string}
   * @memberof Transaction
   */
  providerSummary: string;
  /**
   * A cleansed version of the `providerSummary`.
   * @type {string}
   * @memberof Transaction
   */
  summary?: string;
  /**
   * This field contains additional descriptive information about the transaction.
   * @type {string}
   * @memberof Transaction
   */
  description?: string;
  /**
   * If this transaction represents a check drafted against this account, this is the check number.
   * @type {number}
   * @memberof Transaction
   */
  checkNumber?: number;
  /**
   * The account number returned from the core.
   * @type {AccountNumbers}
   * @memberof Transaction
   */
  sourceAccountNumbers?: AccountNumbers;
  /**
   * The account name returned from the core.
   * @type {string}
   * @memberof Transaction
   */
  sourceAccountName?: string;
  /**
   * The account number returned from the core.
   * @type {TargetAccountNumbers}
   * @memberof Transaction
   */
  targetAccountNumbers?: TargetAccountNumbers;
  /**
   * The account name returned from the core.
   * @type {string}
   * @memberof Transaction
   */
  targetAccountName?: string;
  /**
   * The transaction code returned from the core.
   * @type {string}
   * @memberof Transaction
   */
  transactionCode: string;
  /**
   * The date when the transaction was completed. This property is set only if the state is `completed`.
   * @type {string}
   * @memberof Transaction
   */
  postedOn?: string;
  /**
   * The date when the transaction was reversed.  This property is set only if the state is `reversed`.
   * @type {string}
   * @memberof Transaction
   */
  reversedOn?: string;
  /**
   * The name of the settlement network that is the transaction source, one of:    * `check` - the transaction was a check   * `eft` - debit card transaction or other electronic funds transfer   * `ach` - transfers and other Automated Clearing House transactions   * `core` - transactions sourced within the bank core
   * @type {string}
   * @memberof Transaction
   */
  network?: string;
  /**
   *
   * @type {HoldState}
   * @memberof Transaction
   */
  holdState?: HoldState;
  /**
   * The amount of funds on hold.
   * @type {Money}
   * @memberof Transaction
   */
  holdAmount?: Money;
  /**
   * The date-time when the hold will expire. This is an [RFC 3369](https://tools.ietf.org/html/rfc3339) formatted date-time string, `YYYY-MM-DDThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof Transaction
   */
  holdExpiresAt?: Date;
  /**
   * The electronic funds transfer. This property exists only if `network` is `eft`.
   * @type {ElectronicFundsTransfer}
   * @memberof Transaction
   */
  eft?: ElectronicFundsTransfer;
  /**
   * The automated clearing house transfer. This property exists only if `network` is `ach`.
   * @type {Ach}
   * @memberof Transaction
   */
  ach?: Ach;
}

/**
 * *`state`* indicates the current state of the transaction
 * @export
 * @enum {string}
 */
export enum TransactionState {
  Pending = 'pending',
  Completed = 'completed',
  Reversed = 'reversed',
}

/**
 * *`type`* should indicate the type of the transaction (not what is allowed for the account). i.e.    * *`credit`* - the transaction was a credit posted to the      account, such as the transfer of funds _to_ this account or interested posted to the account    * *`debit`* - the transaction debited funds from the account, such as a check written against an account.
 * @export
 * @enum {string}
 */
export enum TransactionType {
  Debit = 'debit',
  Credit = 'credit',
}

/**
 * Collection of transactions. The items in the collection are ordered in the `_embedded` object with array `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).  When this response is used for the `getPendingTransactions` operation, the pagination links will reference `/transactions/pendingTransactions`; when this response is used for the `getTransactions` operation, the pagination links will reference `/transactions/transactions`;  when this response is used for the `getHistory` operation, the pagination links will reference `/transactions/history`. The example shows the response for `getTransactions`.
 * @export
 * @interface Transactions
 */
export interface Transactions extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Transactions
   */
  _embedded?: any;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:accounts`* : links to the collection of accounts held at this financial institution
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:accounts`* : links to the collection of accounts held at this financial institution
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:accounts`* : links to the collection of accounts held at this financial institution
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. This API returns the following links: *`apiture:accounts`* : links to the collection of accounts held at this financial institution
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * HistoryApi - axios parameter creator
 * @export
 */
export const HistoryApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Transactions in the history are immutable and not deletable.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of past transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getHistory(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { checkNumber, holdState, start, limit, sortBy, filter, q, account } = query;

      const localVarPath = `/history`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (checkNumber !== undefined) {
        localVarQueryParameter['checkNumber'] = checkNumber;
      }

      if (holdState !== undefined) {
        localVarQueryParameter['holdState'] = holdState;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * HistoryApi - functional programming interface
 * @export
 */
export const HistoryApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Transactions in the history are immutable and not deletable.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of past transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getHistory(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Transactions> {
      const localVarAxiosArgs = HistoryApiAxiosParamCreator(configuration).getHistory(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * HistoryApi - factory interface
 * @export
 */
export const HistoryApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Transactions in the history are immutable and not deletable.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of past transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getHistory(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ) {
      return HistoryApiFp(configuration).getHistory(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * HistoryApi - object-oriented interface
 * @export
 * @class HistoryApi
 * @extends {BaseAPI}
 */
export class HistoryApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Transactions in the history are immutable and not deletable.  The default will show transactions for all accounts that the user has access to.
   * @summary Return a collection of past transactions
   * @param {Object} [query] Query object
   * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
   * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Transactions}
   * @memberof HistoryApi
   */
  public getHistory(
    query?: {
      checkNumber?: string;
      holdState?: string;
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      account?: string;
    },
    options?: any,
  ) {
    return HistoryApiFp(this.configuration).getHistory(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * PendingTransactionsApi - axios parameter creator
 * @export
 */
export const PendingTransactionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show pending transactions for all accounts that the user has access to.
     * @summary Return a collection of pending transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPendingTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { checkNumber, holdState, start, limit, sortBy, filter, q, account } = query;

      const localVarPath = `/pendingTransactions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (checkNumber !== undefined) {
        localVarQueryParameter['checkNumber'] = checkNumber;
      }

      if (holdState !== undefined) {
        localVarQueryParameter['holdState'] = holdState;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PendingTransactionsApi - functional programming interface
 * @export
 */
export const PendingTransactionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show pending transactions for all accounts that the user has access to.
     * @summary Return a collection of pending transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPendingTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Transactions> {
      const localVarAxiosArgs = PendingTransactionsApiAxiosParamCreator(
        configuration,
      ).getPendingTransactions(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PendingTransactionsApi - factory interface
 * @export
 */
export const PendingTransactionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show pending transactions for all accounts that the user has access to.
     * @summary Return a collection of pending transactions
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPendingTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ) {
      return PendingTransactionsApiFp(configuration).getPendingTransactions(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PendingTransactionsApi - object-oriented interface
 * @export
 * @class PendingTransactionsApi
 * @extends {BaseAPI}
 */
export class PendingTransactionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show pending transactions for all accounts that the user has access to.
   * @summary Return a collection of pending transactions
   * @param {Object} [query] Query object
   * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
   * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Transactions}
   * @memberof PendingTransactionsApi
   */
  public getPendingTransactions(
    query?: {
      checkNumber?: string;
      holdState?: string;
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      account?: string;
    },
    options?: any,
  ) {
    return PendingTransactionsApiFp(this.configuration).getPendingTransactions(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * TransactionsApi - axios parameter creator
 * @export
 */
export const TransactionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transaction resource.
     * @summary Fetch a representation of this transaction
     * @param {string} transactionId The unique identifier of this transaction. This is an opaque string. This string is not the same as the bank&#39;s core transaction ID; it is simply the resource ID for referencing the transaction resource via the API.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transaction, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransaction(
      transactionId: string,
      query?: { unmasked?: boolean },
      options: any = {},
    ): RequestArgs {
      const { unmasked } = query;

      // verify required parameter 'transactionId' is not null or undefined
      if (transactionId === null || transactionId === undefined) {
        throw new RequiredError(
          'transactionId',
          'Required parameter transactionId was null or undefined when calling getTransaction.',
        );
      }
      const localVarPath = `/transactions/{transactionId}`.replace(
        `{${'transactionId'}}`,
        encodeURIComponent(String(transactionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending and completed transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of pending and completed transactions.
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { checkNumber, holdState, start, limit, sortBy, filter, q, account } = query;

      const localVarPath = `/transactions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (checkNumber !== undefined) {
        localVarQueryParameter['checkNumber'] = checkNumber;
      }

      if (holdState !== undefined) {
        localVarQueryParameter['holdState'] = holdState;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TransactionsApi - functional programming interface
 * @export
 */
export const TransactionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transaction resource.
     * @summary Fetch a representation of this transaction
     * @param {string} transactionId The unique identifier of this transaction. This is an opaque string. This string is not the same as the bank&#39;s core transaction ID; it is simply the resource ID for referencing the transaction resource via the API.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transaction, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransaction(
      transactionId: string,
      query?: { unmasked?: boolean },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Transaction> {
      const localVarAxiosArgs = TransactionsApiAxiosParamCreator(configuration).getTransaction(
        transactionId ? transactionId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending and completed transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of pending and completed transactions.
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Transactions> {
      const localVarAxiosArgs = TransactionsApiAxiosParamCreator(configuration).getTransactions(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TransactionsApi - factory interface
 * @export
 */
export const TransactionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transaction resource.
     * @summary Fetch a representation of this transaction
     * @param {string} transactionId The unique identifier of this transaction. This is an opaque string. This string is not the same as the bank&#39;s core transaction ID; it is simply the resource ID for referencing the transaction resource via the API.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transaction, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransaction(transactionId: string, query?: { unmasked?: boolean }, options?: any) {
      return TransactionsApiFp(configuration).getTransaction(
        transactionId ? transactionId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending and completed transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show transactions for all accounts that the user has access to.
     * @summary Return a collection of pending and completed transactions.
     * @param {Object} [query] Query object
     * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
     * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTransactions(
      query?: {
        checkNumber?: string;
        holdState?: string;
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        account?: string;
      },
      options?: any,
    ) {
      return TransactionsApiFp(configuration).getTransactions(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TransactionsApi - object-oriented interface
 * @export
 * @class TransactionsApi
 * @extends {BaseAPI}
 */
export class TransactionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transaction resource.
   * @summary Fetch a representation of this transaction
   * @param {string} transactionId The unique identifier of this transaction. This is an opaque string. This string is not the same as the bank&#39;s core transaction ID; it is simply the resource ID for referencing the transaction resource via the API.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting a transaction, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Transaction}
   * @memberof TransactionsApi
   */
  public getTransaction(transactionId: string, query?: { unmasked?: boolean }, options?: any) {
    return TransactionsApiFp(this.configuration).getTransaction(
      transactionId ? transactionId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of pending and completed transactions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  The default will show transactions for all accounts that the user has access to.
   * @summary Return a collection of pending and completed transactions.
   * @param {Object} [query] Query object
   * @param {string} [query.checkNumber] Specify one or more check numbers or check number ranges. This is a comma-separated or &#x60;|&#x60; separated list of number or ranges. Ranges have the form &#x60;number-number&#x60;. For example, the value &#x60;201,202,210-213&#x60; matches the transactions where the check number is 201, 202, 210, 211, 212, or 213; this may also be expressed as &#x60;201|202|210-213&#x60;.
   * @param {string} [query.holdState] Subset the transactions collection to those whose &#x60;holdState&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values.  For example, &#x60;?holdState&#x3D;active&#x60; will match only items whose &#x60;holdState&#x60; is &#x60;active&#x60;; &#x60;?holdState&#x3D;active|expired&#x60; will match items whose &#x60;holdState&#x60; is &#x60;active&#x60; or &#x60;expired&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {number} [query.start] The zero-based index of the first transaction in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of transaction representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.account] A list of server-supplied values which identify the account instances, i.e. ?account&#x3D;acct1|acct2|acct3.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Transactions}
   * @memberof TransactionsApi
   */
  public getTransactions(
    query?: {
      checkNumber?: string;
      holdState?: string;
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      account?: string;
    },
    options?: any,
  ) {
    return TransactionsApiFp(this.configuration).getTransactions(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
