# @apiture/transfers-client-sdk@0.12.8
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/transfers-client-sdk@0.12.8 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, ConfigurationApi, PastTransferApi, ScheduledTransferApi } from "@apiture/transfers-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate ConfigurationApi main class passing the configuration object.
    const configurationApi = new ConfigurationApi(configuration);

// Instantiate PastTransferApi main class passing the configuration object.
    const pastTransferApi = new PastTransferApi(configuration);

// Instantiate ScheduledTransferApi main class passing the configuration object.
    const scheduledTransferApi = new ScheduledTransferApi(configuration);


// Use the methods to call the apis ( Refer to the Transfers SDK Classes and Methods list ).
  scheduledTransfer.getScheduledTransfers().then( response => {
    const getscheduledtransfersData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate ScheduledTransferApi main class.
    const scheduledTransferApi = new ScheduledTransferApi();


// Update the accessToken using the class method `setAccessToken`.
    scheduledTransferApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    scheduledTransferApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    scheduledTransferApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { ScheduledTransfers } from "@apiture/transfers-client-sdk";

  const stronglyTypedObject :ScheduledTransfers = { ... };

  // ______ Scoped import

  import * as TransfersTypes from "@apiture/transfers-client-sdk";

  const stronglyTypedObject :TransfersTypes.ScheduledTransfers = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/transfers",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Transfers SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### ConfigurationApi


  `ConfigurationApi.getConfiguration` - Configuration definition for this API

  `ConfigurationApi.getConfigurationGroup` - Fetch a representation of this configuration group

  `ConfigurationApi.getConfigurationGroupSchema` - Fetch the schema for this configuration group

  `ConfigurationApi.getConfigurationGroupValue` - Fetch a single value associated with the specified configuration group

  `ConfigurationApi.getConfigurationGroupValues` - Fetch the values for the specified configuration group

  `ConfigurationApi.getConfigurationGroups` - Return a collection of configuration groups

  `ConfigurationApi.updateConfigurationGroupValue` - Update a single value associated with the specified configuration group

  `ConfigurationApi.updateConfigurationGroupValues` - Update the values for the specified configuration group



### PastTransferApi


  `PastTransferApi.getPastTransfer` - Fetch a representation of this past transfer

  `PastTransferApi.getPastTransfers` - Return a collection of past transfers



### ScheduledTransferApi


  `ScheduledTransferApi.cancelScheduledTransfer` - Cancel a scheduled transfer

  `ScheduledTransferApi.createScheduledTransfer` - Create a new scheduled transfer request

  `ScheduledTransferApi.deleteScheduledTransfer` - Delete this scheduled transfer

  `ScheduledTransferApi.getScheduledTransfer` - Fetch a representation of this transfer

  `ScheduledTransferApi.getScheduledTransfers` - Return a collection of scheduled transfers

  `ScheduledTransferApi.patchScheduledTransfer` - Update this scheduled transfer

  `ScheduledTransferApi.resumeScheduledTransfer` - Resume a suspended scheduled transfer

  `ScheduledTransferApi.suspendScheduledTransfer` - Suspend a scheduled transfer



## About the Transfers API
___
Clients can use the Transfers API to schedule transfer requests to move funds from one account to another. Transfers are one-time transfers or recurring transfers, based on the transfer's [`schedule`](#schema-schedule). To schedule a new transfer, use the [`createScheduledTransfer`](#op-createScheduledTransfer) operation. Use the [`getScheduledTransfers`](#op-getScheduledTransfers) operation to list the user's scheduled transfers. Scheduled transfers which have been processed are automatically removed from `/scheduledTransfers`. The [`getPastTransfers`](#op-getPastTransfers) operation returns the history of processed or canceled transfers.
