# @apiture/vault-client-sdk@0.10.5
Typescript/Javascript client SDK that using [axios](https://github.com/axios/axios) as core http client.
It also include a collection of Typescript Definition interfaces.

## Installation
```
npm install @apiture/vault-client-sdk@0.10.5 --save
```

## Usage

```typescript
import { SdkConfiguration, APIApi, FileApi, FolderApi, UploadApi } from "@apiture/vault-client-sdk";

  // Define a configuration object [ optional ]
  const configuration: SdkConfiguration = {
    host: "api.institution.com", // [ optional ] Api host 
    accessToken: token, // [ optional ] Oauth2 Authorization token 
  };


// Instantiate APIApi main class passing the configuration object.
    const aPIApi = new APIApi(configuration);

// Instantiate FileApi main class passing the configuration object.
    const fileApi = new FileApi(configuration);

// Instantiate FolderApi main class passing the configuration object.
    const folderApi = new FolderApi(configuration);

// Instantiate UploadApi main class passing the configuration object.
    const uploadApi = new UploadApi(configuration);


// Use the methods to call the apis ( Refer to the Vault SDK Classes and Methods list ).
  upload.getUploads().then( response => {
    const getuploadsData = response.data;
    const headers = response.headers;
  });


```

## Updating configuration values.
The SDK can be instantiated without a configuration object. If that's the case it would need to receive configuration values after.
List of values available to setup after instantiated.
- host
- accessToken
- apiKey

```typescript
// Instantiate UploadApi main class.
    const uploadApi = new UploadApi();


// Update the accessToken using the class method `setAccessToken`.
    uploadApi.setAccessToken(newAccessToken);

// Update the host using the class method `setHost`.
    uploadApi.setHost("api.staging.institution.com");

// Update the apiKey using the class method `setApiKey`.
    uploadApi.setApiKey(newApiKey);


```

## Using Typescript interfaces only
If you want to only use the interfaces you can export them individually or create an scope import directly from the package.

```typescript

  // ______ Individual Import

  import { Uploads } from "@apiture/vault-client-sdk";

  const stronglyTypedObject :Uploads = { ... };

  // ______ Scoped import

  import * as VaultTypes from "@apiture/vault-client-sdk";

  const stronglyTypedObject :VaultTypes.Uploads = { ... };

```

## SdkConfiguration object
The SDK configuration object provides a convenient way to initialize all the SDK classes reusing the same object. **Below is the full list of options allowed.**
```typescript
  const configuration: SdkConfiguration = {
    
    host: "api.institution.com", 
    // [ optional ] Api host, protocol allowed as well. ( https://api.institution.com )

    accessToken: token, 
    // [ optional ] Oauth2 Authorization token  
    
    apiKey: key, 
    // [ optional ] Apiture apiKey 
    
    baseOptions: {
      headers: {
        "a-global-header-key": "a global header value",
      },
    },
    // [ optional ] Extend Axios global config 

    basePath: "/vault",
    // [ optional ] Overrides the BasePath (Not necessary in 90% of cases)
  }
  ```

## Vault SDK Classes and Methods
---


### APIApi


  `APIApi.getApi` - Top-level resources and operations in this API

  `APIApi.getApiDoc` - Return API definition document



### FileApi


  `FileApi.createFile` - Create a new file

  `FileApi.deleteFile` - Delete this file resource

  `FileApi.getFile` - Fetch the file descriptor

  `FileApi.getFileContent` - Return the raw content of the file

  `FileApi.getFileRevision` - Fetch a representation of an immutable revision of this file

  `FileApi.getFileRevisions` - Return a collection of file revisions

  `FileApi.getFiles` - Return a collection of files

  `FileApi.getSharedContent` - Get a shared file&#39;s content

  `FileApi.patchFile` - Update this file&#39;s descriptor

  `FileApi.updateFile` - Update this file descriptor



### FolderApi


  `FolderApi.createFolder` - Create a new folder

  `FolderApi.deleteFolder` - Delete this folder resource

  `FolderApi.getFolder` - Fetch a representation of this folder

  `FolderApi.getFolders` - Return a collection of folders

  `FolderApi.patchFolder` - Update this folder

  `FolderApi.updateFolder` - Update this folder



### UploadApi


  `UploadApi.createUpload` - Create a new upload

  `UploadApi.deleteUpload` - Delete this upload resource

  `UploadApi.getUpload` - Fetch a representation of this upload

  `UploadApi.getUploads` - Return a collection of recent and in progress uploads

  `UploadApi.uploadContent` - Upload the file&#39;s raw content to the corresponding file resource.



## About the Vault API
___
The Vault API manages secure content files and document storage for other Apiture APIs and application use. Documents which may be stored in Vault include _Terms and Conditions_, privacy statements, check images, statements, images/documents required for an account application, etc. Clients may upload and download files with this API, or search for files by date or type or role. Files may be organized into hierarchical folders. Each file has a JSON representation _file descriptor_ which includes the attributes  (metadata) of the file (the name, type, size, `_links`, etc.), and a `content` resource which accesses the text or binary content of the file. The content URI is available via the *`apiture:content`* link in the file descriptor. The `_links` of a file or folder include an *`apiture:folder`* link to its containing folder. Each folder has *`apiture:files`* and *`apiture:children`* links to its directly contained files and subfolders, respectively.  To upload a file, first `POST` a request to the `/uploads` path (the `createUpload` operation) containing file descriptor(s) to be uploaded. When uploading a new file, the caller may specify a desired target folder by setting the *`apiture:folder`* link within the request's `_links`.  The _upload tracker response_ from the upload operation contains an array of items, one for each file to upload. Each item in the array contains an *`apiture:uploadUrl`* link, which is an upload URL for the corresponding file. The client should next `PUT` the file(s) content to the upload URLs to upload the files' contents. The upload is done when the upload resource `state` is `completed` or `failed`. The upload resource will contain the file descriptor resources in the `items` array within the `_embedded` object; each file will include a `self` link to the corresponding file resource.  After a file has been created, the file resource contains links to its containing folder, the public share URI, and the content URI for downloading the file's content.  For files which reside in folders with revisions enabled, updating a file's content creates a new revision of the file. The revisions are available from the file's `/files/{fileId}/revisions` collection.
