// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Vault
 * The Vault API manages secure content files and document storage for other Apiture APIs and application use. Documents which may be stored in Vault include _Terms and Conditions_, privacy statements, check images, statements, images/documents required for an account application, etc. Clients may upload and download files with this API, or search for files by date or type or role. Files may be organized into hierarchical folders. Each file has a JSON representation _file descriptor_ which includes the attributes  (metadata) of the file (the name, type, size, `_links`, etc.), and a `content` resource which accesses the text or binary content of the file. The content URI is available via the *`apiture:content`* link in the file descriptor. The `_links` of a file or folder include an *`apiture:folder`* link to its containing folder. Each folder has *`apiture:files`* and *`apiture:children`* links to its directly contained files and subfolders, respectively.  To upload a file, first `POST` a request to the `/uploads` path (the `createUpload` operation) containing file descriptor(s) to be uploaded. When uploading a new file, the caller may specify a desired target folder by setting the *`apiture:folder`* link within the request's `_links`.  The _upload tracker response_ from the upload operation contains an array of items, one for each file to upload. Each item in the array contains an *`apiture:uploadUrl`* link, which is an upload URL for the corresponding file. The client should next `PUT` the file(s) content to the upload URLs to upload the files' contents. The upload is done when the upload resource `state` is `completed` or `failed`. The upload resource will contain the file descriptor resources in the `items` array within the `_embedded` object; each file will include a `self` link to the corresponding file resource.  After a file has been created, the file resource contains links to its containing folder, the public share URI, and the content URI for downloading the file's content.  For files which reside in folders with revisions enabled, updating a file's content creates a new revision of the file. The revisions are available from the file's `/files/{fileId}/revisions` collection.
 *
 * OpenAPI spec version: 0.10.5
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/vault'.replace(/\/+$/, '');

export const API_VERSION = '0.10.5';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation used to create a new file. When creating a file, one can specify a link to the parent folder:   * *`apiture:folder`* A link to the desired target folder. The user must have permission to add files to this folder.
 * @export
 * @interface CreateFile
 */
export interface CreateFile extends AbstractResource, FileFields {}

/**
 * @export
 * @namespace CreateFile
 */
export namespace CreateFile {}

/**
 * Representation used to create a new folder. When creating a new folder, the request may contain the following links:   * *`apiture:folder`* : The `href` is the URI of the desired parent folder. The user must have permission to add a subfolder to the parent folder.
 * @export
 * @interface CreateFolder
 */
export interface CreateFolder extends AbstractResource, FolderFields, AbstractResource {}

/**
 * Representation used to create a new upload. The `_embedded.items` array must contain one or more file descriptors with the file `name`, `description`, `type`, and `contentType`. Optional links that are honored in an upload request include the following:   * *`apiture:folder`* : The target folder where to uploaded the file(s) should be placed.'
 * @export
 * @interface CreateUpload
 */
export interface CreateUpload extends AbstractResource, UploadFields {
  /**
   * A list of the file descriptions which will be uploaded.
   * @type {any}
   * @memberof CreateUpload
   */
  _embedded?: any;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Representation of a file (document) resource residing in the file vault. A file may have the following links:   * *`apiture:folder`* : The folder where the file resides.   * *`apiture:share`* : The publicly shared URI of the file's content.   * *`apiture:content`* : The direct URI of the file's content   * *`apiture:uploadUrl`* : The URL which is used to upload the   file content with `PUT`. This link only exists when this file representation   is included within an upload tracker.   * *`apiture:revisions`* : The previous revisions of this file, if any.
 * @export
 * @interface File
 */
export interface File extends SummaryFile {
  /**
   * The date-time when the file was created or uploaded.
   * @type {Date}
   * @memberof File
   */
  createdAt?: Date;
  /**
   * The file size in bytes. This is a derived property and cannot be modified in updates.
   * @type {number}
   * @memberof File
   */
  sizeBytes?: number;
}

/**
 * @export
 * @namespace File
 */
export namespace File {}

/**
 * Core fields of the file resource. This model schema is used to construct other model schema.
 * @export
 * @interface FileFields
 */
export interface FileFields {
  /**
   * The file name, for identification purposes. File names may include file extensions such as `.pdf` for PDF documents, although the system does not validate or ensure that extensions match the file content type. This is limited to 64 characters and may not contain certain special characters such as / or \\\\. If omitted, the system will assign a name.
   * @type {string}
   * @memberof FileFields
   */
  name?: string;
  /**
   * A description of this file and its contents.
   * @type {string}
   * @memberof FileFields
   */
  description?: string;
  /**
   * The document type as determined by the business use case. Unlike the contentType, this indicates what the document content represents (such as a `processedCheckImage`,  `mobileCheckDepositImageFront`, etc.).
   * @type {string}
   * @memberof FileFields
   */
  type?: string;
  /**
   * The file size in bytes. When creating an upload, the caller can pass this in to indicate the file's size. The services uses this to generate a more accurate upload progress as a percentage of the total upload size. It is not enforced (that is, the actual upload size does not have to match this value).
   * @type {number}
   * @memberof FileFields
   */
  sizeBytes?: number;
  /**
   * The [media type](https://tools.ietf.org/html/rfc6838) for this file. For text documents, the content type should include the text encoding; if omitted, the encoding type is assumed to be utf-8.
   * @type {string}
   * @memberof FileFields
   */
  contentType?: string;
  /**
   * The revision identifier for this file, if this file is in a folder that has revisions enabled. This is an ISO 8601 formatted date-time string, `yyyy-mm-ddTHH:MM:SS.sssZ`. This field is immutable.
   * @type {number}
   * @memberof FileFields
   */
  revisionId?: number;
  /**
   * If using external data hosting, externalId is used as a lookup key
   * @type {string}
   * @memberof FileFields
   */
  externalId?: string;
  /**
   * Required document category, within the enum of options. Required for compliance to categorize PII documents.
   * @type {string}
   * @memberof FileFields
   */
  category?: FileFields.CategoryEnum;
}

/**
 * @export
 * @namespace FileFields
 */
export namespace FileFields {
  /**
   * @export
   * @enum {string}
   */
  export enum CategoryEnum {
    DriversLicense = 'driversLicense',
    MilitaryIdentification = 'militaryIdentification',
    Passport = 'passport',
    SocialSecurityCard = 'socialSecurityCard',
    StateIdentification = 'stateIdentification',
    TaxForm = 'taxForm',
    UtilityBill = 'utilityBill',
    ApplicationFile = 'applicationFile',
    EntityAuthorization = 'entityAuthorization',
    ArticlesOfOrganization = 'articlesOfOrganization',
  }
}

/**
 * Collection of files. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Files
 */
export interface Files extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Files
   */
  _embedded?: any;
}

/**
 * Hierarchical folder structures for organizing related files and folders. A folder has a parent folder, a set of files, and a set of child folders. Links in a folder resource:   * *`apiture:folder`* : links to the parent folder, if the folder has a parent.   * *`apiture:files`* : links to the collection of files in the   folder; this may be empty.   * *`apiture:children`* : links to the collection of subfolder whose parent is this folder; this may be empty.
 * @export
 * @interface Folder
 */
export interface Folder extends SummaryFolder {
  /**
   * This folder's unique ID.
   * @type {string}
   * @memberof Folder
   */
  _id?: string;
  /**
   * The number of files in this folder.
   * @type {number}
   * @memberof Folder
   */
  fileCount?: number;
  /**
   * The number of subfolders of this folder
   * @type {number}
   * @memberof Folder
   */
  folderCount?: number;
  /**
   * The date-time when the folder was created or uploaded.
   * @type {Date}
   * @memberof Folder
   */
  createdAt?: Date;
}

/**
 * Core fields of the folder resource. This model schema is used to construct other model schema.
 * @export
 * @interface FolderFields
 */
export interface FolderFields {
  /**
   * The folder name, for identification purposes. This is limited to 64 characters and may not contain certain special characters such as / or \\\\. If omitted, the system will assign a name.
   * @type {string}
   * @memberof FolderFields
   */
  name?: string;
  /**
   * A description of this folder and its contents.
   * @type {string}
   * @memberof FolderFields
   */
  description?: string;
  /**
   * An optional folder type which describes the intended use or role of the folder and its contents.
   * @type {string}
   * @memberof FolderFields
   */
  type?: string;
  /**
   * If `true`, files in this folder maintain revisions. This property may not be changed after a folder has been created. Moving a file from a folder which has revisions enable to one that has them disabled will result in the loss of the revisions.
   * @type {boolean}
   * @memberof FolderFields
   */
  revisionsEnabled?: boolean;
}

/**
 * Collection of folders. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Folders
 */
export interface Folders extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Folders
   */
  _embedded?: any;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of a file resource in files collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryFile
 */
export interface SummaryFile extends AbstractResource, FileFields, RevisionEffectiveInterval {
  /**
   * The unique identifier for this file resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryFile
   */
  _id?: string;
}

/**
 * @export
 * @namespace SummaryFile
 */
export namespace SummaryFile {}

/**
 * Summary representation of a folder resource in folders collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryFolder
 */
export interface SummaryFolder extends AbstractResource, FolderFields {
  /**
   * The unique identifier for this folder resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryFolder
   */
  _id?: string;
}

/**
 * Summary representation of an upload tracker resource in the uploads collection. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryUpload
 */
export interface SummaryUpload extends AbstractResource, UploadFields {
  /**
   * The unique identifier for this upload resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryUpload
   */
  _id?: string;
}

/**
 * Representation used to update or patch a file.
 * @export
 * @interface UpdateFile
 */
export interface UpdateFile extends File {}

/**
 * @export
 * @namespace UpdateFile
 */
export namespace UpdateFile {}

/**
 * Representation used to update or patch a folder. **Note**: The folder's `revisionsEnabled` property is _immutable_.
 * @export
 * @interface UpdateFolder
 */
export interface UpdateFolder extends Folder {}

/**
 * A request to start a file upload. Optional links that are honored in an upload request include the following:    * *`apiture:folder`* : The target folder for where to upload the file(s)   This _upload tracker response_  contains an array of items, one for each file to upload. Each item contains an *`apiture:uploadUrl`* link within the item's `_links`. The client should next `PUT` the file(s) content to the upload URLs to upload each file's contents.
 * @export
 * @interface Upload
 */
export interface Upload extends SummaryUpload {
  /**
   * The name of the items collection. In this case, the items in the embedded list are '`files`'.
   * @type {string}
   * @memberof Upload
   */
  name?: Upload.NameEnum;
  /**
   * The status of the upload request.   * *`pending`* - The upload is pending but has not started  * *`started`* - The upload has started  * *`completed`* - The upload has completed successfully  * *`failed`* - The upload has failed or timed out.
   * @type {string}
   * @memberof Upload
   */
  state?: Upload.StateEnum;
  /**
   * The maximum individual file size allowed, in bytes. This is a derived field and ignored in an upload request.
   * @type {number}
   * @memberof Upload
   */
  maximumFileSizeBytes?: number;
  /**
   * The maximum upload request size allowed, in bytes; this is the total size of the `multipart/form-data` request which is larger than the sum of just the file bytes due to extra metadata and encoding in a `multipart/form-data` request body. This is a derived field and ignored in an upload request.
   * @type {number}
   * @memberof Upload
   */
  maximumRequestSizeBytes?: number;
  /**
   * The date-time when this upload request expires. If no file is uploaded by this time, this upload request will be deleted and the upload URL in each file descriptor may no longer work.  This is a derived field and ignored in an upload request.
   * @type {Date}
   * @memberof Upload
   */
  expiresAt?: Date;
  /**
   * A list of the file descriptions which will be uploaded.
   * @type {any}
   * @memberof Upload
   */
  _embedded?: any;
}

/**
 * @export
 * @namespace Upload
 */
export namespace Upload {
  /**
   * @export
   * @enum {string}
   */
  export enum NameEnum {
    Files = 'files',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Pending = 'pending',
    Started = 'started',
    Completed = 'completed',
    Failed = 'failed',
  }
}

/**
 * Core fields of the _upload_ resource. This model schema is used to construct other model schema.
 * @export
 * @interface UploadFields
 */
export interface UploadFields {
  /**
   * The number of files to upload.
   * @type {number}
   * @memberof UploadFields
   */
  count?: number;
  /**
   * The name of the items collection in the `items` array in this upload's `_embedded` objects. This should be '`files`'.
   * @type {string}
   * @memberof UploadFields
   */
  name?: string;
}

/**
 * Collection of uploads. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Uploads
 */
export interface Uploads extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Uploads
   */
  _embedded?: any;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:   * *`apiture:files`* : A link to the collection of all files.   * *`apiture:folders`* : A link to the collection of all folders.   * *`apiture:uploads`* : A link to the collection of all upload tasks.   * *`apiture:myFolder`* : A link to the currently authenticated user's primary folder.   * *`apiture:myUploads`* : A link to the currently authenticated user's primary upload folder, a child folder of the user's primary folder.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:   * *`apiture:files`* : A link to the collection of all files.   * *`apiture:folders`* : A link to the collection of all folders.   * *`apiture:uploads`* : A link to the collection of all upload tasks.   * *`apiture:myFolder`* : A link to the currently authenticated user's primary folder.   * *`apiture:myUploads`* : A link to the currently authenticated user's primary upload folder, a child folder of the user's primary folder.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:   * *`apiture:files`* : A link to the collection of all files.   * *`apiture:folders`* : A link to the collection of all folders.   * *`apiture:uploads`* : A link to the collection of all upload tasks.   * *`apiture:myFolder`* : A link to the currently authenticated user's primary folder.   * *`apiture:myUploads`* : A link to the currently authenticated user's primary upload folder, a child folder of the user's primary folder.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. Links in the root response may include:   * *`apiture:files`* : A link to the collection of all files.   * *`apiture:folders`* : A link to the collection of all folders.   * *`apiture:uploads`* : A link to the collection of all upload tasks.   * *`apiture:myFolder`* : A link to the currently authenticated user's primary folder.   * *`apiture:myUploads`* : A link to the currently authenticated user's primary upload folder, a child folder of the user's primary folder.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * FileApi - axios parameter creator
 * @export
 */
export const FileApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new file in the files collection. This operation is called upon successful completion of an upload operation and associates the file descriptor (name, description, parent folder, etc.) with the file contents. <p> If there is already a file of the same name in the target folder, the file is renamed by adding a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`. <p> The file will be placed in the folder specified in the *`apiture:folder`* link, which should be derived from the *`apiture:folder`* specified in upload request. If no folder was specified, the file is placed in the user's uploads folder.
     * @summary Create a new file
     * @param {CreateFile} CreateFile The data necessary to create a new file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFile(CreateFile: CreateFile, options: any = {}): RequestArgs {
      // verify required parameter 'CreateFile' is not null or undefined
      if (CreateFile === null || CreateFile === undefined) {
        throw new RequiredError(
          'CreateFile',
          'Required parameter CreateFile was null or undefined when calling createFile.',
        );
      }
      const localVarPath = `/files`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateFile' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateFile || {})
        : CreateFile || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this file resource and any resources that are owned by it.
     * @summary Delete this file resource
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFile(fileId: string, headers?: { If_Match?: string }, options: any = {}): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling deleteFile.',
        );
      }
      const localVarPath = `/files/{fileId}`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this file resource. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch the file descriptor
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFile(fileId: string, headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling getFile.',
        );
      }
      const localVarPath = `/files/{fileId}`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the raw content of the file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available.
     * @summary Return the raw content of the file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileContent(fileId: string, options: any = {}): RequestArgs {
      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling getFileContent.',
        );
      }
      const localVarPath = `/files/{fileId}/content`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this file resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use ISO 8601 format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevision(
      fileId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling getFileRevision.',
        );
      }
      // verify required parameter 'revisionId' is not null or undefined
      if (revisionId === null || revisionId === undefined) {
        throw new RequiredError(
          'revisionId',
          'Required parameter revisionId was null or undefined when calling getFileRevision.',
        );
      }
      const localVarPath = `/files/{fileId}/revisions/{revisionId}`
        .replace(`{${'fileId'}}`, encodeURIComponent(String(fileId)))
        .replace(`{${'revisionId'}}`, encodeURIComponent(String(revisionId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of file revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of file revisions
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevisions(
      fileId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling getFileRevisions.',
        );
      }
      const localVarPath = `/files/{fileId}/revisions`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of files. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of files
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first file in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of file representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the files collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the files collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFiles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, name, type, filter, q, folder } = query;

      const localVarPath = `/files`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (folder !== undefined) {
        localVarQueryParameter['folder'] = folder;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * `/content/{contentId}` represents the _shared_ URL  Return the raw content of the file as a stream of bytes. This operation  normally returns a 302 to redirect the caller to the actual URL where  the file content is available.    In the future, a `delete` method will unshare a file.
     * @summary Get a shared file's content
     * @param {string} contentId The unique ID that refers to a file&#39;s raw content and represents the publicly _shared_ file.  This  ID is not related to the &#x60;{fileId}&#x60; and can be revoked when the user decides to unshare a file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getSharedContent(contentId: string, options: any = {}): RequestArgs {
      // verify required parameter 'contentId' is not null or undefined
      if (contentId === null || contentId === undefined) {
        throw new RequiredError(
          'contentId',
          'Required parameter contentId was null or undefined when calling getSharedContent.',
        );
      }
      const localVarPath = `/content/{contentId}`.replace(
        `{${'contentId'}}`,
        encodeURIComponent(String(contentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this file's descriptor. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this file's descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling patchFile.',
        );
      }
      // verify required parameter 'UpdateFile' is not null or undefined
      if (UpdateFile === null || UpdateFile === undefined) {
        throw new RequiredError(
          'UpdateFile',
          'Required parameter UpdateFile was null or undefined when calling patchFile.',
        );
      }
      const localVarPath = `/files/{fileId}`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateFile' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateFile || {})
        : UpdateFile || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this file's descriptor.
     * @summary Update this file descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'fileId' is not null or undefined
      if (fileId === null || fileId === undefined) {
        throw new RequiredError(
          'fileId',
          'Required parameter fileId was null or undefined when calling updateFile.',
        );
      }
      // verify required parameter 'UpdateFile' is not null or undefined
      if (UpdateFile === null || UpdateFile === undefined) {
        throw new RequiredError(
          'UpdateFile',
          'Required parameter UpdateFile was null or undefined when calling updateFile.',
        );
      }
      const localVarPath = `/files/{fileId}`.replace(
        `{${'fileId'}}`,
        encodeURIComponent(String(fileId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateFile' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateFile || {})
        : UpdateFile || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * FileApi - functional programming interface
 * @export
 */
export const FileApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new file in the files collection. This operation is called upon successful completion of an upload operation and associates the file descriptor (name, description, parent folder, etc.) with the file contents. <p> If there is already a file of the same name in the target folder, the file is renamed by adding a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`. <p> The file will be placed in the folder specified in the *`apiture:folder`* link, which should be derived from the *`apiture:folder`* specified in upload request. If no folder was specified, the file is placed in the user's uploads folder.
     * @summary Create a new file
     * @param {CreateFile} CreateFile The data necessary to create a new file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFile(
      CreateFile: CreateFile,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).createFile(
        CreateFile ? CreateFile : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this file resource and any resources that are owned by it.
     * @summary Delete this file resource
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFile(
      fileId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).deleteFile(
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this file resource. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch the file descriptor
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFile(
      fileId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getFile(
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the raw content of the file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available.
     * @summary Return the raw content of the file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileContent(
      fileId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getFileContent(
        fileId ? fileId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this file resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use ISO 8601 format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevision(
      fileId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getFileRevision(
        fileId ? fileId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of file revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of file revisions
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevisions(
      fileId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Files> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getFileRevisions(
        fileId ? fileId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of files. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of files
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first file in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of file representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the files collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the files collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFiles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Files> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getFiles(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * `/content/{contentId}` represents the _shared_ URL  Return the raw content of the file as a stream of bytes. This operation  normally returns a 302 to redirect the caller to the actual URL where  the file content is available.    In the future, a `delete` method will unshare a file.
     * @summary Get a shared file's content
     * @param {string} contentId The unique ID that refers to a file&#39;s raw content and represents the publicly _shared_ file.  This  ID is not related to the &#x60;{fileId}&#x60; and can be revoked when the user decides to unshare a file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getSharedContent(
      contentId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).getSharedContent(
        contentId ? contentId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this file's descriptor. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this file's descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).patchFile(
        UpdateFile ? UpdateFile : null,
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this file's descriptor.
     * @summary Update this file descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = FileApiAxiosParamCreator(configuration).updateFile(
        UpdateFile ? UpdateFile : null,
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * FileApi - factory interface
 * @export
 */
export const FileApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new file in the files collection. This operation is called upon successful completion of an upload operation and associates the file descriptor (name, description, parent folder, etc.) with the file contents. <p> If there is already a file of the same name in the target folder, the file is renamed by adding a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`. <p> The file will be placed in the folder specified in the *`apiture:folder`* link, which should be derived from the *`apiture:folder`* specified in upload request. If no folder was specified, the file is placed in the user's uploads folder.
     * @summary Create a new file
     * @param {CreateFile} CreateFile The data necessary to create a new file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFile(CreateFile: CreateFile, options?: any) {
      return FileApiFp(configuration).createFile(
        CreateFile ? CreateFile : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this file resource and any resources that are owned by it.
     * @summary Delete this file resource
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFile(fileId: string, headers?: { If_Match?: string }, options?: any) {
      return FileApiFp(configuration).deleteFile(
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this file resource. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch the file descriptor
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFile(fileId: string, headers?: { If_None_Match?: string }, options?: any) {
      return FileApiFp(configuration).getFile(
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the raw content of the file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available.
     * @summary Return the raw content of the file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileContent(fileId: string, options?: any) {
      return FileApiFp(configuration).getFileContent(
        fileId ? fileId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this file resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this file
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use ISO 8601 format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevision(
      fileId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return FileApiFp(configuration).getFileRevision(
        fileId ? fileId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of file revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of file revisions
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFileRevisions(
      fileId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return FileApiFp(configuration).getFileRevisions(
        fileId ? fileId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of files. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of files
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first file in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of file representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the files collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the files collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFiles(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options?: any,
    ) {
      return FileApiFp(configuration).getFiles(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * `/content/{contentId}` represents the _shared_ URL  Return the raw content of the file as a stream of bytes. This operation  normally returns a 302 to redirect the caller to the actual URL where  the file content is available.    In the future, a `delete` method will unshare a file.
     * @summary Get a shared file's content
     * @param {string} contentId The unique ID that refers to a file&#39;s raw content and represents the publicly _shared_ file.  This  ID is not related to the &#x60;{fileId}&#x60; and can be revoked when the user decides to unshare a file.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getSharedContent(contentId: string, options?: any) {
      return FileApiFp(configuration).getSharedContent(
        contentId ? contentId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this file's descriptor. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this file's descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return FileApiFp(configuration).patchFile(
        UpdateFile ? UpdateFile : null,
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this file's descriptor.
     * @summary Update this file descriptor
     * @param {UpdateFile} UpdateFile
     * @param {string} fileId The unique identifier of this file. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFile(
      UpdateFile: UpdateFile,
      fileId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return FileApiFp(configuration).updateFile(
        UpdateFile ? UpdateFile : null,
        fileId ? fileId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * FileApi - object-oriented interface
 * @export
 * @class FileApi
 * @extends {BaseAPI}
 */
export class FileApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new file in the files collection. This operation is called upon successful completion of an upload operation and associates the file descriptor (name, description, parent folder, etc.) with the file contents. <p> If there is already a file of the same name in the target folder, the file is renamed by adding a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`. <p> The file will be placed in the folder specified in the *`apiture:folder`* link, which should be derived from the *`apiture:folder`* specified in upload request. If no folder was specified, the file is placed in the user's uploads folder.
   * @summary Create a new file
   * @param {CreateFile} CreateFile The data necessary to create a new file.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public createFile(CreateFile: CreateFile, options?: any) {
    return FileApiFp(this.configuration).createFile(
      CreateFile ? CreateFile : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this file resource and any resources that are owned by it.
   * @summary Delete this file resource
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof FileApi
   */
  public deleteFile(fileId: string, headers?: { If_Match?: string }, options?: any) {
    return FileApiFp(this.configuration).deleteFile(
      fileId ? fileId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this file resource. The `Content-Location` response header, if present, identifies the equivalent revision.
   * @summary Fetch the file descriptor
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public getFile(fileId: string, headers?: { If_None_Match?: string }, options?: any) {
    return FileApiFp(this.configuration).getFile(
      fileId ? fileId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the raw content of the file as a stream of bytes. This operation normally returns a 302 to redirect the caller to the actual URL where the file content is available.
   * @summary Return the raw content of the file
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public getFileContent(fileId: string, options?: any) {
    return FileApiFp(this.configuration).getFileContent(
      fileId ? fileId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this file resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
   * @summary Fetch a representation of an immutable revision of this file
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use ISO 8601 format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public getFileRevision(
    fileId: string,
    revisionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return FileApiFp(this.configuration).getFileRevision(
      fileId ? fileId : null,
      revisionId ? revisionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of file revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of file revisions
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of product representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Files}
   * @memberof FileApi
   */
  public getFileRevisions(
    fileId: string,
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return FileApiFp(this.configuration).getFileRevisions(
      fileId ? fileId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of files. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of files
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first file in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of file representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.name] Subset the files collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the files collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is Personal Savings; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is Personal Savings or Investment Account. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Files}
   * @memberof FileApi
   */
  public getFiles(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      name?: string;
      type?: string;
      filter?: string;
      q?: string;
      folder?: string;
    },
    options?: any,
  ) {
    return FileApiFp(this.configuration).getFiles(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * `/content/{contentId}` represents the _shared_ URL  Return the raw content of the file as a stream of bytes. This operation  normally returns a 302 to redirect the caller to the actual URL where  the file content is available.    In the future, a `delete` method will unshare a file.
   * @summary Get a shared file's content
   * @param {string} contentId The unique ID that refers to a file&#39;s raw content and represents the publicly _shared_ file.  This  ID is not related to the &#x60;{fileId}&#x60; and can be revoked when the user decides to unshare a file.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public getSharedContent(contentId: string, options?: any) {
    return FileApiFp(this.configuration).getSharedContent(
      contentId ? contentId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this file's descriptor. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this file's descriptor
   * @param {UpdateFile} UpdateFile
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public patchFile(
    UpdateFile: UpdateFile,
    fileId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return FileApiFp(this.configuration).patchFile(
      UpdateFile ? UpdateFile : null,
      fileId ? fileId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this file's descriptor.
   * @summary Update this file descriptor
   * @param {UpdateFile} UpdateFile
   * @param {string} fileId The unique identifier of this file. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {File}
   * @memberof FileApi
   */
  public updateFile(
    UpdateFile: UpdateFile,
    fileId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return FileApiFp(this.configuration).updateFile(
      UpdateFile ? UpdateFile : null,
      fileId ? fileId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * FolderApi - axios parameter creator
 * @export
 */
export const FolderApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new folder in the folders collection. To locate the folder within an existing folder (as a subfolder), specify the desired target folder  with the *`apiture:folder`* link within the request body's `_links`.
     * @summary Create a new folder
     * @param {CreateFolder} CreateFolder The data necessary to create a new folder.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFolder(CreateFolder: CreateFolder, options: any = {}): RequestArgs {
      // verify required parameter 'CreateFolder' is not null or undefined
      if (CreateFolder === null || CreateFolder === undefined) {
        throw new RequiredError(
          'CreateFolder',
          'Required parameter CreateFolder was null or undefined when calling createFolder.',
        );
      }
      const localVarPath = `/folders`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateFolder' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateFolder || {})
        : CreateFolder || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this folder. <p> Normally, one can only delete a folder if it is empty (contains no files or subfolders). With the `?recursive=true` option, this operation will delete a non-empty folder and its contents, including nested folders. The user must have authorization to delete all the contents. <p> The user may not delete their top-level folder.
     * @summary Delete this folder resource
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.recursive] If true, also delete all files and nested folders that are stored in this folder.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFolder(
      folderId: string,
      query?: { recursive?: boolean },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { recursive } = query;
      const { If_Match } = headers;

      // verify required parameter 'folderId' is not null or undefined
      if (folderId === null || folderId === undefined) {
        throw new RequiredError(
          'folderId',
          'Required parameter folderId was null or undefined when calling deleteFolder.',
        );
      }
      const localVarPath = `/folders/{folderId}`.replace(
        `{${'folderId'}}`,
        encodeURIComponent(String(folderId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (recursive !== undefined) {
        localVarQueryParameter['recursive'] = recursive;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this folder resource.
     * @summary Fetch a representation of this folder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolder(
      folderId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'folderId' is not null or undefined
      if (folderId === null || folderId === undefined) {
        throw new RequiredError(
          'folderId',
          'Required parameter folderId was null or undefined when calling getFolder.',
        );
      }
      const localVarPath = `/folders/{folderId}`.replace(
        `{${'folderId'}}`,
        encodeURIComponent(String(folderId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of folders. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of folders
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first folder in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of folder representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the folders collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolders(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, name, filter, q, folder } = query;

      const localVarPath = `/folders`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (folder !== undefined) {
        localVarQueryParameter['folder'] = folder;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this folder. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'folderId' is not null or undefined
      if (folderId === null || folderId === undefined) {
        throw new RequiredError(
          'folderId',
          'Required parameter folderId was null or undefined when calling patchFolder.',
        );
      }
      // verify required parameter 'UpdateFolder' is not null or undefined
      if (UpdateFolder === null || UpdateFolder === undefined) {
        throw new RequiredError(
          'UpdateFolder',
          'Required parameter UpdateFolder was null or undefined when calling patchFolder.',
        );
      }
      const localVarPath = `/folders/{folderId}`.replace(
        `{${'folderId'}}`,
        encodeURIComponent(String(folderId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateFolder' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateFolder || {})
        : UpdateFolder || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this folder.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'folderId' is not null or undefined
      if (folderId === null || folderId === undefined) {
        throw new RequiredError(
          'folderId',
          'Required parameter folderId was null or undefined when calling updateFolder.',
        );
      }
      // verify required parameter 'UpdateFolder' is not null or undefined
      if (UpdateFolder === null || UpdateFolder === undefined) {
        throw new RequiredError(
          'UpdateFolder',
          'Required parameter UpdateFolder was null or undefined when calling updateFolder.',
        );
      }
      const localVarPath = `/folders/{folderId}`.replace(
        `{${'folderId'}}`,
        encodeURIComponent(String(folderId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateFolder' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateFolder || {})
        : UpdateFolder || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * FolderApi - functional programming interface
 * @export
 */
export const FolderApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new folder in the folders collection. To locate the folder within an existing folder (as a subfolder), specify the desired target folder  with the *`apiture:folder`* link within the request body's `_links`.
     * @summary Create a new folder
     * @param {CreateFolder} CreateFolder The data necessary to create a new folder.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFolder(
      CreateFolder: CreateFolder,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Folder> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).createFolder(
        CreateFolder ? CreateFolder : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this folder. <p> Normally, one can only delete a folder if it is empty (contains no files or subfolders). With the `?recursive=true` option, this operation will delete a non-empty folder and its contents, including nested folders. The user must have authorization to delete all the contents. <p> The user may not delete their top-level folder.
     * @summary Delete this folder resource
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.recursive] If true, also delete all files and nested folders that are stored in this folder.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFolder(
      folderId: string,
      query?: { recursive?: boolean },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).deleteFolder(
        folderId ? folderId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this folder resource.
     * @summary Fetch a representation of this folder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolder(
      folderId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Folder> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).getFolder(
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of folders. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of folders
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first folder in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of folder representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the folders collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolders(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Folders> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).getFolders(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this folder. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Folder> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).patchFolder(
        UpdateFolder ? UpdateFolder : null,
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this folder.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Folder> {
      const localVarAxiosArgs = FolderApiAxiosParamCreator(configuration).updateFolder(
        UpdateFolder ? UpdateFolder : null,
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * FolderApi - factory interface
 * @export
 */
export const FolderApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new folder in the folders collection. To locate the folder within an existing folder (as a subfolder), specify the desired target folder  with the *`apiture:folder`* link within the request body's `_links`.
     * @summary Create a new folder
     * @param {CreateFolder} CreateFolder The data necessary to create a new folder.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createFolder(CreateFolder: CreateFolder, options?: any) {
      return FolderApiFp(configuration).createFolder(
        CreateFolder ? CreateFolder : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this folder. <p> Normally, one can only delete a folder if it is empty (contains no files or subfolders). With the `?recursive=true` option, this operation will delete a non-empty folder and its contents, including nested folders. The user must have authorization to delete all the contents. <p> The user may not delete their top-level folder.
     * @summary Delete this folder resource
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.recursive] If true, also delete all files and nested folders that are stored in this folder.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteFolder(
      folderId: string,
      query?: { recursive?: boolean },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return FolderApiFp(configuration).deleteFolder(
        folderId ? folderId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this folder resource.
     * @summary Fetch a representation of this folder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolder(folderId: string, headers?: { If_None_Match?: string }, options?: any) {
      return FolderApiFp(configuration).getFolder(
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of folders. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of folders
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first folder in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of folder representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the folders collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getFolders(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
        folder?: string;
      },
      options?: any,
    ) {
      return FolderApiFp(configuration).getFolders(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this folder. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return FolderApiFp(configuration).patchFolder(
        UpdateFolder ? UpdateFolder : null,
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this folder.
     * @summary Update this folder
     * @param {UpdateFolder} UpdateFolder
     * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateFolder(
      UpdateFolder: UpdateFolder,
      folderId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return FolderApiFp(configuration).updateFolder(
        UpdateFolder ? UpdateFolder : null,
        folderId ? folderId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * FolderApi - object-oriented interface
 * @export
 * @class FolderApi
 * @extends {BaseAPI}
 */
export class FolderApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new folder in the folders collection. To locate the folder within an existing folder (as a subfolder), specify the desired target folder  with the *`apiture:folder`* link within the request body's `_links`.
   * @summary Create a new folder
   * @param {CreateFolder} CreateFolder The data necessary to create a new folder.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Folder}
   * @memberof FolderApi
   */
  public createFolder(CreateFolder: CreateFolder, options?: any) {
    return FolderApiFp(this.configuration).createFolder(
      CreateFolder ? CreateFolder : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this folder. <p> Normally, one can only delete a folder if it is empty (contains no files or subfolders). With the `?recursive=true` option, this operation will delete a non-empty folder and its contents, including nested folders. The user must have authorization to delete all the contents. <p> The user may not delete their top-level folder.
   * @summary Delete this folder resource
   * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.recursive] If true, also delete all files and nested folders that are stored in this folder.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof FolderApi
   */
  public deleteFolder(
    folderId: string,
    query?: { recursive?: boolean },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return FolderApiFp(this.configuration).deleteFolder(
      folderId ? folderId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this folder resource.
   * @summary Fetch a representation of this folder
   * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Folder}
   * @memberof FolderApi
   */
  public getFolder(folderId: string, headers?: { If_None_Match?: string }, options?: any) {
    return FolderApiFp(this.configuration).getFolder(
      folderId ? folderId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of folders. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of folders
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first folder in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of folder representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.name] Subset the folders collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.folder] Subset the response to resources that reside directly within the specified folder. The value may be a folder ID or a folder URI.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Folders}
   * @memberof FolderApi
   */
  public getFolders(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      name?: string;
      filter?: string;
      q?: string;
      folder?: string;
    },
    options?: any,
  ) {
    return FolderApiFp(this.configuration).getFolders(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a partial update of this folder. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this folder
   * @param {UpdateFolder} UpdateFolder
   * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Folder}
   * @memberof FolderApi
   */
  public patchFolder(
    UpdateFolder: UpdateFolder,
    folderId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return FolderApiFp(this.configuration).patchFolder(
      UpdateFolder ? UpdateFolder : null,
      folderId ? folderId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this folder.
   * @summary Update this folder
   * @param {UpdateFolder} UpdateFolder
   * @param {string} folderId The unique identifier of this folder. This is an immutable opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Folder}
   * @memberof FolderApi
   */
  public updateFolder(
    UpdateFolder: UpdateFolder,
    folderId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return FolderApiFp(this.configuration).updateFolder(
      UpdateFolder ? UpdateFolder : null,
      folderId ? folderId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * UploadApi - axios parameter creator
 * @export
 */
export const UploadApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new file upload tracker.  The caller provides a list of one or more files to be uploaded in `_embedded.items`. <p> This operation returns a modified _upload tracker_ resource representation which contains embedded file descriptors. Each file descriptor contain the file name, type, etc. and a link named `apiture:uploadUrl` which points to an upload URL. The client must `PUT` the file content to those respective URLs to complete the uploads. </p> <p> The `state` of the upload tracker shows the upload status. When the  `state` is `completes`, the files associated with the upload will  be in this resource's `_embedded` object with the name `files`; that value an array of file descriptor objects. </p> <p> The target folder in which the file will be stored may be specified in `_links` using the *`apiture:folder`* link relation name.   </p> <p>   If there is already a file of the same name in the target folder, the file is renamed by adding or incrementing a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`; uploading another file will be renamed `tax-summary-2018 (2).pdf`, and so on. </p> **TODO** In the future, this API will also support uploading new revisions of the document and maintaining document revision history.
     * @summary Create a new upload
     * @param {CreateUpload} CreateUpload The data necessary to create a new upload.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUpload(CreateUpload: CreateUpload, options: any = {}): RequestArgs {
      // verify required parameter 'CreateUpload' is not null or undefined
      if (CreateUpload === null || CreateUpload === undefined) {
        throw new RequiredError(
          'CreateUpload',
          'Required parameter CreateUpload was null or undefined when calling createUpload.',
        );
      }
      const localVarPath = `/uploads`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateUpload' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateUpload || {})
        : CreateUpload || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this upload resource and any resources that are owned by it. Note that deleting an upload does _not_ delete any files that have been uploaded.
     * @summary Delete this upload resource
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteUpload(
      uploadId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'uploadId' is not null or undefined
      if (uploadId === null || uploadId === undefined) {
        throw new RequiredError(
          'uploadId',
          'Required parameter uploadId was null or undefined when calling deleteUpload.',
        );
      }
      const localVarPath = `/uploads/{uploadId}`.replace(
        `{${'uploadId'}}`,
        encodeURIComponent(String(uploadId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this upload resource.
     * @summary Fetch a representation of this upload
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUpload(
      uploadId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'uploadId' is not null or undefined
      if (uploadId === null || uploadId === undefined) {
        throw new RequiredError(
          'uploadId',
          'Required parameter uploadId was null or undefined when calling getUpload.',
        );
      }
      const localVarPath = `/uploads/{uploadId}`.replace(
        `{${'uploadId'}}`,
        encodeURIComponent(String(uploadId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of uploads. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Upload resources expire after a while and these resources are automatically deleted.
     * @summary Return a collection of recent and in progress uploads
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first upload in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of upload representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the uploads collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUploads(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, name, filter, q } = query;

      const localVarPath = `/uploads`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Upload the raw content of the file as a stream of bytes.  Examples include the binary bytes for an image or PDF document, or the `multipart/form-data` representation of the file. The `Content-Type` header (or the `Content-Type` in the multipart form data) must match the `contentType` of the file resource. The response is the `/files/{fileId}` file resource, not the file content. *Note*: This is a _hidden_ operation which is a proxy for the `apiture:uploadUrl` link returned when creating a new upload in the `createUpload` operation. Clients should *not* assume this URL exists but should instead use the `apiture:uploadUrl` link that is returned when creating a new upload resource.  If the file is in a folder for which revisions are enable, this will create a new revision of the file; see the `getFileRevisions` and `getFileRevision` operations.
     * @summary Upload the file's raw content to the corresponding file resource.
     * @param {any} body The file contents as a stream of bytes.
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Content_Type] The media type describing the file&#39;s content type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    uploadContent(
      body: any,
      uploadId: string,
      headers?: { Content_Type?: string },
      options: any = {},
    ): RequestArgs {
      const { Content_Type } = headers;

      // verify required parameter 'uploadId' is not null or undefined
      if (uploadId === null || uploadId === undefined) {
        throw new RequiredError(
          'uploadId',
          'Required parameter uploadId was null or undefined when calling uploadContent.',
        );
      }
      // verify required parameter 'Content_Type' is not null or undefined
      if (Content_Type === null || Content_Type === undefined) {
        throw new RequiredError(
          'Content_Type',
          'Required parameter Content_Type was null or undefined when calling uploadContent.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling uploadContent.',
        );
      }
      const localVarPath = `/uploads/{uploadId}/content`.replace(
        `{${'uploadId'}}`,
        encodeURIComponent(String(uploadId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Content_Type !== undefined && Content_Type !== null) {
        localVarHeaderParameter['Content-Type'] = String(Content_Type);
      }

      localVarHeaderParameter['Content-Type'] = 'multipart/form-data';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'any' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * UploadApi - functional programming interface
 * @export
 */
export const UploadApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new file upload tracker.  The caller provides a list of one or more files to be uploaded in `_embedded.items`. <p> This operation returns a modified _upload tracker_ resource representation which contains embedded file descriptors. Each file descriptor contain the file name, type, etc. and a link named `apiture:uploadUrl` which points to an upload URL. The client must `PUT` the file content to those respective URLs to complete the uploads. </p> <p> The `state` of the upload tracker shows the upload status. When the  `state` is `completes`, the files associated with the upload will  be in this resource's `_embedded` object with the name `files`; that value an array of file descriptor objects. </p> <p> The target folder in which the file will be stored may be specified in `_links` using the *`apiture:folder`* link relation name.   </p> <p>   If there is already a file of the same name in the target folder, the file is renamed by adding or incrementing a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`; uploading another file will be renamed `tax-summary-2018 (2).pdf`, and so on. </p> **TODO** In the future, this API will also support uploading new revisions of the document and maintaining document revision history.
     * @summary Create a new upload
     * @param {CreateUpload} CreateUpload The data necessary to create a new upload.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUpload(
      CreateUpload: CreateUpload,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Upload> {
      const localVarAxiosArgs = UploadApiAxiosParamCreator(configuration).createUpload(
        CreateUpload ? CreateUpload : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this upload resource and any resources that are owned by it. Note that deleting an upload does _not_ delete any files that have been uploaded.
     * @summary Delete this upload resource
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteUpload(
      uploadId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = UploadApiAxiosParamCreator(configuration).deleteUpload(
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this upload resource.
     * @summary Fetch a representation of this upload
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUpload(
      uploadId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Upload> {
      const localVarAxiosArgs = UploadApiAxiosParamCreator(configuration).getUpload(
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of uploads. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Upload resources expire after a while and these resources are automatically deleted.
     * @summary Return a collection of recent and in progress uploads
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first upload in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of upload representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the uploads collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUploads(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Uploads> {
      const localVarAxiosArgs = UploadApiAxiosParamCreator(configuration).getUploads(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Upload the raw content of the file as a stream of bytes.  Examples include the binary bytes for an image or PDF document, or the `multipart/form-data` representation of the file. The `Content-Type` header (or the `Content-Type` in the multipart form data) must match the `contentType` of the file resource. The response is the `/files/{fileId}` file resource, not the file content. *Note*: This is a _hidden_ operation which is a proxy for the `apiture:uploadUrl` link returned when creating a new upload in the `createUpload` operation. Clients should *not* assume this URL exists but should instead use the `apiture:uploadUrl` link that is returned when creating a new upload resource.  If the file is in a folder for which revisions are enable, this will create a new revision of the file; see the `getFileRevisions` and `getFileRevision` operations.
     * @summary Upload the file's raw content to the corresponding file resource.
     * @param {any} body The file contents as a stream of bytes.
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Content_Type] The media type describing the file&#39;s content type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    uploadContent(
      body: any,
      uploadId: string,
      headers?: { Content_Type?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Files> {
      const localVarAxiosArgs = UploadApiAxiosParamCreator(configuration).uploadContent(
        body ? body : null,
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * UploadApi - factory interface
 * @export
 */
export const UploadApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new file upload tracker.  The caller provides a list of one or more files to be uploaded in `_embedded.items`. <p> This operation returns a modified _upload tracker_ resource representation which contains embedded file descriptors. Each file descriptor contain the file name, type, etc. and a link named `apiture:uploadUrl` which points to an upload URL. The client must `PUT` the file content to those respective URLs to complete the uploads. </p> <p> The `state` of the upload tracker shows the upload status. When the  `state` is `completes`, the files associated with the upload will  be in this resource's `_embedded` object with the name `files`; that value an array of file descriptor objects. </p> <p> The target folder in which the file will be stored may be specified in `_links` using the *`apiture:folder`* link relation name.   </p> <p>   If there is already a file of the same name in the target folder, the file is renamed by adding or incrementing a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`; uploading another file will be renamed `tax-summary-2018 (2).pdf`, and so on. </p> **TODO** In the future, this API will also support uploading new revisions of the document and maintaining document revision history.
     * @summary Create a new upload
     * @param {CreateUpload} CreateUpload The data necessary to create a new upload.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUpload(CreateUpload: CreateUpload, options?: any) {
      return UploadApiFp(configuration).createUpload(
        CreateUpload ? CreateUpload : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this upload resource and any resources that are owned by it. Note that deleting an upload does _not_ delete any files that have been uploaded.
     * @summary Delete this upload resource
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteUpload(uploadId: string, headers?: { If_Match?: string }, options?: any) {
      return UploadApiFp(configuration).deleteUpload(
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this upload resource.
     * @summary Fetch a representation of this upload
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUpload(uploadId: string, headers?: { If_None_Match?: string }, options?: any) {
      return UploadApiFp(configuration).getUpload(
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of uploads. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Upload resources expire after a while and these resources are automatically deleted.
     * @summary Return a collection of recent and in progress uploads
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first upload in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of upload representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the uploads collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUploads(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ) {
      return UploadApiFp(configuration).getUploads(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Upload the raw content of the file as a stream of bytes.  Examples include the binary bytes for an image or PDF document, or the `multipart/form-data` representation of the file. The `Content-Type` header (or the `Content-Type` in the multipart form data) must match the `contentType` of the file resource. The response is the `/files/{fileId}` file resource, not the file content. *Note*: This is a _hidden_ operation which is a proxy for the `apiture:uploadUrl` link returned when creating a new upload in the `createUpload` operation. Clients should *not* assume this URL exists but should instead use the `apiture:uploadUrl` link that is returned when creating a new upload resource.  If the file is in a folder for which revisions are enable, this will create a new revision of the file; see the `getFileRevisions` and `getFileRevision` operations.
     * @summary Upload the file's raw content to the corresponding file resource.
     * @param {any} body The file contents as a stream of bytes.
     * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Content_Type] The media type describing the file&#39;s content type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    uploadContent(body: any, uploadId: string, headers?: { Content_Type?: string }, options?: any) {
      return UploadApiFp(configuration).uploadContent(
        body ? body : null,
        uploadId ? uploadId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * UploadApi - object-oriented interface
 * @export
 * @class UploadApi
 * @extends {BaseAPI}
 */
export class UploadApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new file upload tracker.  The caller provides a list of one or more files to be uploaded in `_embedded.items`. <p> This operation returns a modified _upload tracker_ resource representation which contains embedded file descriptors. Each file descriptor contain the file name, type, etc. and a link named `apiture:uploadUrl` which points to an upload URL. The client must `PUT` the file content to those respective URLs to complete the uploads. </p> <p> The `state` of the upload tracker shows the upload status. When the  `state` is `completes`, the files associated with the upload will  be in this resource's `_embedded` object with the name `files`; that value an array of file descriptor objects. </p> <p> The target folder in which the file will be stored may be specified in `_links` using the *`apiture:folder`* link relation name.   </p> <p>   If there is already a file of the same name in the target folder, the file is renamed by adding or incrementing a unique numeric suffix in parentheses. For example, if `tax-summary-2018.pdf` already exists, uploading a new document with that name will be renamed `tax-summary-2018 (1).pdf`; uploading another file will be renamed `tax-summary-2018 (2).pdf`, and so on. </p> **TODO** In the future, this API will also support uploading new revisions of the document and maintaining document revision history.
   * @summary Create a new upload
   * @param {CreateUpload} CreateUpload The data necessary to create a new upload.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Upload}
   * @memberof UploadApi
   */
  public createUpload(CreateUpload: CreateUpload, options?: any) {
    return UploadApiFp(this.configuration).createUpload(
      CreateUpload ? CreateUpload : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this upload resource and any resources that are owned by it. Note that deleting an upload does _not_ delete any files that have been uploaded.
   * @summary Delete this upload resource
   * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof UploadApi
   */
  public deleteUpload(uploadId: string, headers?: { If_Match?: string }, options?: any) {
    return UploadApiFp(this.configuration).deleteUpload(
      uploadId ? uploadId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this upload resource.
   * @summary Fetch a representation of this upload
   * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Upload}
   * @memberof UploadApi
   */
  public getUpload(uploadId: string, headers?: { If_None_Match?: string }, options?: any) {
    return UploadApiFp(this.configuration).getUpload(
      uploadId ? uploadId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of uploads. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Upload resources expire after a while and these resources are automatically deleted.
   * @summary Return a collection of recent and in progress uploads
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first upload in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of upload representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.name] Subset the uploads collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Uploads}
   * @memberof UploadApi
   */
  public getUploads(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      name?: string;
      filter?: string;
      q?: string;
    },
    options?: any,
  ) {
    return UploadApiFp(this.configuration).getUploads(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Upload the raw content of the file as a stream of bytes.  Examples include the binary bytes for an image or PDF document, or the `multipart/form-data` representation of the file. The `Content-Type` header (or the `Content-Type` in the multipart form data) must match the `contentType` of the file resource. The response is the `/files/{fileId}` file resource, not the file content. *Note*: This is a _hidden_ operation which is a proxy for the `apiture:uploadUrl` link returned when creating a new upload in the `createUpload` operation. Clients should *not* assume this URL exists but should instead use the `apiture:uploadUrl` link that is returned when creating a new upload resource.  If the file is in a folder for which revisions are enable, this will create a new revision of the file; see the `getFileRevisions` and `getFileRevision` operations.
   * @summary Upload the file's raw content to the corresponding file resource.
   * @param {any} body The file contents as a stream of bytes.
   * @param {string} uploadId The unique identifier of this upload. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Content_Type] The media type describing the file&#39;s content type.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Files}
   * @memberof UploadApi
   */
  public uploadContent(
    body: any,
    uploadId: string,
    headers?: { Content_Type?: string },
    options?: any,
  ) {
    return UploadApiFp(this.configuration).uploadContent(
      body ? body : null,
      uploadId ? uploadId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
