// tslint:disable
/**
 * Vault
 * The Vault API manages secure content files and document storage for other Apiture APIs and application use. Documents which may be stored in Vault include _Terms and Conditions_, privacy statements, check images, statements, images/documents required for an account application, etc. Clients may upload and download files with this API, or search for files by date or type or role. Files may be organized into hierarchical folders. Each file has a JSON representation _file descriptor_ which includes the attributes  (metadata) of the file (the name, type, size, `_links`, etc.), and a `content` resource which accesses the text or binary content of the file. The content URI is available via the *`apiture:content`* link in the file descriptor. The `_links` of a file or folder include an *`apiture:folder`* link to its containing folder. Each folder has *`apiture:files`* and *`apiture:children`* links to its directly contained files and subfolders, respectively.  To upload a file, first `POST` a request to the `/uploads` path (the `createUpload` operation) containing file descriptor(s) to be uploaded. When uploading a new file, the caller may specify a desired target folder by setting the *`apiture:folder`* link within the request's `_links`.  The _upload tracker response_ from the upload operation contains an array of items, one for each file to upload. Each item in the array contains an *`apiture:uploadUrl`* link, which is an upload URL for the corresponding file. The client should next `PUT` the file(s) content to the upload URLs to upload the files' contents. The upload is done when the upload resource `state` is `completed` or `failed`. The upload resource will contain the file descriptor resources in the `items` array within the `_embedded` object; each file will include a `self` link to the corresponding file resource.  After a file has been created, the file resource contains links to its containing folder, the public share URI, and the content URI for downloading the file's content.  For files which reside in folders with revisions enabled, updating a file's content creates a new revision of the file. The revisions are available from the file's `/files/{fileId}/revisions` collection.
 *
 * OpenAPI spec version: 0.10.5
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
