// tslint:disable
/**
 * Workflow
 * The workflow API allows definition and execution of workflows. A _workflow_ is a set of tasks in a dependency graph, with state and business rules which connect and constrain the execution of the workflow tasks. Each workflow maintains some state. Each task in the workflow has entry criteria, input variables, and output variables. A task may be a composite task, built from another workflow. (This allows for reuse of such subflows.)   Each task and workflow has the following data:   * `domain`, `name`, `label`, `description` (descriptive information)  * A set of `values` (a map of name/value pairs) based on a `schema`  * A `state` field, one of `definition`, `pending`, `blocked`, `running`, `paused`, `failed`,    `completed`, `canceled`. The default state is `running` (or   `blocked` if no tasks are runnable)  * A `done` field is `true` if the state is one of those last three states.  * A list of `bindings` which connect workflow state `values` or the outputs    of previous tasks to the inputs of dependent tasks.   Some changes to the `state` of a workflow item is managed by the service. Clients can change some states via links in a task instance or workflow instance, via a `PUT` (operations `updateWorkflowValues`, `updateWorkflowValue`, `updateTaskValues` and `updateTaskValue`).   A workflow orchestrates a set of tasks and contains additional data:   * `dependencies`, which maps each task to a set of 0 or more    dependent tasks that trigger the task when they are `completed`.  * Entry criteria for each dependent task may also include a business    `rule` which must evaluate to `true`. The rules can access the    input values on the task as well as the workflow's values.    The default business rule tests that any dependent task is `completed`.  Tasks in a workflow which have no predecessor tasks and whose entry criteria rule evaluate to `true` may be run immediately.   Workflows are _static_: once a workflow has been created, tasks cannot be added or removed from the workflow and the task dependency graph may not be changed.  ## Workflow execution  Several operations change the execution state of workflow or task instances. Use the `startWorkflow`, `pauseWorkflow`, `cancelWorkflow`, `failWorkflow` operations to start a workflow, pause it, cancel it, or set it to a failed state. (Use `startWorkflow` to resume a paused workflow.) The `startTask`, `pauseTask`, `cancelTask`, `failTask` operations do the same for task instances. These operations are provided via links named `apiture:start`, `apiture:pause`, `apiture:cancel`, and `apiture:fail` in the `workflow` and `task` schemas, if the operations are available.   A workflow is `done` when the `state` of all its tasks are `done`, _or_ if the workflow has one or more _terminal_ tasks that are `done`, or if the workflow is in a `failed` state. If a terminal task completes, causing the workflow to complete, any remaining tasks are `canceled`. This allows business rules and flow to define the completion criteria, for example, three of four tasks completed instead all four.   ## Workflow and Task Definitions  Workflow _definitions_ are workflows with a `state` of `definition`; the tasks in a workflow definition are also tasks with `state` equal to `definition`. Definitions act as workflow templates: one creates new workflow instances by specifying an existing workflow definition. This also creates new task instances from each task definition. The workflow and all tasks' `state` is set to `blocked` with the exception of tasks that do not have dependent tasks (`initial` is `true`).   Workflow definitions may have cycles. That is, some tasks may be entered again, effectively restarting those tasks.  ## Workflow revisions  Workflow definitions and task definitions also retain a _revision history_, available in the definition's `revisions` collection. New revisions are created via a `POST` operation to a definition's `revisions` collection (see the `createWorkflowDefinitionRevision` and `createTaskDefinitionRevision` operations). Revisions are immutable copies of the resource which preserve or record the definition's data at the point in time that the revision was created. This allows preserving specific behavior of a workflow when after changing the definition.   For example, a specific revision of a workflow definition (using the revision URI, `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`) may be associated with other resources (such as banking products) so that the specific revision can be instantiated as a new workflow, rather than instantiating the currently active, revisionless definition found at `/workflowDefinitions/{workflowDefinitionId}`.   Revisions also support auditing: the immutable revision is a record of which workflow was used and its initial state. A workflow definition may reference either a specific revision of the embedded task definitions, or _revisionless_ task definitions; this determines which task definition (a specific revision or the most recent revision) is used for all the tasks in that workflow when that definition is used to create a new workflow instance. A reference to a revisionless task definition URL matches the URL pattern `/workflow/taskDefinitions/{taskDefinitionId}`; a task definition revision instance has a URL pattern `/workflow/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}` where revisionId is an [RFC 3339](https://tools.ietf.org/html/rfc3339) format timestamp:  `YYYY-MM-DDThh:mm:ss.sssZ`.   ## Error handling   If a workflow task fails, the service sets its `state` to `failed`. If the task has an `errorTask` defined, the workflow starts that task; it is included in the `/runningTasks`. The error task may be an interactive or hidden task. This allows the workflow to restart a sequence of tasks, for example, to let the user retry an operation that may fail. (The error task should be `restartable`.) The workflow may also define an `errorTask` which the workflow starts if the failed task does not define its own `errorTask`. If the error task is a terminal state, the workflow sets it's `state` to `failed`. The `errorTask` for a workflow or a workflow task is initialized from the same property of the workflow definition or a workflow task definition.
 *
 * OpenAPI spec version: 0.18.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

export interface SdkConfigurationParameters {
  apiKey?: string | ((name: string) => string);
  username?: string;
  password?: string;
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  host?: string;
  basePath?: string;
  baseOptions?: any;
}

export class SdkConfiguration {
  /**
   * parameter for apiKey security
   * @param name security name
   * @memberof SdkConfiguration
   */
  apiKey?: string | ((name: string) => string);
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  username?: string;
  /**
   * parameter for basic security
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  password?: string;
  /**
   * parameter for oauth2 security
   * @param name security name
   * @param scopes oauth2 scope
   * @memberof SdkConfiguration
   */
  accessToken?: string | ((name: string, scopes?: string[]) => string);
  /**
   * override host
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  host?: string;
  /**
   * override base path
   *
   * @type {string}
   * @memberof SdkConfiguration
   */
  basePath?: string;
  /**
   * base options for axios calls
   *
   * @type {any}
   * @memberof SdkConfiguration
   */
  baseOptions?: any;

  constructor(param: SdkConfigurationParameters = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.host = param.host;
    this.basePath = param.basePath;
  }
}
