// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Accounts
 * The Accounts API manages banking accounts for bank customers. This API manages two primary types of resources:    * *Accounts* (or _internal_ accounts) are those controlled by the   financial institution (FI). Account holders can perform a various operations   on such accounts: Users may view balances and account details,   open new accounts, lock internal accounts, blocking new banking activity on the account   until they unlock it. Users may also close accounts. The FI can freeze or unfreeze accounts   if they suspect fraudulent or other malicious or suspicious activity.   Users map also transfer money, view transactions, etc. using other Apiture APIs.   * *External Accounts* are accounts controlled by an external   financial institution. These are also known as _linked accounts_.   The user can perform fewer operations on external accounts,   primarily scheduling transfers between and an external account   and an internal account, using other Apiture APIs.   Accounts are instances of a banking _product_ (see the Products API). The product defines the type, rate, terms, attributes, and capabilities of accounts attached to the product. Accounts may be either _personal_ accounts (also known as _retail_ accounts) or _business_ accounts (accounts for businesses, institutions, trusts, non-profits, etc., also known as _commercial accounts_).   A user can list their existing accounts and see the balances of those accounts (based on entitlements) and may have permission to change the account name and label and description. Each account has a _primary user_, which is a bank user (via the Users service). The primary user has full management and entitlements for the account, receives mailings such as statements or tax documents.   For personal (retail) accounts, an account has a primary owner and may have additional joint owners. For business (commercial) accounts, the account owner is the business organization and one or more authorized signers who have account access entitlements.   Because the account number is sensitive data, it is not included by default in account representations. The masked account number is returned in the `accountNumbers` object. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request. The `accountNumbers.full` property is included with the 201 response of creating an account.   This API also manages additional resources which are associated with accounts. For personal accounts, one can get the list of owners (the primary owner and joint owners). The account owner can also view and update the account's beneficiaries. For business accounts, the account holders can view the account's authorized signers: those who have authorization to conduct activity against the account.
 *
 * OpenAPI spec version: 0.37.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/accounts'.replace(/\/+$/, '');

export const API_VERSION = '0.37.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Representation of an account resource. A banking account, which is an instance of a banking product   A business account may have authorized signers, which are people authorized to perform banking operations on the account such as initiating funds transfers.   The `_links` on an external account may include the following, depending on the state of the account:  The `apiture:rolloverProduct` and `apiture:transferTargetAccount` links may be updated by the [`patchAccount`](#op-patchAccount)operations. The owners are listed by the [`getOwners`](#op-getOwners) operation. The beneficiaries are listed and updated by the [`getBeneficiaries`](#op-getBeneficiaries) and [`patchBeneficiaries`](#op-patchBeneficiaries) operations. The authorized signers are listed and updated by the [`getAuthorizedSigners`](#op-getAuthorizedSigners) and [`updateAuthorizedSigners`](#op-updateAuthorizedSigners) operation.
 * @export
 * @interface Account
 */
export interface Account extends AbstractResource, AccountFields {
  /**
   * The account's rates of return (for deposit accounts) or interest rate (for debit accounts).
   * @type {InterestRates}
   * @memberof Account
   */
  rates?: InterestRates;
  /**
   * If the account is set to disburse earned interest into another account, this is the target account. The fields are derived from the account that is assigned with the `apiture:interestTargetAccount` link when [creating](#op-createAccount) or [updating](#op-patchAccount) the account.
   * @type {InterestTargetAccount}
   * @memberof Account
   */
  interestTargetAccount?: InterestTargetAccount;
  /**
   * Embedded objects.
   * @type {EmbeddedAccountObjects}
   * @memberof Account
   */
  _embedded?: EmbeddedAccountObjects;
  /**
   * An optional map of name/value pairs which contains additional dynamic data about the resource.
   * @type {{ [key: string]: AttributeValue; }}
   * @memberof Account
   */
  attributes?: { [key: string]: AttributeValue };
}

/**
 * @export
 * @namespace Account
 */
export namespace Account {}

/**
 * Fields used when creating an account.
 * @export
 * @interface AccountCreationFields
 */
export interface AccountCreationFields {
  /**
   * The user-assigned name of this account.
   * @type {string}
   * @memberof AccountCreationFields
   */
  name?: string;
  /**
   * The user-assigned description of this account.
   * @type {string}
   * @memberof AccountCreationFields
   */
  description?: string;
  /**
   * How interest credits on the account (if any) are disbursed. This field is `none` for non-interest bearing accounts. If this is `transfer`, the `apiture:interestTargetAccount` link in the account's `_link` references the target account for the disbursements. This field applies if the account is a CD (Certificate of Deposit a.k.a. Time Deposit) account.
   * @type {string}
   * @memberof AccountCreationFields
   */
  interestPolicy?: AccountCreationFields.InterestPolicyEnum;
}

/**
 * @export
 * @namespace AccountCreationFields
 */
export namespace AccountCreationFields {
  /**
   * @export
   * @enum {string}
   */
  export enum InterestPolicyEnum {
    None = 'none',
    Capitalize = 'capitalize',
    Transfer = 'transfer',
  }
}

/**
 * Fields of an internal account.
 * @export
 * @interface AccountFields
 */
export interface AccountFields extends AccountCreationFields {
  /**
   * The unique identifier for this account resource. This is an immutable opaque string.
   * @type {string}
   * @memberof AccountFields
   */
  _id?: string;
  /**
   * The state of the internal account.
   * @type {InternalAccountState}
   * @memberof AccountFields
   */
  state?: InternalAccountState;
  /**
   * The name of the account holder. This is derived from the user resource.
   * @type {string}
   * @memberof AccountFields
   */
  title?: string;
  /**
   * The name of the banking product that this account is an instance of. This is derived from the product resource.
   * @type {string}
   * @memberof AccountFields
   */
  productName?: string;
  /**
   * The name of the banking product type. This is derived from the _product_ resource. The `subtype` is more specific; `type` is a broad account category.
   * @type {string}
   * @memberof AccountFields
   */
  type?: string;
  /**
   * The name of the banking product sub type. This is derived from the _product_ resource. This is more specific than the `type`.
   * @type {string}
   * @memberof AccountFields
   */
  subtype?: string;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof AccountFields
   */
  ifxType?: IfxType;
  /**
   * Different representations of the account number.
   * @type {AccountNumbers}
   * @memberof AccountFields
   */
  accountNumbers?: AccountNumbers;
  /**
   * The account balance.
   * @type {Balance}
   * @memberof AccountFields
   */
  balance?: Balance;
  /**
   * If `true`, the account is open to deposits and credits such as transfers or rollovers.
   * @type {boolean}
   * @memberof AccountFields
   */
  allowsTransfers?: boolean;
  /**
   * The date-time the account was opened. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp.
   * @type {Date}
   * @memberof AccountFields
   */
  openedAt?: Date;
  /**
   * Interest disbursement settings for the account.
   * @type {Interest}
   * @memberof AccountFields
   */
  interest?: Interest;
  /**
   * Certificate of Deposit properties for the account.
   * @type {Cd}
   * @memberof AccountFields
   */
  cd?: Cd;
  /**
   * The number of withdrawals made against this account within the current statement cycle. For some deposit accounts such as savings accounts, this is limited to a maximum defined in the corresponding product's constraints. If exceeded over multiple statement cycles, the financial institution may convert the account to a demand deposit (checking) account.
   * @type {number}
   * @memberof AccountFields
   */
  cycleWithdrawalCount?: number;
  /**
   * The user-assigned name of this account.
   * @type {string}
   * @memberof AccountFields
   */
  name?: string;
  /**
   * The user-assigned description of this account.
   * @type {string}
   * @memberof AccountFields
   */
  description?: string;
  /**
   * The name of the financial institution (FI), derived from the FI's configuration.
   * @type {string}
   * @memberof AccountFields
   */
  institutionName?: string;
  /**
   * The account routing number which identifies the financial institution (FI). The full routing number is derived from the FI's configuration.
   * @type {string}
   * @memberof AccountFields
   */
  routingNumber?: string;
}

/**
 * @export
 * @namespace AccountFields
 */
export namespace AccountFields {}

/**
 * Properties which identify a specific account.
 * @export
 * @interface AccountIdentification
 */
export interface AccountIdentification {
  /**
   * The account name.
   * @type {string}
   * @memberof AccountIdentification
   */
  name?: string;
  /**
   * The title of the account. Traditionally, this is the name of the account holder.
   * @type {string}
   * @memberof AccountIdentification
   */
  title?: string;
  /**
   * The name of the financial institution which manages the account.
   * @type {string}
   * @memberof AccountIdentification
   */
  institutionName?: string;
  /**
   * The account routing number which identifies the financial institution. The full routing number and full account number are required to fully identify the account.
   * @type {string}
   * @memberof AccountIdentification
   */
  routingNumber?: string;
  /**
   * The masked and full account numbers for this account. The `full` value only appears when `?unmasked=true` is passed on the `GET` request.
   * @type {AccountNumbers}
   * @memberof AccountIdentification
   */
  accountNumbers?: AccountNumbers;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * The purpose of the account.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `accountPurpose` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AccountPurpose {
  Unknown = 'unknown',
  CreditCardProcessing = 'creditCardProcessing',
  GeneralOperatingFunds = 'generalOperatingFunds',
  Lottery = 'lottery',
  Payroll = 'payroll',
  Savings = 'savings',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A page of embedded account summaries.
 * @export
 * @interface AccountSummaries
 */
export interface AccountSummaries {
  /**
   * An array containing a page of account items.
   * @type {Array<SummaryAccount>}
   * @memberof AccountSummaries
   */
  items: Array<SummaryAccount>;
}

/**
 * Collection of accounts. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Accounts
 */
export interface Accounts extends Collection {
  /**
   * Embedded objects.
   * @type {AccountSummaries}
   * @memberof Accounts
   */
  _embedded?: AccountSummaries;
}

/**
 * Indicates how interest is accrued according to the `compoundPeriod`.  <strong><code>accrualType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named accrualType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `accrualType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>compounding</code></strong></td><td>Compounding interest</td>     </tr> <tr>     <td><strong><code>simple</code></strong></td><td>Simple interest</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum AccrualType {
  Compounding = 'compounding',
  Simple = 'simple',
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The type of this address.
   * @type {AddressType}
   * @memberof Address
   */
  type: AddressType;
  /**
   * A text label, suitable for presentation to the end user. This is derived from `type` or from `otherType` if `type` is `other`
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The actual address type if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  otherType?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
  /**
   * An identifier for this address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all addresses within the `addresses` array.
   * @type {string}
   * @memberof Address
   */
  _id?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A list of postal addresses and the preferred mailing address.
 * @export
 * @interface Addresses
 */
export interface Addresses {
  /**
   * An array of postal/mailing addresses.
   * @type {Array<Address>}
   * @memberof Addresses
   */
  addresses?: Array<Address>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array.
   * @type {string}
   * @memberof Addresses
   */
  preferredMailingAddressId?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Represents a person authorized for account access. This object contains key identification information for the person and the type of access or role that the person has in relation to the banking account or organization.
 * @export
 * @interface Authorization
 */
export interface Authorization extends IndividualIdentification {
  /**
   * The unique ID of the user. This is the `_id` value of the user resource from the Users API.
   * @type {string}
   * @memberof Authorization
   */
  userId?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof Authorization
   */
  customerId?: string;
  /**
   * The type of this account access authorization.  * *`primary`* the `contact` is the primary owner of a personal account. There may be only one  primary owner. The target of the authorization is a single personal account.  * *`joint`* the `contact` is a non-primary joint owner of a  personal account. The target of the authorization is a single personal account.  * *`authorizedSigner`* the `contact` is an authorized signer  for a business account. The target of the authorization is an  all business accounts owned by the organization.
   * @type {AuthorizationType}
   * @memberof Authorization
   */
  type?: AuthorizationType;
  /**
   * The person's role at the organization. This attribute is required when the authorization type is authorizedSigner.
   * @type {string}
   * @memberof Authorization
   */
  role?: string;
}

/**
 * The type of this account access authorization.  * *`primary`* the person is the primary owner of a personal account.  There may be only one primary owner.  * *`joint`* the person is a non-primary joint owner of a  personal account.  * *`authorizedSigner`* the person is an authorized signer  for all business accounts owned by the organization.
 * @export
 * @enum {string}
 */
export enum AuthorizationType {
  Primary = 'primary',
  Joint = 'joint',
  AuthorizedSigner = 'authorizedSigner',
}

/**
 * The list of users who are authorized to access the organization and its bank accounts.
 * @export
 * @interface AuthorizedSigners
 */
export interface AuthorizedSigners extends AbstractResource {
  /**
   * The array of authorized signers for this business and their role within the organization. These people have account access for all business accounts owned by the business. The items in this array must all have the `type` of `authorizedSigner`.
   * @type {Array<Authorization>}
   * @memberof AuthorizedSigners
   */
  items?: Array<Authorization>;
}

/**
 * The balance of the account. This is derived data and not mutable through the API. Balances may be negative, indicating a deficit or loan balance.
 * @export
 * @interface Balance
 */
export interface Balance {
  /**
   * The current balance is the available balance plus all pending credits and minus all pending debits.
   * @type {string}
   * @memberof Balance
   */
  current?: string;
  /**
   * The string representation of the exact decimal available balance. For deposit accounts, this reflects the amount that may be used for withdrawals or transfers. This field does not apply to debit accounts such as loans.
   * @type {string}
   * @memberof Balance
   */
  available?: string;
  /**
   * The `hold` balance is the total amount of funds held due to holds placed on individual transactions. Transaction holds reduce the available balance until expiration.
   * @type {string}
   * @memberof Balance
   */
  hold?: string;
  /**
   * A `reserve` balance is the amount placed on hold by the Financial Institution.  A reserve balance reduces the available balance.
   * @type {string}
   * @memberof Balance
   */
  reserve?: string;
  /**
   * The string representation of the total of all pending credits against this account. This contributes to the current balance but not the available balance.
   * @type {string}
   * @memberof Balance
   */
  pendingCredits?: string;
  /**
   * The string representation of the total of all pending debits against this account. This contributes to the current balance but not the available balance.
   * @type {string}
   * @memberof Balance
   */
  pendingDebits?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this balance.
   * @type {string}
   * @memberof Balance
   */
  currency?: string;
}

/**
 * A person who owns 25% or more of a business organization.
 * @export
 * @interface BeneficialOwner
 */
export interface BeneficialOwner extends SimpleContact {
  /**
   * The person's role at the organization.
   * @type {string}
   * @memberof BeneficialOwner
   */
  role?: string;
  /**
   * The percent of the business that this person owns.
   * @type {number}
   * @memberof BeneficialOwner
   */
  percentage?: number;
  /**
   * The beneficial's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof BeneficialOwner
   */
  birthdate?: string;
  /**
   * The `_id` of an existing contact resource associated with the beneficial owner. Create the beneficial owner contact resource using the Contacts API.
   * @type {string}
   * @memberof BeneficialOwner
   */
  contactId?: string;
}

/**
 * A list of people who own at least 25% of the business or who have a major role in the organization. The sum of the percentages may not exceed 100%. The percentage may be less than 25 for non-owners with a major role, or to retain other owners whose percentage may change to 25% in the future.
 * @export
 * @interface BeneficialOwners
 */
export interface BeneficialOwners extends AbstractResource {
  /**
   * A list of people who own at least 25% of the business, and the percentage owned.
   * @type {Array<BeneficialOwner>}
   * @memberof BeneficialOwners
   */
  items?: Array<BeneficialOwner>;
}

/**
 * Account beneficiaries who received the account assets if the owner dies. Beneficiaries apply only to personal accounts.
 * @export
 * @interface Beneficiaries
 */
export interface Beneficiaries extends AbstractResource {
  /**
   * A list of beneficiaries who receive the account assets payable on death (POD) of the account owner(s). This array may be empty. If the array is not empty, the percentages in this array should add up to 100 and may not exceed 100. However, if the array contains exactly one beneficiary, the percentage is automatically adjusted to 100%. The maximum number of account beneficiaries is 10 (but in the future, this will be configurable by the financial institution.) Beneficiaries are updated via the [`patchBeneficiaries`](#op-patchBeneficiaries) operation.
   * @type {Array<Beneficiary>}
   * @memberof Beneficiaries
   */
  items?: Array<Beneficiary>;
}

/**
 * An account beneficiary which receives a percentage of the account assets if the personal account owner dies. A beneficiary is either a person or a business organization representing a trust or charity.
 * @export
 * @interface Beneficiary
 */
export interface Beneficiary {
  /**
   * Indicates if this beneficiary is a business organization or an individual person.
   * @type {string}
   * @memberof Beneficiary
   */
  type?: Beneficiary.TypeEnum;
  /**
   * Details of a beneficiary who is an individual person. The `individual` property is only used if `type` is `individual` and is thus mutually exclusive with `organization`.
   * @type {IndividualBeneficiary}
   * @memberof Beneficiary
   */
  individual?: IndividualBeneficiary;
  /**
   * Details of a trust or charity beneficiary. The `organization` property is only used if `type` is `organization` and is thus mutually exclusive with `individual`.  The organization must have a `type` of `trust` or `nonProfit`; if `type` is `nonProfit` the `subtype` must be `charitableTrust`. Each organization must also include their TIN in an `identification` record with `type` of `taxId`. Trusts must also include their legal name, mailing address, the date the trust was established, and the legal name. Charities and non-profit beneficiary must include the charity's legal name and a mailing address.
   * @type {SimpleOrganization}
   * @memberof Beneficiary
   */
  organization?: SimpleOrganization;
  /**
   * The percent of the account assets that this beneficiary should receive.   A value of 0 is allowed so a user can change the percentage to a non-zero value in the future without having to enter all the beneficiary data again.
   * @type {number}
   * @memberof Beneficiary
   */
  percentage?: number;
}

/**
 * @export
 * @namespace Beneficiary
 */
export namespace Beneficiary {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    Individual = 'individual',
    Organization = 'organization',
  }
}

/**
 * Properties of a Certificate of Deposit (CD, a.k.a. Time Deposit) account.
 * @export
 * @interface Cd
 */
export interface Cd {
  /**
   * The date-time that this account will mature. The account matures on the date which is derived by adding the duration of the `term` to the opening date-time. The date-time is a string in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTF format: `YYYY-MM-DDThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof Cd
   */
  maturesAt?: Date;
  /**
   * The date-time that the user bumped the rate after the financial institution offered a higher rate. This property only exists if the user elected to bump the APY rate during this account's current term. If the account is rolled over to a new account, this property does not exist (even if the rollover has the same account number). See the [`bumpApyRate`](#op-bumpApyRate) operation. The date-time is a string in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTF format: `YYYY-MM-DDThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof Cd
   */
  apyBumpedAt?: Date;
  /**
   * The maturity term. The account matures on the date which is derived by adding the duration of the `term` to the opening date-time.   This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof Cd
   */
  term?: string;
  /**
   * What happens to the account upon maturity.
   * @type {MaturityPolicy}
   * @memberof Cd
   */
  maturityPolicy?: MaturityPolicy;
  /**
   * If this account rolls over into a new product at maturity, this is the name of the banking product for the rollover account. The product is defined in the `apiture:rolloverProduct` in the account's `_links`.
   * @type {string}
   * @memberof Cd
   */
  rolloverProductName?: string;
  /**
   * Details of the existing internal or external account where interest and/or balance are transferred at CD maturity, depending on the settings in `maturityPolicy`. This object only exists if the maturity policy specifies transferring. This object and the properties are derived from the account referenced by the `apiture:transferTargetAccount` link that is used in [`createAccount`](#op-createAccount) or [`updateAccount`](#op-updateAccount).
   * @type {CdTransferAccount}
   * @memberof Cd
   */
  transferAccount?: CdTransferAccount;
  /**
   * If this account is within the debit grace period, then it is eligible to withdraw funds without being assessed a penalty. If `true` the account is in the grace period in which debits are allowed.
   * @type {boolean}
   * @memberof Cd
   */
  inDebitGracePeriod?: boolean;
  /**
   * If this account is within the credit grace period, then it is eligible to add funds without being assessed a penalty. If `true` the account is in the grace period in which credits are allowed.
   * @type {boolean}
   * @memberof Cd
   */
  inCreditGracePeriod?: boolean;
  /**
   * If the account is in a debit-eligible grace period, this is the date the grace period ends for debits in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, `YYYY-MM-DD`. Otherwise, this field is omitted.
   * @type {string}
   * @memberof Cd
   */
  gracePeriodDebitEndsOn?: string;
  /**
   * If the account is in a credit-eligible grace period, this is the date the grace period ends for credits in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, `YYYY-MM-DD`. Otherwise, this field is omitted.
   * @type {string}
   * @memberof Cd
   */
  gracePeriodCreditEndsOn?: string;
  /**
   * When updating the maturity settings for a business CD account, a `true` value indicates the user has confirmed the existing beneficial owners on the account. This property exists _only_ in [`patchAccount`](#op-patchAccount) _request_ operations and is not present in responses. Note: The beneficial owners are part of the owning organization for business accounts; see the Organization's API.
   * @type {boolean}
   * @memberof Cd
   */
  beneficialOwnersConfirmed?: boolean;
}

/**
 * Properties of the target account for transferring funds from a maturing CD account.
 * @export
 * @interface CdTransferAccount
 */
export interface CdTransferAccount extends AccountIdentification {}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Represents a configuration group.
 * @export
 * @interface ConfigurationGroup
 */
export interface ConfigurationGroup extends ConfigurationGroupSummary {
  /**
   * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
   * @type {{ [key: string]: ConfigurationSchemaValue; }}
   * @memberof ConfigurationGroup
   */
  schema?: { [key: string]: ConfigurationSchemaValue };
  /**
   * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
   * @type {{ [key: string]: ConfigurationValue; }}
   * @memberof ConfigurationGroup
   */
  values?: { [key: string]: ConfigurationValue };
}

/**
 * A summary of the data contained within a configuration group resource.
 * @export
 * @interface ConfigurationGroupSummary
 */
export interface ConfigurationGroupSummary extends AbstractResource {
  /**
   * The name of this configuration group, must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  name?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  description?: string;
}

/**
 * Collection of configuration groups. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ConfigurationGroups
 */
export interface ConfigurationGroups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ConfigurationGroups
   */
  _embedded?: any;
}

/**
 * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
 * @export
 * @interface ConfigurationSchema
 */
export interface ConfigurationSchema {
  [key: string]: ConfigurationSchemaValue;
}

/**
 * The data associated with this configuration schema.
 * @export
 * @interface ConfigurationSchemaValue
 */
export interface ConfigurationSchemaValue {}

/**
 * The data associated with this configuration.
 * @export
 * @interface ConfigurationValue
 */
export interface ConfigurationValue {}

/**
 * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
 * @export
 * @interface ConfigurationValues
 */
export interface ConfigurationValues {
  [key: string]: ConfigurationValue;
}

/**
 * Product constraints, such as minimum and maximum balances.  This schema is version `v1.0.0`.
 * @export
 * @interface Constraints
 */
export interface Constraints {
  /**
   * The types of transactions permitted for this account. Values which appear in this array are permitted.
   * @type {TransactionTypes}
   * @memberof Constraints
   */
  transactionTypes?: TransactionTypes;
  /**
   * The minimum balance for accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumBalance?: string;
  /**
   * The minimum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumFundingAmount?: string;
  /**
   * The maximum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumFundingAmount?: string;
  /**
   * The minimum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumTransferAmount?: string;
  /**
   * The maximum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumTransferAmount?: string;
  /**
   * The maximum number of withdrawals allowed per cycle. If not present, there is no hard limit.
   * @type {number}
   * @memberof Constraints
   */
  maximumWithdrawalCount?: number;
  /**
   * The time limit within which account opening funding must occur after account creation. This is expressed as an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  fundingTerm?: string;
  /**
   * If true, deposits are not allowed after the rollover grace period (see `gracePeriod`). This applies to time deposit products only.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterGracePeriod?: boolean;
  /**
   * If true, deposits are not allowed after the initial account funding has completed. This typically applies to time deposit products.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterFunding?: boolean;
  /**
   * A period of time after account rollover when additional deposits are allowed. This is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  gracePeriod?: string;
}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * Representation used to create a new account. The request must contain a link to an active product, user, organization (for a business account) and, optionally, an approved account application; the account type and product are extracted from that product resource, and additional associations to people or organizations that should be attached to the account may come from the application, such as co-owners, owning business (if not passed in the `apiture:organization` link), etc. The product must be passed as `apiture:product`, user as `apiture:user`, organization as `apiture:organization`, and account application should be passed as the `apiture:application` link in `_links` in the request.   Interest-bearing accounts can either have interest disbursements _capitalized_ (back into the account) or _transferred_ to another internal account or an external account. This account is specified in the `apiture:interestTargetAccount` link in the request's `_links`.  The account must be active and eligible for deposits/credits. This link can be updated in the [`patchAccount`](#op-patchAccount) operations.   An account for a Certificate of Deposit (CD, a.k.a. Time Deposit) account may also specify an `apiture:rolloverProduct` link at creation time. If this account rolls over into a new product at maturity, this link is the URI of the banking product for the rollover account (see the Products API). This is used if `cd.maturityPolicy` is `rolloverPrincipalAndInterest` or `rolloverPrincipalAndTransferInterest`.   CD accounts may also specify an existing account (savings, checking) to transfer principal and/or interest to upon maturity in the `apiture:transferTargetAccount` link. The account must be an internal account which is active and available for deposits. This is used if `cd.maturityPolicy` is `transferPrincipalAndInterest` or `rolloverPrincipalAndTransferInterest`.  An `apiture:user` must be defined for specifying the owner of a non-business account and as an authorized signer of a business account.  Business accounts must specify the organization owning the account as an organization link, such as `apiture:organization`.
 * @export
 * @interface CreateAccount
 */
export interface CreateAccount extends AbstractRequest, AccountCreationFields {}

/**
 * @export
 * @namespace CreateAccount
 */
export namespace CreateAccount {}

/**
 * Representation used to create a new external account. The request should include a *`apiture:productType`* link to a product type.
 * @export
 * @interface CreateExternalAccount
 */
export interface CreateExternalAccount extends SummaryExternalAccountFields, AbstractRequest {
  /**
   * The masked and full account number
   * @type {CreateExternalAccountNumbers}
   * @memberof CreateExternalAccount
   */
  accountNumbers?: CreateExternalAccountNumbers;
  /**
   * Embedded objects.
   * @type {CreateExternalAccountEmbeddedObjects}
   * @memberof CreateExternalAccount
   */
  _embedded?: CreateExternalAccountEmbeddedObjects;
}

/**
 * Optional embedded resources to include when creating an external account.
 * @export
 * @interface CreateExternalAccountEmbeddedObjects
 */
export interface CreateExternalAccountEmbeddedObjects {
  /**
   * The array of account owners. This may be an empty array (0 items) but is always present.
   * @type {Array<ExternalAccountOwner>}
   * @memberof CreateExternalAccountEmbeddedObjects
   */
  accountOwners?: Array<ExternalAccountOwner>;
}

/**
 * The account numbers necessary to link an external account.
 * @export
 * @interface CreateExternalAccountNumbers
 */
export interface CreateExternalAccountNumbers {
  /**
   * The full account number. Pass in this value when linking an external account. This field can be updated whenever the account is still in the pending state.
   * @type {string}
   * @memberof CreateExternalAccountNumbers
   */
  full: string;
}

/**
 * A list of email addresses and the preferred email address.
 * @export
 * @interface EmailAddresses
 */
export interface EmailAddresses {
  /**
   * An array of email addresses.
   * @type {Array<TypedEmailAddress>}
   * @memberof EmailAddresses
   */
  emailAddresses?: Array<TypedEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.
   * @type {string}
   * @memberof EmailAddresses
   */
  preferredEmailAddressId?: string;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Embedded objects to include within an account's `_embedded` object, as selected with the `embed` query parameter on the [`getAccount`](#op-getAccount) operation.
 * @export
 * @interface EmbeddedAccountObjects
 */
export interface EmbeddedAccountObjects {
  /**
   * A personal account's primary and joint owners. This object is only available for personal accounts.
   * @type {Owners}
   * @memberof EmbeddedAccountObjects
   */
  owners?: Owners;
  /**
   * A personal account's primary and joint owners. This object is only available for personal accounts.
   * @type {Beneficiaries}
   * @memberof EmbeddedAccountObjects
   */
  beneficiaries?: Beneficiaries;
  /**
   * A business account's owning organization. This object is only available for business accounts. This is derived from the `organization` in the account application resource with which the account was created. This object is an Organization in the Organizations API. The business organization maintains a list of _authorized signers_ who having permission to banking activity on the account.
   * @type {Organization}
   * @memberof EmbeddedAccountObjects
   */
  owningBusiness?: Organization;
  /**
   * A list of authorized signers for a business account. This object is only available for business accounts.
   * @type {AuthorizedSigners}
   * @memberof EmbeddedAccountObjects
   */
  authorizedSigners?: AuthorizedSigners;
  /**
   * Summary representation of a product resource in products collections.
   * @type {SummaryProduct}
   * @memberof EmbeddedAccountObjects
   */
  product?: SummaryProduct;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * The estimated annual revenue in USD.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `estimatedAnnualRevenue` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EstimatedAnnualRevenue {
  Unknown = 'unknown',
  Under1Million = 'under1Million',
  From1to10Million = 'from1to10Million',
  From10to100Million = 'from10to100Million',
  Over100Million = 'over100Million',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Estimated monthly amounts for banking services.
 * @export
 * @interface EstimatedMonthlyAmounts
 */
export interface EstimatedMonthlyAmounts {
  /**
   * The percentage of gross revenue the organization derives from money services.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  percentGrossRevenue?: string;
  /**
   * Indicates the estimated monthly total amount to send by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentAch?: string;
  /**
   * Indicates the estimated monthly total amount to receive by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedAch?: string;
  /**
   * Indicates the estimated monthly minimum amount to deposit.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  mobileCheckDeposit?: string;
  /**
   * Indicates the estimated monthly minimum wires amount sent.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentWire?: string;
  /**
   * Indicates the estimated monthly minimum wires amount received.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedWire?: string;
}

/**
 * Representation of an external account resource, a banking account held by another financial institution.   The `_links` on an external account may include the following, depending on the state of the account:  *`self`* - The link to the external account.  *`apiture:activate`* - Activate the account (POST).  *`apiture:deactivate`* - Deactivate the account (POST).  *`apiture:freeze`* - Freeze the account (POST).  *`apiture:close`* - Close the account (POST).  *`apiture:review`* - Under review the account (POST).
 * @export
 * @interface ExternalAccount
 */
export interface ExternalAccount extends SummaryExternalAccount, ExternalAccountFields {}

/**
 * Embedded objects to include within an external account's `_embedded` object, as selected with the `embed` query parameter on the [`getExternalAccounts`](#op-getExternalAccounts) operation.
 * @export
 * @interface ExternalAccountEmbeddedObjects
 */
export interface ExternalAccountEmbeddedObjects {
  /**
   * The array of account owners.
   * @type {Array<ExternalAccountOwner>}
   * @memberof ExternalAccountEmbeddedObjects
   */
  accountOwners?: Array<ExternalAccountOwner>;
}

/**
 * Fields of an external account resource.
 * @export
 * @interface ExternalAccountFields
 */
export interface ExternalAccountFields extends SummaryExternalAccountFields {
  /**
   * The masked and full account number
   * @type {ExternalAccountNumbers}
   * @memberof ExternalAccountFields
   */
  accountNumbers?: ExternalAccountNumbers;
}

/**
 * The account numbers necessary to link an external account.
 * @export
 * @interface ExternalAccountNumbers
 */
export interface ExternalAccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is included when accounts are embedded in collections or other resources. This value is derived and immutable.
   * @type {string}
   * @memberof ExternalAccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request for an account. Not included in the summary representation of the account that is included in account collection responses. Pass in this value when linking an external account. This field can be updated whenever the account is still in the pending state.
   * @type {string}
   * @memberof ExternalAccountNumbers
   */
  full?: string;
}

/**
 * An external account owner. Since this is a small finite set, this is not a paginated collection, just an array.
 * @export
 * @interface ExternalAccountOwner
 */
export interface ExternalAccountOwner extends ContactName {
  /**
   * The account owner's full name (first name and last name).
   * @type {string}
   * @memberof ExternalAccountOwner
   */
  fullName?: string;
  /**
   * The account owner's ownership type.
   * @type {AuthorizationType}
   * @memberof ExternalAccountOwner
   */
  type?: AuthorizationType;
}

/**
 * A (possibly empty) list of external account owners. Since this is a small finite set, this is not a paginated collection, just an array.
 * @export
 * @interface ExternalAccountOwners
 */
export interface ExternalAccountOwners extends AbstractResource {
  /**
   * The array of account owners. This may be an empty array (0 items) but is always present.
   * @type {Array<ExternalAccountOwner>}
   * @memberof ExternalAccountOwners
   */
  accountOwners: Array<ExternalAccountOwner>;
}

/**
 * The state of an external (linked) banking account. This field is immutable and derived.   To change the state of an account, `POST` the account ID to the corresponding resource endpoints, using the corresponding link on the external account resource: * To activate an account, use the `apiture:activate` link to `POST` to `/accounts/activeAccounts`. * To deactivate an account, use the `apiture:deactivate` link to `POST` to `/accounts/inactiveAccounts`. * To freeze an account, use the `apiture:freeze` link to `POST` to `/accounts/frozenAccounts`. * To close an account, use the `apiture:close` link to `POST` to `/accounts/closedAccounts`. * To under review an account, use the `apiture:review` link to `POST` to `/accounts/externalAccountsUnderReview`. * To idicate a request to verify the account using micro-deposits, use the `apiture:requestMicroDepositVerification` link to `POST` to `/externalAccountsNeedingMicroDepositVerification`.
 * @export
 * @enum {string}
 */
export enum ExternalAccountState {
  Pending = 'pending',
  Verifying = 'verifying',
  Failed = 'failed',
  Active = 'active',
  Inactive = 'inactive',
  Frozen = 'frozen',
  Closed = 'closed',
  UnderReview = 'underReview',
  MicroDepositsRequested = 'microDepositsRequested',
}

/**
 * A page of embedded external account summaries.
 * @export
 * @interface ExternalAccountSummaries
 */
export interface ExternalAccountSummaries {
  /**
   * An array containing a page of external account items.
   * @type {Array<SummaryExternalAccount>}
   * @memberof ExternalAccountSummaries
   */
  items: Array<SummaryExternalAccount>;
}

/**
 * Collection of external accounts. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ExternalAccounts
 */
export interface ExternalAccounts extends Collection {
  /**
   * Embedded objects.
   * @type {ExternalAccountSummaries}
   * @memberof ExternalAccounts
   */
  _embedded?: ExternalAccountSummaries;
}

/**
 * Official identifying information associated with the contact.
 * @export
 * @interface Identification
 */
export interface Identification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof Identification
   */
  value: string;
  /**
   * The type of this form of identification.
   * @type {string}
   * @memberof Identification
   */
  type: Identification.TypeEnum;
  /**
   * The date when the form of identification expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` format.
   * @type {string}
   * @memberof Identification
   */
  expiration?: string;
}

/**
 * @export
 * @namespace Identification
 */
export namespace Identification {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    TaxId = 'taxId',
    PassportNumber = 'passportNumber',
  }
}

/**
 * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values. Labels and descriptions for the enumeration values are in the `ifxType` key in the response of the `getLabels` operation.  <strong><code>ifxType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named ifxType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `ifxType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>CCA</code></strong></td><td>Credit card account</td>     </tr> <tr>     <td><strong><code>CDA</code></strong></td><td>Certificate of deposit account (CD)</td>     </tr> <tr>     <td><strong><code>CLA</code></strong></td><td>Commercial loan account</td>     </tr> <tr>     <td><strong><code>CMA</code></strong></td><td>Cash management account</td>     </tr> <tr>     <td><strong><code>DDA</code></strong></td><td>Demand deposit account</td>     </tr> <tr>     <td><strong><code>EQU</code></strong></td><td>Home equity loan</td>     </tr> <tr>     <td><strong><code>GLA</code></strong></td><td>General ledger account</td>     </tr> <tr>     <td><strong><code>ILA</code></strong></td><td>Installment loan account</td>     </tr> <tr>     <td><strong><code>INV</code></strong></td><td>Investment account</td>     </tr> <tr>     <td><strong><code>IRA</code></strong></td><td>Individual retirement account</td>     </tr> <tr>     <td><strong><code>IRL</code></strong></td><td>Accounts held in Ireland</td>     </tr> <tr>     <td><strong><code>LOC</code></strong></td><td>Consumer line of credit</td>     </tr> <tr>     <td><strong><code>MLA</code></strong></td><td>Military Lending Account: Credit facility held by former US service member</td>     </tr> <tr>     <td><strong><code>MMA</code></strong></td><td>Money market account</td>     </tr> <tr>     <td><strong><code>PBA</code></strong></td><td>Packaged bank Account: Account with additional benefits that charges a fixed monthly fee.</td>     </tr> <tr>     <td><strong><code>PPA</code></strong></td><td>Private pension administrator</td>     </tr> <tr>     <td><strong><code>RWD</code></strong></td><td>Reward accounts</td>     </tr> <tr>     <td><strong><code>SDA</code></strong></td><td>Savings deposit account</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum IfxType {
  CCA = 'CCA',
  CDA = 'CDA',
  CLA = 'CLA',
  CMA = 'CMA',
  DDA = 'DDA',
  EQU = 'EQU',
  GLA = 'GLA',
  ILA = 'ILA',
  INV = 'INV',
  IRA = 'IRA',
  IRL = 'IRL',
  LOC = 'LOC',
  MLA = 'MLA',
  MMA = 'MMA',
  PBA = 'PBA',
  PPA = 'PPA',
  RWD = 'RWD',
  SDA = 'SDA',
}

/**
 * Details of a beneficiary who is an individual person. The `individual` property is only used if `type` is `individual` and is thus mutually exclusive with `organization`.
 * @export
 * @interface IndividualBeneficiary
 */
export interface IndividualBeneficiary extends IndividualIdentification {
  /**
   * The beneficiary's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof IndividualBeneficiary
   */
  birthdate?: string;
  /**
   * The beneficiary's relationship to the primary account owner, such as `\"child\"` or `\"spouse\"`.
   * @type {string}
   * @memberof IndividualBeneficiary
   */
  relationship?: string;
}

/**
 * This object contains key identification information for a person associated with digital banking.
 * @export
 * @interface IndividualIdentification
 */
export interface IndividualIdentification extends ContactName, Addresses {
  /**
   * Official government identification (tax ID) for this person.
   * @type {string}
   * @memberof IndividualIdentification
   */
  taxId?: string;
  /**
   * Indicates if the person is a (US) citizen.
   * @type {boolean}
   * @memberof IndividualIdentification
   */
  citizen?: boolean;
  /**
   * Optional email address.
   * @type {string}
   * @memberof IndividualIdentification
   */
  emailAddress?: string;
}

/**
 * The account's accrued interest. The values are in the `currency` associated with the account.
 * @export
 * @interface Interest
 */
export interface Interest {
  /**
   * The interest earned to date since the beginning of the year.
   * @type {string}
   * @memberof Interest
   */
  yearToDate?: string;
  /**
   * The interest earned since the account was opened.
   * @type {string}
   * @memberof Interest
   */
  sinceOpening?: string;
}

/**
 * The rate type. The rate type may not be changed once it is set at product creation. Rate types are:   * *`apr`* - annual percentage rate   * *`apy`* - annual percentage yield  This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum InterestRateType {
  Apr = 'apr',
  Apy = 'apy',
}

/**
 * The interest rates of the account. For deposit accounts, the rates describe the rate of return; for loan accounts, this includes the interest rate charged on balances. The values are percentages, expressed as strings containing a decimal percentage in order to represent the rate exactly. Rates are typically coded to 3 decimal places, but may have more. For example, `\"1.450\"` means 1.45%.
 * @export
 * @interface InterestRates
 */
export interface InterestRates extends SummaryInterestRates {
  /**
   * The original APY for this account's term, before the user bumped the APY rate. If the user bumped the rate, the `apy` reflects the new bumped APY. This property exists only on CD time-deposit accounts and only if the user has previously bumped APY rate.
   * @type {string}
   * @memberof InterestRates
   */
  originalApy?: string;
  /**
   * The annual percentage yield that this account is earning. The `apye` is an annualized rate based on the amount of interest actually earned, including compounding, as a percentage of the account's average daily balance. The `apye` is updated every account statement period.
   * @type {string}
   * @memberof InterestRates
   */
  apye?: string;
}

/**
 * Properties of the target where the financial institution transfers interest disbursements.
 * @export
 * @interface InterestTargetAccount
 */
export interface InterestTargetAccount extends AccountIdentification {}

/**
 * The intermediary/non-bank financial institution services provided.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `intermediaryServices` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum IntermediaryServices {
  Unknown = 'unknown',
  Accounting = 'accounting',
  FundsManagement = 'fundsManagement',
  Insurance = 'insurance',
  Investment = 'investment',
  Legal = 'legal',
  Medical = 'medical',
  Notary = 'notary',
  RealEstate = 'realEstate',
  TaxPreparation = 'taxPreparation',
  TrustManagement = 'trustManagement',
  Gambling = 'gambling',
  Securities = 'securities',
  LoanFinance = 'loanFinance',
  PawnBrokerage = 'pawnBrokerage',
  TravelAgency = 'travelAgency',
  VehicleSales = 'vehicleSales',
  ForeignCurrency = 'foreignCurrency',
  PreciousMetals = 'preciousMetals',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The state of the account. This field is immutable and derived.   To change the state of an account, `POST` the account ID to the corresponding resource endpoints, using the corresponding link on the account resource: * To activate an account, use the `apiture:activate` link to `POST` to `/accounts/activeAccounts`. * To deactivate an account, use the `apiture:deactivate` link to `POST` to `/accounts/inactiveAccounts`. * To freeze an account, use the `apiture:freeze` link to `POST` to `/accounts/frozenAccounts`. * To close an account, use the `apiture:close` link to `POST` to `/accounts/closedAccounts`.
 * @export
 * @enum {string}
 */
export enum InternalAccountState {
  Pending = 'pending',
  Active = 'active',
  Inactive = 'inactive',
  Frozen = 'frozen',
  Closed = 'closed',
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * A localized label and optional description for localizable content defined in this API. This schema is deprecated; use [`labelItem`](#schema-labelitem) instead.
 * @export
 * @interface LocalizedLabel
 */
export interface LocalizedLabel {
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  label?: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof LocalizedLabel
   */
  description?: string;
  /**
   * The actual natural language tag to which this localized label is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1)
   * @type {string}
   * @memberof LocalizedLabel
   */
  language?: string;
  /**
   * If the localized value is associated with an external standard, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LocalizedLabel
   */
  code?: string;
}

/**
 * A map that defines lables for an enumeration or other item in a JSON schema. This is a map which maps enumeration schema names to an `localizedLabel` object. This schema is deprecated. Use [`labelGroups`](#schema-labelgroups)` instead.
 * @export
 * @interface LocalizedLabels
 */
export interface LocalizedLabels {
  [key: string]: LocalizedLabel;
}

/**
 * Indicates how the principal and interest are processed upon maturity. The values indicate whether to rollover (to a time deposit account of the same rate and term), transfer funds to another (possibly new) deposit account, or simply hold the funds in the current account (which may no longer accrue interest). Labels and descriptions for the enumeration values are in the `maturityPolicy` key in the response of the `getLabels` operation.  <strong><code>maturityPolicy</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named maturityPolicy)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `maturityPolicy` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>rolloverPrincipalAndInterest</code></strong></td><td>Rollover principal and interest to a new CD of the same product: Upon maturity, both principal and interest rollover into a specified banking product, such as a savings, checking, or other deposit account.</td>     </tr> <tr>     <td><strong><code>transferPrincipalAndInterest</code></strong></td><td>Transfer principal and interest to a deposit account: Upon maturity, the principal an interest are both transferred to an existing or new deposit account.</td>     </tr> <tr>     <td><strong><code>rolloverPrincipalAndTransferInterest</code></strong></td><td>Transfer interest to a new deposit account an rollover principal to a new CD of the same product: Upon maturity, the principal rolls over into a specified banking product and the interest is transferred to an existing deposit account.</td>     </tr> <tr>     <td><strong><code>holdPrincipalAndInterest</code></strong></td><td>Hold principal and accued interest in the CD account until withdrawal: Upon maturity, the principal and interest are held in the current time deposit account. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> <tr>     <td><strong><code>partialTransfer</code></strong></td><td>Partial Transfer: Upon maturity, any funds greater than the maturity threshold is transfered to an existing deposit account and the rest remains on deposit. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum MaturityPolicy {
  RolloverPrincipalAndInterest = 'rolloverPrincipalAndInterest',
  TransferPrincipalAndInterest = 'transferPrincipalAndInterest',
  RolloverPrincipalAndTransferInterest = 'rolloverPrincipalAndTransferInterest',
  HoldPrincipalAndInterest = 'holdPrincipalAndInterest',
  PartialTransfer = 'partialTransfer',
}

/**
 * Describes if the product is available for opening new accounts.  <strong><code>newAccountAvailability</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named newAccountAvailability)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `newAccountAvailability` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>available</code></strong></td><td>Users may open new accounts of this type</td>     </tr> <tr>     <td><strong><code>notAvailable</code></strong></td><td>Users may not open new accounts of this type</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum NewAccountAvailability {
  Available = 'available',
  NotAvailable = 'notAvailable',
}

/**
 * Representation of content and descriptive data (mailing addresses, phone numbers, email addresses) for an organization.  An organization which is used for a business banking account may have authorized signers, which are people authorized to perform banking operations on the business account(s) such as initiating funds transfers.  Regulations require identifying an organization's _beneficial owners_: people who own 25% or more of a business. These may be listed and updated with the `getBeneficialOwners` and `updateBeneficialOwners` operations.  An organization may have the following links in the `_links` object:   * **`apiture:activate`** - Activate a new, pending organization.   * **`apiture:deactivate`** - Deactivate an organization (if it   is pending or active).   * **`apiture:remove`** - Remove an inactive organization.   * **`apiture:authorizedSigners`** - List the authorized signers.   * **`apiture:beneficialOwners`** - List the beneficial owners.
 * @export
 * @interface Organization
 */
export interface Organization extends SummaryOrganization {
  /**
   * The date-time when the organization was created.
   * @type {Date}
   * @memberof Organization
   */
  createdAt?: Date;
  /**
   * The date-time when the organization was updated
   * @type {Date}
   * @memberof Organization
   */
  updatedAt?: Date;
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof Organization
   */
  attributes?: any;
  /**
   * Embedded objects, as selected with the `?embed` query parameter.
   * @type {any}
   * @memberof Organization
   */
  _embedded?: any;
}

/**
 * Representation of an organization's address resource.
 * @export
 * @interface OrganizationAddress
 */
export interface OrganizationAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof OrganizationAddress
   */
  state?: ProfileItemState;
}

/**
 * Representation of email address resources. An email address is immutable, although organizations can add new email addresses.
 * @export
 * @interface OrganizationEmailAddress
 */
export interface OrganizationEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof OrganizationEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * Common fields of the organization resource, for organizations which conduct banking.
 * @export
 * @interface OrganizationFields
 */
export interface OrganizationFields extends SimpleOrganization {
  /**
   * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
   * @type {OrganizationState}
   * @memberof OrganizationFields
   */
  state?: OrganizationState;
  /**
   * The trade name of the organization.
   * @type {string}
   * @memberof OrganizationFields
   */
  tradeName?: string;
  /**
   * Indicates whether the organization is a government-owned entity.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  governmentOwned?: boolean;
  /**
   * Indicates whether the organization is publicly held.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  publiclyHeld?: boolean;
  /**
   * Indicates whether the organization is classified as a small business
   * @type {boolean}
   * @memberof OrganizationFields
   */
  smallBusiness?: boolean;
  /**
   * Indicates whether the organization is the tax-exempt.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  taxExempt?: boolean;
  /**
   * Indicates the approximate number of employees, as a range.
   * @type {string}
   * @memberof OrganizationFields
   */
  employeeCountRange?: string;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountLowerBound?: number;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountUpperBound?: number;
  /**
   * The organization's home page.
   * @type {string}
   * @memberof OrganizationFields
   */
  homeUrl?: string;
  /**
   * Indicates what industry does this organization work within.
   * @type {string}
   * @memberof OrganizationFields
   */
  industry?: string;
  /**
   * The ISO 3166-1 country code for the organization's operation.
   * @type {string}
   * @memberof OrganizationFields
   */
  countryOfOperations?: string;
  /**
   * Answers to organization-specific regulatory questions.
   * @type {Regulatory}
   * @memberof OrganizationFields
   */
  regulatory?: Regulatory;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII. TODO: ISO 4217 defines three-character codes. However, ISO 4217 does not account for cryptocurrencies. Of note, DASH uses 4 characters.
   * @type {string}
   * @memberof OrganizationFields
   */
  currency?: string;
  /**
   * Indicates that the organization use mobile check deposits.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  mobileCheckDepositEnabled?: boolean;
  /**
   * Indicates that the organization use ACH transfers.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  achEnabled?: boolean;
  /**
   * Estimated monthly amounts for banking services.
   * @type {EstimatedMonthlyAmounts}
   * @memberof OrganizationFields
   */
  estimatedMonthlyAmounts?: EstimatedMonthlyAmounts;
  /**
   * The purpose of the account.
   * @type {AccountPurpose}
   * @memberof OrganizationFields
   */
  accountPurpose?: AccountPurpose;
  /**
   * The US state or other region in which the organization is registered.
   * @type {string}
   * @memberof OrganizationFields
   */
  registeredIn?: string;
}

/**
 * The type and value of the organizations unique identification numbers.
 * @export
 * @interface OrganizationIdentification
 */
export interface OrganizationIdentification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof OrganizationIdentification
   */
  value: string;
  /**
   * The type of this form of identification. `taxId` is the only supported type at this time.
   * @type {OrganizationIdentificationType}
   * @memberof OrganizationIdentification
   */
  type: OrganizationIdentificationType;
  /**
   * The date when this form of identification expires.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiresOn?: string;
  /**
   * The date when this form of identification expires. **Note** This property is deprecated; use `expiresOn`.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiration?: string;
}

/**
 * The type of the form of an organization's identification. `taxId` is the only supported type at this time.
 * @export
 * @enum {string}
 */
export enum OrganizationIdentificationType {
  TaxId = 'taxId',
  DunsNumber = 'dunsNumber',
}

/**
 * Representation of phone number resources.
 * @export
 * @interface OrganizationPhoneNumber
 */
export interface OrganizationPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof OrganizationPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum OrganizationState {
  Pending = 'pending',
  Inactive = 'inactive',
  Active = 'active',
  Merged = 'merged',
  Removed = 'removed',
}

/**
 * Personal account primary and joint owners. These are fetched and set via the [`getOwners`](#op-getOwners) operations. Owners are added when other users accept invitations to become joint account holders. The user cannot directly modify this set of owners.
 * @export
 * @interface Owners
 */
export interface Owners extends AbstractResource {
  /**
   * An array of account owners. For personal accounts, this array contains exactly one `primary` owner and zero or more `joint` owners. The maximum number of joint account owners, including the primary owner, is 10 (but in the future, this will be configurable by the financial institution.) The primary owner for new accounts is the user who creates the account application and account. Joint owners are added by inviting others.
   * @type {Array<Authorization>}
   * @memberof Owners
   */
  items?: Array<Authorization>;
}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * A list of phone numbers and the preferred phone number.
 * @export
 * @interface PhoneNumbers
 */
export interface PhoneNumbers {
  /**
   * An array of phone numbers.
   * @type {Array<PhoneNumber>}
   * @memberof PhoneNumbers
   */
  phones?: Array<PhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array.
   * @type {string}
   * @memberof PhoneNumbers
   */
  preferredPhoneId?: string;
}

/**
 * The contact's preferred method of communication.
 * @export
 * @enum {string}
 */
export enum PreferredContactMethod {
  Unknown = 'unknown',
  Sms = 'sms',
  Email = 'email',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.  <strong><code>prodState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named prodState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `prodState` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>pending</code></strong></td><td>This product has been created in draft form but is not yet available</td>     </tr> <tr>     <td><strong><code>active</code></strong></td><td>This product is active and available for use</td>     </tr> <tr>     <td><strong><code>inactive</code></strong></td><td>This product is temporarily not available for use</td>     </tr> <tr>     <td><strong><code>removed</code></strong></td><td>This product has been removed and is permanently not available for use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProdState {
  Pending = 'pending',
  Active = 'active',
  Inactive = 'inactive',
  Removed = 'removed',
}

/**
 * Common fields of the product resource.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductFields
 */
export interface ProductFields extends ProductState {
  /**
   * The name of this product.
   * @type {string}
   * @memberof ProductFields
   */
  name?: string;
  /**
   * The text label for this product. This field may be localized.
   * @type {string}
   * @memberof ProductFields
   */
  label?: string;
  /**
   * A fuller description of this product. This field may be localized. The content is processed as  [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof ProductFields
   */
  description?: string;
  /**
   * The unique product code for this product, normally defined by the underlying banking core. The `code` cannot be changed once the `state` is beyond `pending`.
   * @type {string}
   * @memberof ProductFields
   */
  code?: string;
  /**
   * Indicates if the product is available for opening new accounts.   * *`available`* means the product may be selected for a new account application.   * *`notAvailable`* means the product may *not* be selected for a new account application. The default is `available`. Note that clients must check both the product `state` and the `newAccountAvailability` when listing products for new account opening. The `?openable=true` query parameter on `/accounts` combines these. Labels and descriptions for the enumeration values are in the `newAccountAvailability` key in the response of the `getLabels` operation.
   * @type {NewAccountAvailability}
   * @memberof ProductFields
   */
  newAccountAvailability?: NewAccountAvailability;
  /**
   * The product category name. This is a more readable form of the product's `type`.
   * @type {string}
   * @memberof ProductFields
   */
  category?: string;
  /**
   * The interest rate for this product.
   * @type {Rate}
   * @memberof ProductFields
   */
  rate?: Rate;
  /**
   * The revision string for this product. This property derived and immutable.
   * @type {string}
   * @memberof ProductFields
   */
  revision?: string;
  /**
   * The product IFX Account Type.
   * @type {IfxType}
   * @memberof ProductFields
   */
  ifxType?: IfxType;
  /**
   * Describes the target audience or consumer of the accounts, `personal` or `business`. Labels and descriptions for the enumeration values are in the `productTarget` key in the response of the `getLabels` operation.
   * @type {ProductTarget}
   * @memberof ProductFields
   */
  target?: ProductTarget;
}

/**
 * The state of a product or type.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductState
 */
export interface ProductState {
  /**
   * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.
   * @type {ProdState}
   * @memberof ProductState
   */
  state?: ProdState;
}

/**
 * The target audience for this product.  <strong><code>productTarget</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named productTarget)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `productTarget` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>personal</code></strong></td><td>Banking products for personal use</td>     </tr> <tr>     <td><strong><code>business</code></strong></td><td>Banking products for business use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProductTarget {
  Personal = 'personal',
  Business = 'business',
}

/**
 * The state of an item (address, email address, or phone number) within the organization's profile. New addresses, email addresses, or phone numbers start with the state `pending`, which means approval by the financial institution is pending. After they have been verified, the state becomes `approved`. Some normalizing or sanitizing of the value may occur when this happens (for example, a ZIP code may change to ZIP+4 format). `pending` items may not be assigned as the preferred item.
 * @export
 * @enum {string}
 */
export enum ProfileItemState {
  Pending = 'pending',
  Approved = 'approved',
}

/**
 * The interest rate of the account. For deposit accounts, this is the rate of return; for loan accounts, this is the interest rate charged on balances. Rates can be absolute, such as \"1.40\" to indicate 1.4%, which is expressed as  `{ \"value\" : \"1.40\" }`, or relative to a benchmark, such as U.S. Prime Rate + 0.5% which is expressed as `{ \"benchmark\" : \"prime\", \"value\" : \"0.50\" }`.  This schema is version `v1.0.0`.
 * @export
 * @interface Rate
 */
export interface Rate {
  /**
   * The rate, expressed as an decimal percentage string in order to represent the rate exactly. This number must have 2 to four decimal points, i.e. '2.00' or '0.50' or '1.015', but not `2` or `.5`. (Regular expression pattern: `-?\\d{1,3}+\\.\\d{2,4}`)
   * @type {string}
   * @memberof Rate
   */
  value?: string;
  /**
   * An optional base benchmark that the rate is relative to. If omitted, the rate is fixed. Otherwise the rate is added to the benchmark rate. Values may be (but are not limited to):  * *`primeUS`* - the [U.S. Prime rate](https://en.wikipedia.org/wiki/Prime_rate)  * *`treasuryUS`* - The [U.S. Treasury rate](https://www.treasury.gov/resource-center/data-chart-center/interest-rates/Pages/TextView.aspx?data=yieldAll)  * *`libor`* - the [London Inter-bank Offered Rates](https://en.wikipedia.org/wiki/Libor) rate
   * @type {string}
   * @memberof Rate
   */
  benchmark?: string;
  /**
   * The period at which interest compounds.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. The default is `\"P0D\"` (continuous).
   * @type {string}
   * @memberof Rate
   */
  compoundPeriod?: string;
  /**
   * Indicates how interest is accrued according to the `compoundPeriod`.
   * @type {AccrualType}
   * @memberof Rate
   */
  accrualType?: AccrualType;
  /**
   * The period at which the rate is adjusted or recomputed to account for differences in the benchmark rate.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days; The default is `\"P1D\"` (daily).
   * @type {string}
   * @memberof Rate
   */
  adjustmentPeriod?: string;
  /**
   * The interest rate type.
   * @type {InterestRateType}
   * @memberof Rate
   */
  type?: InterestRateType;
}

/**
 * Responses to regulatory-related questions.
 * @export
 * @interface Regulatory
 */
export interface Regulatory {
  [key: string]: RegulatoryValue | any;

  /**
   * The range of estimated revenue in US dollars.
   * @type {EstimatedAnnualRevenue}
   * @memberof Regulatory
   */
  estimatedAnnualRevenue?: EstimatedAnnualRevenue;
  /**
   * The organization operates automated teller machines (ATMs).
   * @type {boolean}
   * @memberof Regulatory
   */
  atmOperator?: boolean;
  /**
   * Some of the organization's income depends on a charity.
   * @type {boolean}
   * @memberof Regulatory
   */
  charity?: boolean;
  /**
   * The organization cashes checks for customers in amounts greater than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  cashesChecksMoreThan1000Usd?: boolean;
  /**
   * The organization derives income from internet gambling.
   * @type {boolean}
   * @memberof Regulatory
   */
  internetGamblingIncorporated?: boolean;
  /**
   * The organization derives income from marijuana or other drugs/controlled substances.
   * @type {boolean}
   * @memberof Regulatory
   */
  marijuanaBusiness?: boolean;
  /**
   * Individuals at the organization may request money orders of more than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  moneyOrderMoreThan1000Usd?: boolean;
  /**
   * The organization processes transactions on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  thirdPartyBenefit?: boolean;
  /**
   * The organization transmits funds on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  transmitBehalfOfCustomer?: boolean;
  /**
   * The organization administers or exchanges virtual currency.
   * @type {boolean}
   * @memberof Regulatory
   */
  virtualCurrency?: boolean;
  /**
   * A list of intermediary/non-bank financial institution services provided the organization performs on behalf of others.
   * @type {Array<IntermediaryServices>}
   * @memberof Regulatory
   */
  intermediaryServices?: Array<IntermediaryServices>;
  /**
   * If `true`, the organization is subject to tax withholdings.
   * @type {boolean}
   * @memberof Regulatory
   */
  subjectToWithholdings?: boolean;
}

/**
 * The value associated with this regulatory property.
 * @export
 * @interface RegulatoryValue
 */
export interface RegulatoryValue {}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Basic contact and identification information for a person, consisting of the name, mailing address, phone numbers, email addresses, and government identification.
 * @export
 * @interface SimpleContact
 */
export interface SimpleContact
  extends ContactName,
    Addresses,
    EmailAddresses,
    PhoneNumbers,
    SimpleContactFields {}

/**
 * Additional properties for a person or contact.
 * @export
 * @interface SimpleContactFields
 */
export interface SimpleContactFields {
  /**
   * A title or honorific prefix such as Dr. or Fr.
   * @type {string}
   * @memberof SimpleContactFields
   */
  prefix?: string;
  /**
   * A title or honorific suffix such as PhD or DDS.
   * @type {string}
   * @memberof SimpleContactFields
   */
  suffix?: string;
  /**
   * The contact's preferred name. This is how the contact's name is presented to the user in the interface. The default is the contact's `firstName`.
   * @type {string}
   * @memberof SimpleContactFields
   */
  preferredName?: string;
  /**
   * A collection of official identifying information associated with the contact.
   * @type {Array<Identification>}
   * @memberof SimpleContactFields
   */
  identification?: Array<Identification>;
  /**
   * The contact's preferred method of communication.
   * @type {PreferredContactMethod}
   * @memberof SimpleContactFields
   */
  preferredContactMethod?: PreferredContactMethod;
}

/**
 * The simplest form of an organization.
 * @export
 * @interface SimpleOrganization
 */
export interface SimpleOrganization {
  /**
   * The organization's official full name
   * @type {string}
   * @memberof SimpleOrganization
   */
  name?: string;
  /**
   * The organization's common name.
   * @type {string}
   * @memberof SimpleOrganization
   */
  label?: string;
  /**
   * Indicates what type of organization this resource represents.   The enumeration values are described by the `organizationType` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  type?: string;
  /**
   * A refinement of the `type`.   The enumeration values are described by the `organizationSubtype` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  subtype?: string;
  /**
   * A collection of official identifying information associated with the organization. This currently only supports government tax ID.
   * @type {Array<OrganizationIdentification>}
   * @memberof SimpleOrganization
   */
  identification?: Array<OrganizationIdentification>;
  /**
   * An array containing address items.
   * @type {Array<OrganizationAddress>}
   * @memberof SimpleOrganization
   */
  addresses?: Array<OrganizationAddress>;
  /**
   * An array of phone numbers associated with the organization. The first item, if present, is the default (preferred) organization phone number.
   * @type {Array<OrganizationPhoneNumber>}
   * @memberof SimpleOrganization
   */
  phones?: Array<OrganizationPhoneNumber>;
  /**
   * An array of email addresses associated with the organization. The first item, if present, is the default (preferred) organization email.
   * @type {Array<OrganizationEmailAddress>}
   * @memberof SimpleOrganization
   */
  emailAddresses?: Array<OrganizationEmailAddress>;
  /**
   * The ID of the organization's preferred email address. This string is the `_id` of an email address in the `emailAddresses` array. This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredEmailAddressId?: string;
  /**
   * The ID of organization's preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredPhoneId?: string;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredMailingAddressId?: string;
  /**
   * The date the organization was established.
   * @type {string}
   * @memberof SimpleOrganization
   */
  establishedDate?: string;
}

/**
 * Summary representation of an account resource in accounts collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.   By default, not all account fields are set when paging through accounts via the collection. The following fields are not set unless the collection request includes `?fields=*`:    * `balance`   * `interest`   * `cd`   Additionally, the `summaryAccount` representation does not support the full set of links or the nested owners, beneficiaries, and authorized signers available in the `account` schema returned by the [`getAccount`](#op-getAccount) operation (`GET /accounts/{accountId}`).
 * @export
 * @interface SummaryAccount
 */
export interface SummaryAccount extends AbstractResource, AccountFields {
  /**
   * The account's rates of return (for deposit account) or interest rate (for debit accounts).
   * @type {SummaryInterestRates}
   * @memberof SummaryAccount
   */
  rates?: SummaryInterestRates;
}

/**
 * @export
 * @namespace SummaryAccount
 */
export namespace SummaryAccount {}

/**
 * Summary representation of an external account resource in external accounts collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryExternalAccount
 */
export interface SummaryExternalAccount extends AbstractResource, SummaryExternalAccountFields {
  /**
   * The unique identifier for this external account resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryExternalAccount
   */
  _id?: string;
  /**
   * The date-time when the external account was created. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339)format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof SummaryExternalAccount
   */
  createdAt?: Date;
  /**
   * The masked and full account number
   * @type {ExternalAccountNumbers}
   * @memberof SummaryExternalAccount
   */
  accountNumbers?: ExternalAccountNumbers;
  /**
   * Embedded objects.
   * @type {ExternalAccountEmbeddedObjects}
   * @memberof SummaryExternalAccount
   */
  _embedded?: ExternalAccountEmbeddedObjects;
}

/**
 * Fields of the representation of an external account summary resource.
 * @export
 * @interface SummaryExternalAccountFields
 */
export interface SummaryExternalAccountFields {
  /**
   * The user-assigned name of this external account
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  name?: string;
  /**
   * The user-assigned description of this external account.
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  description?: string;
  /**
   * The name of the financial institution.
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  institutionName?: string;
  /**
   * The primary user or owner of the external account.
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  primaryUserName?: string;
  /**
   * The name of the account holder. This is derived from the user resource.
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  title?: string;
  /**
   * The type of account.  This is the name of an external product type associated with this external account. (The product type is defined in the Products API.)
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  type?: string;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof SummaryExternalAccountFields
   */
  ifxType?: IfxType;
  /**
   * The account routing number which identifies the financial institution. The full routing number and full account number are required to fully identify the account.
   * @type {string}
   * @memberof SummaryExternalAccountFields
   */
  routingNumber?: string;
  /**
   * The state of the external account.
   * @type {ExternalAccountState}
   * @memberof SummaryExternalAccountFields
   */
  state?: ExternalAccountState;
  /**
   * The date-time when the external account was most recently verified. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339) format, UTC.
   * @type {Date}
   * @memberof SummaryExternalAccountFields
   */
  verifiedAt?: Date;
  /**
   * An optional map of name/value pairs which contains additional dynamic data about the resource.
   * @type {{ [key: string]: AttributeValue; }}
   * @memberof SummaryExternalAccountFields
   */
  attributes?: { [key: string]: AttributeValue };
}

/**
 * The interest rates of the account summary. For deposit accounts, the rates describe the rate of return; for loan accounts, this includes the interest rate charged on balances. The values are percentages, expressed as strings containing a decimal percentage in order to represent the rate exactly. Rates are typically coded to 3 decimal places, but may have more. For example, `\"1.450\"` means 1.45%.
 * @export
 * @interface SummaryInterestRates
 */
export interface SummaryInterestRates {
  /**
   * The annual percentage yield (APY), the effective yield from interest, including compounding, as a percentage.
   * @type {string}
   * @memberof SummaryInterestRates
   */
  apy?: string;
  /**
   * The interest rate that is effective as of the current day. This is the rate before accounting for inflation.
   * @type {string}
   * @memberof SummaryInterestRates
   */
  nominal?: string;
  /**
   * The APY of a new bump rate offered by the financial institution. This property exists if and only if the associated deposit product offers a new bumped APY rate, typically only on CD time-deposit accounts that normally have an APY that is fixed for the term of the CD. The user can accept this APY increase offer via the [`bumpApyRate`](#op-bumpApyRate) operation.
   * @type {string}
   * @memberof SummaryInterestRates
   */
  bumpToApy?: string;
  /**
   * The base annual percentage rate (APR); typically present on loan accounts.
   * @type {string}
   * @memberof SummaryInterestRates
   */
  apr?: string;
}

/**
 * Summary representation of an organization resource in organizations collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryOrganization
 */
export interface SummaryOrganization extends AbstractResource, OrganizationFields {
  /**
   * The unique identifier for this organization resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryOrganization
   */
  _id?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the organization in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Organizations API).
   * @type {string}
   * @memberof SummaryOrganization
   */
  customerId?: string;
}

/**
 * Summary representation of a product resource in products collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. This representation omits the `attributes` of the full representation.  This schema is version `v1.0.0`.
 * @export
 * @interface SummaryProduct
 */
export interface SummaryProduct extends AbstractResource, ProductFields, RevisionEffectiveInterval {
  /**
   * The unique identifier for this product resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryProduct
   */
  _id?: string;
  /**
   * The product type name, which is derived from the linked product type.
   * @type {string}
   * @memberof SummaryProduct
   */
  type?: string;
  /**
   * The product subtype name, which is derived from the linked product subtype. This is a derived, immutable property.
   * @type {string}
   * @memberof SummaryProduct
   */
  subtype?: string;
  /**
   *
   * @type {TimeDeposit}
   * @memberof SummaryProduct
   */
  timeDeposit?: TimeDeposit;
  /**
   *
   * @type {Constraints}
   * @memberof SummaryProduct
   */
  constraints?: Constraints;
}

/**
 * Properties of time deposit products, primarily Certificate of Deposit products.  This schema is version `v1.0.0`.
 * @export
 * @interface TimeDeposit
 */
export interface TimeDeposit {
  /**
   *
   * @type {MaturityPolicy}
   * @memberof TimeDeposit
   */
  maturityPolicy?: MaturityPolicy;
  /**
   * The minimum maturity term offered by this product, for products such as certificates of deposits. See also `maximumTerm` For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  minimumTerm?: string;
  /**
   * The maximum maturity term offered by this product, for products such as certificates of deposits. If omitted, there is no fixed term (not all product types impose a term). For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  maximumTerm?: string;
  /**
   * The time period in which additional deposits may be made to a CD after it has rolled over after maturity. This value applies only if the `depositsAllowed` is `duringGracePeriod`. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days.
   * @type {string}
   * @memberof TimeDeposit
   */
  fees?: string;
}

/**
 * A string which defines a transaction type allowed for an account.   * *`credit`* : Credits may be posted to this account, such as transfer funds _to_ this external account.   * *`debit`* : Debits may be posted to this account, such as transfer funds _from_ this external account. Labels and descriptions for the enumeration values are in the `transactionType` key in the response of the `getLabels` operation.  <strong><code>transactionType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named transactionType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `transactionType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>debit</code></strong></td><td>A transaction which descreases an account's balance</td>     </tr> <tr>     <td><strong><code>credit</code></strong></td><td>A transaction which increases an accounts's balance</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum TransactionType {
  Debit = 'debit',
  Credit = 'credit',
}

/**
 * An array which lists which transaction types are allowed for an account.  This schema is version `v1.0.0`.
 * @export
 * @interface TransactionTypes
 */
export interface TransactionTypes {}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * Properties required to update a product on an account.
 * @export
 * @interface UpdateAccountProduct
 */
export interface UpdateAccountProduct extends AbstractRequest {
  /**
   * The ID of the banking product that this account is converted to. This is the `_id` from a product or product summary object.
   * @type {string}
   * @memberof UpdateAccountProduct
   */
  productId: string;
  /**
   * The id of the user's most recent consent for the new product. This is the `_id` of the consent resource whose `targetUri` is the terms and conditions document for the selected product.
   * @type {string}
   * @memberof UpdateAccountProduct
   */
  consentId: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:    * **`apiture:accounts`** : links to the   collection of accounts held at this financial institution.   * **`apiture:externalAccounts`** : links to the collection of external   accounts held at other financial institutions.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:    * **`apiture:accounts`** : links to the   collection of accounts held at this financial institution.   * **`apiture:externalAccounts`** : links to the collection of external   accounts held at other financial institutions.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: LocalizedLabel }> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:    * **`apiture:accounts`** : links to the   collection of accounts held at this financial institution.   * **`apiture:externalAccounts`** : links to the collection of external   accounts held at other financial institutions.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. This API returns the following links:    * **`apiture:accounts`** : links to the   collection of accounts held at this financial institution.   * **`apiture:externalAccounts`** : links to the collection of external   accounts held at other financial institutions.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LocalizedLabel}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AccountApi - axios parameter creator
 * @export
 */
export const AccountApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate an account that is eligible to be activated. Only internal accounts which are `pending` or `inactive` or `frozen` may be activated. External accounts which are `pending`, `verifying`, `inactive`, `frozen`, `underReview`, or `closed` may be activated. Activating `frozen` accounts or `underReview` external accounts is only allowed for administrators. This operation is invoked from the `apiture:activate` link on an account, which only exists if the action is allowed. This changes the `state` to `active`.
     * @summary Activate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling activateAccount.',
        );
      }
      const localVarPath = `/activeAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * On some banking products (CD or time-deposit accounts), the financial institution (Financial Institution) may offer a new rate in the `rates.bumpToApy` property. The user can either accept that offer or defer accepting the offer in anticipation of a better APY offer in the future. **Note**: The FI may restrict the user to only one rate increase per term.  The client should call this operation when the user elects to accept the APY offer. There is no additional confirmation of this action; the new rate becomes effective and future rate bumps may not be allowed during the remainder of this account's term. The APY rate that was in effect before bump becomes the `rates.originalApy`, the `rates.bumpToApy` becomes the new `apy`, and `rates.bumpToApy` is dropped from the `rates`. The account's `cd.apyBumpedAt` records when the user accepted the bumped rate.  If and only if a new APY offer is available, this operation is listed in the accounts `_links` with the link relation `apiture:bumpApyRate`.
     * @summary Bump the account's APY rate
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    bumpApyRate(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling bumpApyRate.',
        );
      }
      const localVarPath = `/bumpedApyAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Close an account that is eligible to be closed.  Only accounts which are `active` or `inactive` or `frozen` may be closed. This operation is invoked from the `apiture:close` link on an account; the link only exists if the action is allowed. This changes the `state` to `closed`. Closing an account will append the text \"` (Closed YYYY-MM-DDThh:mm:ssZ)`\" to the name, so that the previous name may be used for other accounts.
     * @summary Close an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    closeAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling closeAccount.',
        );
      }
      const localVarPath = `/closedAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new banking account. The request body must contain a link to an active product, user, organization (for a business account), and may contain an approved application. The required resource links are detailed in the `createAccount` schema used for the request body. The application will be linked to the account and can be identifiable with the account. The product provides specific banking information like the type of product and it's subtype; the new account will adopt the terms and attributes of that banking product. If a name is not included in the request, the product name will be used to provide a unique name for this user. The account will be created in the `pending` state (which allows deletion of the account). A successful operation returns the full account number.
     * @summary Create a new account.
     * @param {CreateAccount} CreateAccount The data necessary to create a new account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAccount(CreateAccount: CreateAccount, options: any = {}): RequestArgs {
      // verify required parameter 'CreateAccount' is not null or undefined
      if (CreateAccount === null || CreateAccount === undefined) {
        throw new RequiredError(
          'CreateAccount',
          'Required parameter CreateAccount was null or undefined when calling createAccount.',
        );
      }
      const localVarPath = `/accounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateAccount' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateAccount || {})
        : CreateAccount || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate an account that is eligible to be deactivated. Only accounts which are `pending` or `active` may be deactivated. This operation is invoked from the `apiture:deactivate` link on an account; the link only exists if the action is allowed. This changes the `state` to `inactive`. Financial Institution administrators can activate an inactive account with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Deactivate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling deactivateAccount.',
        );
      }
      const localVarPath = `/inactiveAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or closed.
     * @summary Delete this account resource
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAccount(
      accountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling deleteAccount.',
        );
      }
      const localVarPath = `/accounts/{accountId}`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Freeze an account that is eligible to be frozen. Only accounts which are `active` or `inactive` may be frozen. This operation is invoked from the `apiture:freeze` link on an account; the link only exists if the action is allowed. This changes the `state` to `frozen`. Financial Institution administrators can unfreeze accounts with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Freeze an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling freezeAccount.',
        );
      }
      const localVarPath = `/frozenAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Generate the account verification letter for this internal account.   If the letter has not been generated, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the letter has been generated for this account, the operations returns 200 OK and the response body is the PDF formatted account verification letter.   For personal accounts, only the primary and joint owners may invoke this operation.   For business accounts, only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate the account verification letter
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateVerificationLetter(
      accountId: string,
      headers?: { Accept?: string },
      options: any = {},
    ): RequestArgs {
      const { Accept } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling generateVerificationLetter.',
        );
      }
      const localVarPath = `/accounts/{accountId}/verificationLetter`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept !== undefined && Accept !== null) {
        localVarHeaderParameter['Accept'] = String(Accept);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account resource.
     * @summary Fetch a representation of this account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;beneficiaries&#x60; : include the account beneficiaries (for &#x60;personal&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;authorizedSigners&#x60; : include the account authorized signers of the owning business (for &#x60;business&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;product&#x60; : include the banking product for this account. This is the default for &#x60;embed&#x60; if omitted, but if &#x60;embed&#x60; is specified explicitly, include &#x60;products&#x60; if you want it embedded.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;owners&#x60; and &#x60;beneficiaries&#x60; for personal accounts use &#x60;GET .../accounts/{accountId}?embed&#x3D;owners,beneficiaries&#x60;. To embed the banking product, the owning business, authorized signers for business accounts, use &#x60;GET .../accounts/{accountId}?embed&#x3D;product,owners,authorizedSigners&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccount(
      accountId: string,
      query?: {
        unmasked?: boolean;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { unmasked, embed } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling getAccount.',
        );
      }
      const localVarPath = `/accounts/{accountId}`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  By default, the items in the collection return a subset of the accounts fields, as described in the `summaryAccount` schema. To include all fields in an account, use the `?fields=*` query parameter.  If `?embed=owners` is used, each summary account representation in the `_embedded.items` array will embed the account owners or the authorized signers and owning organization.
     * @summary Return a collection of accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.subtype] Subset the accounts or external accounts collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?subtype&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?subtype&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;Basic Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.productName] Subset the accounts collection to those with this &#x60;productName&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?productName&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?productName&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {string} [query.fields] Select which fields to include in each account in the collection&#39;s &#x60;_embedded.items&#x60; array. By default, a subset of all the fields in the account are returned (detailed in the &#x60;summaryAccount&#x60; schema). Use the value &#x60;*&#x60; to request all the fields in the account. Note that there is a performance impact of requesting this, since the account balance and interest (year to date) may require additional computation.
     * @param {string} [query.activeBetween] Limit the response to only accounts that are (or were) active between two dates, inclusive. The format of the query parameter is &#x60;start-date,end-date&#x60; where each date is in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, &#x60;YYYY-MM-DD&#x60;. The response includes accounts which became active on or before the end date and which were not closed before the start date. &lt;br&gt; Example: &#x60;?activeBetween&#x3D;2019-03-01,2019-03-31&#x60;. &lt;br&gt; This option may be combined with &#x60;?embed&#x3D;owners&#x60;. **Note**: _This option is limited to administrative use._
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] If set, each account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt; This option may be combined with &#x60;?activeBetween&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        subtype?: string;
        name?: string;
        productName?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        fields?: string;
        activeBetween?: string;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      options: any = {},
    ): RequestArgs {
      const {
        start,
        limit,
        sortBy,
        state,
        type,
        subtype,
        name,
        productName,
        filter,
        q,
        unmasked,
        fields,
        activeBetween,
        embed,
      } = query;

      const localVarPath = `/accounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (subtype !== undefined) {
        localVarQueryParameter['subtype'] = subtype;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (productName !== undefined) {
        localVarQueryParameter['productName'] = productName;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (fields !== undefined) {
        localVarQueryParameter['fields'] = fields;
      }

      if (activeBetween !== undefined) {
        localVarQueryParameter['activeBetween'] = activeBetween;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this account. Fields which are omitted from the request are not updated. Nested `_embedded` objects are ignored if included. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), or [`closeAccount`](#op-closeAccount) which are available in the `_links` on an account instance.
     * @summary Update this account
     * @param {Account} Account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAccount(
      Account: Account,
      accountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling patchAccount.',
        );
      }
      // verify required parameter 'Account' is not null or undefined
      if (Account === null || Account === undefined) {
        throw new RequiredError(
          'Account',
          'Required parameter Account was null or undefined when calling patchAccount.',
        );
      }
      const localVarPath = `/accounts/{accountId}`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Account' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Account || {})
        : Account || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Start micro-deposit verification for an external account. This operation moves an account with `state` of `failed` or `inactive` to the state of `microDepositsRequested`. This lets the user reuse an external account when instant account verification fails. The micro-deposit verification flow must be completed as described in the Account Verification API. This operation is available via the `apiture:requestMicroDepositVerification` link on an external account if this operation is valid. Only administrative or service applications may call this operation, not bank customers.
     * @summary Request micro-deposit verification
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    requestMicroDepositVerification(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling requestMicroDepositVerification.',
        );
      }
      const localVarPath = `/externalAccountsNeedingMicroDepositVerification`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Begin review of an account, if its state allows review. This changes the state to `underReview`. When an external account is under review, the financial institution reviews the account details and may approve or reject the account; this will set the state to `active` or `frozen`, respectively. Only accounts which are `verifying` may make this state transition, and review is normally triggered automatically if external account verification was successful and customer data does not match with the account's holders' information. This operation is invoked from the `apiture:review` link on an account, which only exists if the action is allowed to update an account state to under review. Only administrative or service applications may call this operation, not bank customers.
     * @summary The account is under review
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviewAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { account } = query;
      const { If_Match } = headers;

      // verify required parameter 'account' is not null or undefined
      if (account === null || account === undefined) {
        throw new RequiredError(
          'account',
          'Required parameter account was null or undefined when calling reviewAccount.',
        );
      }
      const localVarPath = `/externalAccountsUnderReview`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the account’s banking product. This applies only to personal and business CD accounts that are in their grace period (immediately following maturity). The new product must also be a CD product, and the account must satisfy the minimum and maximum balance and other constraints of the new product.
     * @summary Change the account's product
     * @param {UpdateAccountProduct} UpdateAccountProduct The data necessary to update a product on an account.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAccountProduct(
      UpdateAccountProduct: UpdateAccountProduct,
      accountId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling updateAccountProduct.',
        );
      }
      // verify required parameter 'UpdateAccountProduct' is not null or undefined
      if (UpdateAccountProduct === null || UpdateAccountProduct === undefined) {
        throw new RequiredError(
          'UpdateAccountProduct',
          'Required parameter UpdateAccountProduct was null or undefined when calling updateAccountProduct.',
        );
      }
      const localVarPath = `/accounts/{accountId}/product`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateAccountProduct' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateAccountProduct || {})
        : UpdateAccountProduct || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountApi - functional programming interface
 * @export
 */
export const AccountApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate an account that is eligible to be activated. Only internal accounts which are `pending` or `inactive` or `frozen` may be activated. External accounts which are `pending`, `verifying`, `inactive`, `frozen`, `underReview`, or `closed` may be activated. Activating `frozen` accounts or `underReview` external accounts is only allowed for administrators. This operation is invoked from the `apiture:activate` link on an account, which only exists if the action is allowed. This changes the `state` to `active`.
     * @summary Activate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).activateAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * On some banking products (CD or time-deposit accounts), the financial institution (Financial Institution) may offer a new rate in the `rates.bumpToApy` property. The user can either accept that offer or defer accepting the offer in anticipation of a better APY offer in the future. **Note**: The FI may restrict the user to only one rate increase per term.  The client should call this operation when the user elects to accept the APY offer. There is no additional confirmation of this action; the new rate becomes effective and future rate bumps may not be allowed during the remainder of this account's term. The APY rate that was in effect before bump becomes the `rates.originalApy`, the `rates.bumpToApy` becomes the new `apy`, and `rates.bumpToApy` is dropped from the `rates`. The account's `cd.apyBumpedAt` records when the user accepted the bumped rate.  If and only if a new APY offer is available, this operation is listed in the accounts `_links` with the link relation `apiture:bumpApyRate`.
     * @summary Bump the account's APY rate
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    bumpApyRate(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).bumpApyRate(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Close an account that is eligible to be closed.  Only accounts which are `active` or `inactive` or `frozen` may be closed. This operation is invoked from the `apiture:close` link on an account; the link only exists if the action is allowed. This changes the `state` to `closed`. Closing an account will append the text \"` (Closed YYYY-MM-DDThh:mm:ssZ)`\" to the name, so that the previous name may be used for other accounts.
     * @summary Close an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    closeAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).closeAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new banking account. The request body must contain a link to an active product, user, organization (for a business account), and may contain an approved application. The required resource links are detailed in the `createAccount` schema used for the request body. The application will be linked to the account and can be identifiable with the account. The product provides specific banking information like the type of product and it's subtype; the new account will adopt the terms and attributes of that banking product. If a name is not included in the request, the product name will be used to provide a unique name for this user. The account will be created in the `pending` state (which allows deletion of the account). A successful operation returns the full account number.
     * @summary Create a new account.
     * @param {CreateAccount} CreateAccount The data necessary to create a new account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAccount(
      CreateAccount: CreateAccount,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<SummaryAccount> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).createAccount(
        CreateAccount ? CreateAccount : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate an account that is eligible to be deactivated. Only accounts which are `pending` or `active` may be deactivated. This operation is invoked from the `apiture:deactivate` link on an account; the link only exists if the action is allowed. This changes the `state` to `inactive`. Financial Institution administrators can activate an inactive account with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Deactivate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).deactivateAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or closed.
     * @summary Delete this account resource
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAccount(
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).deleteAccount(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Freeze an account that is eligible to be frozen. Only accounts which are `active` or `inactive` may be frozen. This operation is invoked from the `apiture:freeze` link on an account; the link only exists if the action is allowed. This changes the `state` to `frozen`. Financial Institution administrators can unfreeze accounts with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Freeze an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).freezeAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Generate the account verification letter for this internal account.   If the letter has not been generated, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the letter has been generated for this account, the operations returns 200 OK and the response body is the PDF formatted account verification letter.   For personal accounts, only the primary and joint owners may invoke this operation.   For business accounts, only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate the account verification letter
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateVerificationLetter(
      accountId: string,
      headers?: { Accept?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(
        configuration,
      ).generateVerificationLetter(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account resource.
     * @summary Fetch a representation of this account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;beneficiaries&#x60; : include the account beneficiaries (for &#x60;personal&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;authorizedSigners&#x60; : include the account authorized signers of the owning business (for &#x60;business&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;product&#x60; : include the banking product for this account. This is the default for &#x60;embed&#x60; if omitted, but if &#x60;embed&#x60; is specified explicitly, include &#x60;products&#x60; if you want it embedded.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;owners&#x60; and &#x60;beneficiaries&#x60; for personal accounts use &#x60;GET .../accounts/{accountId}?embed&#x3D;owners,beneficiaries&#x60;. To embed the banking product, the owning business, authorized signers for business accounts, use &#x60;GET .../accounts/{accountId}?embed&#x3D;product,owners,authorizedSigners&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccount(
      accountId: string,
      query?: {
        unmasked?: boolean;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).getAccount(
        accountId ? accountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  By default, the items in the collection return a subset of the accounts fields, as described in the `summaryAccount` schema. To include all fields in an account, use the `?fields=*` query parameter.  If `?embed=owners` is used, each summary account representation in the `_embedded.items` array will embed the account owners or the authorized signers and owning organization.
     * @summary Return a collection of accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.subtype] Subset the accounts or external accounts collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?subtype&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?subtype&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;Basic Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.productName] Subset the accounts collection to those with this &#x60;productName&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?productName&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?productName&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {string} [query.fields] Select which fields to include in each account in the collection&#39;s &#x60;_embedded.items&#x60; array. By default, a subset of all the fields in the account are returned (detailed in the &#x60;summaryAccount&#x60; schema). Use the value &#x60;*&#x60; to request all the fields in the account. Note that there is a performance impact of requesting this, since the account balance and interest (year to date) may require additional computation.
     * @param {string} [query.activeBetween] Limit the response to only accounts that are (or were) active between two dates, inclusive. The format of the query parameter is &#x60;start-date,end-date&#x60; where each date is in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, &#x60;YYYY-MM-DD&#x60;. The response includes accounts which became active on or before the end date and which were not closed before the start date. &lt;br&gt; Example: &#x60;?activeBetween&#x3D;2019-03-01,2019-03-31&#x60;. &lt;br&gt; This option may be combined with &#x60;?embed&#x3D;owners&#x60;. **Note**: _This option is limited to administrative use._
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] If set, each account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt; This option may be combined with &#x60;?activeBetween&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        subtype?: string;
        name?: string;
        productName?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        fields?: string;
        activeBetween?: string;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Accounts> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).getAccounts(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this account. Fields which are omitted from the request are not updated. Nested `_embedded` objects are ignored if included. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), or [`closeAccount`](#op-closeAccount) which are available in the `_links` on an account instance.
     * @summary Update this account
     * @param {Account} Account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAccount(
      Account: Account,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).patchAccount(
        Account ? Account : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Start micro-deposit verification for an external account. This operation moves an account with `state` of `failed` or `inactive` to the state of `microDepositsRequested`. This lets the user reuse an external account when instant account verification fails. The micro-deposit verification flow must be completed as described in the Account Verification API. This operation is available via the `apiture:requestMicroDepositVerification` link on an external account if this operation is valid. Only administrative or service applications may call this operation, not bank customers.
     * @summary Request micro-deposit verification
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    requestMicroDepositVerification(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(
        configuration,
      ).requestMicroDepositVerification(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Begin review of an account, if its state allows review. This changes the state to `underReview`. When an external account is under review, the financial institution reviews the account details and may approve or reject the account; this will set the state to `active` or `frozen`, respectively. Only accounts which are `verifying` may make this state transition, and review is normally triggered automatically if external account verification was successful and customer data does not match with the account's holders' information. This operation is invoked from the `apiture:review` link on an account, which only exists if the action is allowed to update an account state to under review. Only administrative or service applications may call this operation, not bank customers.
     * @summary The account is under review
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviewAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).reviewAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the account’s banking product. This applies only to personal and business CD accounts that are in their grace period (immediately following maturity). The new product must also be a CD product, and the account must satisfy the minimum and maximum balance and other constraints of the new product.
     * @summary Change the account's product
     * @param {UpdateAccountProduct} UpdateAccountProduct The data necessary to update a product on an account.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAccountProduct(
      UpdateAccountProduct: UpdateAccountProduct,
      accountId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Account> {
      const localVarAxiosArgs = AccountApiAxiosParamCreator(configuration).updateAccountProduct(
        UpdateAccountProduct ? UpdateAccountProduct : null,
        accountId ? accountId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountApi - factory interface
 * @export
 */
export const AccountApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate an account that is eligible to be activated. Only internal accounts which are `pending` or `inactive` or `frozen` may be activated. External accounts which are `pending`, `verifying`, `inactive`, `frozen`, `underReview`, or `closed` may be activated. Activating `frozen` accounts or `underReview` external accounts is only allowed for administrators. This operation is invoked from the `apiture:activate` link on an account, which only exists if the action is allowed. This changes the `state` to `active`.
     * @summary Activate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateAccount(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).activateAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * On some banking products (CD or time-deposit accounts), the financial institution (Financial Institution) may offer a new rate in the `rates.bumpToApy` property. The user can either accept that offer or defer accepting the offer in anticipation of a better APY offer in the future. **Note**: The FI may restrict the user to only one rate increase per term.  The client should call this operation when the user elects to accept the APY offer. There is no additional confirmation of this action; the new rate becomes effective and future rate bumps may not be allowed during the remainder of this account's term. The APY rate that was in effect before bump becomes the `rates.originalApy`, the `rates.bumpToApy` becomes the new `apy`, and `rates.bumpToApy` is dropped from the `rates`. The account's `cd.apyBumpedAt` records when the user accepted the bumped rate.  If and only if a new APY offer is available, this operation is listed in the accounts `_links` with the link relation `apiture:bumpApyRate`.
     * @summary Bump the account's APY rate
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    bumpApyRate(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).bumpApyRate(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Close an account that is eligible to be closed.  Only accounts which are `active` or `inactive` or `frozen` may be closed. This operation is invoked from the `apiture:close` link on an account; the link only exists if the action is allowed. This changes the `state` to `closed`. Closing an account will append the text \"` (Closed YYYY-MM-DDThh:mm:ssZ)`\" to the name, so that the previous name may be used for other accounts.
     * @summary Close an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    closeAccount(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).closeAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new banking account. The request body must contain a link to an active product, user, organization (for a business account), and may contain an approved application. The required resource links are detailed in the `createAccount` schema used for the request body. The application will be linked to the account and can be identifiable with the account. The product provides specific banking information like the type of product and it's subtype; the new account will adopt the terms and attributes of that banking product. If a name is not included in the request, the product name will be used to provide a unique name for this user. The account will be created in the `pending` state (which allows deletion of the account). A successful operation returns the full account number.
     * @summary Create a new account.
     * @param {CreateAccount} CreateAccount The data necessary to create a new account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAccount(CreateAccount: CreateAccount, options?: any) {
      return AccountApiFp(configuration).createAccount(
        CreateAccount ? CreateAccount : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate an account that is eligible to be deactivated. Only accounts which are `pending` or `active` may be deactivated. This operation is invoked from the `apiture:deactivate` link on an account; the link only exists if the action is allowed. This changes the `state` to `inactive`. Financial Institution administrators can activate an inactive account with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Deactivate an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateAccount(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApiFp(configuration).deactivateAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or closed.
     * @summary Delete this account resource
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAccount(accountId: string, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).deleteAccount(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Freeze an account that is eligible to be frozen. Only accounts which are `active` or `inactive` may be frozen. This operation is invoked from the `apiture:freeze` link on an account; the link only exists if the action is allowed. This changes the `state` to `frozen`. Financial Institution administrators can unfreeze accounts with the [`activateAccount`](#op-activateAccount) operation.
     * @summary Freeze an account
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeAccount(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).freezeAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Generate the account verification letter for this internal account.   If the letter has not been generated, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the letter has been generated for this account, the operations returns 200 OK and the response body is the PDF formatted account verification letter.   For personal accounts, only the primary and joint owners may invoke this operation.   For business accounts, only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate the account verification letter
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateVerificationLetter(accountId: string, headers?: { Accept?: string }, options?: any) {
      return AccountApiFp(configuration).generateVerificationLetter(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account resource.
     * @summary Fetch a representation of this account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;beneficiaries&#x60; : include the account beneficiaries (for &#x60;personal&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;authorizedSigners&#x60; : include the account authorized signers of the owning business (for &#x60;business&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;product&#x60; : include the banking product for this account. This is the default for &#x60;embed&#x60; if omitted, but if &#x60;embed&#x60; is specified explicitly, include &#x60;products&#x60; if you want it embedded.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;owners&#x60; and &#x60;beneficiaries&#x60; for personal accounts use &#x60;GET .../accounts/{accountId}?embed&#x3D;owners,beneficiaries&#x60;. To embed the banking product, the owning business, authorized signers for business accounts, use &#x60;GET .../accounts/{accountId}?embed&#x3D;product,owners,authorizedSigners&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccount(
      accountId: string,
      query?: {
        unmasked?: boolean;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AccountApiFp(configuration).getAccount(
        accountId ? accountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  By default, the items in the collection return a subset of the accounts fields, as described in the `summaryAccount` schema. To include all fields in an account, use the `?fields=*` query parameter.  If `?embed=owners` is used, each summary account representation in the `_embedded.items` array will embed the account owners or the authorized signers and owning organization.
     * @summary Return a collection of accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.subtype] Subset the accounts or external accounts collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?subtype&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?subtype&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;Basic Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.productName] Subset the accounts collection to those with this &#x60;productName&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?productName&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?productName&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {string} [query.fields] Select which fields to include in each account in the collection&#39;s &#x60;_embedded.items&#x60; array. By default, a subset of all the fields in the account are returned (detailed in the &#x60;summaryAccount&#x60; schema). Use the value &#x60;*&#x60; to request all the fields in the account. Note that there is a performance impact of requesting this, since the account balance and interest (year to date) may require additional computation.
     * @param {string} [query.activeBetween] Limit the response to only accounts that are (or were) active between two dates, inclusive. The format of the query parameter is &#x60;start-date,end-date&#x60; where each date is in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, &#x60;YYYY-MM-DD&#x60;. The response includes accounts which became active on or before the end date and which were not closed before the start date. &lt;br&gt; Example: &#x60;?activeBetween&#x3D;2019-03-01,2019-03-31&#x60;. &lt;br&gt; This option may be combined with &#x60;?embed&#x3D;owners&#x60;. **Note**: _This option is limited to administrative use._
     * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] If set, each account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt; This option may be combined with &#x60;?activeBetween&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        subtype?: string;
        name?: string;
        productName?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        fields?: string;
        activeBetween?: string;
        embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
      },
      options?: any,
    ) {
      return AccountApiFp(configuration).getAccounts(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this account. Fields which are omitted from the request are not updated. Nested `_embedded` objects are ignored if included. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), or [`closeAccount`](#op-closeAccount) which are available in the `_links` on an account instance.
     * @summary Update this account
     * @param {Account} Account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchAccount(
      Account: Account,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApiFp(configuration).patchAccount(
        Account ? Account : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Start micro-deposit verification for an external account. This operation moves an account with `state` of `failed` or `inactive` to the state of `microDepositsRequested`. This lets the user reuse an external account when instant account verification fails. The micro-deposit verification flow must be completed as described in the Account Verification API. This operation is available via the `apiture:requestMicroDepositVerification` link on an external account if this operation is valid. Only administrative or service applications may call this operation, not bank customers.
     * @summary Request micro-deposit verification
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    requestMicroDepositVerification(
      query?: { account?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApiFp(configuration).requestMicroDepositVerification(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Begin review of an account, if its state allows review. This changes the state to `underReview`. When an external account is under review, the financial institution reviews the account details and may approve or reject the account; this will set the state to `active` or `frozen`, respectively. Only accounts which are `verifying` may make this state transition, and review is normally triggered automatically if external account verification was successful and customer data does not match with the account's holders' information. This operation is invoked from the `apiture:review` link on an account, which only exists if the action is allowed to update an account state to under review. Only administrative or service applications may call this operation, not bank customers.
     * @summary The account is under review
     * @param {Object} [query] Query object
     * @param {string} [query.account] A server-supplied value which identifies the account instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    reviewAccount(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
      return AccountApiFp(configuration).reviewAccount(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Change the account’s banking product. This applies only to personal and business CD accounts that are in their grace period (immediately following maturity). The new product must also be a CD product, and the account must satisfy the minimum and maximum balance and other constraints of the new product.
     * @summary Change the account's product
     * @param {UpdateAccountProduct} UpdateAccountProduct The data necessary to update a product on an account.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAccountProduct(
      UpdateAccountProduct: UpdateAccountProduct,
      accountId: string,
      options?: any,
    ) {
      return AccountApiFp(configuration).updateAccountProduct(
        UpdateAccountProduct ? UpdateAccountProduct : null,
        accountId ? accountId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountApi - object-oriented interface
 * @export
 * @class AccountApi
 * @extends {BaseAPI}
 */
export class AccountApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate an account that is eligible to be activated. Only internal accounts which are `pending` or `inactive` or `frozen` may be activated. External accounts which are `pending`, `verifying`, `inactive`, `frozen`, `underReview`, or `closed` may be activated. Activating `frozen` accounts or `underReview` external accounts is only allowed for administrators. This operation is invoked from the `apiture:activate` link on an account, which only exists if the action is allowed. This changes the `state` to `active`.
   * @summary Activate an account
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public activateAccount(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).activateAccount(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * On some banking products (CD or time-deposit accounts), the financial institution (Financial Institution) may offer a new rate in the `rates.bumpToApy` property. The user can either accept that offer or defer accepting the offer in anticipation of a better APY offer in the future. **Note**: The FI may restrict the user to only one rate increase per term.  The client should call this operation when the user elects to accept the APY offer. There is no additional confirmation of this action; the new rate becomes effective and future rate bumps may not be allowed during the remainder of this account's term. The APY rate that was in effect before bump becomes the `rates.originalApy`, the `rates.bumpToApy` becomes the new `apy`, and `rates.bumpToApy` is dropped from the `rates`. The account's `cd.apyBumpedAt` records when the user accepted the bumped rate.  If and only if a new APY offer is available, this operation is listed in the accounts `_links` with the link relation `apiture:bumpApyRate`.
   * @summary Bump the account's APY rate
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public bumpApyRate(query?: { account?: string }, headers?: { If_Match?: string }, options?: any) {
    return AccountApiFp(this.configuration).bumpApyRate(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Close an account that is eligible to be closed.  Only accounts which are `active` or `inactive` or `frozen` may be closed. This operation is invoked from the `apiture:close` link on an account; the link only exists if the action is allowed. This changes the `state` to `closed`. Closing an account will append the text \"` (Closed YYYY-MM-DDThh:mm:ssZ)`\" to the name, so that the previous name may be used for other accounts.
   * @summary Close an account
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public closeAccount(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).closeAccount(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new banking account. The request body must contain a link to an active product, user, organization (for a business account), and may contain an approved application. The required resource links are detailed in the `createAccount` schema used for the request body. The application will be linked to the account and can be identifiable with the account. The product provides specific banking information like the type of product and it's subtype; the new account will adopt the terms and attributes of that banking product. If a name is not included in the request, the product name will be used to provide a unique name for this user. The account will be created in the `pending` state (which allows deletion of the account). A successful operation returns the full account number.
   * @summary Create a new account.
   * @param {CreateAccount} CreateAccount The data necessary to create a new account.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {SummaryAccount}
   * @memberof AccountApi
   */
  public createAccount(CreateAccount: CreateAccount, options?: any) {
    return AccountApiFp(this.configuration).createAccount(
      CreateAccount ? CreateAccount : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate an account that is eligible to be deactivated. Only accounts which are `pending` or `active` may be deactivated. This operation is invoked from the `apiture:deactivate` link on an account; the link only exists if the action is allowed. This changes the `state` to `inactive`. Financial Institution administrators can activate an inactive account with the [`activateAccount`](#op-activateAccount) operation.
   * @summary Deactivate an account
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public deactivateAccount(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).deactivateAccount(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or closed.
   * @summary Delete this account resource
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AccountApi
   */
  public deleteAccount(accountId: string, headers?: { If_Match?: string }, options?: any) {
    return AccountApiFp(this.configuration).deleteAccount(
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Freeze an account that is eligible to be frozen. Only accounts which are `active` or `inactive` may be frozen. This operation is invoked from the `apiture:freeze` link on an account; the link only exists if the action is allowed. This changes the `state` to `frozen`. Financial Institution administrators can unfreeze accounts with the [`activateAccount`](#op-activateAccount) operation.
   * @summary Freeze an account
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public freezeAccount(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).freezeAccount(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Generate the account verification letter for this internal account.   If the letter has not been generated, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the letter has been generated for this account, the operations returns 200 OK and the response body is the PDF formatted account verification letter.   For personal accounts, only the primary and joint owners may invoke this operation.   For business accounts, only the authorized signers associated with the owning business organization may invoke this operation.
   * @summary Generate the account verification letter
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AccountApi
   */
  public generateVerificationLetter(
    accountId: string,
    headers?: { Accept?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).generateVerificationLetter(
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account resource.
   * @summary Fetch a representation of this account
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.)&lt;/li&gt; &lt;li&gt;&#x60;beneficiaries&#x60; : include the account beneficiaries (for &#x60;personal&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;authorizedSigners&#x60; : include the account authorized signers of the owning business (for &#x60;business&#x60; accounts).&lt;/li&gt; &lt;li&gt;&#x60;product&#x60; : include the banking product for this account. This is the default for &#x60;embed&#x60; if omitted, but if &#x60;embed&#x60; is specified explicitly, include &#x60;products&#x60; if you want it embedded.&lt;/li&gt; &lt;/ul&gt; For example, to embed both the &#x60;owners&#x60; and &#x60;beneficiaries&#x60; for personal accounts use &#x60;GET .../accounts/{accountId}?embed&#x3D;owners,beneficiaries&#x60;. To embed the banking product, the owning business, authorized signers for business accounts, use &#x60;GET .../accounts/{accountId}?embed&#x3D;product,owners,authorizedSigners&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public getAccount(
    accountId: string,
    query?: {
      unmasked?: boolean;
      embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
    },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).getAccount(
      accountId ? accountId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  By default, the items in the collection return a subset of the accounts fields, as described in the `summaryAccount` schema. To include all fields in an account, use the `?fields=*` query parameter.  If `?embed=owners` is used, each summary account representation in the `_embedded.items` array will embed the account owners or the authorized signers and owning organization.
   * @summary Return a collection of accounts
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first account item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of account representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.subtype] Subset the accounts or external accounts collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?subtype&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?subtype&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;subtype&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;Basic Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.productName] Subset the accounts collection to those with this &#x60;productName&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?productName&#x3D;Basic%20Personal%20Savings&#x60; matches only items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60;; &#x60;?productName&#x3D;Basic%20Personal%20Savings|Basic%20Investment%20Account&#x60; matches items whose &#x60;productName&#x60; is &#x60;Basic Personal Savings&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {string} [query.fields] Select which fields to include in each account in the collection&#39;s &#x60;_embedded.items&#x60; array. By default, a subset of all the fields in the account are returned (detailed in the &#x60;summaryAccount&#x60; schema). Use the value &#x60;*&#x60; to request all the fields in the account. Note that there is a performance impact of requesting this, since the account balance and interest (year to date) may require additional computation.
   * @param {string} [query.activeBetween] Limit the response to only accounts that are (or were) active between two dates, inclusive. The format of the query parameter is &#x60;start-date,end-date&#x60; where each date is in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format, &#x60;YYYY-MM-DD&#x60;. The response includes accounts which became active on or before the end date and which were not closed before the start date. &lt;br&gt; Example: &#x60;?activeBetween&#x3D;2019-03-01,2019-03-31&#x60;. &lt;br&gt; This option may be combined with &#x60;?embed&#x3D;owners&#x60;. **Note**: _This option is limited to administrative use._
   * @param {Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>} [query.embed] If set, each account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for &#x60;personal&#x60; accounts, include the account owners in the &#x60;_embedded.owners&#x60; object; for business accounts, include authorized signers in the &#x60;_embedded.owners&#x60; object and the owning business in the &#x60;_embedded.owningBusiness&#x60; object. (See the &#x60;embeddedAccountObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt; This option may be combined with &#x60;?activeBetween&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Accounts}
   * @memberof AccountApi
   */
  public getAccounts(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
      type?: string;
      subtype?: string;
      name?: string;
      productName?: string;
      filter?: string;
      q?: string;
      unmasked?: boolean;
      fields?: string;
      activeBetween?: string;
      embed?: Array<'owners' | 'beneficiaries' | 'authorizedSigners' | 'product'>;
    },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).getAccounts(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a partial update of this account. Fields which are omitted from the request are not updated. Nested `_embedded` objects are ignored if included. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), or [`closeAccount`](#op-closeAccount) which are available in the `_links` on an account instance.
   * @summary Update this account
   * @param {Account} Account
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public patchAccount(
    Account: Account,
    accountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).patchAccount(
      Account ? Account : null,
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Start micro-deposit verification for an external account. This operation moves an account with `state` of `failed` or `inactive` to the state of `microDepositsRequested`. This lets the user reuse an external account when instant account verification fails. The micro-deposit verification flow must be completed as described in the Account Verification API. This operation is available via the `apiture:requestMicroDepositVerification` link on an external account if this operation is valid. Only administrative or service applications may call this operation, not bank customers.
   * @summary Request micro-deposit verification
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public requestMicroDepositVerification(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).requestMicroDepositVerification(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Begin review of an account, if its state allows review. This changes the state to `underReview`. When an external account is under review, the financial institution reviews the account details and may approve or reject the account; this will set the state to `active` or `frozen`, respectively. Only accounts which are `verifying` may make this state transition, and review is normally triggered automatically if external account verification was successful and customer data does not match with the account's holders' information. This operation is invoked from the `apiture:review` link on an account, which only exists if the action is allowed to update an account state to under review. Only administrative or service applications may call this operation, not bank customers.
   * @summary The account is under review
   * @param {Object} [query] Query object
   * @param {string} [query.account] A server-supplied value which identifies the account instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public reviewAccount(
    query?: { account?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApiFp(this.configuration).reviewAccount(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Change the account’s banking product. This applies only to personal and business CD accounts that are in their grace period (immediately following maturity). The new product must also be a CD product, and the account must satisfy the minimum and maximum balance and other constraints of the new product.
   * @summary Change the account's product
   * @param {UpdateAccountProduct} UpdateAccountProduct The data necessary to update a product on an account.
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Account}
   * @memberof AccountApi
   */
  public updateAccountProduct(
    UpdateAccountProduct: UpdateAccountProduct,
    accountId: string,
    options?: any,
  ) {
    return AccountApiFp(this.configuration).updateAccountProduct(
      UpdateAccountProduct ? UpdateAccountProduct : null,
      accountId ? accountId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AccountBeneficiariesApi - axios parameter creator
 * @export
 */
export const AccountBeneficiariesApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account beneficiaries.
     * @summary Fetch the account's beneficiaries
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficiaries(
      accountId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling getBeneficiaries.',
        );
      }
      const localVarPath = `/accounts/{accountId}/beneficiaries`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create or update the array of the beneficiaries for this account. Beneficiaries may be individuals, or a trust or charity. If the array contains only one item, it's percentage is automatically set to 100%.   When updating an existing set of beneficiaries, `null` values in the `items` array or omitted objects (such as `individual` or `organization`) inside the items are ignored: the beneficiary corresponding to a `null` item is not changed. For example, the client may omit the `type`, `individual`, and `organization` properties in the `items` array in order to adjust just the percentages:  ```json [ { 'percentage': 20 }, { 'percentage': 30 }, { 'percentage' : 20 }, null, null ] ```  will change just the percentages of the first three beneficiaries and not update their other data for any of the five beneficiaries;   The beneficiaries list is truncated to the size of the `items` array. For example: if there were five beneficiaries, and the request body contains only three items, the last two are removed from the accounts beneficiaries array (The new total must still total 100%.)   This operation applies only to `personal` accounts.
     * @summary Create or Update the account's beneficiaries
     * @param {Beneficiaries} Beneficiaries The array of account beneficiaries.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchBeneficiaries(
      Beneficiaries: Beneficiaries,
      accountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling patchBeneficiaries.',
        );
      }
      // verify required parameter 'Beneficiaries' is not null or undefined
      if (Beneficiaries === null || Beneficiaries === undefined) {
        throw new RequiredError(
          'Beneficiaries',
          'Required parameter Beneficiaries was null or undefined when calling patchBeneficiaries.',
        );
      }
      const localVarPath = `/accounts/{accountId}/beneficiaries`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Beneficiaries' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Beneficiaries || {})
        : Beneficiaries || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountBeneficiariesApi - functional programming interface
 * @export
 */
export const AccountBeneficiariesApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account beneficiaries.
     * @summary Fetch the account's beneficiaries
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficiaries(
      accountId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Beneficiaries> {
      const localVarAxiosArgs = AccountBeneficiariesApiAxiosParamCreator(
        configuration,
      ).getBeneficiaries(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create or update the array of the beneficiaries for this account. Beneficiaries may be individuals, or a trust or charity. If the array contains only one item, it's percentage is automatically set to 100%.   When updating an existing set of beneficiaries, `null` values in the `items` array or omitted objects (such as `individual` or `organization`) inside the items are ignored: the beneficiary corresponding to a `null` item is not changed. For example, the client may omit the `type`, `individual`, and `organization` properties in the `items` array in order to adjust just the percentages:  ```json [ { 'percentage': 20 }, { 'percentage': 30 }, { 'percentage' : 20 }, null, null ] ```  will change just the percentages of the first three beneficiaries and not update their other data for any of the five beneficiaries;   The beneficiaries list is truncated to the size of the `items` array. For example: if there were five beneficiaries, and the request body contains only three items, the last two are removed from the accounts beneficiaries array (The new total must still total 100%.)   This operation applies only to `personal` accounts.
     * @summary Create or Update the account's beneficiaries
     * @param {Beneficiaries} Beneficiaries The array of account beneficiaries.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchBeneficiaries(
      Beneficiaries: Beneficiaries,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Beneficiaries> {
      const localVarAxiosArgs = AccountBeneficiariesApiAxiosParamCreator(
        configuration,
      ).patchBeneficiaries(
        Beneficiaries ? Beneficiaries : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountBeneficiariesApi - factory interface
 * @export
 */
export const AccountBeneficiariesApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account beneficiaries.
     * @summary Fetch the account's beneficiaries
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficiaries(accountId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AccountBeneficiariesApiFp(configuration).getBeneficiaries(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create or update the array of the beneficiaries for this account. Beneficiaries may be individuals, or a trust or charity. If the array contains only one item, it's percentage is automatically set to 100%.   When updating an existing set of beneficiaries, `null` values in the `items` array or omitted objects (such as `individual` or `organization`) inside the items are ignored: the beneficiary corresponding to a `null` item is not changed. For example, the client may omit the `type`, `individual`, and `organization` properties in the `items` array in order to adjust just the percentages:  ```json [ { 'percentage': 20 }, { 'percentage': 30 }, { 'percentage' : 20 }, null, null ] ```  will change just the percentages of the first three beneficiaries and not update their other data for any of the five beneficiaries;   The beneficiaries list is truncated to the size of the `items` array. For example: if there were five beneficiaries, and the request body contains only three items, the last two are removed from the accounts beneficiaries array (The new total must still total 100%.)   This operation applies only to `personal` accounts.
     * @summary Create or Update the account's beneficiaries
     * @param {Beneficiaries} Beneficiaries The array of account beneficiaries.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchBeneficiaries(
      Beneficiaries: Beneficiaries,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountBeneficiariesApiFp(configuration).patchBeneficiaries(
        Beneficiaries ? Beneficiaries : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountBeneficiariesApi - object-oriented interface
 * @export
 * @class AccountBeneficiariesApi
 * @extends {BaseAPI}
 */
export class AccountBeneficiariesApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account beneficiaries.
   * @summary Fetch the account's beneficiaries
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Beneficiaries}
   * @memberof AccountBeneficiariesApi
   */
  public getBeneficiaries(accountId: string, headers?: { If_None_Match?: string }, options?: any) {
    return AccountBeneficiariesApiFp(this.configuration).getBeneficiaries(
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create or update the array of the beneficiaries for this account. Beneficiaries may be individuals, or a trust or charity. If the array contains only one item, it's percentage is automatically set to 100%.   When updating an existing set of beneficiaries, `null` values in the `items` array or omitted objects (such as `individual` or `organization`) inside the items are ignored: the beneficiary corresponding to a `null` item is not changed. For example, the client may omit the `type`, `individual`, and `organization` properties in the `items` array in order to adjust just the percentages:  ```json [ { 'percentage': 20 }, { 'percentage': 30 }, { 'percentage' : 20 }, null, null ] ```  will change just the percentages of the first three beneficiaries and not update their other data for any of the five beneficiaries;   The beneficiaries list is truncated to the size of the `items` array. For example: if there were five beneficiaries, and the request body contains only three items, the last two are removed from the accounts beneficiaries array (The new total must still total 100%.)   This operation applies only to `personal` accounts.
   * @summary Create or Update the account's beneficiaries
   * @param {Beneficiaries} Beneficiaries The array of account beneficiaries.
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Beneficiaries}
   * @memberof AccountBeneficiariesApi
   */
  public patchBeneficiaries(
    Beneficiaries: Beneficiaries,
    accountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountBeneficiariesApiFp(this.configuration).patchBeneficiaries(
      Beneficiaries ? Beneficiaries : null,
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AccountOwnersApi - axios parameter creator
 * @export
 */
export const AccountOwnersApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a list of the external account's account owners (holders). The result may be empty if the data was not available when user created the external account or the account aggregator provider does not provide this information.
     * @summary Return a list of external account owners
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccountOwners(
      externalAccountId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'externalAccountId' is not null or undefined
      if (externalAccountId === null || externalAccountId === undefined) {
        throw new RequiredError(
          'externalAccountId',
          'Required parameter externalAccountId was null or undefined when calling getExternalAccountOwners.',
        );
      }
      const localVarPath = `/externalAccounts/{externalAccountId}/accountOwners`.replace(
        `{${'externalAccountId'}}`,
        encodeURIComponent(String(externalAccountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account owners for personal accounts. There is one `primary` owner and zero or more `joint` owners. Bank customers cannot directly change this set; only the bank system or admins can change owners. Existing primary or joint owners may invite other joint owners via the Invitations API.   For business accounts, refer to the `owningBusiness` in the account resource's embedded objects.
     * @summary Fetch the primary and joint owners of an account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOwners(
      accountId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { unmasked } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling getOwners.',
        );
      }
      const localVarPath = `/accounts/{accountId}/owners`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update the array of the primary and joint owners on a personal account. Each owner in the request must be a verified user. This operation completely replaces the set of owners. This operation applies only to personal accounts. The new owners must have exactly one primary owner and may have additional joint owners.   Only financial institutions may update owners; this occurs after an existing owner or the person who created the personal account has invited other users and those verified users have accepted the invitation.
     * @summary Update the owners of this account
     * @param {Owners} Owners The array of owners.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOwners(
      Owners: Owners,
      accountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling updateOwners.',
        );
      }
      // verify required parameter 'Owners' is not null or undefined
      if (Owners === null || Owners === undefined) {
        throw new RequiredError(
          'Owners',
          'Required parameter Owners was null or undefined when calling updateOwners.',
        );
      }
      const localVarPath = `/accounts/{accountId}/owners`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Owners' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Owners || {})
        : Owners || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountOwnersApi - functional programming interface
 * @export
 */
export const AccountOwnersApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a list of the external account's account owners (holders). The result may be empty if the data was not available when user created the external account or the account aggregator provider does not provide this information.
     * @summary Return a list of external account owners
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccountOwners(
      externalAccountId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ExternalAccountOwners> {
      const localVarAxiosArgs = AccountOwnersApiAxiosParamCreator(
        configuration,
      ).getExternalAccountOwners(
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account owners for personal accounts. There is one `primary` owner and zero or more `joint` owners. Bank customers cannot directly change this set; only the bank system or admins can change owners. Existing primary or joint owners may invite other joint owners via the Invitations API.   For business accounts, refer to the `owningBusiness` in the account resource's embedded objects.
     * @summary Fetch the primary and joint owners of an account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOwners(
      accountId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Owners> {
      const localVarAxiosArgs = AccountOwnersApiAxiosParamCreator(configuration).getOwners(
        accountId ? accountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update the array of the primary and joint owners on a personal account. Each owner in the request must be a verified user. This operation completely replaces the set of owners. This operation applies only to personal accounts. The new owners must have exactly one primary owner and may have additional joint owners.   Only financial institutions may update owners; this occurs after an existing owner or the person who created the personal account has invited other users and those verified users have accepted the invitation.
     * @summary Update the owners of this account
     * @param {Owners} Owners The array of owners.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOwners(
      Owners: Owners,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Owners> {
      const localVarAxiosArgs = AccountOwnersApiAxiosParamCreator(configuration).updateOwners(
        Owners ? Owners : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountOwnersApi - factory interface
 * @export
 */
export const AccountOwnersApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a list of the external account's account owners (holders). The result may be empty if the data was not available when user created the external account or the account aggregator provider does not provide this information.
     * @summary Return a list of external account owners
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccountOwners(
      externalAccountId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AccountOwnersApiFp(configuration).getExternalAccountOwners(
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account owners for personal accounts. There is one `primary` owner and zero or more `joint` owners. Bank customers cannot directly change this set; only the bank system or admins can change owners. Existing primary or joint owners may invite other joint owners via the Invitations API.   For business accounts, refer to the `owningBusiness` in the account resource's embedded objects.
     * @summary Fetch the primary and joint owners of an account
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOwners(
      accountId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AccountOwnersApiFp(configuration).getOwners(
        accountId ? accountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update the array of the primary and joint owners on a personal account. Each owner in the request must be a verified user. This operation completely replaces the set of owners. This operation applies only to personal accounts. The new owners must have exactly one primary owner and may have additional joint owners.   Only financial institutions may update owners; this occurs after an existing owner or the person who created the personal account has invited other users and those verified users have accepted the invitation.
     * @summary Update the owners of this account
     * @param {Owners} Owners The array of owners.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOwners(
      Owners: Owners,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountOwnersApiFp(configuration).updateOwners(
        Owners ? Owners : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountOwnersApi - object-oriented interface
 * @export
 * @class AccountOwnersApi
 * @extends {BaseAPI}
 */
export class AccountOwnersApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a list of the external account's account owners (holders). The result may be empty if the data was not available when user created the external account or the account aggregator provider does not provide this information.
   * @summary Return a list of external account owners
   * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ExternalAccountOwners}
   * @memberof AccountOwnersApi
   */
  public getExternalAccountOwners(
    externalAccountId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountOwnersApiFp(this.configuration).getExternalAccountOwners(
      externalAccountId ? externalAccountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account owners for personal accounts. There is one `primary` owner and zero or more `joint` owners. Bank customers cannot directly change this set; only the bank system or admins can change owners. Existing primary or joint owners may invite other joint owners via the Invitations API.   For business accounts, refer to the `owningBusiness` in the account resource's embedded objects.
   * @summary Fetch the primary and joint owners of an account
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Owners}
   * @memberof AccountOwnersApi
   */
  public getOwners(
    accountId: string,
    query?: { unmasked?: boolean },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountOwnersApiFp(this.configuration).getOwners(
      accountId ? accountId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update the array of the primary and joint owners on a personal account. Each owner in the request must be a verified user. This operation completely replaces the set of owners. This operation applies only to personal accounts. The new owners must have exactly one primary owner and may have additional joint owners.   Only financial institutions may update owners; this occurs after an existing owner or the person who created the personal account has invited other users and those verified users have accepted the invitation.
   * @summary Update the owners of this account
   * @param {Owners} Owners The array of owners.
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Owners}
   * @memberof AccountOwnersApi
   */
  public updateOwners(
    Owners: Owners,
    accountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountOwnersApiFp(this.configuration).updateOwners(
      Owners ? Owners : null,
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AuthorizedSignersApi - axios parameter creator
 * @export
 */
export const AuthorizedSignersApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.   This operation applies only to business accounts.
     * @summary Fetch the business account's authorized signers
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(
      accountId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling getAuthorizedSigners.',
        );
      }
      const localVarPath = `/accounts/{accountId}/authorizedSigners`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update the array of the authorized signers. Each signer must be a verified user. This operation completely replaces the set of signers. Only financial institutions may update authorized signers; this occurs after an existing authorized signer or the person who created the business account has invited other users and those verified users have accepted the invitation.   This operation applies only to business accounts.
     * @summary Update the authorized signers of an account
     * @param {AuthorizedSigners} AuthorizedSigners The array of authorized signers.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthorizedSigners(
      AuthorizedSigners: AuthorizedSigners,
      accountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'accountId' is not null or undefined
      if (accountId === null || accountId === undefined) {
        throw new RequiredError(
          'accountId',
          'Required parameter accountId was null or undefined when calling updateAuthorizedSigners.',
        );
      }
      // verify required parameter 'AuthorizedSigners' is not null or undefined
      if (AuthorizedSigners === null || AuthorizedSigners === undefined) {
        throw new RequiredError(
          'AuthorizedSigners',
          'Required parameter AuthorizedSigners was null or undefined when calling updateAuthorizedSigners.',
        );
      }
      const localVarPath = `/accounts/{accountId}/authorizedSigners`.replace(
        `{${'accountId'}}`,
        encodeURIComponent(String(accountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'AuthorizedSigners' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(AuthorizedSigners || {})
        : AuthorizedSigners || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AuthorizedSignersApi - functional programming interface
 * @export
 */
export const AuthorizedSignersApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.   This operation applies only to business accounts.
     * @summary Fetch the business account's authorized signers
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(
      accountId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<AuthorizedSigners> {
      const localVarAxiosArgs = AuthorizedSignersApiAxiosParamCreator(
        configuration,
      ).getAuthorizedSigners(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update the array of the authorized signers. Each signer must be a verified user. This operation completely replaces the set of signers. Only financial institutions may update authorized signers; this occurs after an existing authorized signer or the person who created the business account has invited other users and those verified users have accepted the invitation.   This operation applies only to business accounts.
     * @summary Update the authorized signers of an account
     * @param {AuthorizedSigners} AuthorizedSigners The array of authorized signers.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthorizedSigners(
      AuthorizedSigners: AuthorizedSigners,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<AuthorizedSigners> {
      const localVarAxiosArgs = AuthorizedSignersApiAxiosParamCreator(
        configuration,
      ).updateAuthorizedSigners(
        AuthorizedSigners ? AuthorizedSigners : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AuthorizedSignersApi - factory interface
 * @export
 */
export const AuthorizedSignersApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.   This operation applies only to business accounts.
     * @summary Fetch the business account's authorized signers
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(accountId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AuthorizedSignersApiFp(configuration).getAuthorizedSigners(
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update the array of the authorized signers. Each signer must be a verified user. This operation completely replaces the set of signers. Only financial institutions may update authorized signers; this occurs after an existing authorized signer or the person who created the business account has invited other users and those verified users have accepted the invitation.   This operation applies only to business accounts.
     * @summary Update the authorized signers of an account
     * @param {AuthorizedSigners} AuthorizedSigners The array of authorized signers.
     * @param {string} accountId The unique identifier of this account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthorizedSigners(
      AuthorizedSigners: AuthorizedSigners,
      accountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AuthorizedSignersApiFp(configuration).updateAuthorizedSigners(
        AuthorizedSigners ? AuthorizedSigners : null,
        accountId ? accountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AuthorizedSignersApi - object-oriented interface
 * @export
 * @class AuthorizedSignersApi
 * @extends {BaseAPI}
 */
export class AuthorizedSignersApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.   This operation applies only to business accounts.
   * @summary Fetch the business account's authorized signers
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthorizedSigners}
   * @memberof AuthorizedSignersApi
   */
  public getAuthorizedSigners(
    accountId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AuthorizedSignersApiFp(this.configuration).getAuthorizedSigners(
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update the array of the authorized signers. Each signer must be a verified user. This operation completely replaces the set of signers. Only financial institutions may update authorized signers; this occurs after an existing authorized signer or the person who created the business account has invited other users and those verified users have accepted the invitation.   This operation applies only to business accounts.
   * @summary Update the authorized signers of an account
   * @param {AuthorizedSigners} AuthorizedSigners The array of authorized signers.
   * @param {string} accountId The unique identifier of this account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthorizedSigners}
   * @memberof AuthorizedSignersApi
   */
  public updateAuthorizedSigners(
    AuthorizedSigners: AuthorizedSigners,
    accountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AuthorizedSignersApiFp(this.configuration).updateAuthorizedSigners(
      AuthorizedSigners ? AuthorizedSigners : null,
      accountId ? accountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ConfigurationApi - axios parameter creator
 * @export
 */
export const ConfigurationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroup.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupSchema.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/schema`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.   The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/configurations/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to the configuration group's schema for the named `{valueName}`. This operation is idempotent.   The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: ConfigurationValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConfigurationApi - functional programming interface
 * @export
 */
export const ConfigurationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroup> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.   The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroups> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroups(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to the configuration group's schema for the named `{valueName}`. This operation is idempotent.   The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConfigurationApi - factory interface
 * @export
 */
export const ConfigurationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(groupName: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.   The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroups(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to the configuration group's schema for the named `{valueName}`. This operation is idempotent.   The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConfigurationApi - object-oriented interface
 * @export
 * @class ConfigurationApi
 * @extends {BaseAPI}
 */
export class ConfigurationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
   * @summary Fetch a representation of this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroup}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroup(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroup(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
   * @summary Fetch the schema for this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupSchema(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupSchema(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.   The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
   * @summary Fetch a single value associated with the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValue(
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a representation of this configuration group values resource.
   * @summary Fetch the values for the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValues(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValues(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of configuration groups
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroups}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroups(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroups(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to the configuration group's schema for the named `{valueName}`. This operation is idempotent.   The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accounts/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
   * @summary Update a single value associated with the specified configuration group
   * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValue(
    body: string,
    groupName: string,
    valueName: string,
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValue(
      body ? body : null,
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this set of values
   * @summary Update the values for the specified configuration group
   * @param {{ [key: string]: ConfigurationValue; }} request_body
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValues(
    request_body: { [key: string]: ConfigurationValue },
    groupName: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValues(
      request_body ? request_body : null,
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ExternalAccountApi - axios parameter creator
 * @export
 */
export const ExternalAccountApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new external account. A successful operation returns the full accountNumber.
     * @summary Create a new external account
     * @param {CreateExternalAccount} CreateExternalAccount The data necessary to create a new external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createExternalAccount(
      CreateExternalAccount: CreateExternalAccount,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'CreateExternalAccount' is not null or undefined
      if (CreateExternalAccount === null || CreateExternalAccount === undefined) {
        throw new RequiredError(
          'CreateExternalAccount',
          'Required parameter CreateExternalAccount was null or undefined when calling createExternalAccount.',
        );
      }
      const localVarPath = `/externalAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateExternalAccount' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateExternalAccount || {})
        : CreateExternalAccount || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this external account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or removed from use.
     * @summary Delete this external account resource
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteExternalAccount(
      externalAccountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'externalAccountId' is not null or undefined
      if (externalAccountId === null || externalAccountId === undefined) {
        throw new RequiredError(
          'externalAccountId',
          'Required parameter externalAccountId was null or undefined when calling deleteExternalAccount.',
        );
      }
      const localVarPath = `/externalAccounts/{externalAccountId}`.replace(
        `{${'externalAccountId'}}`,
        encodeURIComponent(String(externalAccountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external account resource.
     * @summary Fetch a representation of this external account
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for external accounts, include the external account owners in the &#x60;_embedded.accountOwners&#x60; object;&lt;/li&gt; &lt;/ul&gt;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccount(
      externalAccountId: string,
      query?: { unmasked?: boolean; embed?: Array<'owners'> },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { unmasked, embed } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'externalAccountId' is not null or undefined
      if (externalAccountId === null || externalAccountId === undefined) {
        throw new RequiredError(
          'externalAccountId',
          'Required parameter externalAccountId was null or undefined when calling getExternalAccount.',
        );
      }
      const localVarPath = `/externalAccounts/{externalAccountId}`.replace(
        `{${'externalAccountId'}}`,
        encodeURIComponent(String(externalAccountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of external accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of external accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first external account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of external account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] If set, each external account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60;: for external accounts, include the account owners in the &#x60;_embedded.accountOwners&#x60; object. (See the &#x60;externalAccountEmbeddedObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        name?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        embed?: Array<'owners'>;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, state, type, name, filter, q, unmasked, embed } = query;

      const localVarPath = `/externalAccounts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this external account. Fields which are omitted from the request are not updated. Nested `_embedded` and `_links` are ignored if included. Bank users may only update the `routingNumber` and `accountNumbers.full` and `institutionName` and `type` if the external account is still `pending`. If `accountNumbers.full` is patched, then the full account number is included in the response. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), [`closeAccount`](#op-closeAccount), [`reviewExternalAccount`](#op-reviewExternalAccount) which are available in the `_links` on an account instance.
     * @summary Update this external account
     * @param {ExternalAccount} ExternalAccount
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchExternalAccount(
      ExternalAccount: ExternalAccount,
      externalAccountId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'externalAccountId' is not null or undefined
      if (externalAccountId === null || externalAccountId === undefined) {
        throw new RequiredError(
          'externalAccountId',
          'Required parameter externalAccountId was null or undefined when calling patchExternalAccount.',
        );
      }
      // verify required parameter 'ExternalAccount' is not null or undefined
      if (ExternalAccount === null || ExternalAccount === undefined) {
        throw new RequiredError(
          'ExternalAccount',
          'Required parameter ExternalAccount was null or undefined when calling patchExternalAccount.',
        );
      }
      const localVarPath = `/externalAccounts/{externalAccountId}`.replace(
        `{${'externalAccountId'}}`,
        encodeURIComponent(String(externalAccountId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ExternalAccount' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ExternalAccount || {})
        : ExternalAccount || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ExternalAccountApi - functional programming interface
 * @export
 */
export const ExternalAccountApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new external account. A successful operation returns the full accountNumber.
     * @summary Create a new external account
     * @param {CreateExternalAccount} CreateExternalAccount The data necessary to create a new external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createExternalAccount(
      CreateExternalAccount: CreateExternalAccount,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ExternalAccount> {
      const localVarAxiosArgs = ExternalAccountApiAxiosParamCreator(
        configuration,
      ).createExternalAccount(
        CreateExternalAccount ? CreateExternalAccount : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this external account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or removed from use.
     * @summary Delete this external account resource
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteExternalAccount(
      externalAccountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ExternalAccountApiAxiosParamCreator(
        configuration,
      ).deleteExternalAccount(
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external account resource.
     * @summary Fetch a representation of this external account
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for external accounts, include the external account owners in the &#x60;_embedded.accountOwners&#x60; object;&lt;/li&gt; &lt;/ul&gt;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccount(
      externalAccountId: string,
      query?: { unmasked?: boolean; embed?: Array<'owners'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ExternalAccount> {
      const localVarAxiosArgs = ExternalAccountApiAxiosParamCreator(
        configuration,
      ).getExternalAccount(
        externalAccountId ? externalAccountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of external accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of external accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first external account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of external account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] If set, each external account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60;: for external accounts, include the account owners in the &#x60;_embedded.accountOwners&#x60; object. (See the &#x60;externalAccountEmbeddedObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        name?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        embed?: Array<'owners'>;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ExternalAccounts> {
      const localVarAxiosArgs = ExternalAccountApiAxiosParamCreator(
        configuration,
      ).getExternalAccounts(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this external account. Fields which are omitted from the request are not updated. Nested `_embedded` and `_links` are ignored if included. Bank users may only update the `routingNumber` and `accountNumbers.full` and `institutionName` and `type` if the external account is still `pending`. If `accountNumbers.full` is patched, then the full account number is included in the response. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), [`closeAccount`](#op-closeAccount), [`reviewExternalAccount`](#op-reviewExternalAccount) which are available in the `_links` on an account instance.
     * @summary Update this external account
     * @param {ExternalAccount} ExternalAccount
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchExternalAccount(
      ExternalAccount: ExternalAccount,
      externalAccountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ExternalAccount> {
      const localVarAxiosArgs = ExternalAccountApiAxiosParamCreator(
        configuration,
      ).patchExternalAccount(
        ExternalAccount ? ExternalAccount : null,
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ExternalAccountApi - factory interface
 * @export
 */
export const ExternalAccountApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new external account. A successful operation returns the full accountNumber.
     * @summary Create a new external account
     * @param {CreateExternalAccount} CreateExternalAccount The data necessary to create a new external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createExternalAccount(CreateExternalAccount: CreateExternalAccount, options?: any) {
      return ExternalAccountApiFp(configuration).createExternalAccount(
        CreateExternalAccount ? CreateExternalAccount : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this external account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or removed from use.
     * @summary Delete this external account resource
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteExternalAccount(
      externalAccountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ExternalAccountApiFp(configuration).deleteExternalAccount(
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external account resource.
     * @summary Fetch a representation of this external account
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for external accounts, include the external account owners in the &#x60;_embedded.accountOwners&#x60; object;&lt;/li&gt; &lt;/ul&gt;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccount(
      externalAccountId: string,
      query?: { unmasked?: boolean; embed?: Array<'owners'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ExternalAccountApiFp(configuration).getExternalAccount(
        externalAccountId ? externalAccountId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of external accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of external accounts
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first external account item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of external account representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Array<'owners'>} [query.embed] If set, each external account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60;: for external accounts, include the account owners in the &#x60;_embedded.accountOwners&#x60; object. (See the &#x60;externalAccountEmbeddedObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getExternalAccounts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
        type?: string;
        name?: string;
        filter?: string;
        q?: string;
        unmasked?: boolean;
        embed?: Array<'owners'>;
      },
      options?: any,
    ) {
      return ExternalAccountApiFp(configuration).getExternalAccounts(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this external account. Fields which are omitted from the request are not updated. Nested `_embedded` and `_links` are ignored if included. Bank users may only update the `routingNumber` and `accountNumbers.full` and `institutionName` and `type` if the external account is still `pending`. If `accountNumbers.full` is patched, then the full account number is included in the response. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), [`closeAccount`](#op-closeAccount), [`reviewExternalAccount`](#op-reviewExternalAccount) which are available in the `_links` on an account instance.
     * @summary Update this external account
     * @param {ExternalAccount} ExternalAccount
     * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchExternalAccount(
      ExternalAccount: ExternalAccount,
      externalAccountId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ExternalAccountApiFp(configuration).patchExternalAccount(
        ExternalAccount ? ExternalAccount : null,
        externalAccountId ? externalAccountId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ExternalAccountApi - object-oriented interface
 * @export
 * @class ExternalAccountApi
 * @extends {BaseAPI}
 */
export class ExternalAccountApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new external account. A successful operation returns the full accountNumber.
   * @summary Create a new external account
   * @param {CreateExternalAccount} CreateExternalAccount The data necessary to create a new external account.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ExternalAccount}
   * @memberof ExternalAccountApi
   */
  public createExternalAccount(CreateExternalAccount: CreateExternalAccount, options?: any) {
    return ExternalAccountApiFp(this.configuration).createExternalAccount(
      CreateExternalAccount ? CreateExternalAccount : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this external account resource and any resources that are owned by it. Note that only `pending` accounts may be deleted. Once an account has been activated, it cannot be deleted, only inactivated or removed from use.
   * @summary Delete this external account resource
   * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ExternalAccountApi
   */
  public deleteExternalAccount(
    externalAccountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ExternalAccountApiFp(this.configuration).deleteExternalAccount(
      externalAccountId ? externalAccountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external account resource.
   * @summary Fetch a representation of this external account
   * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Array<'owners'>} [query.embed] The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in the response. &#x60;embed&#x60; supports the following comma-separated values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60; : for external accounts, include the external account owners in the &#x60;_embedded.accountOwners&#x60; object;&lt;/li&gt; &lt;/ul&gt;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ExternalAccount}
   * @memberof ExternalAccountApi
   */
  public getExternalAccount(
    externalAccountId: string,
    query?: { unmasked?: boolean; embed?: Array<'owners'> },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ExternalAccountApiFp(this.configuration).getExternalAccount(
      externalAccountId ? externalAccountId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of external accounts. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of external accounts
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first external account item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of external account representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {'pending' | 'active' | 'inactive' | 'frozen' | 'closed'} [query.state] Subset the accounts or external accounts collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the accounts or external accounts collection to those with this exact &#x60;type&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose &#x60;type&#x60; is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the accounts or external accounts collection to those with this &#x60;name&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose &#x60;name&#x60; is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose &#x60;name&#x60; is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Array<'owners'>} [query.embed] If set, each external account in the &#x60;_embedded.items&#x60; array will include additional embedded objects. The &#x60;embed&#x60; query parameter specifies which related resources to include in the &#x60;_embedded&#x60; object in each account in response. &#x60;embed&#x60; supports the following values: &lt;ul&gt; &lt;li&gt;&#x60;owners&#x60;: for external accounts, include the account owners in the &#x60;_embedded.accountOwners&#x60; object. (See the &#x60;externalAccountEmbeddedObjects&#x60; schema.) &lt;/li&gt; &lt;/ul&gt;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ExternalAccounts}
   * @memberof ExternalAccountApi
   */
  public getExternalAccounts(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      state?: 'pending' | 'active' | 'inactive' | 'frozen' | 'closed';
      type?: string;
      name?: string;
      filter?: string;
      q?: string;
      unmasked?: boolean;
      embed?: Array<'owners'>;
    },
    options?: any,
  ) {
    return ExternalAccountApiFp(this.configuration).getExternalAccounts(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this external account. Fields which are omitted from the request are not updated. Nested `_embedded` and `_links` are ignored if included. Bank users may only update the `routingNumber` and `accountNumbers.full` and `institutionName` and `type` if the external account is still `pending`. If `accountNumbers.full` is patched, then the full account number is included in the response. This operation does not change the `state` property. To change the `state` of the account, use the `POST` operations [`activateAccount`](#op-activateAccount), [`deactivateAccount`](#op-deactivateAccount), [`freezeAccount`](#op-freezeAccount), [`closeAccount`](#op-closeAccount), [`reviewExternalAccount`](#op-reviewExternalAccount) which are available in the `_links` on an account instance.
   * @summary Update this external account
   * @param {ExternalAccount} ExternalAccount
   * @param {string} externalAccountId The unique identifier of this external account. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If supplied, the value must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ExternalAccount}
   * @memberof ExternalAccountApi
   */
  public patchExternalAccount(
    ExternalAccount: ExternalAccount,
    externalAccountId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ExternalAccountApiFp(this.configuration).patchExternalAccount(
      ExternalAccount ? ExternalAccount : null,
      externalAccountId ? externalAccountId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
