// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * External Account Verification
 *  This API allows financial institutions to verify their customer's external accounts. An external account is defined as a customer's account held at a different financial institution.  Two sets of operations can be utilized to accomplish the verification of an external account: instant verification and micro-deposit. Both operations are asynchronous, which means that upon resource creation the API will return a resource with `state` equal to `pending`. Once the verification completes, the `state` will be updated to `verified` or `failed` to indicate the result of the operation.  ## Instant Account Verification (IAV) This process verifies accounts held at a financial institution within seconds by authenticating via user account credentials with the external financial institution and multi-factor challenges when available.  ## Micro-Deposit Verification (MD) This is an alternative verification method for institutions that don't support IAV. When this verification is initiated, Apiture creates two deposits (typically less than $0.99) to the customer account to be verified, followed by a debit which balances those deposits. Once the transactions post to the user account, the account owner should find the deposits on their external account and submit the two amounts to the micro-deposits resources. This verifies that the user has ownership or access to the external account. Please note that the micro-deposit transactions may take up to two business days to be reflected on the external financial institution.
 *
 * OpenAPI spec version: 0.17.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/accountVerifications'.replace(/\/+$/, '');

export const API_VERSION = '0.17.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Description an authentication field used to authenticate against a financial institution. This service does not persist the user's responses to these field prompts.
 * @export
 * @interface AuthenticationField
 */
export interface AuthenticationField {
  /**
   * User readable title or label for this prompt/field.
   * @type {string}
   * @memberof AuthenticationField
   */
  title?: string;
  /**
   * Type of this field.
   * @type {string}
   * @memberof AuthenticationField
   */
  type?: string;
  /**
   * The data value the user entered for this field.
   * @type {string}
   * @memberof AuthenticationField
   */
  value?: string;
  /**
   * JSON schema `format` for this field.
   * @type {string}
   * @memberof AuthenticationField
   */
  format?: string;
}

/**
 * A set of authentication fields necessary to authenticate against the external financial institution. The keys in this object are field names. The values describe each field prompt. The client application prompts the user for values for these fields. The underlying account verification service uses but does not persist the values of these fields to authenticate.
 * @export
 * @interface AuthenticationFields
 */
export interface AuthenticationFields {
  [key: string]: AuthenticationField;
}

/**
 * Map of authentication fields.
 * @export
 * @interface AuthenticationFieldsResponse
 */
export interface AuthenticationFieldsResponse extends AbstractResource {
  /**
   * A set of authentication fields necessary to authenticate against the external financial institution. The keys in this object are field names. The values describe each field prompt. The client application prompts the user for values for these fields. The underlying account verification service uses but does not persist the values of these fields to authenticate.
   * @type {{ [key: string]: AuthenticationField; }}
   * @memberof AuthenticationFieldsResponse
   */
  fields?: { [key: string]: AuthenticationField };
}

/**
 * The type of this account access authorization.  * *`primary`* the person is the primary owner of a personal account.  There may be only one primary owner.  * *`joint`* the person is a non-primary joint owner of a  personal account.  * *`authorizedSigner`* the person is an authorized signer  for all business accounts owned by the organization.
 * @export
 * @enum {string}
 */
export enum AuthorizationType {
  Primary = 'primary',
  Joint = 'joint',
  AuthorizedSigner = 'authorizedSigner',
}

/**
 * Representation of question choice.
 * @export
 * @interface Choice
 */
export interface Choice {
  /**
   * The user interface type of choice.
   * @type {string}
   * @memberof Choice
   */
  type?: Choice.TypeEnum;
  /**
   * The choice's unique key.
   * @type {string}
   * @memberof Choice
   */
  key?: string;
  /**
   * The choice's value.
   * @type {string}
   * @memberof Choice
   */
  value?: string;
  /**
   * The content specific to this choice.
   * @type {string}
   * @memberof Choice
   */
  content?: string;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Choice
   */
  _links?: { [key: string]: Link };
}

/**
 * @export
 * @namespace Choice
 */
export namespace Choice {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    Image = 'image',
    Text = 'text',
    Option = 'option',
    Checkbox = 'checkbox',
    Radio = 'radio',
  }
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Represents the configuration for various services.
 * @export
 * @interface Configuration
 */
export interface Configuration {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Configuration
   */
  _links?: { [key: string]: Link };
}

/**
 * Represents a configuration group.
 * @export
 * @interface ConfigurationGroup
 */
export interface ConfigurationGroup extends ConfigurationGroupSummary {
  /**
   *
   * @type {ConfigurationSchema}
   * @memberof ConfigurationGroup
   */
  schema?: ConfigurationSchema;
  /**
   *
   * @type {ConfigurationValues}
   * @memberof ConfigurationGroup
   */
  values?: ConfigurationValues;
}

/**
 * A summary of the data contained within a configuration group resource.
 * @export
 * @interface ConfigurationGroupSummary
 */
export interface ConfigurationGroupSummary extends AbstractResource {
  /**
   * The name of this configuration group, must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  name?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  description?: string;
}

/**
 * Collection of configuration groups. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ConfigurationGroups
 */
export interface ConfigurationGroups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ConfigurationGroups
   */
  _embedded?: any;
}

/**
 * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers consisting of alphanumeric characters, `-`, `_` following the pattern _`letter [letter | digit | '-' | '_']*`_ This is implicitly a schema for `type: object` and contains the properties.  The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
 * @export
 * @interface ConfigurationSchema
 */
export interface ConfigurationSchema {}

/**
 * The data associated with this configuration: the resource's variable names and values. These values must conform to this item's `schema`. *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`. (For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.)
 * @export
 * @interface ConfigurationValues
 */
export interface ConfigurationValues {}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * Representation used to create a new instant verification resource. The `_links` on a createInstantVerification must include the following:  *`apiture:*institution`* An institution must be provided to authenticate and retreive data from the financial institution provider.  *`apiture:*contact`* The contact associated to the account to verify.
 * @export
 * @interface CreateInstantVerification
 */
export interface CreateInstantVerification extends AbstractRequest {
  /**
   * A set of authentication fields necessary to authenticate against the external financial institution. The keys in this object are field names. The values describe each field prompt. The client application prompts the user for values for these fields. The underlying account verification service uses but does not persist the values of these fields to authenticate.
   * @type {{ [key: string]: AuthenticationField; }}
   * @memberof CreateInstantVerification
   */
  authenticationFields?: { [key: string]: AuthenticationField };
}

/**
 * Representation used to create a micro-deposit verification resource.
 * @export
 * @interface CreateMicroDepositVerification
 */
export interface CreateMicroDepositVerification extends AbstractRequest {
  /**
   * The account routing number which identifies the financial institution. The full routing number and full account number are required to fully identify the account.
   * @type {string}
   * @memberof CreateMicroDepositVerification
   */
  routingNumber: string;
  /**
   *
   * @type {AccountNumbers}
   * @memberof CreateMicroDepositVerification
   */
  accountNumbers: AccountNumbers;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof CreateMicroDepositVerification
   */
  ifxType: IfxType;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * The account numbers necessary to link an external account.
 * @export
 * @interface ExternalAccountNumbers
 */
export interface ExternalAccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is included when accounts are embedded in collections or other resources. This value is derived and immutable.
   * @type {string}
   * @memberof ExternalAccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request for an account. Not included in the summary representation of the account that is included in account collection responses. Pass in this value when linking an external account. This field can be updated whenever the account is still in the pending state.
   * @type {string}
   * @memberof ExternalAccountNumbers
   */
  full?: string;
}

/**
 * An external account owner. Since this is a small finite set, this is not a paginated collection, just an array.
 * @export
 * @interface ExternalAccountOwner
 */
export interface ExternalAccountOwner extends ContactName {
  /**
   * The account owner's full name (first name and last name).
   * @type {string}
   * @memberof ExternalAccountOwner
   */
  fullName?: string;
  /**
   * The account owner's ownership type.
   * @type {AuthorizationType}
   * @memberof ExternalAccountOwner
   */
  type?: AuthorizationType;
}

/**
 * The state of an external (linked) banking account. This field is immutable and derived.    * **`pending`** : A new external account that has not been verified   * **`verifying`** : A new account that is being verified. This state only   applies to _external_ accounts.   * **`failed`** : A external account which has failed account verification.   * **`active`** : An account which is active and available for use   and for making new transactions.   * **`inactive`** : An account which is marked inactive and   not available for new transactions. Inactive accounts   may be changed back to active.   * **`frozen`** : An account which is frozen and not eligible   for new transactions. This is typically the result of   suspicious activity or fraud detection. The user must contact   their financial institution to unfreeze the account (by changing   the state back to `active`) or the financial institution   may opt to close the account.   * **`closed`** : An account that is closed and removed from use.   Closed accounts are not eligible for transactions or to become active.   Such accounts are retained for historical purposes because some   transactions may refer to it. Users do not see closed accounts   when they view their accounts.   * **`underReview`** : A new account that is being under review. This state only   applies to _external_ accounts.  To change the state of an account, `POST` the account ID to the corresponding resource endpoints, using the corresponding link on the account resource. To activate an account, use the `apiture:activate` link to `POST` to `/accounts/activeAccounts`. To deactivate an account, use the `apiture:deactivate` link to `POST` to `/accounts/inactiveAccounts`. To freeze an account, use the `apiture:freeze` link to `POST` to `/accounts/frozenAccounts`. To close an account, use the `apiture:close` link to `POST` to `/accounts/closedAccounts`. To under review an account, use the `apiture:review` link to `POST` to `/accounts/externalAccountsUnderReview`.
 * @export
 * @enum {string}
 */
export enum ExternalAccountState {
  Pending = 'pending',
  Verifying = 'verifying',
  Failed = 'failed',
  Active = 'active',
  Inactive = 'inactive',
  Frozen = 'frozen',
  Closed = 'closed',
  UnderReview = 'underReview',
}

/**
 * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values. Labels and descriptions for the enumeration values are in the `ifxType` key in the response of the `getLabels` operation.  <strong><code>ifxType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named ifxType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `ifxType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>CCA</code></strong></td><td>Credit card account</td>     </tr> <tr>     <td><strong><code>CDA</code></strong></td><td>Certificate of deposit account (CD)</td>     </tr> <tr>     <td><strong><code>CLA</code></strong></td><td>Commercial loan account</td>     </tr> <tr>     <td><strong><code>CMA</code></strong></td><td>Cash management account</td>     </tr> <tr>     <td><strong><code>DDA</code></strong></td><td>Demand deposit account</td>     </tr> <tr>     <td><strong><code>EQU</code></strong></td><td>Home equity loan</td>     </tr> <tr>     <td><strong><code>GLA</code></strong></td><td>General ledger account</td>     </tr> <tr>     <td><strong><code>ILA</code></strong></td><td>Installment loan account</td>     </tr> <tr>     <td><strong><code>INV</code></strong></td><td>Investment account</td>     </tr> <tr>     <td><strong><code>IRA</code></strong></td><td>Individual retirement account</td>     </tr> <tr>     <td><strong><code>IRL</code></strong></td><td>Accounts held in Ireland</td>     </tr> <tr>     <td><strong><code>LOC</code></strong></td><td>Consumer line of credit</td>     </tr> <tr>     <td><strong><code>MLA</code></strong></td><td>Military Lending Account: Credit facility held by former US service member</td>     </tr> <tr>     <td><strong><code>MMA</code></strong></td><td>Money market account</td>     </tr> <tr>     <td><strong><code>PBA</code></strong></td><td>Packaged bank Account: Account with additional benefits that charges a fixed monthly fee.</td>     </tr> <tr>     <td><strong><code>PPA</code></strong></td><td>Private pension administrator</td>     </tr> <tr>     <td><strong><code>RWD</code></strong></td><td>Reward accounts</td>     </tr> <tr>     <td><strong><code>SDA</code></strong></td><td>Savings deposit account</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum IfxType {
  CCA = 'CCA',
  CDA = 'CDA',
  CLA = 'CLA',
  CMA = 'CMA',
  DDA = 'DDA',
  EQU = 'EQU',
  GLA = 'GLA',
  ILA = 'ILA',
  INV = 'INV',
  IRA = 'IRA',
  IRL = 'IRL',
  LOC = 'LOC',
  MLA = 'MLA',
  MMA = 'MMA',
  PBA = 'PBA',
  PPA = 'PPA',
  RWD = 'RWD',
  SDA = 'SDA',
}

/**
 *
 * @export
 * @interface InlineResponse200
 */
export interface InlineResponse200 {
  /**
   *
   * @type {InstantVerification}
   * @memberof InlineResponse200
   */
  instantVerification?: InstantVerification;
}

/**
 * Representation of an instant verification resource.
 * @export
 * @interface InstantVerification
 */
export interface InstantVerification extends AbstractResource, InstantVerificationFields {
  /**
   * The unique identifier for this resource. This is an immutable opaque string.
   * @type {string}
   * @memberof InstantVerification
   */
  _id?: string;
  /**
   * The state of the verification, one of the following:   * `pending` - account verification is pending  * `mfaPending` - multi-factor authentication is pending  * `mfaSubmitted`  - multi-factor authentication has been submitted  * `verified` - the account verification succeeded  * `failed` - the account verification failed
   * @type {string}
   * @memberof InstantVerification
   */
  state?: InstantVerification.StateEnum;
  /**
   * An ISO 8601 UTC time stamp indicating when the verification completed (has a status different from pending).
   * @type {Date}
   * @memberof InstantVerification
   */
  completedAt?: Date;
  /**
   * An ISO 8601 UTC time stamp indicating when the verification report was created.
   * @type {Date}
   * @memberof InstantVerification
   */
  createdAt?: Date;
  /**
   * Indicates if multi-factor authentication (MFA) is required.
   * @type {boolean}
   * @memberof InstantVerification
   */
  mfaRequired?: boolean;
  /**
   *
   * @type {MfaPrompt}
   * @memberof InstantVerification
   */
  mfaPrompt?: MfaPrompt;
  /**
   * An array of messages providing aditional information of the status of the verification.
   * @type {Array<any>}
   * @memberof InstantVerification
   */
  stateMessages?: Array<any>;
  /**
   * The objects which participate in this verification resource.
   * @type {any}
   * @memberof InstantVerification
   */
  _embedded?: any;
}

/**
 * @export
 * @namespace InstantVerification
 */
export namespace InstantVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Pending = 'pending',
    MfaPending = 'mfaPending',
    MfaSubmitted = 'mfaSubmitted',
    Verified = 'verified',
    Failed = 'failed',
  }
}

/**
 * Common fields of an instant verification resource.
 * @export
 * @interface InstantVerificationFields
 */
export interface InstantVerificationFields {}

/**
 * Collection of account verification. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface InstantVerifications
 */
export interface InstantVerifications extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof InstantVerifications
   */
  _embedded?: any;
}

/**
 * The links in a institution may contain the following: * **`home`** - Home URL of the finantial website * **`icon`** - URL referencing an instution icon. The possible image formats are SVG, PNG or JPEG. The maximum aspect ratio for the image is 250*100.
 * @export
 * @interface Institution
 */
export interface Institution extends AbstractResource {
  /**
   * The unique identifier for this resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Institution
   */
  _id?: string;
  /**
   * Name of the financial institution.
   * @type {string}
   * @memberof Institution
   */
  name?: string;
  /**
   * Display name of the institution
   * @type {string}
   * @memberof Institution
   */
  label?: string;
  /**
   * indicates whether the institution is highlighted as one of the top most popular institutions.
   * @type {boolean}
   * @memberof Institution
   */
  featured?: boolean;
}

/**
 * Collection of external financial institutions. This list is supplied by a third party and is immutable (there are no operations to add, modify, or remove institutions). The items in the collection are ordered in the `_embedded.items` array; the `name` is `institutions`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Institutions
 */
export interface Institutions extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Institutions
   */
  _embedded?: any;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Representation of a multi-factor authentication challenge.
 * @export
 * @interface MfaPrompt
 */
export interface MfaPrompt {}

/**
 * Representation of a multi-factor authentication (MFA) response.
 * @export
 * @interface MfaResponse
 */
export interface MfaResponse {
  /**
   * The answers provided for this MFA request.
   * @type {Array<QuestionResponse>}
   * @memberof MfaResponse
   */
  answers?: Array<QuestionResponse>;
}

/**
 * A micro-deposit.
 * @export
 * @interface MicroDeposit
 */
export interface MicroDeposit {
  /**
   * Numeric value for the micro-deposit. Must include a leading zero and two decimal places. This value will always be between 0.01 and 0.99.
   * @type {string}
   * @memberof MicroDeposit
   */
  value: string;
  /**
   * ISO 4217 currency code of the micro-deposit. Currently the only supported currency is USD.
   * @type {string}
   * @memberof MicroDeposit
   */
  currency: string;
  /**
   * Type of micro-deposit transaction.
   * @type {string}
   * @memberof MicroDeposit
   */
  baseType: MicroDeposit.BaseTypeEnum;
}

/**
 * @export
 * @namespace MicroDeposit
 */
export namespace MicroDeposit {
  /**
   * @export
   * @enum {string}
   */
  export enum BaseTypeEnum {
    Credit = 'credit',
    Debit = 'debit',
  }
}

/**
 * Representation of a micro-deposit verification resource.
 * @export
 * @interface MicroDepositVerification
 */
export interface MicroDepositVerification extends AbstractResource {
  /**
   * The unique identifier for this resource. This is an immutable opaque string.
   * @type {string}
   * @memberof MicroDepositVerification
   */
  _id?: string;
  /**
   * The state of the micro-deposit verification, one of the following:   * `pending` - account verification is pending  * `mfaPending` - multi-factor authentication is pending  * `mfaSubmitted`  - multi-factor authentication has been submitted  * `deposited` - the provider has applied the micro-deposits transacions  * `verified` - the account verification succeeded  * `failed` - the account verification failed  * `expired` - the account verification expired
   * @type {string}
   * @memberof MicroDepositVerification
   */
  state?: MicroDepositVerification.StateEnum;
  /**
   * An ISO 8601 UTC time stamp indicating when the verification completed (has a status different from pending).
   * @type {Date}
   * @memberof MicroDepositVerification
   */
  completedAt?: Date;
  /**
   * The date-time when the account verification expires. This is in [RFC 3339] (https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof MicroDepositVerification
   */
  expiresAt?: Date;
  /**
   * An ISO 8601 UTC time stamp indicating when the verification report was created.
   * @type {Date}
   * @memberof MicroDepositVerification
   */
  createdAt?: Date;
  /**
   * An array of messages providing aditional information of the status of the verification.
   * @type {Array<any>}
   * @memberof MicroDepositVerification
   */
  stateMessages?: Array<any>;
  /**
   * The objects which participate in this verification resource.
   * @type {any}
   * @memberof MicroDepositVerification
   */
  _embedded?: any;
}

/**
 * @export
 * @namespace MicroDepositVerification
 */
export namespace MicroDepositVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Pending = 'pending',
    MfaPending = 'mfaPending',
    MfaSubmitted = 'mfaSubmitted',
    Deposited = 'deposited',
    Verified = 'verified',
    Failed = 'failed',
    Expired = 'expired',
  }
}

/**
 * Representation used to update a micro-deposit verification resource.
 * @export
 * @interface MicroDepositVerificationAmounts
 */
export interface MicroDepositVerificationAmounts extends AbstractResource {
  /**
   * An array containing a page of account verification items.
   * @type {Array<MicroDeposit>}
   * @memberof MicroDepositVerificationAmounts
   */
  amounts?: Array<MicroDeposit>;
}

/**
 * Collection of micro-deposit verifications. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface MicroDepositVerifications
 */
export interface MicroDepositVerifications extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof MicroDepositVerifications
   */
  _embedded?: any;
}

/**
 * Representation of a multi-factor authentication question. The supported question formats are text and image, in which case the encoded payload is available under the content field.
 * @export
 * @interface Question
 */
export interface Question extends QuestionFields {
  /**
   * The question's content: the token value, or image URI.
   * @type {string}
   * @memberof Question
   */
  content?: string;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Question
   */
  _links?: { [key: string]: Link };
  /**
   * Optional array of choices for this question.
   * @type {Array<Choice>}
   * @memberof Question
   */
  choices?: Array<Choice>;
  /**
   * The question type.
   * @type {string}
   * @memberof Question
   */
  type?: Question.TypeEnum;
  /**
   * The question text.
   * @type {string}
   * @memberof Question
   */
  value?: string;
}

/**
 * @export
 * @namespace Question
 */
export namespace Question {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    Question = 'question',
    Token = 'token',
    Image = 'image',
  }
}

/**
 * Common question and answer fields.
 * @export
 * @interface QuestionFields
 */
export interface QuestionFields {
  /**
   * The unique key for this question's fields.
   * @type {string}
   * @memberof QuestionFields
   */
  key: string;
}

/**
 * Representation of a multi-factor authentication question answer.
 * @export
 * @interface QuestionResponse
 */
export interface QuestionResponse extends QuestionFields {
  /**
   * User provided value for this question.
   * @type {string}
   * @memberof QuestionResponse
   */
  value?: string;
}

/**
 * A risk factor indicates a mismatch between user data and available account data.
 * @export
 * @interface RiskFactor
 */
export interface RiskFactor {
  /**
   * The risk factor risk code
   * @type {string}
   * @memberof RiskFactor
   */
  riskCode?: string;
  /**
   * The risk code description
   * @type {string}
   * @memberof RiskFactor
   */
  description?: string;
  /**
   *
   * @type {RiskFactorAttributes}
   * @memberof RiskFactor
   */
  attributes?: RiskFactorAttributes;
}

/**
 * Details of the data used to determine a risk factor.
 * @export
 * @interface RiskFactorAttributes
 */
export interface RiskFactorAttributes {
  /**
   * Supplied value for risk factor analysis
   * @type {string}
   * @memberof RiskFactorAttributes
   */
  value?: string;
  /**
   * Known values referenced for risk factor analysis
   * @type {Array<string>}
   * @memberof RiskFactorAttributes
   */
  expected?: Array<string>;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Simple representation of an external account resource.
 * @export
 * @interface SimpleExternalAccount
 */
export interface SimpleExternalAccount {
  /**
   * The unique identifier for this external account resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SimpleExternalAccount
   */
  id?: string;
  /**
   * The user-assigned name of this external account.
   * @type {string}
   * @memberof SimpleExternalAccount
   */
  name?: string;
  /**
   * The state of the external account.
   * @type {ExternalAccountState}
   * @memberof SimpleExternalAccount
   */
  state?: ExternalAccountState;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof SimpleExternalAccount
   */
  ifxType?: IfxType;
  /**
   * The array of account owners. This may be an empty array (0 items) but is always present.
   * @type {Array<ExternalAccountOwner>}
   * @memberof SimpleExternalAccount
   */
  accountOwners?: Array<ExternalAccountOwner>;
  /**
   * The account routing number which identifies the financial institution (FI). The full routing number is derived from the FI's configuration.
   * @type {string}
   * @memberof SimpleExternalAccount
   */
  routingNumber?: string;
  /**
   * The masked and full account number.
   * @type {ExternalAccountNumbers}
   * @memberof SimpleExternalAccount
   */
  accountNumbers?: ExternalAccountNumbers;
}

/**
 * A list of of external accounts related to this verification resource. Since this is a small finite set, this is not a paginated collection, just an array.
 * @export
 * @interface SimpleExternalAccounts
 */
export interface SimpleExternalAccounts extends AbstractResource {
  /**
   * A list of external accounts.
   * @type {Array<SimpleExternalAccount>}
   * @memberof SimpleExternalAccounts
   */
  externalAccounts?: Array<SimpleExternalAccount>;
}

/**
 * Summary representation of an instant verification resource.
 * @export
 * @interface SummaryInstantVerification
 */
export interface SummaryInstantVerification extends AbstractResource, InstantVerificationFields {
  /**
   * The unique identifier for this resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryInstantVerification
   */
  _id?: string;
  /**
   * The state of an instant account verification, one of the following:   * `pending` - account verification is pending  * `mfaPending` - multi-factor authentication is pending  * `mfaSubmitted`  - multi-factor authentication has been submitted  * `verified` - the account verification succeeded  * `failed` - the account verification failed
   * @type {string}
   * @memberof SummaryInstantVerification
   */
  state?: SummaryInstantVerification.StateEnum;
  /**
   * indicates whether the institution resource is highlighted as one of the top most popular institutions.
   * @type {boolean}
   * @memberof SummaryInstantVerification
   */
  featured?: boolean;
}

/**
 * @export
 * @namespace SummaryInstantVerification
 */
export namespace SummaryInstantVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Pending = 'pending',
    MfaPending = 'mfaPending',
    MfaSubmitted = 'mfaSubmitted',
    Verified = 'verified',
    Failed = 'failed',
  }
}

/**
 * Representation used to update an instant verification resource.
 * @export
 * @interface UpdateInstantVerification
 */
export interface UpdateInstantVerification extends AbstractResource {
  /**
   *
   * @type {MfaResponse}
   * @memberof UpdateInstantVerification
   */
  mfa?: MfaResponse;
}

/**
 * A verification report is an additional layer of validation that can be run against an instant verification resource. It uses available account aggregation data to generate a pass/fail result based on configured risk factors.
 * @export
 * @interface VerificationReport
 */
export interface VerificationReport {
  /**
   * The state of a verification report.  `passed` indicates that the verification does not conain any risk factors based upon the user and account information, `failed` indicates that the verification contains one or more risk factors.
   * @type {string}
   * @memberof VerificationReport
   */
  state?: VerificationReport.StateEnum;
  /**
   * Risk factors associated with the account verification.
   * @type {Array<RiskFactor>}
   * @memberof VerificationReport
   */
  accountRiskFactors?: Array<RiskFactor>;
}

/**
 * @export
 * @namespace VerificationReport
 */
export namespace VerificationReport {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Passed = 'passed',
    Failed = 'failed',
  }
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AccountVerificationApi - axios parameter creator
 * @export
 */
export const AccountVerificationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * This type of verification requires to send encrypted login fields to initiate an authentication process with the external financial institution. A `GET` to `/institutions/{institutionId}/authenticationFields` must be executed to retrieve the required login fields. This operation returns a verification resource with a `pending` status. In order to check for status updates, a client must continuously poll the resource via `GET` to the `/instantVerifications` endpoint.
     * @summary Create a new instant verification resource
     * @param {CreateInstantVerification} CreateInstantVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInstantVerification(
      CreateInstantVerification: CreateInstantVerification,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'CreateInstantVerification' is not null or undefined
      if (CreateInstantVerification === null || CreateInstantVerification === undefined) {
        throw new RequiredError(
          'CreateInstantVerification',
          'Required parameter CreateInstantVerification was null or undefined when calling createInstantVerification.',
        );
      }
      const localVarPath = `/instantVerifications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateInstantVerification' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateInstantVerification || {})
        : CreateInstantVerification || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This operation is used to verify an account using micro-deposits. The verification must contain full unmasked account numbers.
     * @summary Create a new micro-deposit verification resource
     * @param {CreateMicroDepositVerification} CreateMicroDepositVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createMicroDepositVerification(
      CreateMicroDepositVerification: CreateMicroDepositVerification,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'CreateMicroDepositVerification' is not null or undefined
      if (CreateMicroDepositVerification === null || CreateMicroDepositVerification === undefined) {
        throw new RequiredError(
          'CreateMicroDepositVerification',
          'Required parameter CreateMicroDepositVerification was null or undefined when calling createMicroDepositVerification.',
        );
      }
      const localVarPath = `/microDepositVerifications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateMicroDepositVerification' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateMicroDepositVerification || {})
        : CreateMicroDepositVerification || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this instant verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling getInstantVerification.',
        );
      }
      const localVarPath = `/instantVerifications/{verificationId}`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes an array of embeded external account entities pertaining to the verified FI account.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerificationAccounts(
      verificationId: string,
      query?: { unmasked?: boolean },
      options: any = {},
    ): RequestArgs {
      const { unmasked } = query;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling getInstantVerificationAccounts.',
        );
      }
      const localVarPath = `/instantVerifications/{verificationId}/accounts`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of account verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of instant verifications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first instant verification item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of instant verification representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, externalAccount } = query;

      const localVarPath = `/instantVerifications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (externalAccount !== undefined) {
        localVarQueryParameter['externalAccount'] = externalAccount;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this micro-deposit verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling getMicroDepositVerification.',
        );
      }
      const localVarPath = `/microDepositVerifications/{verificationId}`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes the external account entities pertaining to the verification.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerificationAccounts(verificationId: string, options: any = {}): RequestArgs {
      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling getMicroDepositVerificationAccounts.',
        );
      }
      const localVarPath = `/microDepositVerifications/{verificationId}/accounts`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of micro-deposit verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of micro-deposit verification resources
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, externalAccount } = query;

      const localVarPath = `/microDepositVerifications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (externalAccount !== undefined) {
        localVarQueryParameter['externalAccount'] = externalAccount;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this micro-deposit verification resource. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this micro-deposit verification resource
     * @param {MicroDepositVerification} MicroDepositVerification The data necessary to update a micro-deposit verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchMicroDepositVerification(
      MicroDepositVerification: MicroDepositVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling patchMicroDepositVerification.',
        );
      }
      // verify required parameter 'MicroDepositVerification' is not null or undefined
      if (MicroDepositVerification === null || MicroDepositVerification === undefined) {
        throw new RequiredError(
          'MicroDepositVerification',
          'Required parameter MicroDepositVerification was null or undefined when calling patchMicroDepositVerification.',
        );
      }
      const localVarPath = `/microDepositVerifications/{verificationId}`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'MicroDepositVerification' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(MicroDepositVerification || {})
        : MicroDepositVerification || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This operation must be used to update a verification resource waiting for user input, that is when the `mfaRequired` field is set to true and the state of the resource is `pending`. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this instant verification resource
     * @param {UpdateInstantVerification} UpdateInstantVerification The data necessary to update an instant verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateInstantVerification(
      UpdateInstantVerification: UpdateInstantVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling updateInstantVerification.',
        );
      }
      // verify required parameter 'UpdateInstantVerification' is not null or undefined
      if (UpdateInstantVerification === null || UpdateInstantVerification === undefined) {
        throw new RequiredError(
          'UpdateInstantVerification',
          'Required parameter UpdateInstantVerification was null or undefined when calling updateInstantVerification.',
        );
      }
      const localVarPath = `/instantVerifications/{verificationId}`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateInstantVerification' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateInstantVerification || {})
        : UpdateInstantVerification || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Complete the verification by providing the amount values from the micro-deposit transactions.
     * @summary Verify micro-deposit amounts
     * @param {MicroDepositVerificationAmounts} MicroDepositVerificationAmounts The amounts from a micro-deposit.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyMicroDepositAmounts(
      MicroDepositVerificationAmounts: MicroDepositVerificationAmounts,
      verificationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'verificationId' is not null or undefined
      if (verificationId === null || verificationId === undefined) {
        throw new RequiredError(
          'verificationId',
          'Required parameter verificationId was null or undefined when calling verifyMicroDepositAmounts.',
        );
      }
      // verify required parameter 'MicroDepositVerificationAmounts' is not null or undefined
      if (
        MicroDepositVerificationAmounts === null ||
        MicroDepositVerificationAmounts === undefined
      ) {
        throw new RequiredError(
          'MicroDepositVerificationAmounts',
          'Required parameter MicroDepositVerificationAmounts was null or undefined when calling verifyMicroDepositAmounts.',
        );
      }
      const localVarPath = `/microDepositVerifications/{verificationId}`.replace(
        `{${'verificationId'}}`,
        encodeURIComponent(String(verificationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'MicroDepositVerificationAmounts' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(MicroDepositVerificationAmounts || {})
        : MicroDepositVerificationAmounts || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountVerificationApi - functional programming interface
 * @export
 */
export const AccountVerificationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * This type of verification requires to send encrypted login fields to initiate an authentication process with the external financial institution. A `GET` to `/institutions/{institutionId}/authenticationFields` must be executed to retrieve the required login fields. This operation returns a verification resource with a `pending` status. In order to check for status updates, a client must continuously poll the resource via `GET` to the `/instantVerifications` endpoint.
     * @summary Create a new instant verification resource
     * @param {CreateInstantVerification} CreateInstantVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInstantVerification(
      CreateInstantVerification: CreateInstantVerification,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InstantVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).createInstantVerification(
        CreateInstantVerification ? CreateInstantVerification : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This operation is used to verify an account using micro-deposits. The verification must contain full unmasked account numbers.
     * @summary Create a new micro-deposit verification resource
     * @param {CreateMicroDepositVerification} CreateMicroDepositVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createMicroDepositVerification(
      CreateMicroDepositVerification: CreateMicroDepositVerification,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<MicroDepositVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).createMicroDepositVerification(
        CreateMicroDepositVerification ? CreateMicroDepositVerification : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this instant verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InstantVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getInstantVerification(
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes an array of embeded external account entities pertaining to the verified FI account.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerificationAccounts(
      verificationId: string,
      query?: { unmasked?: boolean },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<SimpleExternalAccounts> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getInstantVerificationAccounts(
        verificationId ? verificationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of account verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of instant verifications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first instant verification item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of instant verification representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InstantVerifications> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getInstantVerifications(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this micro-deposit verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<MicroDepositVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getMicroDepositVerification(
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes the external account entities pertaining to the verification.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerificationAccounts(
      verificationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<SimpleExternalAccounts> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getMicroDepositVerificationAccounts(
        verificationId ? verificationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of micro-deposit verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of micro-deposit verification resources
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<MicroDepositVerifications> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).getMicroDepositVerifications(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this micro-deposit verification resource. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this micro-deposit verification resource
     * @param {MicroDepositVerification} MicroDepositVerification The data necessary to update a micro-deposit verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchMicroDepositVerification(
      MicroDepositVerification: MicroDepositVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<MicroDepositVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).patchMicroDepositVerification(
        MicroDepositVerification ? MicroDepositVerification : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This operation must be used to update a verification resource waiting for user input, that is when the `mfaRequired` field is set to true and the state of the resource is `pending`. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this instant verification resource
     * @param {UpdateInstantVerification} UpdateInstantVerification The data necessary to update an instant verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateInstantVerification(
      UpdateInstantVerification: UpdateInstantVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).updateInstantVerification(
        UpdateInstantVerification ? UpdateInstantVerification : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Complete the verification by providing the amount values from the micro-deposit transactions.
     * @summary Verify micro-deposit amounts
     * @param {MicroDepositVerificationAmounts} MicroDepositVerificationAmounts The amounts from a micro-deposit.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyMicroDepositAmounts(
      MicroDepositVerificationAmounts: MicroDepositVerificationAmounts,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<MicroDepositVerification> {
      const localVarAxiosArgs = AccountVerificationApiAxiosParamCreator(
        configuration,
      ).verifyMicroDepositAmounts(
        MicroDepositVerificationAmounts ? MicroDepositVerificationAmounts : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountVerificationApi - factory interface
 * @export
 */
export const AccountVerificationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * This type of verification requires to send encrypted login fields to initiate an authentication process with the external financial institution. A `GET` to `/institutions/{institutionId}/authenticationFields` must be executed to retrieve the required login fields. This operation returns a verification resource with a `pending` status. In order to check for status updates, a client must continuously poll the resource via `GET` to the `/instantVerifications` endpoint.
     * @summary Create a new instant verification resource
     * @param {CreateInstantVerification} CreateInstantVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createInstantVerification(CreateInstantVerification: CreateInstantVerification, options?: any) {
      return AccountVerificationApiFp(configuration).createInstantVerification(
        CreateInstantVerification ? CreateInstantVerification : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This operation is used to verify an account using micro-deposits. The verification must contain full unmasked account numbers.
     * @summary Create a new micro-deposit verification resource
     * @param {CreateMicroDepositVerification} CreateMicroDepositVerification The data necessary to create a new account verification.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createMicroDepositVerification(
      CreateMicroDepositVerification: CreateMicroDepositVerification,
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).createMicroDepositVerification(
        CreateMicroDepositVerification ? CreateMicroDepositVerification : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this instant verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).getInstantVerification(
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes an array of embeded external account entities pertaining to the verified FI account.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerificationAccounts(
      verificationId: string,
      query?: { unmasked?: boolean },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).getInstantVerificationAccounts(
        verificationId ? verificationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of account verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of instant verifications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first instant verification item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of instant verification representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstantVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).getInstantVerifications(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
     * @summary Fetch a representation of this micro-deposit verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerification(
      verificationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).getMicroDepositVerification(
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes the external account entities pertaining to the verification.
     * @summary Returns a collection of external accounts related to this verification resource
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerificationAccounts(verificationId: string, options?: any) {
      return AccountVerificationApiFp(configuration).getMicroDepositVerificationAccounts(
        verificationId ? verificationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of micro-deposit verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of micro-deposit verification resources
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMicroDepositVerifications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        externalAccount?: string;
      },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).getMicroDepositVerifications(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this micro-deposit verification resource. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this micro-deposit verification resource
     * @param {MicroDepositVerification} MicroDepositVerification The data necessary to update a micro-deposit verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchMicroDepositVerification(
      MicroDepositVerification: MicroDepositVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).patchMicroDepositVerification(
        MicroDepositVerification ? MicroDepositVerification : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This operation must be used to update a verification resource waiting for user input, that is when the `mfaRequired` field is set to true and the state of the resource is `pending`. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
     * @summary Update this instant verification resource
     * @param {UpdateInstantVerification} UpdateInstantVerification The data necessary to update an instant verification resource.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateInstantVerification(
      UpdateInstantVerification: UpdateInstantVerification,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).updateInstantVerification(
        UpdateInstantVerification ? UpdateInstantVerification : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Complete the verification by providing the amount values from the micro-deposit transactions.
     * @summary Verify micro-deposit amounts
     * @param {MicroDepositVerificationAmounts} MicroDepositVerificationAmounts The amounts from a micro-deposit.
     * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyMicroDepositAmounts(
      MicroDepositVerificationAmounts: MicroDepositVerificationAmounts,
      verificationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountVerificationApiFp(configuration).verifyMicroDepositAmounts(
        MicroDepositVerificationAmounts ? MicroDepositVerificationAmounts : null,
        verificationId ? verificationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountVerificationApi - object-oriented interface
 * @export
 * @class AccountVerificationApi
 * @extends {BaseAPI}
 */
export class AccountVerificationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * This type of verification requires to send encrypted login fields to initiate an authentication process with the external financial institution. A `GET` to `/institutions/{institutionId}/authenticationFields` must be executed to retrieve the required login fields. This operation returns a verification resource with a `pending` status. In order to check for status updates, a client must continuously poll the resource via `GET` to the `/instantVerifications` endpoint.
   * @summary Create a new instant verification resource
   * @param {CreateInstantVerification} CreateInstantVerification The data necessary to create a new account verification.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InstantVerification}
   * @memberof AccountVerificationApi
   */
  public createInstantVerification(
    CreateInstantVerification: CreateInstantVerification,
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).createInstantVerification(
      CreateInstantVerification ? CreateInstantVerification : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This operation is used to verify an account using micro-deposits. The verification must contain full unmasked account numbers.
   * @summary Create a new micro-deposit verification resource
   * @param {CreateMicroDepositVerification} CreateMicroDepositVerification The data necessary to create a new account verification.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {MicroDepositVerification}
   * @memberof AccountVerificationApi
   */
  public createMicroDepositVerification(
    CreateMicroDepositVerification: CreateMicroDepositVerification,
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).createMicroDepositVerification(
      CreateMicroDepositVerification ? CreateMicroDepositVerification : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
   * @summary Fetch a representation of this instant verification resource
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InstantVerification}
   * @memberof AccountVerificationApi
   */
  public getInstantVerification(
    verificationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).getInstantVerification(
      verificationId ? verificationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes an array of embeded external account entities pertaining to the verified FI account.
   * @summary Returns a collection of external accounts related to this verification resource
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting an account, the full account number is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {SimpleExternalAccounts}
   * @memberof AccountVerificationApi
   */
  public getInstantVerificationAccounts(
    verificationId: string,
    query?: { unmasked?: boolean },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).getInstantVerificationAccounts(
      verificationId ? verificationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of account verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of instant verifications
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first instant verification item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of instant verification representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InstantVerifications}
   * @memberof AccountVerificationApi
   */
  public getInstantVerifications(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      externalAccount?: string;
    },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).getInstantVerifications(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account verification resource.
   * @summary Fetch a representation of this micro-deposit verification resource
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {MicroDepositVerification}
   * @memberof AccountVerificationApi
   */
  public getMicroDepositVerification(
    verificationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).getMicroDepositVerification(
      verificationId ? verificationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Once a verification is successful, this operation retrieves the accounts associated with it. The response includes the external account entities pertaining to the verification.
   * @summary Returns a collection of external accounts related to this verification resource
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {SimpleExternalAccounts}
   * @memberof AccountVerificationApi
   */
  public getMicroDepositVerificationAccounts(verificationId: string, options?: any) {
    return AccountVerificationApiFp(this.configuration).getMicroDepositVerificationAccounts(
      verificationId ? verificationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of micro-deposit verifications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of micro-deposit verification resources
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of institution representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.externalAccount] Return verifications for the external account identified by this query parameter. The value is the unique &#x60;_id&#x60; or URL of an external account.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {MicroDepositVerifications}
   * @memberof AccountVerificationApi
   */
  public getMicroDepositVerifications(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      externalAccount?: string;
    },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).getMicroDepositVerifications(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this micro-deposit verification resource. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
   * @summary Update this micro-deposit verification resource
   * @param {MicroDepositVerification} MicroDepositVerification The data necessary to update a micro-deposit verification resource.
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {MicroDepositVerification}
   * @memberof AccountVerificationApi
   */
  public patchMicroDepositVerification(
    MicroDepositVerification: MicroDepositVerification,
    verificationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).patchMicroDepositVerification(
      MicroDepositVerification ? MicroDepositVerification : null,
      verificationId ? verificationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This operation must be used to update a verification resource waiting for user input, that is when the `mfaRequired` field is set to true and the state of the resource is `pending`. To associate this account verification with an external account resource, include an `apiture:externalAccount` link inside the `_links` collection, with the link's `href` set to that external account's URL.
   * @summary Update this instant verification resource
   * @param {UpdateInstantVerification} UpdateInstantVerification The data necessary to update an instant verification resource.
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof AccountVerificationApi
   */
  public updateInstantVerification(
    UpdateInstantVerification: UpdateInstantVerification,
    verificationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).updateInstantVerification(
      UpdateInstantVerification ? UpdateInstantVerification : null,
      verificationId ? verificationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Complete the verification by providing the amount values from the micro-deposit transactions.
   * @summary Verify micro-deposit amounts
   * @param {MicroDepositVerificationAmounts} MicroDepositVerificationAmounts The amounts from a micro-deposit.
   * @param {string} verificationId The unique identifier of this account verificaton. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {MicroDepositVerification}
   * @memberof AccountVerificationApi
   */
  public verifyMicroDepositAmounts(
    MicroDepositVerificationAmounts: MicroDepositVerificationAmounts,
    verificationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountVerificationApiFp(this.configuration).verifyMicroDepositAmounts(
      MicroDepositVerificationAmounts ? MicroDepositVerificationAmounts : null,
      verificationId ? verificationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ConfigurationApi - axios parameter creator
 * @export
 */
export const ConfigurationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options: any = {}): RequestArgs {
      const localVarPath = `/configurations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroup.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupSchema.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/schema`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/configurations/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {ConfigurationValues} ConfigurationValues
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      ConfigurationValues: ConfigurationValues,
      groupName: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'ConfigurationValues' is not null or undefined
      if (ConfigurationValues === null || ConfigurationValues === undefined) {
        throw new RequiredError(
          'ConfigurationValues',
          'Required parameter ConfigurationValues was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ConfigurationValues' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ConfigurationValues || {})
        : ConfigurationValues || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConfigurationApi - functional programming interface
 * @export
 */
export const ConfigurationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Configuration> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(configuration).getConfiguration(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroup> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationSchema> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationValues> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroups> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroups(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {ConfigurationValues} ConfigurationValues
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      ConfigurationValues: ConfigurationValues,
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationSchema> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValues(
        ConfigurationValues ? ConfigurationValues : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConfigurationApi - factory interface
 * @export
 */
export const ConfigurationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options?: any) {
      return ConfigurationApiFp(configuration).getConfiguration(options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(groupName: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroups(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {ConfigurationValues} ConfigurationValues
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      ConfigurationValues: ConfigurationValues,
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValues(
        ConfigurationValues ? ConfigurationValues : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConfigurationApi - object-oriented interface
 * @export
 * @class ConfigurationApi
 * @extends {BaseAPI}
 */
export class ConfigurationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Returns the configuration for this API
   * @summary Configuration definition for this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Configuration}
   * @memberof ConfigurationApi
   */
  public getConfiguration(options?: any) {
    return ConfigurationApiFp(this.configuration).getConfiguration(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
   * @summary Fetch a representation of this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroup}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroup(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroup(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
   * @summary Fetch the schema for this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchema}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupSchema(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupSchema(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
   * @summary Fetch a single value associated with the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValue(
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a representation of this configuration group values resource.
   * @summary Fetch the values for the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValues}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValues(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValues(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of configuration groups
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroups}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroups(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroups(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountVerifications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
   * @summary Update a single value associated with the specified configuration group
   * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValue(
    body: string,
    groupName: string,
    valueName: string,
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValue(
      body ? body : null,
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this set of values
   * @summary Update the values for the specified configuration group
   * @param {ConfigurationValues} ConfigurationValues
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchema}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValues(
    ConfigurationValues: ConfigurationValues,
    groupName: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValues(
      ConfigurationValues ? ConfigurationValues : null,
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * InstitutionsApi - axios parameter creator
 * @export
 */
export const InstitutionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external financial institution resource.  The links in an institution may contain the following:     * **`home`** - Home URL of the financial website.   * **`icon`** - URL referencing an institution icon. The possible image formats are SVG and PNG.
     * @summary Fetch a representation of this external financial institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitution(institutionId: string, options: any = {}): RequestArgs {
      // verify required parameter 'institutionId' is not null or undefined
      if (institutionId === null || institutionId === undefined) {
        throw new RequiredError(
          'institutionId',
          'Required parameter institutionId was null or undefined when calling getInstitution.',
        );
      }
      const localVarPath = `/institutions/{institutionId}`.replace(
        `{${'institutionId'}}`,
        encodeURIComponent(String(institutionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This endpoint returns descriptions of the fields required to authenticate with the external institution.
     * @summary Return descriptions of the fields required to authenticate with the external institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutionFields(institutionId: string, options: any = {}): RequestArgs {
      // verify required parameter 'institutionId' is not null or undefined
      if (institutionId === null || institutionId === undefined) {
        throw new RequiredError(
          'institutionId',
          'Required parameter institutionId was null or undefined when calling getInstitutionFields.',
        );
      }
      const localVarPath = `/institutions/{institutionId}/authenticationFields`.replace(
        `{${'institutionId'}}`,
        encodeURIComponent(String(institutionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of registered external financial institutions. This list is supplied by a third party and is immutable (there are no operations to add, modify, or remove institutions). The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  In adition to the standard sorting mechanisms, it is possible to sort institutions by popularity by using the `popularity` criteria, such as `?sortBy=popularity`.
     * @summary Return a collection of institutions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of financial institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the institutions collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the institutions collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, name, label } = query;

      const localVarPath = `/institutions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * InstitutionsApi - functional programming interface
 * @export
 */
export const InstitutionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external financial institution resource.  The links in an institution may contain the following:     * **`home`** - Home URL of the financial website.   * **`icon`** - URL referencing an institution icon. The possible image formats are SVG and PNG.
     * @summary Fetch a representation of this external financial institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitution(
      institutionId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Institution> {
      const localVarAxiosArgs = InstitutionsApiAxiosParamCreator(configuration).getInstitution(
        institutionId ? institutionId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This endpoint returns descriptions of the fields required to authenticate with the external institution.
     * @summary Return descriptions of the fields required to authenticate with the external institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutionFields(
      institutionId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<AuthenticationFieldsResponse> {
      const localVarAxiosArgs = InstitutionsApiAxiosParamCreator(
        configuration,
      ).getInstitutionFields(
        institutionId ? institutionId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of registered external financial institutions. This list is supplied by a third party and is immutable (there are no operations to add, modify, or remove institutions). The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  In adition to the standard sorting mechanisms, it is possible to sort institutions by popularity by using the `popularity` criteria, such as `?sortBy=popularity`.
     * @summary Return a collection of institutions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of financial institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the institutions collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the institutions collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Institutions> {
      const localVarAxiosArgs = InstitutionsApiAxiosParamCreator(configuration).getInstitutions(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * InstitutionsApi - factory interface
 * @export
 */
export const InstitutionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external financial institution resource.  The links in an institution may contain the following:     * **`home`** - Home URL of the financial website.   * **`icon`** - URL referencing an institution icon. The possible image formats are SVG and PNG.
     * @summary Fetch a representation of this external financial institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitution(institutionId: string, options?: any) {
      return InstitutionsApiFp(configuration).getInstitution(
        institutionId ? institutionId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This endpoint returns descriptions of the fields required to authenticate with the external institution.
     * @summary Return descriptions of the fields required to authenticate with the external institution
     * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutionFields(institutionId: string, options?: any) {
      return InstitutionsApiFp(configuration).getInstitutionFields(
        institutionId ? institutionId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of registered external financial institutions. This list is supplied by a third party and is immutable (there are no operations to add, modify, or remove institutions). The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  In adition to the standard sorting mechanisms, it is possible to sort institutions by popularity by using the `popularity` criteria, such as `?sortBy=popularity`.
     * @summary Return a collection of institutions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of financial institution representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.name] Subset the institutions collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the institutions collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getInstitutions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        name?: string;
        label?: string;
      },
      options?: any,
    ) {
      return InstitutionsApiFp(configuration).getInstitutions(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * InstitutionsApi - object-oriented interface
 * @export
 * @class InstitutionsApi
 * @extends {BaseAPI}
 */
export class InstitutionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this external financial institution resource.  The links in an institution may contain the following:     * **`home`** - Home URL of the financial website.   * **`icon`** - URL referencing an institution icon. The possible image formats are SVG and PNG.
   * @summary Fetch a representation of this external financial institution
   * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Institution}
   * @memberof InstitutionsApi
   */
  public getInstitution(institutionId: string, options?: any) {
    return InstitutionsApiFp(this.configuration).getInstitution(
      institutionId ? institutionId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This endpoint returns descriptions of the fields required to authenticate with the external institution.
   * @summary Return descriptions of the fields required to authenticate with the external institution
   * @param {string} institutionId The unique identifier of this institution resource. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthenticationFieldsResponse}
   * @memberof InstitutionsApi
   */
  public getInstitutionFields(institutionId: string, options?: any) {
    return InstitutionsApiFp(this.configuration).getInstitutionFields(
      institutionId ? institutionId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of registered external financial institutions. This list is supplied by a third party and is immutable (there are no operations to add, modify, or remove institutions). The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  In adition to the standard sorting mechanisms, it is possible to sort institutions by popularity by using the `popularity` criteria, such as `?sortBy=popularity`.
   * @summary Return a collection of institutions
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first institution item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of financial institution representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.name] Subset the institutions collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the institutions collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;email_verification&#x60; matches only items whose label is &#x60;email_verification&#x60;; &#x60;?label&#x3D;email_verification|account_verification&#x60; will match items whose label is &#x60;email_verification&#x60; or &#x60;account_verification&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Institutions}
   * @memberof InstitutionsApi
   */
  public getInstitutions(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      name?: string;
      label?: string;
    },
    options?: any,
  ) {
    return InstitutionsApiFp(this.configuration).getInstitutions(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * VerificationReportApi - axios parameter creator
 * @export
 */
export const VerificationReportApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * A verification report is an additional layer of validation that can be run against a verification resource. It uses available account aggregation data from an external provider to generate a pass/fail result based on pre-configured risk factors. This operation does not create a new persisent resource; the report is transient and returned in the response body only. <p>
     * @summary Create a new verification report resource
     * @param {Object} [query] Query object
     * @param {string} [query.verification] A string which identifies a specific verification resource. The value may be a &#x60;{verificationId}&#x60; or a verification URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createVerificationReport(query?: { verification?: string }, options: any = {}): RequestArgs {
      const { verification } = query;

      // verify required parameter 'verification' is not null or undefined
      if (verification === null || verification === undefined) {
        throw new RequiredError(
          'verification',
          'Required parameter verification was null or undefined when calling createVerificationReport.',
        );
      }
      const localVarPath = `/verificationReports`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (verification !== undefined) {
        localVarQueryParameter['verification'] = verification;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * VerificationReportApi - functional programming interface
 * @export
 */
export const VerificationReportApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * A verification report is an additional layer of validation that can be run against a verification resource. It uses available account aggregation data from an external provider to generate a pass/fail result based on pre-configured risk factors. This operation does not create a new persisent resource; the report is transient and returned in the response body only. <p>
     * @summary Create a new verification report resource
     * @param {Object} [query] Query object
     * @param {string} [query.verification] A string which identifies a specific verification resource. The value may be a &#x60;{verificationId}&#x60; or a verification URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createVerificationReport(
      query?: { verification?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<VerificationReport> {
      const localVarAxiosArgs = VerificationReportApiAxiosParamCreator(
        configuration,
      ).createVerificationReport(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * VerificationReportApi - factory interface
 * @export
 */
export const VerificationReportApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * A verification report is an additional layer of validation that can be run against a verification resource. It uses available account aggregation data from an external provider to generate a pass/fail result based on pre-configured risk factors. This operation does not create a new persisent resource; the report is transient and returned in the response body only. <p>
     * @summary Create a new verification report resource
     * @param {Object} [query] Query object
     * @param {string} [query.verification] A string which identifies a specific verification resource. The value may be a &#x60;{verificationId}&#x60; or a verification URI.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createVerificationReport(query?: { verification?: string }, options?: any) {
      return VerificationReportApiFp(configuration).createVerificationReport(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * VerificationReportApi - object-oriented interface
 * @export
 * @class VerificationReportApi
 * @extends {BaseAPI}
 */
export class VerificationReportApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * A verification report is an additional layer of validation that can be run against a verification resource. It uses available account aggregation data from an external provider to generate a pass/fail result based on pre-configured risk factors. This operation does not create a new persisent resource; the report is transient and returned in the response body only. <p>
   * @summary Create a new verification report resource
   * @param {Object} [query] Query object
   * @param {string} [query.verification] A string which identifies a specific verification resource. The value may be a &#x60;{verificationId}&#x60; or a verification URI.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {VerificationReport}
   * @memberof VerificationReportApi
   */
  public createVerificationReport(query?: { verification?: string }, options?: any) {
    return VerificationReportApiFp(this.configuration).createVerificationReport(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
