// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Account Applications
 * This API manages _applications_ to create new accounts. An account application coordinates the following resources necessary to complete the application:   * account applicant(s) and their identity verification status  * banking product for the new account  * documents (required documents, uploaded instances, approvals)  * consents the applicant has given (such as terms and conditions for the banking product, electronic consent)  * external funding account and amount (Transfer)  * business verifications (for business accounts)  * workflow/business process used to perform the application process  * application approval   These individual resources will be nested within in the full representation inside the application resource, but are omitted in the summary application representations that are returned in the `applications` collection. Only the banking product is required to create a new account application. The application retains snapshots of these objects as they existed when the application was reviewed.  An application may be seeded with initial data. This allows \"pre-approved\" applications from external sources. All completed applications (whether `approved` or `rejected`) are retained indefinitely for auditing purposes. Incomplete applications expire after 30 days of inactivity or a period specified by the financial institution in the service configuration.  Each banking product (such as a checking account or money market account) has an association to an _account application workflow definition_ which defines the business process for opening a new account for that product. This workflow is a set of tasks the user must perform in order to open a new account for that product. This service instantiates the workflow, sets the `accountApplication`, `accountApplicant`, `product`, `fundingAccount`, and `organization` properties of the workflow instance, and starts the workflow.  **Note:** A task in the workflow typically performs the actual account creation. A valid account is necessary for an _initial funding_ operation to occur.  Each application maintains a `state` field which indicates the state of that application: `pending`, `running`, `canceled`, `expired`, `rejected`, `approved`. The `pending` state is reserved for future use. The default state when creating a new application is `running`'  Allowed state transitions are:    * `running` &rarr; `canceled` | `expired`  | `approved` | `rejected`   * `blocked` &rarr; `running`  | `canceled` | `expired`  | `approved` | `rejected`   The service will also change an application's state from `blocked` to `running` once the condition that is blocking the application has changed (such as completion of workflow tasks or financial institution approvals.)  This API also manages _enrollments_, which represent a new user enrolling in on-line digital banking. Enrollments consist of collecting personal information (name, address, phone, email, tax ID) and other personal data. Enrollments also support Customer Identification Program regulatory requirements, also known as \"Know Your Customer\", by verifying the user's identity and ensuring they are not involved with fraud or other risk factors. Enrollments are used when new users register in response to invitations to become joint owners or authorized signers on existing accounts. State transitions for enrollments are similar to those for applications. Note: This API uses the base path `/accountApplications` to avoid confusion with _software applications_.
 *
 * OpenAPI spec version: 0.17.9
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/accountApplications'.replace(/\/+$/, '');

export const API_VERSION = '0.17.9';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * The purpose of the account.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `accountPurpose` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AccountPurpose {
  Unknown = 'unknown',
  CreditCardProcessing = 'creditCardProcessing',
  GeneralOperatingFunds = 'generalOperatingFunds',
  Lottery = 'lottery',
  Payroll = 'payroll',
  Savings = 'savings',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Indicates how interest is accrued according to the `compoundPeriod`.  <strong><code>accrualType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named accrualType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `accrualType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>compounding</code></strong></td><td>Compounding interest</td>     </tr> <tr>     <td><strong><code>simple</code></strong></td><td>Simple interest</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum AccrualType {
  Compounding = 'compounding',
  Simple = 'simple',
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * A text label, suitable for presentation to the user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada.
   * @type {string}
   * @memberof Address
   */
  regionCode: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode: string;
  /**
   * The ISO 3166-1 country code.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A list of postal addresses and the preferred mailing address.
 * @export
 * @interface Addresses
 */
export interface Addresses {
  /**
   * An array of postal/mailing addresses.
   * @type {Array<Address>}
   * @memberof Addresses
   */
  addresses?: Array<Address>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array.
   * @type {string}
   * @memberof Addresses
   */
  preferredMailingAddressId?: string;
}

/**
 * An applicant for a new account.
 * @export
 * @interface Applicant
 */
export interface Applicant {
  /**
   * The unique username for the user. If omitted on a request, this field will be set for the primary applicant, based on the username of the authenticated user that creates the application. For co-owners and beneficial-owners this field is optional.
   * @type {string}
   * @memberof Applicant
   */
  username?: string;
  /**
   * A Contact object representing an individual contact.
   * @type {Contact}
   * @memberof Applicant
   */
  contact?: Contact;
  /**
   * A User object representing an individual user.
   * @type {SummaryUser}
   * @memberof Applicant
   */
  user?: SummaryUser;
  /**
   * The role the user has on the account. This is a Role resource from the Associations API; it must be a bank account role. The default is determined by the number of applicants and the type of account (personal vs. business).
   * @type {Role}
   * @memberof Applicant
   */
  role?: Role;
  /**
   * The verification status of the user or contact.
   * @type {ContactVerification}
   * @memberof Applicant
   */
  verification?: ContactVerification;
  /**
   * Any approvals associated with this applicant.
   * @type {Array<Approval>}
   * @memberof Applicant
   */
  approvals?: Array<Approval>;
  /**
   * An array of documents (such as terms and conditions, electronic consent) and the user's consent or agreement of the terms of those documents. The service configuration determines which consents are required for enrollment or account applications and sets this array on construction.
   * @type {Array<Consent>}
   * @memberof Applicant
   */
  consents?: Array<Consent>;
  /**
   * The fraud risk report for the applicant.
   * @type {FraudRiskReport}
   * @memberof Applicant
   */
  fraudReport?: FraudRiskReport;
  /**
   * `true` if and only if the applicant has been verified.
   * @type {boolean}
   * @memberof Applicant
   */
  verified?: boolean;
  /**
   * A secure token that contains identity verification data about a given contact including their verified status.  The verified property in this applicant schema is derived from the Boolean status embedded in this token.  The data contained in this token is derived from the results of any identity verification service operations previously performed on the contact.
   * @type {string}
   * @memberof Applicant
   */
  verificationToken?: string;
}

/**
 * An application for a new account. The resource contains summary fields that identify the account applicant, the primary product, and the state of the applications. The nested arrays and objects contains related resources which support the application: `applicants` and their identity verification, related `products`, documents, the `organization` (for business accounts), etc.
 * @export
 * @interface Application
 */
export interface Application extends SummaryApplication, CommonObjects, ApplicationObjects {
  /**
   * The unique identifier for this application. This is an immutable opaque string.
   * @type {string}
   * @memberof Application
   */
  _id?: string;
  /**
   * The number of visible workflow tasks which have been completed.
   * @type {number}
   * @memberof Application
   */
  completedTaskCount?: number;
  /**
   * The number of visible workflow tasks which are currently running.
   * @type {number}
   * @memberof Application
   */
  runningTaskCount?: number;
  /**
   * The names of the tasks which are currently `running` in the application's workflow.
   * @type {Array<string>}
   * @memberof Application
   */
  runningTaskNames?: Array<string>;
  /**
   * The number of visible workflow tasks which are still pending.
   * @type {number}
   * @memberof Application
   */
  pendingTaskCount?: number;
  /**
   * The number of visible workflow tasks which are blocked.
   * @type {number}
   * @memberof Application
   */
  blockedTaskCount?: number;
  /**
   * The number of visible workflow tasks which have been canceled.
   * @type {number}
   * @memberof Application
   */
  canceledTaskCount?: number;
  /**
   * The date-time when the application expires. This is in [RFC 3339] (https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Application
   */
  expiresAt?: Date;
}

/**
 * @export
 * @namespace Application
 */
export namespace Application {}

/**
 * Common fields of the account application resource used to build other model schemas.
 * @export
 * @interface ApplicationFields
 */
export interface ApplicationFields {
  /**
   * The name of new account. If initially blank, this will be initialized from the name of the first product.
   * @type {string}
   * @memberof ApplicationFields
   */
  accountName?: string;
  /**
   * How much money the applicant wishes to transfer from the funding account in order to initially fund this new account.
   * @type {Money}
   * @memberof ApplicationFields
   */
  fundingAmount?: Money;
  /**
   * An optional map of name/value pairs which provide additional metadata about the application. If this object contain an `accountAtributes` object, the properties in that object are placed in the `attributes` of the new account that this application creates.
   * @type {Attributes}
   * @memberof ApplicationFields
   */
  attributes?: Attributes;
}

/**
 * Additional objects related to a new account application.
 * @export
 * @interface ApplicationObjects
 */
export interface ApplicationObjects {
  /**
   * The bank product(s) for this account. The first item in the array is the _primary_ product for the new account. The remaining optional items in the array are secondary associated products.
   * @type {Array<SummaryProduct>}
   * @memberof ApplicationObjects
   */
  products?: Array<SummaryProduct>;
  /**
   *
   * @type {Organization}
   * @memberof ApplicationObjects
   */
  organization?: Organization;
  /**
   *
   * @type {BusinessVerifications}
   * @memberof ApplicationObjects
   */
  organizationVerification?: BusinessVerifications;
  /**
   * Any Approvals for administrator verification of the organization.
   * @type {Array<Approval>}
   * @memberof ApplicationObjects
   */
  organizationApprovals?: Array<Approval>;
  /**
   * An Approval object which the reviewer can use to approve or reject the entire account application. The `apiture:approve` and `apiture:reject` links in the resource may be used to reject or approve the applications via `POST` operations (no request body).
   * @type {Approval}
   * @memberof ApplicationObjects
   */
  accountApproval?: Approval;
  /**
   *
   * @type {VerifiedTransferAccount}
   * @memberof ApplicationObjects
   */
  fundingAccount?: VerifiedTransferAccount;
  /**
   * New accounts opened via this application. This array has a one-to-one mapping to the `products` array. Use the `self` link in each item's `_links` to access each account.
   * @type {Array<TransferAccount>}
   * @memberof ApplicationObjects
   */
  newAccounts?: Array<TransferAccount>;
}

/**
 * Collection of account applications. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links: `self`, `next`, `prev`, `first`, `last`, `collection`.
 * @export
 * @interface Applications
 */
export interface Applications extends Collection {
  /**
   * Embedded resources.
   * @type {any}
   * @memberof Applications
   */
  _embedded?: any;
}

/**
 * An approval represents the _review_ of some process, activity or resource, such as a document or an application. The state of the approval is recorded in its `state` property. The target of the approval is in the link named `apiture:target`; see the _Create Approval_ schema and `createApproval` operation.   Links on an approval convey which state transitions are available. The client should use `POST` to invoke these operations, using the `href` on the named link object. No request body is used on these operations.   The absence of a link indicates that the particular state transition is not available at that time or that the caller is not authorized to make the change. For example, a bank customer may lack permissions to approve a wire transfer they submitted.
 * @export
 * @interface Approval
 */
export interface Approval extends UpdateApproval {
  /**
   * The reason given for the last state change, such as why the approval was approved, rejected, waived, canceled, or returned.
   * @type {string}
   * @memberof Approval
   */
  reason?: string;
  /**
   * The date-time when the approval was created.
   * @type {Date}
   * @memberof Approval
   */
  createdAt?: Date;
  /**
   * The date-time when the approval was updated.
   * @type {Date}
   * @memberof Approval
   */
  updatedAt?: Date;
  /**
   * Embedded objects.
   * @type {ApprovalEmbeddedObjects}
   * @memberof Approval
   */
  _embedded?: ApprovalEmbeddedObjects;
}

/**
 * The objects which participate in this approval.
 * @export
 * @interface ApprovalEmbeddedObjects
 */
export interface ApprovalEmbeddedObjects {
  /**
   * The type of this approval.
   * @type {SummaryApprovalType}
   * @memberof ApprovalEmbeddedObjects
   */
  approvalType?: SummaryApprovalType;
  /**
   * The target of this approval.
   * @type {any}
   * @memberof ApprovalEmbeddedObjects
   */
  target?: any;
}

/**
 * Common fields of the approval resource, used to define other model schemas.
 * @export
 * @interface ApprovalFields
 */
export interface ApprovalFields {
  /**
   * The approval's common name.  If omitted on create request, this will default to the label of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  label?: string;
  /**
   * The approval's description.  If omitted on create request, this will default to the description of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  description?: string;
  /**
   * The state of this approval. This property is derived and immutable. Its value can only be changed by using the corresponding `POST` operations, `submitApproval`, `approveApproval`, `rejectApproval`, `waiveApproval`, `returnApproval`, and `cancelApproval`, if the corresponding links exist on the approval resource, as determined by the existing state of the approval and the allowed states determined by the approval type.
   * @type {ApprovalState}
   * @memberof ApprovalFields
   */
  state?: ApprovalState;
  /**
   * If `done` is true, the approval is in a terminal state and may no longer be acted upon.  Done states include `canceled`, `approved`, `waived` or `rejected`. This property is derived from the `state` field and is immutable.
   * @type {boolean}
   * @memberof ApprovalFields
   */
  done?: boolean;
  /**
   * The name of the Approval Type.  This field is immutable and derived from the name of the Approval Type.
   * @type {string}
   * @memberof ApprovalFields
   */
  typeName?: string;
  /**
   * The id of the User that reviewed the approval.
   * @type {string}
   * @memberof ApprovalFields
   */
  reviewedBy?: string;
  /**
   * The date-time when the approval was reviewed.
   * @type {Date}
   * @memberof ApprovalFields
   */
  reviewedAt?: Date;
}

/**
 * The approval's state.     * **`open`** Created but pending input subject to approval   * **`submitted`** Pending review by approver   * **`approved`** Approval granted   * **`rejected`** Approval denied   * **`waived`** Approval forgiven   * **`returned`** Approver returns approval for modification   * **`canceled`** Approval request withdrawn   This is an immutable and derived property. Its value can only be changed by using the corresponding `POST` operations, `submitApproval`, `approveApproval`, `rejectApproval`, `waiveApproval`, `returnApproval`, and `cancelApproval`.
 * @export
 * @enum {string}
 */
export enum ApprovalState {
  Open = 'open',
  Submitted = 'submitted',
  Approved = 'approved',
  Rejected = 'rejected',
  Waived = 'waived',
  Returned = 'returned',
  Canceled = 'canceled',
}

/**
 * Common fields of the approval resource used to build other model schemas.
 * @export
 * @interface ApprovalTypeFields
 */
export interface ApprovalTypeFields {
  /**
   * The approval's name.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  name?: string;
  /**
   * The approval's common name.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  label?: string;
  /**
   * The approval's description.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  description?: string;
  /**
   * A namespace for grouping related resources, to keep them separate from other resources. For example, a department or bank branch may define a domain, and all Approval Type instances  they define will use that domain, so that they can avoid conflicting with Approval Type names in other domains. An API or service may define a domain for new Approval Types that it defines. The combination of `domain` and `name` must be unique within the set of all approval types. It is a best practice to define `domain` with a URI or a URN.
   * @type {string}
   * @memberof ApprovalTypeFields
   */
  domain?: string;
  /**
   * An optional array of states that are not allowed for this approval type. If omitted, all state transitions are allowed. The states `open` and `approved` are always allowed, so this enumeration set is a subset of the `approvalState` enumeration on an approval.
   * @type {Array<DisallowedState>}
   * @memberof ApprovalTypeFields
   */
  disallowedStates?: Array<DisallowedState>;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Represents a person authorized for account access. This object contains key identification information for the person and the type of access or role that the person has in relation to the banking account or organization.
 * @export
 * @interface Authorization
 */
export interface Authorization extends IndividualIdentification {
  /**
   * The unique ID of the user. This is the `_id` value of the user resource from the Users API.
   * @type {string}
   * @memberof Authorization
   */
  userId?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof Authorization
   */
  customerId?: string;
  /**
   * The type of this account access authorization.  * *`primary`* the `contact` is the primary owner of a personal account. There may be only one  primary owner. The target of the authorization is a single personal account.  * *`joint`* the `contact` is a non-primary joint owner of a  personal account. The target of the authorization is a single personal account.  * *`authorizedSigner`* the `contact` is an authorized signer  for a business account. The target of the authorization is an  all business accounts owned by the organization.
   * @type {AuthorizationType}
   * @memberof Authorization
   */
  type?: AuthorizationType;
  /**
   * The person's role at the organization. This attribute is required when the authorization type is authorizedSigner.
   * @type {string}
   * @memberof Authorization
   */
  role?: string;
}

/**
 * The type of this account access authorization.  * *`primary`* the person is the primary owner of a personal account.  There may be only one primary owner.  * *`joint`* the person is a non-primary joint owner of a  personal account.  * *`authorizedSigner`* the person is an authorized signer  for all business accounts owned by the organization.
 * @export
 * @enum {string}
 */
export enum AuthorizationType {
  Primary = 'primary',
  Joint = 'joint',
  AuthorizedSigner = 'authorizedSigner',
}

/**
 * Authorized Signers are primary bank users and co-owners of a business, optionally passed when creating verification reports.
 * @export
 * @interface AuthorizedSigner
 */
export interface AuthorizedSigner {
  /**
   * The authorized signer's first name
   * @type {string}
   * @memberof AuthorizedSigner
   */
  firstName: string;
  /**
   * The authorized signer's last name
   * @type {string}
   * @memberof AuthorizedSigner
   */
  lastName: string;
  /**
   *
   * @type {IdentificationModel}
   * @memberof AuthorizedSigner
   */
  identification?: IdentificationModel;
  /**
   * The authorized signer's birth date in `yyyy-mm-dd` format.
   * @type {string}
   * @memberof AuthorizedSigner
   */
  birthdate?: string;
  /**
   * The authorized signer's email address
   * @type {string}
   * @memberof AuthorizedSigner
   */
  email?: string;
}

/**
 * The list of users who are authorized to access the organization and its bank accounts.
 * @export
 * @interface AuthorizedSigners
 */
export interface AuthorizedSigners extends AbstractResource {
  /**
   * The array of authorized signers for this business and their role within the organization. These people have account access for all business accounts owned by the business. The items in this array must all have the `type` of `authorizedSigner`.
   * @type {Array<Authorization>}
   * @memberof AuthorizedSigners
   */
  items?: Array<Authorization>;
}

/**
 * A person who owns 25% or more of a business organization.
 * @export
 * @interface BeneficialOwner
 */
export interface BeneficialOwner extends SimpleContact {
  /**
   * The person's role at the organization.
   * @type {string}
   * @memberof BeneficialOwner
   */
  role?: string;
  /**
   * The percent of the business that this person owns.
   * @type {number}
   * @memberof BeneficialOwner
   */
  percentage?: number;
  /**
   * The beneficial's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof BeneficialOwner
   */
  birthdate?: string;
  /**
   * The `_id` of an existing contact resource associated with the beneficial owner. Create the beneficial owner contact resource using the Contacts API.
   * @type {string}
   * @memberof BeneficialOwner
   */
  contactId?: string;
}

/**
 * A list of people who own at least 25% of the business or who have a major role in the organization. The sum of the percentages may not exceed 100%. The percentage may be less than 25 for non-owners with a major role, or to retain other owners whose percentage may change to 25% in the future.
 * @export
 * @interface BeneficialOwners
 */
export interface BeneficialOwners extends AbstractResource {
  /**
   * A list of people who own at least 25% of the business, and the percentage owned.
   * @type {Array<BeneficialOwner>}
   * @memberof BeneficialOwners
   */
  items?: Array<BeneficialOwner>;
}

/**
 * The verification report contains analsys of the business data and includes the state of the verification.
 * @export
 * @interface BusinessVerification
 */
export interface BusinessVerification {
  /**
   * The state of a verification report.  _passed_ indicates that the Business was successfully verified based upon the supplied information, _failed_ indicates it was not.
   * @type {string}
   * @memberof BusinessVerification
   */
  state?: BusinessVerification.StateEnum;
  /**
   * An ISO 8601 UTC time stamp indicating when the verification report was created.
   * @type {Date}
   * @memberof BusinessVerification
   */
  completedAt?: Date;
  /**
   * The identity method type. Possible values are `verificationReport` or `administratorApproval`.
   * @type {string}
   * @memberof BusinessVerification
   */
  type?: BusinessVerification.TypeEnum;
  /**
   * This business verification's unique id
   * @type {string}
   * @memberof BusinessVerification
   */
  _id?: string;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof BusinessVerification
   */
  _links?: { [key: string]: Link };
}

/**
 * @export
 * @namespace BusinessVerification
 */
export namespace BusinessVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Passed = 'passed',
    Failed = 'failed',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    VerificationReport = 'verificationReport',
    AdministratorApproval = 'administratorApproval',
  }
}

/**
 * An score that summarizes the verification of the input information. This objects contains a score `value` and accompanying `description`.
 * @export
 * @interface BusinessVerificationScore
 */
export interface BusinessVerificationScore {
  /**
   * The business verification score value
   * @type {string}
   * @memberof BusinessVerificationScore
   */
  value?: string;
  /**
   * The business verification score description
   * @type {string}
   * @memberof BusinessVerificationScore
   */
  description?: string;
}

/**
 * Representation of the verification results that were previously generated by this service via the `POST /businessVerifications`. The result contains a link to `apiture:organization` if an `apiture:organization` link was passed on the request to create the report.
 * @export
 * @interface BusinessVerifications
 */
export interface BusinessVerifications extends AbstractResource {
  /**
   * An array of business verification resources
   * @type {Array<BusinessVerification>}
   * @memberof BusinessVerifications
   */
  businessVerifications?: Array<BusinessVerification>;
}

/**
 * Citizenship or nationality status.
 * @export
 * @interface Citizenship
 */
export interface Citizenship {}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Fields common to applications and enrollments (applications to enroll in digital banking).
 * @export
 * @interface CommonFields
 */
export interface CommonFields {
  /**
   * The name of the person who started this application or enrollment. This is derived from the applicant resource passed via the first applicant if present, or the current user.
   * @type {string}
   * @memberof CommonFields
   */
  applicantName?: string;
  /**
   * The state of the embedded application workflow. This is derived and immutable.
   * @type {string}
   * @memberof CommonFields
   */
  workflowState?: string;
  /**
   * The state of the enrollment or application. The values mean:   * *`pending`* - Available to be started (`POST` to the `apiture:start` link to start it).     This state is reserved for future use.   * *`running`* - Started and has not completed or been canceled.   * *`blocked`* - Started but is blocked; there are no available workflow tasks.   * *`canceled`* - Canceled prior to completion   * *`expired`* - Not completed prior to a pre-defined application life cycle term.  For example, the FI may set a rule that all applications open longer than 30 days and not completed must be set to expired.   * *`rejected`* - Completed but was rejected after review   * *`approved`* - Completed and approved The value is updated by the various enrollment or application  operations.
   * @type {string}
   * @memberof CommonFields
   */
  state?: CommonFields.StateEnum;
  /**
   * `true` if the application is blocked awaiting review from the financial institution. This will be derived from the state and approvals of the application, and is immutable.
   * @type {boolean}
   * @memberof CommonFields
   */
  flaggedForReview?: boolean;
  /**
   * The date-time when this application was opened/created. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: `YYYY-MM-DDThh:mm:ss.sssZ`
   * @type {Date}
   * @memberof CommonFields
   */
  createdAt?: Date;
  /**
   * The date-time when this application was completed and its final resolution was set (approved, rejected, canceled, or expired). This is in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: `YYYY-MM-DDThh:mm:ss.sssZ`
   * @type {Date}
   * @memberof CommonFields
   */
  completedAt?: Date;
}

/**
 * @export
 * @namespace CommonFields
 */
export namespace CommonFields {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Pending = 'pending',
    Running = 'running',
    Blocked = 'blocked',
    Canceled = 'canceled',
    Expired = 'expired',
    Rejected = 'rejected',
    Approved = 'approved',
  }
}

/**
 * Objects common to enrollments and applications.
 * @export
 * @interface CommonObjects
 */
export interface CommonObjects {
  /**
   * The applicant or co-applicants seeking to enroll in digital banking and optionally open the account. If omitted, the service will create an array with one applicant, based on the current user.
   * @type {Array<Applicant>}
   * @memberof CommonObjects
   */
  applicants?: Array<Applicant>;
  /**
   * An array of metadata describing one or more required documents which the applicant may need to provide during the enrollment or application process. These can be applicant identity verification forms, such as a government ID, a tax ID, a utility bill, articles of incorporation (for business accounts) etc.
   * @type {Array<RequiredDocument>}
   * @memberof CommonObjects
   */
  requiredDocuments?: Array<RequiredDocument>;
  /**
   * An array of metadata listing zero or more documents which the FI reviewer must review and approve. These can be applicant identity verification forms, such as a government ID, a tax ID, a utility bill, articles of incorporation (for business accounts) etc.
   * @type {Array<Document>}
   * @memberof CommonObjects
   */
  documents?: Array<Document>;
  /**
   * All of the Approval objects which are associated with this enrollment or application. The `apiture:approve`, `apiture:reject`, `apiture:waive`, and `apiture:return` links in each Approval resource may be used to approve, reject, waive, or return the approval via `POST` operations (no request body).
   * @type {Array<Approval>}
   * @memberof CommonObjects
   */
  approvals?: Array<Approval>;
}

/**
 * The comprehensive verification score is a risk verification score for the authorized representative.
 * @export
 * @interface ComprehensiveVerificationScore
 */
export interface ComprehensiveVerificationScore {
  /**
   * the rep number for the authorized representative
   * @type {string}
   * @memberof ComprehensiveVerificationScore
   */
  inputRepNumber?: string;
  /**
   * The comprehensive verification score is a risk verification score of the authorized representative
   * @type {number}
   * @memberof ComprehensiveVerificationScore
   */
  score?: number;
  /**
   * The description for the CVI value
   * @type {string}
   * @memberof ComprehensiveVerificationScore
   */
  description?: string;
}

/**
 * Represents the configuration for various services.
 * @export
 * @interface Configuration
 */
export interface Configuration {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Configuration
   */
  _links?: { [key: string]: Link };
}

/**
 * Represents a configuration group.
 * @export
 * @interface ConfigurationGroup
 */
export interface ConfigurationGroup extends ConfigurationGroupSummary {
  /**
   * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
   * @type {{ [key: string]: ConfigurationSchemaValue; }}
   * @memberof ConfigurationGroup
   */
  schema?: { [key: string]: ConfigurationSchemaValue };
  /**
   * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
   * @type {{ [key: string]: ConfigurationValue; }}
   * @memberof ConfigurationGroup
   */
  values?: { [key: string]: ConfigurationValue };
}

/**
 * A summary of the data contained within a configuration group resource.
 * @export
 * @interface ConfigurationGroupSummary
 */
export interface ConfigurationGroupSummary extends AbstractResource {
  /**
   * The name of this configuration group, must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  name?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  description?: string;
}

/**
 * Collection of configuration groups. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ConfigurationGroups
 */
export interface ConfigurationGroups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ConfigurationGroups
   */
  _embedded?: any;
}

/**
 * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
 * @export
 * @interface ConfigurationSchema
 */
export interface ConfigurationSchema {
  [key: string]: ConfigurationSchemaValue;
}

/**
 * The data associated with this configuration schema.
 * @export
 * @interface ConfigurationSchemaValue
 */
export interface ConfigurationSchemaValue {}

/**
 * The data associated with this configuration.
 * @export
 * @interface ConfigurationValue
 */
export interface ConfigurationValue {}

/**
 * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
 * @export
 * @interface ConfigurationValues
 */
export interface ConfigurationValues {
  [key: string]: ConfigurationValue;
}

/**
 * Representation of a consent resource. Users consent or acceptance of a policy or other document.
 * @export
 * @interface Consent
 */
export interface Consent extends SummaryConsent {}

/**
 * Common fields of the consent resource used to build other model schemas.
 * @export
 * @interface ConsentFields
 */
export interface ConsentFields {
  /**
   * Properties of the target document.
   * @type {Document}
   * @memberof ConsentFields
   */
  document?: Document;
  /**
   * Describe what kind of consent this is. This value must be one of the type names in the `/consentTypeNames` resource.
   * @type {string}
   * @memberof ConsentFields
   */
  type?: string;
  /**
   * The URI of a resource that establishes the context in which the user's consent is requested for a specific document. For example, for consent of an account's terms and conditions, the context might be the banking product for that account.
   * @type {string}
   * @memberof ConsentFields
   */
  contextUri?: string;
  /**
   * The user ID of the user who is requested to consent to a document. This is the `_id` of the User resource.
   * @type {string}
   * @memberof ConsentFields
   */
  userId?: string;
}

/**
 * The state of a consent resource.
 * @export
 * @enum {string}
 */
export enum ConsentStates {
  Pending = 'pending',
  Given = 'given',
  Stale = 'stale',
  Rescinded = 'rescinded',
  Revoked = 'revoked',
}

/**
 * Product constraints, such as minimum and maximum balances.  This schema is version `v1.0.0`.
 * @export
 * @interface Constraints
 */
export interface Constraints {
  /**
   * The types of transactions permitted for this account. Values which appear in this array are permitted.
   * @type {TransactionTypes}
   * @memberof Constraints
   */
  transactionTypes?: TransactionTypes;
  /**
   * The minimum balance for accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumBalance?: string;
  /**
   * The minimum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumFundingAmount?: string;
  /**
   * The maximum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumFundingAmount?: string;
  /**
   * The minimum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumTransferAmount?: string;
  /**
   * The maximum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumTransferAmount?: string;
  /**
   * The maximum number of withdrawals allowed per cycle. If not present, there is no hard limit.
   * @type {number}
   * @memberof Constraints
   */
  maximumWithdrawalCount?: number;
  /**
   * The time limit within which account opening funding must occur after account creation. This is expressed as an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  fundingTerm?: string;
  /**
   * If true, deposits are not allowed after the rollover grace period (see `gracePeriod`). This applies to time deposit products only.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterGracePeriod?: boolean;
  /**
   * If true, deposits are not allowed after the initial account funding has completed. This typically applies to time deposit products.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterFunding?: boolean;
  /**
   * A period of time after account rollover when additional deposits are allowed. This is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  gracePeriod?: string;
}

/**
 * Representation of a contact resource. Contact data (mailing addresses, phone numbers, email addresses) for an individual.
 * @export
 * @interface Contact
 */
export interface Contact extends SummaryContact {
  /**
   * An optional map of name/value pairs which provide additional metadata about the contact.
   * @type {any}
   * @memberof Contact
   */
  attributes?: any;
  /**
   * The date-time when the contact was created.
   * @type {Date}
   * @memberof Contact
   */
  createdAt?: Date;
  /**
   * The date-time when the contact was updated
   * @type {Date}
   * @memberof Contact
   */
  updatedAt?: Date;
}

/**
 * @export
 * @namespace Contact
 */
export namespace Contact {}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * The state of this person. The values are described in the `contactState` text via the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum ContactState {
  Inactive = 'inactive',
  Active = 'active',
  Merged = 'merged',
  Removed = 'removed',
}

/**
 * The contact's verification history and status.
 * @export
 * @interface ContactVerification
 */
export interface ContactVerification extends AbstractResource {
  /**
   * The history of this contact's identity verifications.
   * @type {Array<IdentityHistoryItem>}
   * @memberof ContactVerification
   */
  verifications?: Array<IdentityHistoryItem>;
}

/**
 * Common fields of the contact resource used to build other model schemas for people who hold bank accounts.
 * @export
 * @interface ContactVerificationFields
 */
export interface ContactVerificationFields {
  /**
   * An object that contains the answers to Know Your Customer (KYC) questions. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {any}
   * @memberof ContactVerificationFields
   */
  kycAnswers?: any;
  /**
   * Use the `state` of `identityVerification`. The identity verification status for this person.  This field is read-only and is derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {string}
   * @memberof ContactVerificationFields
   */
  identityVerificationStatus?: ContactVerificationFields.IdentityVerificationStatusEnum;
  /**
   * The identity verification data for this person.  These fields are derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record. **Warning**: This property is deprecated. Identity verification details will only exist on Users, not Contacts.
   * @type {IdentityVerification}
   * @memberof ContactVerificationFields
   */
  identityVerification?: IdentityVerification;
}

/**
 * @export
 * @namespace ContactVerificationFields
 */
export namespace ContactVerificationFields {
  /**
   * @export
   * @enum {string}
   */
  export enum IdentityVerificationStatusEnum {
    Verified = 'verified',
    Unverified = 'unverified',
  }
}

/**
 * Representation of the request used to create a new account application. This does not create an _account_, just an _application_. When the application is completed and approved, the account will be created. The request must contain the following contents:    * `products` - an array of one or more Product objects which determine    the banking product for the new account(s). The first(required)    item in    the array is the primary account; others are optional secondary accounts in    a product bundle. The products must be an    _active_ internal account products that is eligible for    opening new accounts. (`\"newAccountAvailability\": \"available\"`)  These objects passed in the request may be complete object representations, or they may be \"thin\" objects with only [HAL](http://developer.apiture.com/docs/concepts/hal) `_links` with a `self` link containing the object URL; the application resource will fetch these objects. Creating an application will instantiate a workflow instance, based on a workflow definition that is associated with the primary banking product in the application. The client application should process that workflow instance and present any interactive tasks which are available to run, and continue until the workflow is done.
 * @export
 * @interface CreateApplication
 */
export interface CreateApplication
  extends AbstractRequest,
    ApplicationFields,
    CommonObjects,
    ApplicationObjects {}

/**
 * Representation of the request to enroll a user in digital banking. Creating an enrollment will instantiate a workflow instance, based on a workflow definition that is configured for new user enrollment. This will typically apply the financial institution's Customer Identification Program (CIP) process, a.k.a. their Know Your Customer process. The client application should monitor that workflow instance and present any interactive tasks which are available to run, and continue until the workflow is done.
 * @export
 * @interface CreateEnrollment
 */
export interface CreateEnrollment extends AbstractRequest, EnrollmentFields, CommonObjects {}

/**
 * Representation used to create a new verification report.
 * @export
 * @interface CreateVerificationReport
 */
export interface CreateVerificationReport extends VerificationRequestFields, AbstractRequest {}

/**
 * A disallowed state for an approval. Approvals of this type may not be set to any of the states defined by this.
 * @export
 * @enum {string}
 */
export enum DisallowedState {
  Rejected = 'rejected',
  Waived = 'waived',
  Returned = 'returned',
  Canceled = 'canceled',
}

/**
 * Properties of a target document.
 * @export
 * @interface Document
 */
export interface Document {
  /**
   * The URI of the target document that the user is consenting to. If the document is revised, this consent is marked as `stale`. (Note: This need not be a document in the Apiture vault.)
   * @type {string}
   * @memberof Document
   */
  uri: string;
  /**
   * The [media type](https://tools.ietf.org/html/rfc6838) for the document. For text documents, the content type should include the text encoding; if omitted, the encoding type is assumed to be utf-8.
   * @type {any}
   * @memberof Document
   */
  contentType: any;
  /**
   * The revision identifier of the document revision the user consented to. If the content management system in which the document is stored does not define revision identifiers or tags, this may be omitted and will default to the revision time stamp.
   * @type {string}
   * @memberof Document
   */
  revisionId?: string;
  /**
   * The time stamp when the target document was last revised (modified), in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Document
   */
  revisedAt: Date;
}

/**
 * A list of email addresses and the preferred email address.
 * @export
 * @interface EmailAddresses
 */
export interface EmailAddresses {
  /**
   * An array of email addresses.
   * @type {Array<TypedEmailAddress>}
   * @memberof EmailAddresses
   */
  emailAddresses?: Array<TypedEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.
   * @type {string}
   * @memberof EmailAddresses
   */
  preferredEmailAddressId?: string;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The employment status of a contact, located in `kycAnswers`.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `employmentStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmploymentStatus {
  Unknown = 'unknown',
  FullTime = 'fullTime',
  PartTime = 'partTime',
  PaidLeave = 'paidLeave',
  Retired = 'retired',
  Unemployed = 'unemployed',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Representation of the request to enroll a user in digital banking.
 * @export
 * @interface Enrollment
 */
export interface Enrollment extends CommonObjects, SummaryEnrollment {}

/**
 * @export
 * @namespace Enrollment
 */
export namespace Enrollment {}

/**
 * Common fields of the enrollment resource used to build other model schemas.
 * @export
 * @interface EnrollmentFields
 */
export interface EnrollmentFields {
  /**
   * The applicant seeking to enroll in digital banking. If omitted, the service will create the applicant, based on the current user. *Warning*: This property is deprecated. Use `applicants`.
   * @type {Applicant}
   * @memberof EnrollmentFields
   */
  applicant?: Applicant;
}

/**
 * Collection digital banking enrollments. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links: `self`, `next`, `prev`, `first`, `last`, `collection`.
 * @export
 * @interface Enrollments
 */
export interface Enrollments extends Collection {
  /**
   * Embedded resources.
   * @type {any}
   * @memberof Enrollments
   */
  _embedded?: any;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * The estimated annual revenue in USD.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `estimatedAnnualRevenue` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EstimatedAnnualRevenue {
  Unknown = 'unknown',
  Under1Million = 'under1Million',
  From1to10Million = 'from1to10Million',
  From10to100Million = 'from10to100Million',
  Over100Million = 'over100Million',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Estimated monthly amounts for banking services.
 * @export
 * @interface EstimatedMonthlyAmounts
 */
export interface EstimatedMonthlyAmounts {
  /**
   * The percentage of gross revenue the organization derives from money services.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  percentGrossRevenue?: string;
  /**
   * Indicates the estimated monthly total amount to send by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentAch?: string;
  /**
   * Indicates the estimated monthly total amount to receive by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedAch?: string;
  /**
   * Indicates the estimated monthly minimum amount to deposit.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  mobileCheckDeposit?: string;
  /**
   * Indicates the estimated monthly minimum wires amount sent.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentWire?: string;
  /**
   * Indicates the estimated monthly minimum wires amount received.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedWire?: string;
}

/**
 * The state of an external (linked) banking account. This field is immutable and derived.    * **`pending`** : A new external account that has not been verified   * **`verifying`** : A new account that is being verified. This state only   applies to _external_ accounts.   * **`failed`** : A external account which has failed account verification.   * **`active`** : An account which is active and available for use   and for making new transactions.   * **`inactive`** : An account which is marked inactive and   not available for new transactions. Inactive accounts   may be changed back to active.   * **`frozen`** : An account which is frozen and not eligible   for new transactions. This is typically the result of   suspicious activity or fraud detection. The user must contact   their financial institution to unfreeze the account (by changing   the state back to `active`) or the financial institution   may opt to close the account.   * **`closed`** : An account that is closed and removed from use.   Closed accounts are not eligible for transactions or to become active.   Such accounts are retained for historical purposes because some   transactions may refer to it. Users do not see closed accounts   when they view their accounts.   * **`underReview`** : A new account that is being under review. This state only   applies to _external_ accounts.  To change the state of an account, `POST` the account ID to the corresponding resource endpoints, using the corresponding link on the account resource. To activate an account, use the `apiture:activate` link to `POST` to `/accounts/activeAccounts`. To deactivate an account, use the `apiture:deactivate` link to `POST` to `/accounts/inactiveAccounts`. To freeze an account, use the `apiture:freeze` link to `POST` to `/accounts/frozenAccounts`. To close an account, use the `apiture:close` link to `POST` to `/accounts/closedAccounts`. To under review an account, use the `apiture:review` link to `POST` to `/accounts/externalAccountsUnderReview`.
 * @export
 * @enum {string}
 */
export enum ExternalAccountState {
  Pending = 'pending',
  Verifying = 'verifying',
  Failed = 'failed',
  Active = 'active',
  Inactive = 'inactive',
  Frozen = 'frozen',
  Closed = 'closed',
  UnderReview = 'underReview',
}

/**
 * The type of association to a foreign political figure. This eumeration is described by the foreignPoliticalFigureAssociation value from the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum ForeignPoliticalFigureAssociation {
  Unknown = 'unknown',
  CloseAssociate = 'closeAssociate',
  FamilyMember = 'familyMember',
  None = 'none',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Representation of a fraud-risk category.
 * @export
 * @interface FraudRiskCategory
 */
export interface FraudRiskCategory {
  /**
   *
   * @type {FraudRiskCategoryType}
   * @memberof FraudRiskCategory
   */
  type?: FraudRiskCategoryType;
  /**
   * The description of the fraud.
   * @type {string}
   * @memberof FraudRiskCategory
   */
  description?: string;
  /**
   * The original result message that was received from the identity verification provider.
   * @type {string}
   * @memberof FraudRiskCategory
   */
  message?: string;
}

/**
 * Represents the possible types of fraud-risk.
 * @export
 * @enum {string}
 */
export enum FraudRiskCategoryType {
  IpRestricted = 'ipRestricted',
  IdentityOnGovernmentWatchlist = 'identityOnGovernmentWatchlist',
  IdentityOnAlertList = 'identityOnAlertList',
  AddressIsPOBoxOrNonApproved = 'addressIsPOBoxOrNonApproved',
  AddressIsHighRisk = 'addressIsHighRisk',
  AgeRestricted = 'ageRestricted',
  NonStandardTaxId = 'nonStandardTaxId',
  PersonalInfoDoesNotMatch = 'personalInfoDoesNotMatch',
  EmailRestricted = 'emailRestricted',
}

/**
 * The result of running a fraud-risk analysys.
 * @export
 * @interface FraudRiskReport
 */
export interface FraudRiskReport extends AbstractResource, IdentityVerification {
  /**
   *
   * @type {FraudRiskReportInputs}
   * @memberof FraudRiskReport
   */
  inputs?: FraudRiskReportInputs;
  /**
   *
   * @type {FraudRiskReportOutputs}
   * @memberof FraudRiskReport
   */
  outputs?: FraudRiskReportOutputs;
}

/**
 * @export
 * @namespace FraudRiskReport
 */
export namespace FraudRiskReport {}

/**
 * The inputs of a fraud-risk report.
 * @export
 * @interface FraudRiskReportInputs
 */
export interface FraudRiskReportInputs {
  /**
   *
   * @type {Identity}
   * @memberof FraudRiskReportInputs
   */
  identity?: Identity;
}

/**
 * The outputs of a fraud-risk report.
 * @export
 * @interface FraudRiskReportOutputs
 */
export interface FraudRiskReportOutputs extends Outputs {
  /**
   * External identity provider report Id.
   * @type {string}
   * @memberof FraudRiskReportOutputs
   */
  providerReportId?: string;
  /**
   *
   * @type {FraudRiskReportState}
   * @memberof FraudRiskReportOutputs
   */
  state?: FraudRiskReportState;
  /**
   * A list of categories in this report.
   * @type {Array<FraudRiskCategory>}
   * @memberof FraudRiskReportOutputs
   */
  fraudRiskCategories?: Array<FraudRiskCategory>;
}

/**
 * The state of a fraud report. `passed` indicates that the provided personally identifiable information (PII) was located and contains no risk factors. `passedWithRiskFactors` means that the provided PII matches an identity but contains risk factors. `failed` means that the provided PII does not match any identity records.
 * @export
 * @enum {string}
 */
export enum FraudRiskReportState {
  Passed = 'passed',
  PassedWithRiskFactors = 'passedWithRiskFactors',
  Failed = 'failed',
}

/**
 * Official identifying information associated with the contact.
 * @export
 * @interface Identification
 */
export interface Identification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof Identification
   */
  value: string;
  /**
   * The type of this form of identification.
   * @type {string}
   * @memberof Identification
   */
  type: Identification.TypeEnum;
  /**
   * The date when the form of identification expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` format.
   * @type {string}
   * @memberof Identification
   */
  expiration?: string;
}

/**
 * @export
 * @namespace Identification
 */
export namespace Identification {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    TaxId = 'taxId',
    PassportNumber = 'passportNumber',
  }
}

/**
 * A collection of official identifying information associated with an entity.
 * @export
 * @interface IdentificationModel
 */
export interface IdentificationModel {}

/**
 * A contact with additional personally identifiable information data.
 * @export
 * @interface IdentifiedContact
 */
export interface IdentifiedContact extends SimpleContact, IdentifiedContactFields {}

/**
 * Properties which provide additional identification of a person.
 * @export
 * @interface IdentifiedContactFields
 */
export interface IdentifiedContactFields {
  /**
   * The contact's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  birthdate?: string;
  /**
   * This individual's citizenship or nationality status.
   * @type {Citizenship}
   * @memberof IdentifiedContactFields
   */
  citizenship?: Citizenship;
  /**
   * This individual's residency status.
   * @type {ResidencyStatus}
   * @memberof IdentifiedContactFields
   */
  residencyStatus?: ResidencyStatus;
  /**
   * The occupation of this individual.
   * @type {Occupation}
   * @memberof IdentifiedContactFields
   */
  occupation?: Occupation;
  /**
   * The actual occupation of this individual if their `occupation` is `other`. This is ignored if `occupation` is not `other`.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  otherOccupation?: string;
  /**
   * The number of years the person has been at their present home address.
   * @type {YearsAtAddress}
   * @memberof IdentifiedContactFields
   */
  yearsAtAddress?: YearsAtAddress;
}

/**
 * Information that describes the identity.
 * @export
 * @interface Identity
 */
export interface Identity {
  /**
   * The identity's tax or government ID.
   * @type {string}
   * @memberof Identity
   */
  taxId: string;
  /**
   * The identity's first name.
   * @type {string}
   * @memberof Identity
   */
  firstName: string;
  /**
   * The identity's last name.
   * @type {string}
   * @memberof Identity
   */
  lastName: string;
  /**
   * Line 1 of the identity's street address.
   * @type {string}
   * @memberof Identity
   */
  address1: string;
  /**
   * Line 2 of the identity's street address.
   * @type {string}
   * @memberof Identity
   */
  address2?: string;
  /**
   * The identity's city.
   * @type {string}
   * @memberof Identity
   */
  city: string;
  /**
   * The identity's region.
   * @type {string}
   * @memberof Identity
   */
  region: string;
  /**
   * The identity's postal code.
   * @type {string}
   * @memberof Identity
   */
  postalCode: string;
  /**
   * The identity's phone.
   * @type {string}
   * @memberof Identity
   */
  phone: string;
  /**
   * The identity's birth date in `yyyy-mm-dd` format.
   * @type {string}
   * @memberof Identity
   */
  birthdate: string;
  /**
   * The identity's email address.
   * @type {string}
   * @memberof Identity
   */
  email?: string;
  /**
   * The identity's IP address.
   * @type {string}
   * @memberof Identity
   */
  ipAddress?: string;
}

/**
 * One verification record for a contact's history of verifications. This may contain a link to the contact in the link `apiture:contact`.
 * @export
 * @interface IdentityHistoryItem
 */
export interface IdentityHistoryItem {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof IdentityHistoryItem
   */
  _links?: { [key: string]: Link };
  /**
   *
   * @type {IdentityVerificationState}
   * @memberof IdentityHistoryItem
   */
  state: IdentityVerificationState;
  /**
   *
   * @type {IdentityVerificationType}
   * @memberof IdentityHistoryItem
   */
  type?: IdentityVerificationType;
  /**
   * The date-time when the verification occurred or completed. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityHistoryItem
   */
  createdAt: Date;
  /**
   * The date-time when the verification expired. This is only set if the `state` is `expired`. This is an [RFC 3066](https://tools.ietf.org/html/rfc3339) time stamp in the form `YYYY-DD-MMThh:mm:ss.sssZ`.
   * @type {Date}
   * @memberof IdentityHistoryItem
   */
  expiredAt?: Date;
}

/**
 * Data points on the identity verification process that tells if a user has passed, failed or expired the identity check.
 * @export
 * @interface IdentityVerification
 */
export interface IdentityVerification {
  /**
   * The name of the identity verification provider.
   * @type {string}
   * @memberof IdentityVerification
   */
  provider?: string;
  /**
   * The unique id for a session of the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  sessionId?: string;
  /**
   * The date-time when the provider ran identity verification. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp.
   * @type {Date}
   * @memberof IdentityVerification
   */
  scoredAt?: Date;
  /**
   * The indication if the contact has passed or failed the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  score?: IdentityVerification.ScoreEnum;
  /**
   * The identity verification status for this person.  This field is read-only and is derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record.
   * @type {string}
   * @memberof IdentityVerification
   */
  state?: IdentityVerification.StateEnum;
}

/**
 * @export
 * @namespace IdentityVerification
 */
export namespace IdentityVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum ScoreEnum {
    Passed = 'passed',
    Failed = 'failed',
    Expired = 'expired',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Verified = 'verified',
    Unverified = 'unverified',
  }
}

/**
 * The type of the historical verification.
 * @export
 * @enum {string}
 */
export enum IdentityVerificationState {
  Passed = 'passed',
  Failed = 'failed',
  PassedWithRiskFactors = 'passedWithRiskFactors',
  Pending = 'pending',
  Asked = 'asked',
  IdentityServiceFailure = 'identityServiceFailure',
  Scoring = 'scoring',
  Expired = 'expired',
}

/**
 * Describes how the identity verification was performed.
 * @export
 * @enum {string}
 */
export enum IdentityVerificationType {
  FraudRiskReport = 'fraudRiskReport',
  Quiz = 'quiz',
  AdminApproval = 'adminApproval',
}

/**
 * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values. Labels and descriptions for the enumeration values are in the `ifxType` key in the response of the `getLabels` operation.  <strong><code>ifxType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named ifxType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `ifxType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>CCA</code></strong></td><td>Credit card account</td>     </tr> <tr>     <td><strong><code>CDA</code></strong></td><td>Certificate of deposit account (CD)</td>     </tr> <tr>     <td><strong><code>CLA</code></strong></td><td>Commercial loan account</td>     </tr> <tr>     <td><strong><code>CMA</code></strong></td><td>Cash management account</td>     </tr> <tr>     <td><strong><code>DDA</code></strong></td><td>Demand deposit account</td>     </tr> <tr>     <td><strong><code>EQU</code></strong></td><td>Home equity loan</td>     </tr> <tr>     <td><strong><code>GLA</code></strong></td><td>General ledger account</td>     </tr> <tr>     <td><strong><code>ILA</code></strong></td><td>Installment loan account</td>     </tr> <tr>     <td><strong><code>INV</code></strong></td><td>Investment account</td>     </tr> <tr>     <td><strong><code>IRA</code></strong></td><td>Individual retirement account</td>     </tr> <tr>     <td><strong><code>IRL</code></strong></td><td>Accounts held in Ireland</td>     </tr> <tr>     <td><strong><code>LOC</code></strong></td><td>Consumer line of credit</td>     </tr> <tr>     <td><strong><code>MLA</code></strong></td><td>Military Lending Account: Credit facility held by former US service member</td>     </tr> <tr>     <td><strong><code>MMA</code></strong></td><td>Money market account</td>     </tr> <tr>     <td><strong><code>PBA</code></strong></td><td>Packaged bank Account: Account with additional benefits that charges a fixed monthly fee.</td>     </tr> <tr>     <td><strong><code>PPA</code></strong></td><td>Private pension administrator</td>     </tr> <tr>     <td><strong><code>RWD</code></strong></td><td>Reward accounts</td>     </tr> <tr>     <td><strong><code>SDA</code></strong></td><td>Savings deposit account</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum IfxType {
  CCA = 'CCA',
  CDA = 'CDA',
  CLA = 'CLA',
  CMA = 'CMA',
  DDA = 'DDA',
  EQU = 'EQU',
  GLA = 'GLA',
  ILA = 'ILA',
  INV = 'INV',
  IRA = 'IRA',
  IRL = 'IRL',
  LOC = 'LOC',
  MLA = 'MLA',
  MMA = 'MMA',
  PBA = 'PBA',
  PPA = 'PPA',
  RWD = 'RWD',
  SDA = 'SDA',
}

/**
 * This object contains key identification information for a person associated with digital banking.
 * @export
 * @interface IndividualIdentification
 */
export interface IndividualIdentification extends ContactName, Addresses {
  /**
   * Official government identification (tax ID) for this person.
   * @type {string}
   * @memberof IndividualIdentification
   */
  taxId?: string;
  /**
   * Indicates if the person is a (US) citizen.
   * @type {boolean}
   * @memberof IndividualIdentification
   */
  citizen?: boolean;
  /**
   * Optional email address.
   * @type {string}
   * @memberof IndividualIdentification
   */
  emailAddress?: string;
}

/**
 * The rate type. The rate type may not be changed once it is set at product creation. Rate types are:   * *`apr`* - annual percentage rate   * *`apy`* - annual percentage yield  This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum InterestRateType {
  Apr = 'apr',
  Apy = 'apy',
}

/**
 * The intermediary/non-bank financial institution services provided.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `intermediaryServices` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum IntermediaryServices {
  Unknown = 'unknown',
  Accounting = 'accounting',
  FundsManagement = 'fundsManagement',
  Insurance = 'insurance',
  Investment = 'investment',
  Legal = 'legal',
  Medical = 'medical',
  Notary = 'notary',
  RealEstate = 'realEstate',
  TaxPreparation = 'taxPreparation',
  TrustManagement = 'trustManagement',
  Gambling = 'gambling',
  Securities = 'securities',
  LoanFinance = 'loanFinance',
  PawnBrokerage = 'pawnBrokerage',
  TravelAgency = 'travelAgency',
  VehicleSales = 'vehicleSales',
  ForeignCurrency = 'foreignCurrency',
  PreciousMetals = 'preciousMetals',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Answers to 'Know Your Customer' questions which allow financial institutions to conform to a customer identification program.
 * @export
 * @interface KycAnswers
 */
export interface KycAnswers {
  /**
   * `true` if the person is a citizen of the country in which the financial institution is doing business.
   * @type {boolean}
   * @memberof KycAnswers
   */
  citizen?: boolean;
  /**
   * `true` if the person is a permanent resident of the country in which the financial institution is doing business.
   * @type {boolean}
   * @memberof KycAnswers
   */
  permanentResident?: boolean;
  /**
   * `true` if the person is a subject to backup W-9 Tax Withholdings.
   * @type {boolean}
   * @memberof KycAnswers
   */
  w9Withholdings?: boolean;
  /**
   * The employment status of the person.
   * @type {EmploymentStatus}
   * @memberof KycAnswers
   */
  employmentStatus?: EmploymentStatus;
  /**
   * `true` if the person is a foreign senior political figure.
   * @type {boolean}
   * @memberof KycAnswers
   */
  foreignPoliticalFigure?: boolean;
  /**
   * If the person is a foreign senior political figure, this is the foreign country. This field is omitted if `foreignPoliticalFigure` is `false`.
   * @type {string}
   * @memberof KycAnswers
   */
  countryPoliticalFigure?: string;
  /**
   * `true` if the person is an immediate family member or a close associate of political figure.
   * @type {boolean}
   * @memberof KycAnswers
   */
  familyOfPoliticalFigure?: boolean;
  /**
   * If the person is a foreign senior political figure, this is the foreign country ISO 3166-1 country code. This field is omitted if `foreignPoliticalFigure` is `false`.
   * @type {string}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureCountry?: string;
  /**
   * The type of association to a foreign political figure.
   * @type {ForeignPoliticalFigureAssociation}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureAssociation?: ForeignPoliticalFigureAssociation;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Indicates how the principal and interest are processed upon maturity. The values indicate whether to rollover (to a time deposit account of the same rate and term), transfer funds to another (possibly new) deposit account, or simply hold the funds in the current account (which may no longer accrue interest). Labels and descriptions for the enumeration values are in the `maturityPolicy` key in the response of the `getLabels` operation.  <strong><code>maturityPolicy</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named maturityPolicy)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `maturityPolicy` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>rolloverPrincipalAndInterest</code></strong></td><td>Rollover principal and interest to a new CD of the same product: Upon maturity, both principal and interest rollover into a specified banking product, such as a savings, checking, or other deposit account.</td>     </tr> <tr>     <td><strong><code>transferPrincipalAndInterest</code></strong></td><td>Transfer principal and interest to a deposit account: Upon maturity, the principal an interest are both transferred to an existing or new deposit account.</td>     </tr> <tr>     <td><strong><code>rolloverPrincipalAndTransferInterest</code></strong></td><td>Transfer interest to a new deposit account an rollover principal to a new CD of the same product: Upon maturity, the principal rolls over into a specified banking product and the interest is transferred to an existing deposit account.</td>     </tr> <tr>     <td><strong><code>holdPrincipalAndInterest</code></strong></td><td>Hold principal and accued interest in the CD account until withdrawal: Upon maturity, the principal and interest are held in the current time deposit account. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> <tr>     <td><strong><code>partialTransfer</code></strong></td><td>Partial Transfer: Upon maturity, any funds greater than the maturity threshold is transfered to an existing deposit account and the rest remains on deposit. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum MaturityPolicy {
  RolloverPrincipalAndInterest = 'rolloverPrincipalAndInterest',
  TransferPrincipalAndInterest = 'transferPrincipalAndInterest',
  RolloverPrincipalAndTransferInterest = 'rolloverPrincipalAndTransferInterest',
  HoldPrincipalAndInterest = 'holdPrincipalAndInterest',
  PartialTransfer = 'partialTransfer',
}

/**
 * An amount of money in a specific currency.
 * @export
 * @interface Money
 */
export interface Money {
  /**
   * The net monetary value. A negative amount denotes a debit; a positive amount a credit. The numeric value is represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof Money
   */
  value?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII. Note: ISO 4217 defines three-character codes. However, ISO 4217 does not account for cryptocurrencies. Of note, DASH uses 4 characters.
   * @type {string}
   * @memberof Money
   */
  currency?: string;
}

/**
 * Describes if the product is available for opening new accounts.  <strong><code>newAccountAvailability</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named newAccountAvailability)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `newAccountAvailability` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>available</code></strong></td><td>Users may open new accounts of this type</td>     </tr> <tr>     <td><strong><code>notAvailable</code></strong></td><td>Users may not open new accounts of this type</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum NewAccountAvailability {
  Available = 'available',
  NotAvailable = 'notAvailable',
}

/**
 * The person's occupation.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `occupation` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum Occupation {
  Unknown = 'unknown',
  ArchitectureAndEngineering = 'architectureAndEngineering',
  ArtsDesignEntertainmentSportsAndMedia = 'artsDesignEntertainmentSportsAndMedia',
  BuildingAndGroundsCleaningAndMaintenance = 'buildingAndGroundsCleaningAndMaintenance',
  BusinessAndFinancialOperations = 'businessAndFinancialOperations',
  CommunityAndSocialService = 'communityAndSocialService',
  ComputerAndMathematical = 'computerAndMathematical',
  ConstructionAndExtraction = 'constructionAndExtraction',
  EducationTrainingAndLibrary = 'educationTrainingAndLibrary',
  FarmingFishingAndForestry = 'farmingFishingAndForestry',
  FoodPreparationAndServingRelated = 'foodPreparationAndServingRelated',
  HealthcarePractitionersAndTechnical = 'healthcarePractitionersAndTechnical',
  HealthcareSupport = 'healthcareSupport',
  InstallationMaintenanceAndRepair = 'installationMaintenanceAndRepair',
  Legal = 'legal',
  LifePhysicalAndSciences = 'lifePhysicalAndSciences',
  Management = 'management',
  MilitarySpecific = 'militarySpecific',
  OfficeAndAdministrativeSupport = 'officeAndAdministrativeSupport',
  PersonalCareAndService = 'personalCareAndService',
  Production = 'production',
  ProtectiveServices = 'protectiveServices',
  SalesAndRelated = 'salesAndRelated',
  TransportationAndMaterialMoving = 'transportationAndMaterialMoving',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Representation of content and descriptive data (mailing addresses, phone numbers, email addresses) for an organization.  An organization which is used for a business banking account may have authorized signers, which are people authorized to perform banking operations on the business account(s) such as initiating funds transfers.  Regulations require identifying an organization's _beneficial owners_: people who own 25% or more of a business. These may be listed and updated with the `getBeneficialOwners` and `updateBeneficialOwners` operations.  An organization may have the following links in the `_links` object:   * **`apiture:activate`** - Activate a new, pending organization.   * **`apiture:deactivate`** - Deactivate an organization (if it   is pending or active).   * **`apiture:remove`** - Remove an inactive organization.   * **`apiture:authorizedSigners`** - List the authorized signers.   * **`apiture:beneficialOwners`** - List the beneficial owners.
 * @export
 * @interface Organization
 */
export interface Organization extends SummaryOrganization {
  /**
   * The date-time when the organization was created.
   * @type {Date}
   * @memberof Organization
   */
  createdAt?: Date;
  /**
   * The date-time when the organization was updated
   * @type {Date}
   * @memberof Organization
   */
  updatedAt?: Date;
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof Organization
   */
  attributes?: any;
  /**
   * Embedded objects, as selected with the `?embed` query parameter.
   * @type {any}
   * @memberof Organization
   */
  _embedded?: any;
}

/**
 * Representation of an organization's address resource.
 * @export
 * @interface OrganizationAddress
 */
export interface OrganizationAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof OrganizationAddress
   */
  state?: ProfileItemState;
}

/**
 * Representation of email address resources. An email address is immutable, although organizations can add new email addresses.
 * @export
 * @interface OrganizationEmailAddress
 */
export interface OrganizationEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof OrganizationEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * Common fields of the organization resource, for organizations which conduct banking.
 * @export
 * @interface OrganizationFields
 */
export interface OrganizationFields extends SimpleOrganization {
  /**
   * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
   * @type {OrganizationState}
   * @memberof OrganizationFields
   */
  state?: OrganizationState;
  /**
   * The trade name of the organization.
   * @type {string}
   * @memberof OrganizationFields
   */
  tradeName?: string;
  /**
   * Indicates whether the organization is a government-owned entity.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  governmentOwned?: boolean;
  /**
   * Indicates whether the organization is publicly held.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  publiclyHeld?: boolean;
  /**
   * Indicates whether the organization is classified as a small business
   * @type {boolean}
   * @memberof OrganizationFields
   */
  smallBusiness?: boolean;
  /**
   * Indicates whether the organization is the tax-exempt.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  taxExempt?: boolean;
  /**
   * Indicates the approximate number of employees, as a range.
   * @type {string}
   * @memberof OrganizationFields
   */
  employeeCountRange?: string;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountLowerBound?: number;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountUpperBound?: number;
  /**
   * The organization's home page.
   * @type {string}
   * @memberof OrganizationFields
   */
  homeUrl?: string;
  /**
   * Indicates what industry does this organization work within.
   * @type {string}
   * @memberof OrganizationFields
   */
  industry?: string;
  /**
   * The ISO 3166-1 country code for the organization's operation.
   * @type {string}
   * @memberof OrganizationFields
   */
  countryOfOperations?: string;
  /**
   * Answers to organization-specific regulatory questions.
   * @type {Regulatory}
   * @memberof OrganizationFields
   */
  regulatory?: Regulatory;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII. TODO: ISO 4217 defines three-character codes. However, ISO 4217 does not account for cryptocurrencies. Of note, DASH uses 4 characters.
   * @type {string}
   * @memberof OrganizationFields
   */
  currency?: string;
  /**
   * Indicates that the organization use mobile check deposits.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  mobileCheckDepositEnabled?: boolean;
  /**
   * Indicates that the organization use ACH transfers.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  achEnabled?: boolean;
  /**
   * Estimated monthly amounts for banking services.
   * @type {EstimatedMonthlyAmounts}
   * @memberof OrganizationFields
   */
  estimatedMonthlyAmounts?: EstimatedMonthlyAmounts;
  /**
   * The purpose of the account.
   * @type {AccountPurpose}
   * @memberof OrganizationFields
   */
  accountPurpose?: AccountPurpose;
  /**
   * The US state or other region in which the organization is registered.
   * @type {string}
   * @memberof OrganizationFields
   */
  registeredIn?: string;
}

/**
 * The type and value of the organizations unique identification numbers.
 * @export
 * @interface OrganizationIdentification
 */
export interface OrganizationIdentification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof OrganizationIdentification
   */
  value: string;
  /**
   * The type of this form of identification. `taxId` is the only supported type at this time.
   * @type {OrganizationIdentificationType}
   * @memberof OrganizationIdentification
   */
  type: OrganizationIdentificationType;
  /**
   * The date when this form of identification expires.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiresOn?: string;
  /**
   * The date when this form of identification expires. **Note** This property is deprecated; use `expiresOn`.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiration?: string;
}

/**
 * The type of the form of an organization's identification. `taxId` is the only supported type at this time.
 * @export
 * @enum {string}
 */
export enum OrganizationIdentificationType {
  TaxId = 'taxId',
  DunsNumber = 'dunsNumber',
}

/**
 * Representation of phone number resources.
 * @export
 * @interface OrganizationPhoneNumber
 */
export interface OrganizationPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof OrganizationPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum OrganizationState {
  Pending = 'pending',
  Inactive = 'inactive',
  Active = 'active',
  Merged = 'merged',
  Removed = 'removed',
}

/**
 * Base model schema for identity verification operations outputs.
 * @export
 * @interface Outputs
 */
export interface Outputs extends VerificationToken {}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * A list of phone numbers and the preferred phone number.
 * @export
 * @interface PhoneNumbers
 */
export interface PhoneNumbers {
  /**
   * An array of phone numbers.
   * @type {Array<PhoneNumber>}
   * @memberof PhoneNumbers
   */
  phones?: Array<PhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array.
   * @type {string}
   * @memberof PhoneNumbers
   */
  preferredPhoneId?: string;
}

/**
 * The contact's preferred method of communication.
 * @export
 * @enum {string}
 */
export enum PreferredContactMethod {
  Unknown = 'unknown',
  Sms = 'sms',
  Email = 'email',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.  <strong><code>prodState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named prodState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `prodState` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>pending</code></strong></td><td>This product has been created in draft form but is not yet available</td>     </tr> <tr>     <td><strong><code>active</code></strong></td><td>This product is active and available for use</td>     </tr> <tr>     <td><strong><code>inactive</code></strong></td><td>This product is temporarily not available for use</td>     </tr> <tr>     <td><strong><code>removed</code></strong></td><td>This product has been removed and is permanently not available for use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProdState {
  Pending = 'pending',
  Active = 'active',
  Inactive = 'inactive',
  Removed = 'removed',
}

/**
 * Common fields of the product resource.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductFields
 */
export interface ProductFields extends ProductState {
  /**
   * The name of this product.
   * @type {string}
   * @memberof ProductFields
   */
  name?: string;
  /**
   * The text label for this product. This field may be localized.
   * @type {string}
   * @memberof ProductFields
   */
  label?: string;
  /**
   * A fuller description of this product. This field may be localized. The content is processed as  [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof ProductFields
   */
  description?: string;
  /**
   * The unique product code for this product, normally defined by the underlying banking core. The `code` cannot be changed once the `state` is beyond `pending`.
   * @type {string}
   * @memberof ProductFields
   */
  code?: string;
  /**
   * Indicates if the product is available for opening new accounts.   * *`available`* means the product may be selected for a new account application.   * *`notAvailable`* means the product may *not* be selected for a new account application. The default is `available`. Note that clients must check both the product `state` and the `newAccountAvailability` when listing products for new account opening. The `?openable=true` query parameter on `/accounts` combines these. Labels and descriptions for the enumeration values are in the `newAccountAvailability` key in the response of the `getLabels` operation.
   * @type {NewAccountAvailability}
   * @memberof ProductFields
   */
  newAccountAvailability?: NewAccountAvailability;
  /**
   * The product category name. This is a more readable form of the product's `type`.
   * @type {string}
   * @memberof ProductFields
   */
  category?: string;
  /**
   * The interest rate for this product.
   * @type {Rate}
   * @memberof ProductFields
   */
  rate?: Rate;
  /**
   * The revision string for this product. This property derived and immutable.
   * @type {string}
   * @memberof ProductFields
   */
  revision?: string;
  /**
   * The product IFX Account Type.
   * @type {IfxType}
   * @memberof ProductFields
   */
  ifxType?: IfxType;
  /**
   * Describes the target audience or consumer of the accounts, `personal` or `business`. Labels and descriptions for the enumeration values are in the `productTarget` key in the response of the `getLabels` operation.
   * @type {ProductTarget}
   * @memberof ProductFields
   */
  target?: ProductTarget;
}

/**
 * The state of a product or type.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductState
 */
export interface ProductState {
  /**
   * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.
   * @type {ProdState}
   * @memberof ProductState
   */
  state?: ProdState;
}

/**
 * The target audience for this product.  <strong><code>productTarget</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named productTarget)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `productTarget` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>personal</code></strong></td><td>Banking products for personal use</td>     </tr> <tr>     <td><strong><code>business</code></strong></td><td>Banking products for business use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProductTarget {
  Personal = 'personal',
  Business = 'business',
}

/**
 * The state of an item (address, email address, or phone number) within the user's profile. New addresses, email addresses, or phone numbers start with the state `pending`, which means approval by the financial institution is pending. After they have been verified, the state becomes `approved`. Some normalizing or sanitizing of the value may occur when this happens (for example, a ZIP code may change to ZIP+4 format). `pending` items may not be assigned as the preferred item.
 * @export
 * @enum {string}
 */
export enum ProfileItemState {
  Pending = 'pending',
  Approved = 'approved',
}

/**
 * The interest rate of the account. For deposit accounts, this is the rate of return; for loan accounts, this is the interest rate charged on balances. Rates can be absolute, such as \"1.40\" to indicate 1.4%, which is expressed as  `{ \"value\" : \"1.40\" }`, or relative to a benchmark, such as U.S. Prime Rate + 0.5% which is expressed as `{ \"benchmark\" : \"prime\", \"value\" : \"0.50\" }`.  This schema is version `v1.0.0`.
 * @export
 * @interface Rate
 */
export interface Rate {
  /**
   * The rate, expressed as an decimal percentage string in order to represent the rate exactly. This number must have 2 to four decimal points, i.e. '2.00' or '0.50' or '1.015', but not `2` or `.5`. (Regular expression pattern: `-?\\d{1,3}+\\.\\d{2,4}`)
   * @type {string}
   * @memberof Rate
   */
  value?: string;
  /**
   * An optional base benchmark that the rate is relative to. If omitted, the rate is fixed. Otherwise the rate is added to the benchmark rate. Values may be (but are not limited to):  * *`primeUS`* - the [U.S. Prime rate](https://en.wikipedia.org/wiki/Prime_rate)  * *`treasuryUS`* - The [U.S. Treasury rate](https://www.treasury.gov/resource-center/data-chart-center/interest-rates/Pages/TextView.aspx?data=yieldAll)  * *`libor`* - the [London Inter-bank Offered Rates](https://en.wikipedia.org/wiki/Libor) rate
   * @type {string}
   * @memberof Rate
   */
  benchmark?: string;
  /**
   * The period at which interest compounds.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. The default is `\"P0D\"` (continuous).
   * @type {string}
   * @memberof Rate
   */
  compoundPeriod?: string;
  /**
   * Indicates how interest is accrued according to the `compoundPeriod`.
   * @type {AccrualType}
   * @memberof Rate
   */
  accrualType?: AccrualType;
  /**
   * The period at which the rate is adjusted or recomputed to account for differences in the benchmark rate.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days; The default is `\"P1D\"` (daily).
   * @type {string}
   * @memberof Rate
   */
  adjustmentPeriod?: string;
  /**
   * The interest rate type.
   * @type {InterestRateType}
   * @memberof Rate
   */
  type?: InterestRateType;
}

/**
 * Responses to regulatory-related questions.
 * @export
 * @interface Regulatory
 */
export interface Regulatory {
  [key: string]: RegulatoryValue | any;

  /**
   * The range of estimated revenue in US dollars.
   * @type {EstimatedAnnualRevenue}
   * @memberof Regulatory
   */
  estimatedAnnualRevenue?: EstimatedAnnualRevenue;
  /**
   * The organization operates automated teller machines (ATMs).
   * @type {boolean}
   * @memberof Regulatory
   */
  atmOperator?: boolean;
  /**
   * Some of the organization's income depends on a charity.
   * @type {boolean}
   * @memberof Regulatory
   */
  charity?: boolean;
  /**
   * The organization cashes checks for customers in amounts greater than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  cashesChecksMoreThan1000Usd?: boolean;
  /**
   * The organization derives income from internet gambling.
   * @type {boolean}
   * @memberof Regulatory
   */
  internetGamblingIncorporated?: boolean;
  /**
   * The organization derives income from marijuana or other drugs/controlled substances.
   * @type {boolean}
   * @memberof Regulatory
   */
  marijuanaBusiness?: boolean;
  /**
   * Individuals at the organization may request money orders of more than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  moneyOrderMoreThan1000Usd?: boolean;
  /**
   * The organization processes transactions on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  thirdPartyBenefit?: boolean;
  /**
   * The organization transmits funds on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  transmitBehalfOfCustomer?: boolean;
  /**
   * The organization administers or exchanges virtual currency.
   * @type {boolean}
   * @memberof Regulatory
   */
  virtualCurrency?: boolean;
  /**
   * A list of intermediary/non-bank financial institution services provided the organization performs on behalf of others.
   * @type {Array<IntermediaryServices>}
   * @memberof Regulatory
   */
  intermediaryServices?: Array<IntermediaryServices>;
  /**
   * If `true`, the organization is subject to tax withholdings.
   * @type {boolean}
   * @memberof Regulatory
   */
  subjectToWithholdings?: boolean;
}

/**
 * The value associated with this regulatory property.
 * @export
 * @interface RegulatoryValue
 */
export interface RegulatoryValue {}

/**
 * An document which is required from the applicant.  If a `templateUri` is provided, the applicant must download the document from the `templateUri` and return it completed.
 * @export
 * @interface RequiredDocument
 */
export interface RequiredDocument {
  /**
   * User friendly label of the document.
   * @type {string}
   * @memberof RequiredDocument
   */
  label: string;
  /**
   * The document type as determined by the business use case. Unlike the contentType, this indicates what the document content represents (such as a `processedCheckImage`,  `mobileCheckDepositImageFront`, etc.). This `type` corresponds to the same `type` in the Vault API.
   * @type {string}
   * @memberof RequiredDocument
   */
  type: string;
  /**
   * The target of the relevant product, either `business` or `personal`. Note that `business` is synonymous with organizations in Apiture APIs.
   * @type {string}
   * @memberof RequiredDocument
   */
  productTarget: RequiredDocument.ProductTargetEnum;
  /**
   * A URI pointing to a form document that the applicant is required to download, fill out, optionally scan, then upload (as a new document) to satisfy this document requirement. The form document must reside in the document storage system. This is the URI of a _shared_ document in the Vault API.
   * @type {string}
   * @memberof RequiredDocument
   */
  documentUri?: string;
  /**
   * Required document category, within the enum of options. Required for compliance to categorize PII documents.
   * @type {string}
   * @memberof RequiredDocument
   */
  category: RequiredDocument.CategoryEnum;
  /**
   * Whether to require this document even if the associated applicant or business has passed verification.  If `true`, this document will always be required.
   * @type {boolean}
   * @memberof RequiredDocument
   */
  requireIfVerified: boolean;
}

/**
 * @export
 * @namespace RequiredDocument
 */
export namespace RequiredDocument {
  /**
   * @export
   * @enum {string}
   */
  export enum ProductTargetEnum {
    Business = 'business',
    Personal = 'personal',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum CategoryEnum {
    DriversLicense = 'driversLicense',
    MilitaryIdentification = 'militaryIdentification',
    Passport = 'passport',
    SocialSecurityCard = 'socialSecurityCard',
    StateIdentification = 'stateIdentification',
    TaxForm = 'taxForm',
    UtilityBill = 'utilityBill',
  }
}

/**
 * Residency status.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `residencyStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum ResidencyStatus {
  Unknown = 'unknown',
  Resident = 'resident',
  Nonresident = 'nonresident',
  ResidentAlien = 'residentAlien',
  NonresidentAlien = 'nonresidentAlien',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * Risk factors, warning codes, or risk codes are not necessarily indicators of fraud or of any fraudulent intent. They are value added attributes that indicate information that may have contributed to a lower score.
 * @export
 * @interface RiskFactor
 */
export interface RiskFactor {
  /**
   * The risk factor risk code
   * @type {string}
   * @memberof RiskFactor
   */
  riskCode?: string;
  /**
   * The risk code description
   * @type {string}
   * @memberof RiskFactor
   */
  description?: string;
}

/**
 * Representation of a role resource. Roles are used to associate resources. The most common roles may be related to entitlements(users) but can also be applied to organizations or non-users (such as beneficiaries, payees, etc.).
 * @export
 * @interface Role
 */
export interface Role extends UpdateRole {
  /**
   * The date-time when the role was created. This is in ISO 8601 format, UTC. This is derived and immutable.
   * @type {Date}
   * @memberof Role
   */
  createdAt?: Date;
}

/**
 * Core fields of the role resource used to build other model schema.
 * @export
 * @interface RoleFields
 */
export interface RoleFields {
  /**
   * The name of this role, for identification purposes, such as `primaryOwner`, `beneficiary`, `authorizedSigner`. Some roles have well-known uses in the platform.
   * @type {string}
   * @memberof RoleFields
   */
  name?: string;
  /**
   * The text label for this role, for use in human presentation. This field may be localized.
   * @type {string}
   * @memberof RoleFields
   */
  label?: string;
  /**
   * A fuller description of this role. This field may be localized.
   * @type {string}
   * @memberof RoleFields
   */
  description?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Basic contact and identification information for a person, consisting of the name, mailing address, phone numbers, email addresses, and government identification.
 * @export
 * @interface SimpleContact
 */
export interface SimpleContact
  extends ContactName,
    Addresses,
    EmailAddresses,
    PhoneNumbers,
    SimpleContactFields {}

/**
 * Additional properties for a person or contact.
 * @export
 * @interface SimpleContactFields
 */
export interface SimpleContactFields {
  /**
   * A title or honorific prefix such as Dr. or Fr.
   * @type {string}
   * @memberof SimpleContactFields
   */
  prefix?: string;
  /**
   * A title or honorific suffix such as PhD or DDS.
   * @type {string}
   * @memberof SimpleContactFields
   */
  suffix?: string;
  /**
   * The contact's preferred name. This is how the contact's name is presented to the user in the interface. The default is the contact's `firstName`.
   * @type {string}
   * @memberof SimpleContactFields
   */
  preferredName?: string;
  /**
   * A collection of official identifying information associated with the contact.
   * @type {Array<Identification>}
   * @memberof SimpleContactFields
   */
  identification?: Array<Identification>;
  /**
   * The contact's preferred method of communication.
   * @type {PreferredContactMethod}
   * @memberof SimpleContactFields
   */
  preferredContactMethod?: PreferredContactMethod;
}

/**
 * The simplest form of an organization.
 * @export
 * @interface SimpleOrganization
 */
export interface SimpleOrganization {
  /**
   * The organization's official full name
   * @type {string}
   * @memberof SimpleOrganization
   */
  name?: string;
  /**
   * The organization's common name.
   * @type {string}
   * @memberof SimpleOrganization
   */
  label?: string;
  /**
   * Indicates what type of organization this resource represents.   The enumeration values are described by the `organizationType` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  type?: string;
  /**
   * A refinement of the `type`.   The enumeration values are described by the `organizationSubtype` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  subtype?: string;
  /**
   * A collection of official identifying information associated with the organization. This currently only supports government tax ID.
   * @type {Array<OrganizationIdentification>}
   * @memberof SimpleOrganization
   */
  identification?: Array<OrganizationIdentification>;
  /**
   * An array containing address items.
   * @type {Array<OrganizationAddress>}
   * @memberof SimpleOrganization
   */
  addresses?: Array<OrganizationAddress>;
  /**
   * An array of phone numbers associated with the organization. The first item, if present, is the default (preferred) organization phone number.
   * @type {Array<OrganizationPhoneNumber>}
   * @memberof SimpleOrganization
   */
  phones?: Array<OrganizationPhoneNumber>;
  /**
   * An array of email addresses associated with the organization. The first item, if present, is the default (preferred) organization email.
   * @type {Array<OrganizationEmailAddress>}
   * @memberof SimpleOrganization
   */
  emailAddresses?: Array<OrganizationEmailAddress>;
  /**
   * The ID of the organization's preferred email address. This string is the `_id` of an email address in the `emailAddresses` array. This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredEmailAddressId?: string;
  /**
   * The ID of organization's preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredPhoneId?: string;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredMailingAddressId?: string;
  /**
   * The date the organization was established.
   * @type {string}
   * @memberof SimpleOrganization
   */
  establishedDate?: string;
}

/**
 * Summary representation of an account application resource in account applications collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryApplication
 */
export interface SummaryApplication extends AbstractResource, CommonFields, ApplicationFields {
  /**
   * The unique identifier for this application. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryApplication
   */
  _id?: string;
  /**
   * The name of the banking product associated with this new account application. This is derived from the first product in the `products` array and is immutable.
   * @type {string}
   * @memberof SummaryApplication
   */
  productName?: string;
  /**
   * The name of the organization, if this is an application for a business account. This will be derived from the organization resource, if present.
   * @type {string}
   * @memberof SummaryApplication
   */
  organizationName?: string;
}

/**
 * @export
 * @namespace SummaryApplication
 */
export namespace SummaryApplication {}

/**
 * Summary representation of an approval resource in approvals collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryApproval
 */
export interface SummaryApproval extends AbstractResource, ApprovalFields {
  /**
   * The unique identifier for this approval resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryApproval
   */
  _id?: string;
}

/**
 * Summary representation of an approval type resource in approvals collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryApprovalType
 */
export interface SummaryApprovalType extends AbstractResource, ApprovalTypeFields {
  /**
   * The unique identifier for this approval resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryApprovalType
   */
  _id?: string;
}

/**
 * Summary representation of a consent resource in consents collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryConsent
 */
export interface SummaryConsent extends ConsentFields, AbstractResource {
  /**
   * The unique identifier for this consent resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryConsent
   */
  _id?: string;
  /**
   * The state of this consent.
   * @type {ConsentStates}
   * @memberof SummaryConsent
   */
  state?: ConsentStates;
  /**
   * The time stamp when the user last consented to the document, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). This property is not set if `state` is `pending`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  givenAt?: Date;
  /**
   * The time stamp when the user revoked consent, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). A revoked consent reflects a consent request that the user has previously given but has reversed. Revoking a consent sets the `state` back to `pending` and clears `consentedAt`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  requestRevokedAt?: Date;
  /**
   * The time stamp when the consent _request_ was rescinded by the requester, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). A rescinded consent reflects a consent request that the system or application has issued in the past but no longer requires. For example, if a user is removed as an authorized signer from an account and a consent is pending for that account's terms and conditions, the Accounts service may rescind that consent request. This property is set only if `state` is `rescinded`.
   * @type {Date}
   * @memberof SummaryConsent
   */
  requestRescindedAt?: Date;
}

/**
 * Summary representation of a contact resource in contacts collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryContact
 */
export interface SummaryContact
  extends ContactVerificationFields,
    IdentifiedContact,
    AbstractResource {
  /**
   * The state of this person's record.
   * @type {ContactState}
   * @memberof SummaryContact
   */
  state?: ContactState;
  /**
   * The unique identifier for this contact resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryContact
   */
  _id?: string;
}

/**
 * @export
 * @namespace SummaryContact
 */
export namespace SummaryContact {}

/**
 * Representation of enrollments in the collection.
 * @export
 * @interface SummaryEnrollment
 */
export interface SummaryEnrollment extends CommonFields, EnrollmentFields, AbstractResource {
  /**
   * The unique identifier for this application. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryEnrollment
   */
  _id?: string;
}

/**
 * @export
 * @namespace SummaryEnrollment
 */
export namespace SummaryEnrollment {}

/**
 * Summary representation of an organization resource in organizations collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryOrganization
 */
export interface SummaryOrganization extends AbstractResource, OrganizationFields {
  /**
   * The unique identifier for this organization resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryOrganization
   */
  _id?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the organization in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Organizations API).
   * @type {string}
   * @memberof SummaryOrganization
   */
  customerId?: string;
}

/**
 * Summary representation of a product resource in products collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. This representation omits the `attributes` of the full representation.  This schema is version `v1.0.0`.
 * @export
 * @interface SummaryProduct
 */
export interface SummaryProduct extends AbstractResource, ProductFields, RevisionEffectiveInterval {
  /**
   * The unique identifier for this product resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryProduct
   */
  _id?: string;
  /**
   * The product type name, which is derived from the linked product type.
   * @type {string}
   * @memberof SummaryProduct
   */
  type?: string;
  /**
   * The product subtype name, which is derived from the linked product subtype. This is a derived, immutable property.
   * @type {string}
   * @memberof SummaryProduct
   */
  subtype?: string;
  /**
   *
   * @type {TimeDeposit}
   * @memberof SummaryProduct
   */
  timeDeposit?: TimeDeposit;
  /**
   *
   * @type {Constraints}
   * @memberof SummaryProduct
   */
  constraints?: Constraints;
}

/**
 * Summary representation of a role resource in roles collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryRole
 */
export interface SummaryRole extends RoleFields, AbstractResource {
  /**
   * The unique identifier for this role resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryRole
   */
  _id?: string;
}

/**
 * Summary representation of a user resource in user collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryUser
 */
export interface SummaryUser extends UserFields, AbstractResource {
  /**
   * The unique identifier for this user resource. This is an opaque string.
   * @type {string}
   * @memberof SummaryUser
   */
  _id?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof SummaryUser
   */
  customerId?: string;
}

/**
 * @export
 * @namespace SummaryUser
 */
export namespace SummaryUser {}

/**
 * Summary representation of a verification report resource in verification report collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryVerificationReport
 */
export interface SummaryVerificationReport extends AbstractResource {
  /**
   * The unique identifier for this verification report resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryVerificationReport
   */
  _id?: string;
  /**
   *
   * @type {VerificationReportScoringSummary}
   * @memberof SummaryVerificationReport
   */
  reportScoringSummary?: VerificationReportScoringSummary;
}

/**
 * Properties of time deposit products, primarily Certificate of Deposit products.  This schema is version `v1.0.0`.
 * @export
 * @interface TimeDeposit
 */
export interface TimeDeposit {
  /**
   *
   * @type {MaturityPolicy}
   * @memberof TimeDeposit
   */
  maturityPolicy?: MaturityPolicy;
  /**
   * The minimum maturity term offered by this product, for products such as certificates of deposits. See also `maximumTerm` For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  minimumTerm?: string;
  /**
   * The maximum maturity term offered by this product, for products such as certificates of deposits. If omitted, there is no fixed term (not all product types impose a term). For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  maximumTerm?: string;
  /**
   * The time period in which additional deposits may be made to a CD after it has rolled over after maturity. This value applies only if the `depositsAllowed` is `duringGracePeriod`. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days.
   * @type {string}
   * @memberof TimeDeposit
   */
  fees?: string;
}

/**
 * A string which defines a transaction type allowed for an account.   * *`credit`* : Credits may be posted to this account, such as transfer funds _to_ this external account.   * *`debit`* : Debits may be posted to this account, such as transfer funds _from_ this external account. Labels and descriptions for the enumeration values are in the `transactionType` key in the response of the `getLabels` operation.  <strong><code>transactionType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named transactionType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `transactionType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>debit</code></strong></td><td>A transaction which descreases an account's balance</td>     </tr> <tr>     <td><strong><code>credit</code></strong></td><td>A transaction which increases an accounts's balance</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum TransactionType {
  Debit = 'debit',
  Credit = 'credit',
}

/**
 * An array which lists which transaction types are allowed for an account.  This schema is version `v1.0.0`.
 * @export
 * @interface TransactionTypes
 */
export interface TransactionTypes {}

/**
 * Summary properties of the source and target account for a transfer.
 * @export
 * @interface TransferAccount
 */
export interface TransferAccount extends AbstractResource {
  /**
   * The title of the account. Traditionally, this is the name of the account holder. This field is deprecated and will be removed in a future release; use `title` instead.
   * @type {string}
   * @memberof TransferAccount
   */
  accountTitle?: string;
  /**
   * The title of the account. Traditionally, this is the name of the account holder.
   * @type {string}
   * @memberof TransferAccount
   */
  title?: string;
  /**
   * The name of the financial institution.
   * @type {string}
   * @memberof TransferAccount
   */
  institutionName?: string;
  /**
   * The account routing number which identifies the financial institution. The full routing number and full account number are required to fully identify the account.
   * @type {string}
   * @memberof TransferAccount
   */
  routingNumber?: string;
  /**
   * The account numbers for this account
   * @type {AccountNumbers}
   * @memberof TransferAccount
   */
  accountNumbers?: AccountNumbers;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof TransferAccount
   */
  ifxType?: IfxType;
}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * Representation used to update or patch an approval.  The `state` field is immutable and not updated by this operation, but by the `state transition` POST operations such as `approve` or `reject` (ex. `apiture:approve` and `apiture:reject`).
 * @export
 * @interface UpdateApproval
 */
export interface UpdateApproval extends SummaryApproval {
  /**
   * An optional map of name/value pairs which provide additional metadata about the approval.
   * @type {any}
   * @memberof UpdateApproval
   */
  attributes?: any;
}

/**
 * Representation used to update or patch a role.
 * @export
 * @interface UpdateRole
 */
export interface UpdateRole extends SummaryRole {}

/**
 * Representation of a user's address resource.
 * @export
 * @interface UserAddress
 */
export interface UserAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof UserAddress
   */
  state?: ProfileItemState;
}

/**
 * Representation of email address resources. An email address is immutable, although users can add new email addresses.
 * @export
 * @interface UserEmailAddress
 */
export interface UserEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof UserEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * Fields for a user. (This fragment schema is used to build other schemas.)   To change user addresses, email addresses, and phone numbers, use operations on the sub-resources (`/users/{userId}/addresses`, `/users/{userId}/emailAddresses`, and `/users/{userId}/phoneNumbers`).
 * @export
 * @interface UserFields
 */
export interface UserFields
  extends IdentifiedContact,
    ContactName,
    SimpleContactFields,
    UserVerificationFields {
  /**
   * The unique username for the user.
   * @type {string}
   * @memberof UserFields
   */
  username?: string;
  /**
   * The state of this user record. The default is `active`.   * Users may not be deleted, but Users with a `state` of `active`, `inactive` or `locked`     may be removed by `POST`ing to the `/removedUsers` endpoint via the `apiture:remove`     endpoint. Removed users may not be reactivated.   * Users with a `state` of `active` or `locked` may be deactivated by `POST`ing to     the `/inactiveUsers` endpoint via the `apiture:deactivate` endpoint.   * Users with a `state` of `inactive` or `locked` may be activated by `POST`ing to     the `/activeUsers` endpoint via the `apiture:activate` endpoint.   * Users with a `state` of `active` or `inactive` may be locked by `POST`ing to     the `/lockedUsers` endpoint via the `apiture:lock` endpoint. A `state` of `locked`     indicates a user has entered the password incorrectly too many times.   * Users with a `state` of `active`, `inactive` or locked may be frozen by     `POST`ing to the `/frozenUsers` endpoint via the `apiture:freeze` endpoint.     A `state` of `frozen` indicates a user can no longer access online banking until     the financial institution re-activates the user.   * Users with a `state` of `active`, `inactive`, or `locked` may be     merged by `POST`ing to the `/mergedUsers` endpoint via the `apiture:merge` endpoint.     Merged users may not have their state changed.
   * @type {string}
   * @memberof UserFields
   */
  state?: UserFields.StateEnum;
  /**
   * An array of postal/mailing addresses. Add or delete addresses with the `createAddress` and `deleteAddress` operations.
   * @type {Array<UserAddress>}
   * @memberof UserFields
   */
  addresses?: Array<UserAddress>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredMailingAddressId?: string;
  /**
   * An array of phone numbers. Add or delete phoneNumbers with the `createPhoneNumber` and `deletePhoneNumber` operations.
   * @type {Array<UserPhoneNumber>}
   * @memberof UserFields
   */
  phoneNumbers?: Array<UserPhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredPhoneId?: string;
  /**
   * An array of email addresses. Add or delete email addresses with the `createEmailAddress` and `deleteEmailAddress` operations.
   * @type {Array<UserEmailAddress>}
   * @memberof UserFields
   */
  emailAddresses?: Array<UserEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.  This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredEmailAddressId?: string;
}

/**
 * @export
 * @namespace UserFields
 */
export namespace UserFields {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Active = 'active',
    Inactive = 'inactive',
    Locked = 'locked',
    Frozen = 'frozen',
    Merged = 'merged',
    Removed = 'removed',
  }
}

/**
 * Representation of phone number resources.
 * @export
 * @interface UserPhoneNumber
 */
export interface UserPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof UserPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * Fields for recording the status of user verification for a financial institution's Customer Identification Program (CIP). (This fragment schema is used to build other schemas.)
 * @export
 * @interface UserVerificationFields
 */
export interface UserVerificationFields {
  /**
   * This user's answers Know Your Customer (KYC) questions.
   * @type {KycAnswers}
   * @memberof UserVerificationFields
   */
  kycAnswers?: KycAnswers;
  /**
   * The identity verification data for this person.  These fields are derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record.
   * @type {IdentityVerification}
   * @memberof UserVerificationFields
   */
  identityVerification?: IdentityVerification;
}

/**
 * Representation of verification report resources.
 * @export
 * @interface VerificationReport
 */
export interface VerificationReport extends AbstractResource, SummaryVerificationReport {
  /**
   * An ISO 8601 UTC time stamp indicating when the verification report was created.
   * @type {Date}
   * @memberof VerificationReport
   */
  createdAt?: Date;
  /**
   * The objects which participate in this verification report
   * @type {any}
   * @memberof VerificationReport
   */
  _embedded?: any;
  /**
   *
   * @type {CreateVerificationReport}
   * @memberof VerificationReport
   */
  input?: CreateVerificationReport;
  /**
   *
   * @type {VerificationReportScoringSummary}
   * @memberof VerificationReport
   */
  reportScoringSummary?: VerificationReportScoringSummary;
  /**
   * The raw verification report results
   * @type {any}
   * @memberof VerificationReport
   */
  reportResults?: any;
}

/**
 * Model schema for business verification report summary.
 * @export
 * @interface VerificationReportScoringSummary
 */
export interface VerificationReportScoringSummary {
  /**
   * The unique transactionId for this verification report used for tracking this verification report
   * @type {string}
   * @memberof VerificationReportScoringSummary
   */
  transactionId?: string;
  /**
   * The state of a verification report.  _passed_ indicates that the Business was successfully verified based upon the supplied information, _failed_ indicates it was not.
   * @type {string}
   * @memberof VerificationReportScoringSummary
   */
  state?: VerificationReportScoringSummary.StateEnum;
  /**
   * A list of business verification scores.
   * @type {Array<BusinessVerificationScore>}
   * @memberof VerificationReportScoringSummary
   */
  businessVerifications?: Array<BusinessVerificationScore>;
  /**
   * A list of business verification risk factors.
   * @type {Array<RiskFactor>}
   * @memberof VerificationReportScoringSummary
   */
  businessRiskFactors?: Array<RiskFactor>;
  /**
   * A list of comprehensive business verification scores.
   * @type {Array<ComprehensiveVerificationScore>}
   * @memberof VerificationReportScoringSummary
   */
  comprehensiveVerificationScores?: Array<ComprehensiveVerificationScore>;
  /**
   * A list of representative business risk factors.
   * @type {Array<RiskFactor>}
   * @memberof VerificationReportScoringSummary
   */
  authorizedRepresentativeRiskFactors?: Array<RiskFactor>;
}

/**
 * @export
 * @namespace VerificationReportScoringSummary
 */
export namespace VerificationReportScoringSummary {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Passed = 'passed',
    Failed = 'failed',
  }
}

/**
 * Common fields of a verification request, used to build other model schemas.
 * @export
 * @interface VerificationRequestFields
 */
export interface VerificationRequestFields {
  /**
   * The business's name
   * @type {string}
   * @memberof VerificationRequestFields
   */
  businessName?: string;
  /**
   * An alternate name for the business
   * @type {string}
   * @memberof VerificationRequestFields
   */
  alternateBusinessName?: string;
  /**
   * The business's phone
   * @type {string}
   * @memberof VerificationRequestFields
   */
  phone?: string;
  /**
   *
   * @type {IdentificationModel}
   * @memberof VerificationRequestFields
   */
  identification?: IdentificationModel;
  /**
   * An optional array of authorized signer entities
   * @type {Array<AuthorizedSigner>}
   * @memberof VerificationRequestFields
   */
  authorizedSigners?: Array<AuthorizedSigner>;
  /**
   * An array of postal mailing addresses for this contact.
   * @type {Array<Address>}
   * @memberof VerificationRequestFields
   */
  addresses?: Array<Address>;
  /**
   * An optional map of name/value pairs which provide additional metadata about the verification report.
   * @type {Attributes}
   * @memberof VerificationRequestFields
   */
  attributes?: Attributes;
}

/**
 * The token used to validate and track a contact for identity verification purposes.
 * @export
 * @interface VerificationToken
 */
export interface VerificationToken {
  /**
   * An opaque string that conveys the state of the contact's identity verification.
   * @type {string}
   * @memberof VerificationToken
   */
  token?: string;
}

/**
 * Details of the account, possibly an external account, used to fund the new account.
 * @export
 * @interface VerifiedTransferAccount
 */
export interface VerifiedTransferAccount extends TransferAccount {}

/**
 * Categories for how long the person has been at their present home address.
 * @export
 * @enum {string}
 */
export enum YearsAtAddress {
  Unknown = 'unknown',
  OneOrFewer = 'oneOrFewer',
  Two = 'two',
  Three = 'three',
  FourOrMore = 'fourOrMore',
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AccountApplicationApi - axios parameter creator
 * @export
 */
export const AccountApplicationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new account application. This also creates and starts the workflow that is associated with the primary banking product in the request body. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. Users can have only one running application at a time.
     * @summary Create a new account application
     * @param {CreateApplication} CreateApplication The data necessary to create a new account application.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApplication(CreateApplication: CreateApplication, options: any = {}): RequestArgs {
      // verify required parameter 'CreateApplication' is not null or undefined
      if (CreateApplication === null || CreateApplication === undefined) {
        throw new RequiredError(
          'CreateApplication',
          'Required parameter CreateApplication was null or undefined when calling createApplication.',
        );
      }
      const localVarPath = `/applications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateApplication' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateApplication || {})
        : CreateApplication || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this account application resource. An application may only be deleted by the user if its `state` is `pending`, or by a financial institution if its `state` is `expired`.
     * @summary Delete an unused or expired application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApplication(
      applicationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling deleteApplication.',
        );
      }
      // verify required parameter 'applicationId' is not null or undefined
      if (applicationId === null || applicationId === undefined) {
        throw new RequiredError(
          'applicationId',
          'Required parameter applicationId was null or undefined when calling deleteApplication.',
        );
      }
      const localVarPath = `/applications/{applicationId}`.replace(
        `{${'applicationId'}}`,
        encodeURIComponent(String(applicationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account application resource.
     * @summary Fetch a representation of this account application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplication(
      applicationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'applicationId' is not null or undefined
      if (applicationId === null || applicationId === undefined) {
        throw new RequiredError(
          'applicationId',
          'Required parameter applicationId was null or undefined when calling getApplication.',
        );
      }
      const localVarPath = `/applications/{applicationId}`.replace(
        `{${'applicationId'}}`,
        encodeURIComponent(String(applicationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Not all nested objects are supported for filtering or sorting applications. The following fields may be used: `accountName`, `applicantName`, `productName`, `organizationName', `state`, `createdAt`, `completedAt`
     * @summary Return a collection of account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.applicant] Filter applications by applicant. The value must be an applicant&#39;s _contact_ URI, not the URI of a user. (To find applications for a _user_, pass the &#x60;href&#x60; from the &#x60;apiture:contact&#x60; link on the user resource.) An application resource is included in the response if and only if the named  contact is among the application&#39;s &#x60;applicants&#x60;. This query parameter exists for administrator use. The collection is automatically filtered to applications which a user created for non-administrator users.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        applicant?: string;
        filter?: string;
        q?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, applicant, filter, q } = query;

      const localVarPath = `/applications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (applicant !== undefined) {
        localVarQueryParameter['applicant'] = applicant;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `blocked`.
     * @summary Return a collection of blocked account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBlockedApplications(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/blockedApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `running`.
     * @summary Return a collection of active, running account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'running' | 'blocked' | 'canceled' | 'expired' | 'rejected' | 'approved'} [query.state] Subset the applications collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;running|canceled&#x60; matches items whose &#x60;state&#x60; is &#x60;running&#x60; or &#x60;canceled&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the applications collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRunningApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'running'
          | 'blocked'
          | 'canceled'
          | 'expired'
          | 'rejected'
          | 'approved';
        name?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, name } = query;

      const localVarPath = `/runningApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this account application. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'applicationId' is not null or undefined
      if (applicationId === null || applicationId === undefined) {
        throw new RequiredError(
          'applicationId',
          'Required parameter applicationId was null or undefined when calling patchApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling patchApplication.',
        );
      }
      // verify required parameter 'Application' is not null or undefined
      if (Application === null || Application === undefined) {
        throw new RequiredError(
          'Application',
          'Required parameter Application was null or undefined when calling patchApplication.',
        );
      }
      const localVarPath = `/applications/{applicationId}`.replace(
        `{${'applicationId'}}`,
        encodeURIComponent(String(applicationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Application' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Application || {})
        : Application || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this account application.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'applicationId' is not null or undefined
      if (applicationId === null || applicationId === undefined) {
        throw new RequiredError(
          'applicationId',
          'Required parameter applicationId was null or undefined when calling updateApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling updateApplication.',
        );
      }
      // verify required parameter 'Application' is not null or undefined
      if (Application === null || Application === undefined) {
        throw new RequiredError(
          'Application',
          'Required parameter Application was null or undefined when calling updateApplication.',
        );
      }
      const localVarPath = `/applications/{applicationId}`.replace(
        `{${'applicationId'}}`,
        encodeURIComponent(String(applicationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Application' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Application || {})
        : Application || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountApplicationApi - functional programming interface
 * @export
 */
export const AccountApplicationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new account application. This also creates and starts the workflow that is associated with the primary banking product in the request body. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. Users can have only one running application at a time.
     * @summary Create a new account application
     * @param {CreateApplication} CreateApplication The data necessary to create a new account application.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApplication(
      CreateApplication: CreateApplication,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).createApplication(
        CreateApplication ? CreateApplication : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this account application resource. An application may only be deleted by the user if its `state` is `pending`, or by a financial institution if its `state` is `expired`.
     * @summary Delete an unused or expired application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApplication(
      applicationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).deleteApplication(
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account application resource.
     * @summary Fetch a representation of this account application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplication(
      applicationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).getApplication(
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Not all nested objects are supported for filtering or sorting applications. The following fields may be used: `accountName`, `applicantName`, `productName`, `organizationName', `state`, `createdAt`, `completedAt`
     * @summary Return a collection of account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.applicant] Filter applications by applicant. The value must be an applicant&#39;s _contact_ URI, not the URI of a user. (To find applications for a _user_, pass the &#x60;href&#x60; from the &#x60;apiture:contact&#x60; link on the user resource.) An application resource is included in the response if and only if the named  contact is among the application&#39;s &#x60;applicants&#x60;. This query parameter exists for administrator use. The collection is automatically filtered to applications which a user created for non-administrator users.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        applicant?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Applications> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).getApplications(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `blocked`.
     * @summary Return a collection of blocked account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBlockedApplications(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Applications> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).getBlockedApplications(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `running`.
     * @summary Return a collection of active, running account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'running' | 'blocked' | 'canceled' | 'expired' | 'rejected' | 'approved'} [query.state] Subset the applications collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;running|canceled&#x60; matches items whose &#x60;state&#x60; is &#x60;running&#x60; or &#x60;canceled&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the applications collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRunningApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'running'
          | 'blocked'
          | 'canceled'
          | 'expired'
          | 'rejected'
          | 'approved';
        name?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Applications> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).getRunningApplications(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this account application. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).patchApplication(
        Application ? Application : null,
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this account application.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationApiAxiosParamCreator(
        configuration,
      ).updateApplication(
        Application ? Application : null,
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountApplicationApi - factory interface
 * @export
 */
export const AccountApplicationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new account application. This also creates and starts the workflow that is associated with the primary banking product in the request body. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. Users can have only one running application at a time.
     * @summary Create a new account application
     * @param {CreateApplication} CreateApplication The data necessary to create a new account application.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createApplication(CreateApplication: CreateApplication, options?: any) {
      return AccountApplicationApiFp(configuration).createApplication(
        CreateApplication ? CreateApplication : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this account application resource. An application may only be deleted by the user if its `state` is `pending`, or by a financial institution if its `state` is `expired`.
     * @summary Delete an unused or expired application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteApplication(applicationId: string, headers?: { If_Match?: string }, options?: any) {
      return AccountApplicationApiFp(configuration).deleteApplication(
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account application resource.
     * @summary Fetch a representation of this account application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplication(applicationId: string, headers?: { If_None_Match?: string }, options?: any) {
      return AccountApplicationApiFp(configuration).getApplication(
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Not all nested objects are supported for filtering or sorting applications. The following fields may be used: `accountName`, `applicantName`, `productName`, `organizationName', `state`, `createdAt`, `completedAt`
     * @summary Return a collection of account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.applicant] Filter applications by applicant. The value must be an applicant&#39;s _contact_ URI, not the URI of a user. (To find applications for a _user_, pass the &#x60;href&#x60; from the &#x60;apiture:contact&#x60; link on the user resource.) An application resource is included in the response if and only if the named  contact is among the application&#39;s &#x60;applicants&#x60;. This query parameter exists for administrator use. The collection is automatically filtered to applications which a user created for non-administrator users.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        applicant?: string;
        filter?: string;
        q?: string;
      },
      options?: any,
    ) {
      return AccountApplicationApiFp(configuration).getApplications(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `blocked`.
     * @summary Return a collection of blocked account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBlockedApplications(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return AccountApplicationApiFp(configuration).getBlockedApplications(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `running`.
     * @summary Return a collection of active, running account applications
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of account application representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'running' | 'blocked' | 'canceled' | 'expired' | 'rejected' | 'approved'} [query.state] Subset the applications collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;running|canceled&#x60; matches items whose &#x60;state&#x60; is &#x60;running&#x60; or &#x60;canceled&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the applications collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getRunningApplications(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'running'
          | 'blocked'
          | 'canceled'
          | 'expired'
          | 'rejected'
          | 'approved';
        name?: string;
      },
      options?: any,
    ) {
      return AccountApplicationApiFp(configuration).getRunningApplications(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this account application. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationApiFp(configuration).patchApplication(
        Application ? Application : null,
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this account application.
     * @summary Update this account application
     * @param {Application} Application
     * @param {string} applicationId The unique identifier of this application. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateApplication(
      Application: Application,
      applicationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationApiFp(configuration).updateApplication(
        Application ? Application : null,
        applicationId ? applicationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountApplicationApi - object-oriented interface
 * @export
 * @class AccountApplicationApi
 * @extends {BaseAPI}
 */
export class AccountApplicationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new account application. This also creates and starts the workflow that is associated with the primary banking product in the request body. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. Users can have only one running application at a time.
   * @summary Create a new account application
   * @param {CreateApplication} CreateApplication The data necessary to create a new account application.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationApi
   */
  public createApplication(CreateApplication: CreateApplication, options?: any) {
    return AccountApplicationApiFp(this.configuration).createApplication(
      CreateApplication ? CreateApplication : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this account application resource. An application may only be deleted by the user if its `state` is `pending`, or by a financial institution if its `state` is `expired`.
   * @summary Delete an unused or expired application
   * @param {string} applicationId The unique identifier of this application. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AccountApplicationApi
   */
  public deleteApplication(applicationId: string, headers?: { If_Match?: string }, options?: any) {
    return AccountApplicationApiFp(this.configuration).deleteApplication(
      applicationId ? applicationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this account application resource.
   * @summary Fetch a representation of this account application
   * @param {string} applicationId The unique identifier of this application. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationApi
   */
  public getApplication(
    applicationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).getApplication(
      applicationId ? applicationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. Not all nested objects are supported for filtering or sorting applications. The following fields may be used: `accountName`, `applicantName`, `productName`, `organizationName', `state`, `createdAt`, `completedAt`
   * @summary Return a collection of account applications
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of account application representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.applicant] Filter applications by applicant. The value must be an applicant&#39;s _contact_ URI, not the URI of a user. (To find applications for a _user_, pass the &#x60;href&#x60; from the &#x60;apiture:contact&#x60; link on the user resource.) An application resource is included in the response if and only if the named  contact is among the application&#39;s &#x60;applicants&#x60;. This query parameter exists for administrator use. The collection is automatically filtered to applications which a user created for non-administrator users.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Applications}
   * @memberof AccountApplicationApi
   */
  public getApplications(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      applicant?: string;
      filter?: string;
      q?: string;
    },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).getApplications(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `blocked`.
   * @summary Return a collection of blocked account applications
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of account application representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Applications}
   * @memberof AccountApplicationApi
   */
  public getBlockedApplications(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).getBlockedApplications(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searching) collection of active running account applications. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. This is a virtual view of all applications, filtered to those whose state is `running`.
   * @summary Return a collection of active, running account applications
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first account application item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of account application representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'running' | 'blocked' | 'canceled' | 'expired' | 'rejected' | 'approved'} [query.state] Subset the applications collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;running|canceled&#x60; matches items whose &#x60;state&#x60; is &#x60;running&#x60; or &#x60;canceled&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the applications collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Applications}
   * @memberof AccountApplicationApi
   */
  public getRunningApplications(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: 'pending' | 'running' | 'blocked' | 'canceled' | 'expired' | 'rejected' | 'approved';
      name?: string;
    },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).getRunningApplications(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this account application. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this account application
   * @param {Application} Application
   * @param {string} applicationId The unique identifier of this application. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationApi
   */
  public patchApplication(
    Application: Application,
    applicationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).patchApplication(
      Application ? Application : null,
      applicationId ? applicationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this account application.
   * @summary Update this account application
   * @param {Application} Application
   * @param {string} applicationId The unique identifier of this application. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationApi
   */
  public updateApplication(
    Application: Application,
    applicationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationApiFp(this.configuration).updateApplication(
      Application ? Application : null,
      applicationId ? applicationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AccountApplicationActionsApi - axios parameter creator
 * @export
 */
export const AccountApplicationActionsApiAxiosParamCreator = function(
  configuration?: SdkConfiguration,
) {
  return {
    /**
     * Approve an account application. This changes the `state` property of the application to `approved`. This operation is available via the `apiture:approve` link on the application resource, if and only if the application is eligible for the approve operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the application state cannot be changed once it has been approved.
     * @summary Approve an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { application } = query;
      const { If_Match } = headers;

      // verify required parameter 'application' is not null or undefined
      if (application === null || application === undefined) {
        throw new RequiredError(
          'application',
          'Required parameter application was null or undefined when calling approveApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling approveApplication.',
        );
      }
      const localVarPath = `/approvedApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (application !== undefined) {
        localVarQueryParameter['application'] = application;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Cancel an account application. This changes the `state` property of the application to `canceled`. This also cancels the application workflow. This operation is available via the `apiture:cancel` link on the application resource, if and only if the application is eligible for the cancel operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the application state cannot be changed once it has been canceled.
     * @summary Cancel an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { application } = query;
      const { If_Match } = headers;

      // verify required parameter 'application' is not null or undefined
      if (application === null || application === undefined) {
        throw new RequiredError(
          'application',
          'Required parameter application was null or undefined when calling cancelApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling cancelApplication.',
        );
      }
      const localVarPath = `/canceledApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (application !== undefined) {
        localVarQueryParameter['application'] = application;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update an application by adding it to the set of expired applications. This changes the `state` property of the application to `expired`. This operation is available via the `apiture:expire` link on the application resource, if and only if the application is eligible for the expire operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `expired`. This is a _terminal_ state: the application state cannot be changed once it has expired.
     * @summary Expire an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    expireApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { application } = query;
      const { If_Match } = headers;

      // verify required parameter 'application' is not null or undefined
      if (application === null || application === undefined) {
        throw new RequiredError(
          'application',
          'Required parameter application was null or undefined when calling expireApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling expireApplication.',
        );
      }
      const localVarPath = `/expiredApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (application !== undefined) {
        localVarQueryParameter['application'] = application;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Reject an account application. This changes the `state` property of the application to `rejected`. This operation is available via the `apiture:reject` link on the application resource, if and only if the application is eligible for the reject operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the application state cannot be changed once it has been rejected.
     * @summary Reject an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { application } = query;
      const { If_Match } = headers;

      // verify required parameter 'application' is not null or undefined
      if (application === null || application === undefined) {
        throw new RequiredError(
          'application',
          'Required parameter application was null or undefined when calling rejectApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling rejectApplication.',
        );
      }
      const localVarPath = `/rejectedApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (application !== undefined) {
        localVarQueryParameter['application'] = application;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Start an application by adding it to the set of running applications. This changes the `state` property of the application to `running`. This operation is available via the `apiture:start` link on the application resource, if and only if the application is eligible for the start operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is only valid if the current state of the application is `blocked`. This operation does nothing if the state is already `running`.
     * @summary Start an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { application } = query;
      const { If_Match } = headers;

      // verify required parameter 'application' is not null or undefined
      if (application === null || application === undefined) {
        throw new RequiredError(
          'application',
          'Required parameter application was null or undefined when calling startApplication.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling startApplication.',
        );
      }
      const localVarPath = `/runningApplications`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (application !== undefined) {
        localVarQueryParameter['application'] = application;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountApplicationActionsApi - functional programming interface
 * @export
 */
export const AccountApplicationActionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Approve an account application. This changes the `state` property of the application to `approved`. This operation is available via the `apiture:approve` link on the application resource, if and only if the application is eligible for the approve operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the application state cannot be changed once it has been approved.
     * @summary Approve an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationActionsApiAxiosParamCreator(
        configuration,
      ).approveApplication(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Cancel an account application. This changes the `state` property of the application to `canceled`. This also cancels the application workflow. This operation is available via the `apiture:cancel` link on the application resource, if and only if the application is eligible for the cancel operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the application state cannot be changed once it has been canceled.
     * @summary Cancel an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationActionsApiAxiosParamCreator(
        configuration,
      ).cancelApplication(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update an application by adding it to the set of expired applications. This changes the `state` property of the application to `expired`. This operation is available via the `apiture:expire` link on the application resource, if and only if the application is eligible for the expire operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `expired`. This is a _terminal_ state: the application state cannot be changed once it has expired.
     * @summary Expire an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    expireApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationActionsApiAxiosParamCreator(
        configuration,
      ).expireApplication(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Reject an account application. This changes the `state` property of the application to `rejected`. This operation is available via the `apiture:reject` link on the application resource, if and only if the application is eligible for the reject operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the application state cannot be changed once it has been rejected.
     * @summary Reject an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationActionsApiAxiosParamCreator(
        configuration,
      ).rejectApplication(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Start an application by adding it to the set of running applications. This changes the `state` property of the application to `running`. This operation is available via the `apiture:start` link on the application resource, if and only if the application is eligible for the start operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is only valid if the current state of the application is `blocked`. This operation does nothing if the state is already `running`.
     * @summary Start an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Application> {
      const localVarAxiosArgs = AccountApplicationActionsApiAxiosParamCreator(
        configuration,
      ).startApplication(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountApplicationActionsApi - factory interface
 * @export
 */
export const AccountApplicationActionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Approve an account application. This changes the `state` property of the application to `approved`. This operation is available via the `apiture:approve` link on the application resource, if and only if the application is eligible for the approve operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the application state cannot be changed once it has been approved.
     * @summary Approve an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationActionsApiFp(configuration).approveApplication(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Cancel an account application. This changes the `state` property of the application to `canceled`. This also cancels the application workflow. This operation is available via the `apiture:cancel` link on the application resource, if and only if the application is eligible for the cancel operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the application state cannot be changed once it has been canceled.
     * @summary Cancel an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationActionsApiFp(configuration).cancelApplication(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update an application by adding it to the set of expired applications. This changes the `state` property of the application to `expired`. This operation is available via the `apiture:expire` link on the application resource, if and only if the application is eligible for the expire operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `expired`. This is a _terminal_ state: the application state cannot be changed once it has expired.
     * @summary Expire an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    expireApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationActionsApiFp(configuration).expireApplication(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Reject an account application. This changes the `state` property of the application to `rejected`. This operation is available via the `apiture:reject` link on the application resource, if and only if the application is eligible for the reject operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the application state cannot be changed once it has been rejected.
     * @summary Reject an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationActionsApiFp(configuration).rejectApplication(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Start an application by adding it to the set of running applications. This changes the `state` property of the application to `running`. This operation is available via the `apiture:start` link on the application resource, if and only if the application is eligible for the start operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is only valid if the current state of the application is `blocked`. This operation does nothing if the state is already `running`.
     * @summary Start an application
     * @param {Object} [query] Query object
     * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startApplication(
      query?: { application?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AccountApplicationActionsApiFp(configuration).startApplication(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountApplicationActionsApi - object-oriented interface
 * @export
 * @class AccountApplicationActionsApi
 * @extends {BaseAPI}
 */
export class AccountApplicationActionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Approve an account application. This changes the `state` property of the application to `approved`. This operation is available via the `apiture:approve` link on the application resource, if and only if the application is eligible for the approve operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the application state cannot be changed once it has been approved.
   * @summary Approve an application
   * @param {Object} [query] Query object
   * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationActionsApi
   */
  public approveApplication(
    query?: { application?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationActionsApiFp(this.configuration).approveApplication(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Cancel an account application. This changes the `state` property of the application to `canceled`. This also cancels the application workflow. This operation is available via the `apiture:cancel` link on the application resource, if and only if the application is eligible for the cancel operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the application state cannot be changed once it has been canceled.
   * @summary Cancel an application
   * @param {Object} [query] Query object
   * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationActionsApi
   */
  public cancelApplication(
    query?: { application?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationActionsApiFp(this.configuration).cancelApplication(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update an application by adding it to the set of expired applications. This changes the `state` property of the application to `expired`. This operation is available via the `apiture:expire` link on the application resource, if and only if the application is eligible for the expire operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `expired`. This is a _terminal_ state: the application state cannot be changed once it has expired.
   * @summary Expire an application
   * @param {Object} [query] Query object
   * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationActionsApi
   */
  public expireApplication(
    query?: { application?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationActionsApiFp(this.configuration).expireApplication(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Reject an account application. This changes the `state` property of the application to `rejected`. This operation is available via the `apiture:reject` link on the application resource, if and only if the application is eligible for the reject operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is valid if the current state of the application is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the application state cannot be changed once it has been rejected.
   * @summary Reject an application
   * @param {Object} [query] Query object
   * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationActionsApi
   */
  public rejectApplication(
    query?: { application?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationActionsApiFp(this.configuration).rejectApplication(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Start an application by adding it to the set of running applications. This changes the `state` property of the application to `running`. This operation is available via the `apiture:start` link on the application resource, if and only if the application is eligible for the start operation. The response is the updated representation of the application. The `If-Match` request header value, if passed, must match the current entity tag value of the application.  This operation is only valid if the current state of the application is `blocked`. This operation does nothing if the state is already `running`.
   * @summary Start an application
   * @param {Object} [query] Query object
   * @param {string} [query.application] A string which uniquely identifies an application which is to added to the running applications resource set. This may be the unique applicationId or the  URI of the application.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Application}
   * @memberof AccountApplicationActionsApi
   */
  public startApplication(
    query?: { application?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AccountApplicationActionsApiFp(this.configuration).startApplication(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ConfigurationApi - axios parameter creator
 * @export
 */
export const ConfigurationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options: any = {}): RequestArgs {
      const localVarPath = `/configurations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroup.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupSchema.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/schema`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/configurations/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: ConfigurationValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConfigurationApi - functional programming interface
 * @export
 */
export const ConfigurationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Configuration> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(configuration).getConfiguration(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroup> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroups> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroups(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConfigurationApi - factory interface
 * @export
 */
export const ConfigurationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options?: any) {
      return ConfigurationApiFp(configuration).getConfiguration(options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(groupName: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroups(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConfigurationApi - object-oriented interface
 * @export
 * @class ConfigurationApi
 * @extends {BaseAPI}
 */
export class ConfigurationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Returns the configuration for this API
   * @summary Configuration definition for this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Configuration}
   * @memberof ConfigurationApi
   */
  public getConfiguration(options?: any) {
    return ConfigurationApiFp(this.configuration).getConfiguration(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
   * @summary Fetch a representation of this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroup}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroup(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroup(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
   * @summary Fetch the schema for this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupSchema(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupSchema(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
   * @summary Fetch a single value associated with the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValue(
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a representation of this configuration group values resource.
   * @summary Fetch the values for the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValues(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValues(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of configuration groups
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroups}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroups(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroups(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /accountApplications/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).
   * @summary Update a single value associated with the specified configuration group
   * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValue(
    body: string,
    groupName: string,
    valueName: string,
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValue(
      body ? body : null,
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this set of values
   * @summary Update the values for the specified configuration group
   * @param {{ [key: string]: ConfigurationValue; }} request_body
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValues(
    request_body: { [key: string]: ConfigurationValue },
    groupName: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValues(
      request_body ? request_body : null,
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EnrollmentApi - axios parameter creator
 * @export
 */
export const EnrollmentApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new enrollment. Creating an enrollment will create and start the workflow that is defined for enrollment in digital banking. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. A user may have only one active enrollment at a time.
     * @summary Create a new enrollment
     * @param {CreateEnrollment} CreateEnrollment The data necessary to create a new enrollment.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEnrollment(CreateEnrollment: CreateEnrollment, options: any = {}): RequestArgs {
      // verify required parameter 'CreateEnrollment' is not null or undefined
      if (CreateEnrollment === null || CreateEnrollment === undefined) {
        throw new RequiredError(
          'CreateEnrollment',
          'Required parameter CreateEnrollment was null or undefined when calling createEnrollment.',
        );
      }
      const localVarPath = `/enrollments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateEnrollment' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateEnrollment || {})
        : CreateEnrollment || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this enrollment resource and any resources that are owned by it.
     * @summary Delete this enrollment resource
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEnrollment(enrollmentId: string, options: any = {}): RequestArgs {
      // verify required parameter 'enrollmentId' is not null or undefined
      if (enrollmentId === null || enrollmentId === undefined) {
        throw new RequiredError(
          'enrollmentId',
          'Required parameter enrollmentId was null or undefined when calling deleteEnrollment.',
        );
      }
      const localVarPath = `/enrollments/{enrollmentId}`.replace(
        `{${'enrollmentId'}}`,
        encodeURIComponent(String(enrollmentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this enrollment resource.
     * @summary Fetch a representation of this enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollment(
      enrollmentId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'enrollmentId' is not null or undefined
      if (enrollmentId === null || enrollmentId === undefined) {
        throw new RequiredError(
          'enrollmentId',
          'Required parameter enrollmentId was null or undefined when calling getEnrollment.',
        );
      }
      const localVarPath = `/enrollments/{enrollmentId}`.replace(
        `{${'enrollmentId'}}`,
        encodeURIComponent(String(enrollmentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of enrollments. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of enrollments
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first enrollment item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of enrollment representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollments(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/enrollments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this enrollment. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'enrollmentId' is not null or undefined
      if (enrollmentId === null || enrollmentId === undefined) {
        throw new RequiredError(
          'enrollmentId',
          'Required parameter enrollmentId was null or undefined when calling patchEnrollment.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling patchEnrollment.',
        );
      }
      // verify required parameter 'Enrollment' is not null or undefined
      if (Enrollment === null || Enrollment === undefined) {
        throw new RequiredError(
          'Enrollment',
          'Required parameter Enrollment was null or undefined when calling patchEnrollment.',
        );
      }
      const localVarPath = `/enrollments/{enrollmentId}`.replace(
        `{${'enrollmentId'}}`,
        encodeURIComponent(String(enrollmentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Enrollment' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Enrollment || {})
        : Enrollment || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this enrollment.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'enrollmentId' is not null or undefined
      if (enrollmentId === null || enrollmentId === undefined) {
        throw new RequiredError(
          'enrollmentId',
          'Required parameter enrollmentId was null or undefined when calling updateEnrollment.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling updateEnrollment.',
        );
      }
      // verify required parameter 'Enrollment' is not null or undefined
      if (Enrollment === null || Enrollment === undefined) {
        throw new RequiredError(
          'Enrollment',
          'Required parameter Enrollment was null or undefined when calling updateEnrollment.',
        );
      }
      const localVarPath = `/enrollments/{enrollmentId}`.replace(
        `{${'enrollmentId'}}`,
        encodeURIComponent(String(enrollmentId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Enrollment' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Enrollment || {})
        : Enrollment || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EnrollmentApi - functional programming interface
 * @export
 */
export const EnrollmentApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new enrollment. Creating an enrollment will create and start the workflow that is defined for enrollment in digital banking. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. A user may have only one active enrollment at a time.
     * @summary Create a new enrollment
     * @param {CreateEnrollment} CreateEnrollment The data necessary to create a new enrollment.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEnrollment(
      CreateEnrollment: CreateEnrollment,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).createEnrollment(
        CreateEnrollment ? CreateEnrollment : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this enrollment resource and any resources that are owned by it.
     * @summary Delete this enrollment resource
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEnrollment(
      enrollmentId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).deleteEnrollment(
        enrollmentId ? enrollmentId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this enrollment resource.
     * @summary Fetch a representation of this enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollment(
      enrollmentId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).getEnrollment(
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of enrollments. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of enrollments
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first enrollment item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of enrollment representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollments(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollments> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).getEnrollments(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this enrollment. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).patchEnrollment(
        Enrollment ? Enrollment : null,
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this enrollment.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentApiAxiosParamCreator(configuration).updateEnrollment(
        Enrollment ? Enrollment : null,
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EnrollmentApi - factory interface
 * @export
 */
export const EnrollmentApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new enrollment. Creating an enrollment will create and start the workflow that is defined for enrollment in digital banking. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. A user may have only one active enrollment at a time.
     * @summary Create a new enrollment
     * @param {CreateEnrollment} CreateEnrollment The data necessary to create a new enrollment.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEnrollment(CreateEnrollment: CreateEnrollment, options?: any) {
      return EnrollmentApiFp(configuration).createEnrollment(
        CreateEnrollment ? CreateEnrollment : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this enrollment resource and any resources that are owned by it.
     * @summary Delete this enrollment resource
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEnrollment(enrollmentId: string, options?: any) {
      return EnrollmentApiFp(configuration).deleteEnrollment(
        enrollmentId ? enrollmentId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this enrollment resource.
     * @summary Fetch a representation of this enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollment(enrollmentId: string, headers?: { If_None_Match?: string }, options?: any) {
      return EnrollmentApiFp(configuration).getEnrollment(
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of enrollments. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of enrollments
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first enrollment item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of enrollment representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEnrollments(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return EnrollmentApiFp(configuration).getEnrollments(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this enrollment. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return EnrollmentApiFp(configuration).patchEnrollment(
        Enrollment ? Enrollment : null,
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this enrollment.
     * @summary Update this enrollment
     * @param {Enrollment} Enrollment
     * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateEnrollment(
      Enrollment: Enrollment,
      enrollmentId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return EnrollmentApiFp(configuration).updateEnrollment(
        Enrollment ? Enrollment : null,
        enrollmentId ? enrollmentId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EnrollmentApi - object-oriented interface
 * @export
 * @class EnrollmentApi
 * @extends {BaseAPI}
 */
export class EnrollmentApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new enrollment. Creating an enrollment will create and start the workflow that is defined for enrollment in digital banking. The client should execute any interactive workflow tasks until the workflow reaches a terminal state and the system approves or rejects the application or the user cancels the application. A user may have only one active enrollment at a time.
   * @summary Create a new enrollment
   * @param {CreateEnrollment} CreateEnrollment The data necessary to create a new enrollment.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentApi
   */
  public createEnrollment(CreateEnrollment: CreateEnrollment, options?: any) {
    return EnrollmentApiFp(this.configuration).createEnrollment(
      CreateEnrollment ? CreateEnrollment : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this enrollment resource and any resources that are owned by it.
   * @summary Delete this enrollment resource
   * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof EnrollmentApi
   */
  public deleteEnrollment(enrollmentId: string, options?: any) {
    return EnrollmentApiFp(this.configuration).deleteEnrollment(
      enrollmentId ? enrollmentId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this enrollment resource.
   * @summary Fetch a representation of this enrollment
   * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentApi
   */
  public getEnrollment(enrollmentId: string, headers?: { If_None_Match?: string }, options?: any) {
    return EnrollmentApiFp(this.configuration).getEnrollment(
      enrollmentId ? enrollmentId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of enrollments. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of enrollments
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first enrollment item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of enrollment representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollments}
   * @memberof EnrollmentApi
   */
  public getEnrollments(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return EnrollmentApiFp(this.configuration).getEnrollments(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this enrollment. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this enrollment
   * @param {Enrollment} Enrollment
   * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentApi
   */
  public patchEnrollment(
    Enrollment: Enrollment,
    enrollmentId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return EnrollmentApiFp(this.configuration).patchEnrollment(
      Enrollment ? Enrollment : null,
      enrollmentId ? enrollmentId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this enrollment.
   * @summary Update this enrollment
   * @param {Enrollment} Enrollment
   * @param {string} enrollmentId The unique identifier of this enrollment. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentApi
   */
  public updateEnrollment(
    Enrollment: Enrollment,
    enrollmentId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return EnrollmentApiFp(this.configuration).updateEnrollment(
      Enrollment ? Enrollment : null,
      enrollmentId ? enrollmentId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EnrollmentActionsApi - axios parameter creator
 * @export
 */
export const EnrollmentActionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Approve an enrollment. This changes the `state` property of the enrollment to `approved`. This operation is available via the `apiture:approve` link on the enrollment resource, if and only if the enrollment is eligible for the approve operation, if the user has completed all enrollment requirements such as passing identity verification and accepting digital banking terms of use and the financial institution's privacy policy. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the enrollment state cannot be changed once it has been approved. This operation can be called by services or administrators only, not end users.
     * @summary Approve an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { enrollment } = query;
      const { If_Match } = headers;

      // verify required parameter 'enrollment' is not null or undefined
      if (enrollment === null || enrollment === undefined) {
        throw new RequiredError(
          'enrollment',
          'Required parameter enrollment was null or undefined when calling approveEnrollment.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling approveEnrollment.',
        );
      }
      const localVarPath = `/approvedEnrollments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (enrollment !== undefined) {
        localVarQueryParameter['enrollment'] = enrollment;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Cancel an enrollment. This changes the `state` property of the enrollment to `canceled`. This operation is available via the `apiture:cancel` link on the enrollment resource, if and only if the enrollment is eligible for the cancel operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the enrollment state cannot be changed once it has been canceled.
     * @summary Cancel an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { enrollment } = query;
      const { If_Match } = headers;

      // verify required parameter 'enrollment' is not null or undefined
      if (enrollment === null || enrollment === undefined) {
        throw new RequiredError(
          'enrollment',
          'Required parameter enrollment was null or undefined when calling cancelEnrollment.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling cancelEnrollment.',
        );
      }
      const localVarPath = `/canceledEnrollments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (enrollment !== undefined) {
        localVarQueryParameter['enrollment'] = enrollment;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Reject an enrollment. This changes the `state` property of the enrollment to `rejected`. This operation is available via the `apiture:reject` link on the enrollment resource, if and only if the enrollment is eligible for the reject operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the enrollment state cannot be changed once it has been rejected. Only service or administrator can call this operation, not end users.
     * @summary Reject an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { enrollment } = query;
      const { If_Match } = headers;

      // verify required parameter 'enrollment' is not null or undefined
      if (enrollment === null || enrollment === undefined) {
        throw new RequiredError(
          'enrollment',
          'Required parameter enrollment was null or undefined when calling rejectEnrollment.',
        );
      }
      // verify required parameter 'If_Match' is not null or undefined
      if (If_Match === null || If_Match === undefined) {
        throw new RequiredError(
          'If_Match',
          'Required parameter If_Match was null or undefined when calling rejectEnrollment.',
        );
      }
      const localVarPath = `/rejectedEnrollments`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (enrollment !== undefined) {
        localVarQueryParameter['enrollment'] = enrollment;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EnrollmentActionsApi - functional programming interface
 * @export
 */
export const EnrollmentActionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Approve an enrollment. This changes the `state` property of the enrollment to `approved`. This operation is available via the `apiture:approve` link on the enrollment resource, if and only if the enrollment is eligible for the approve operation, if the user has completed all enrollment requirements such as passing identity verification and accepting digital banking terms of use and the financial institution's privacy policy. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the enrollment state cannot be changed once it has been approved. This operation can be called by services or administrators only, not end users.
     * @summary Approve an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentActionsApiAxiosParamCreator(
        configuration,
      ).approveEnrollment(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Cancel an enrollment. This changes the `state` property of the enrollment to `canceled`. This operation is available via the `apiture:cancel` link on the enrollment resource, if and only if the enrollment is eligible for the cancel operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the enrollment state cannot be changed once it has been canceled.
     * @summary Cancel an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentActionsApiAxiosParamCreator(
        configuration,
      ).cancelEnrollment(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Reject an enrollment. This changes the `state` property of the enrollment to `rejected`. This operation is available via the `apiture:reject` link on the enrollment resource, if and only if the enrollment is eligible for the reject operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the enrollment state cannot be changed once it has been rejected. Only service or administrator can call this operation, not end users.
     * @summary Reject an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Enrollment> {
      const localVarAxiosArgs = EnrollmentActionsApiAxiosParamCreator(
        configuration,
      ).rejectEnrollment(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EnrollmentActionsApi - factory interface
 * @export
 */
export const EnrollmentActionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Approve an enrollment. This changes the `state` property of the enrollment to `approved`. This operation is available via the `apiture:approve` link on the enrollment resource, if and only if the enrollment is eligible for the approve operation, if the user has completed all enrollment requirements such as passing identity verification and accepting digital banking terms of use and the financial institution's privacy policy. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the enrollment state cannot be changed once it has been approved. This operation can be called by services or administrators only, not end users.
     * @summary Approve an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    approveEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return EnrollmentActionsApiFp(configuration).approveEnrollment(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Cancel an enrollment. This changes the `state` property of the enrollment to `canceled`. This operation is available via the `apiture:cancel` link on the enrollment resource, if and only if the enrollment is eligible for the cancel operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the enrollment state cannot be changed once it has been canceled.
     * @summary Cancel an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return EnrollmentActionsApiFp(configuration).cancelEnrollment(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Reject an enrollment. This changes the `state` property of the enrollment to `rejected`. This operation is available via the `apiture:reject` link on the enrollment resource, if and only if the enrollment is eligible for the reject operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the enrollment state cannot be changed once it has been rejected. Only service or administrator can call this operation, not end users.
     * @summary Reject an enrollment
     * @param {Object} [query] Query object
     * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    rejectEnrollment(
      query?: { enrollment?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return EnrollmentActionsApiFp(configuration).rejectEnrollment(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EnrollmentActionsApi - object-oriented interface
 * @export
 * @class EnrollmentActionsApi
 * @extends {BaseAPI}
 */
export class EnrollmentActionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Approve an enrollment. This changes the `state` property of the enrollment to `approved`. This operation is available via the `apiture:approve` link on the enrollment resource, if and only if the enrollment is eligible for the approve operation, if the user has completed all enrollment requirements such as passing identity verification and accepting digital banking terms of use and the financial institution's privacy policy. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `approved`. This is a _terminal_ state: the enrollment state cannot be changed once it has been approved. This operation can be called by services or administrators only, not end users.
   * @summary Approve an enrollment
   * @param {Object} [query] Query object
   * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentActionsApi
   */
  public approveEnrollment(
    query?: { enrollment?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return EnrollmentActionsApiFp(this.configuration).approveEnrollment(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Cancel an enrollment. This changes the `state` property of the enrollment to `canceled`. This operation is available via the `apiture:cancel` link on the enrollment resource, if and only if the enrollment is eligible for the cancel operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `canceled`. This is a _terminal_ state: the enrollment state cannot be changed once it has been canceled.
   * @summary Cancel an enrollment
   * @param {Object} [query] Query object
   * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentActionsApi
   */
  public cancelEnrollment(
    query?: { enrollment?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return EnrollmentActionsApiFp(this.configuration).cancelEnrollment(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Reject an enrollment. This changes the `state` property of the enrollment to `rejected`. This operation is available via the `apiture:reject` link on the enrollment resource, if and only if the enrollment is eligible for the reject operation. The response is the updated representation of the enrollment. The `If-Match` request header value, if passed, must match the current entity tag value of the enrollment.  This operation is valid if the current state of the enrollment is `running`, or `blocked`. This operation does nothing if the state is already `rejected`. This is a _terminal_ state: the enrollment state cannot be changed once it has been rejected. Only service or administrator can call this operation, not end users.
   * @summary Reject an enrollment
   * @param {Object} [query] Query object
   * @param {string} [query.enrollment] A string which uniquely identifies an enrollment which is to added to the running enrollments resource set. This may be the unique enrollmentId or the URI of the enrollment.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Enrollment}
   * @memberof EnrollmentActionsApi
   */
  public rejectEnrollment(
    query?: { enrollment?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return EnrollmentActionsApiFp(this.configuration).rejectEnrollment(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
