// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Auth
 *  The Authentication API is an identity layer based on OpenID Connect (OIDC) and OAuth 2.0. Accessing resources in the Apiture Open platform requires registering an OAuth consumer before making authenticated API requests. ## Discovery The OpenID Connect Discovery metadata can be retrieved by browsing to the `/auth/openid/metadata` URL. The metadata information is public. ## Creating a client Request an OAuth client key and secret by visiting [developer.apiture.com](https://developer.apiture.com), registering your partner organization, defining a new client application, and requesting API keys for that application and a target environment. After submitting the request, Apiture will provision the API keys and the client ID and client secret which allow the client's user to authenticate and request authentication tokens at run time; these authentication tokens and the API key are used to authenticate each API request. See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ## Open ID Connect and OAuth 2.0 Authentication The Authentication API supports OpenID Connect authentication flows and OAuth 2.0:    - Authorization Code Flow (OpenID Connect), for Mobile Applications or Web Applications or apps where a user logs in   - Client Credentials Grant (OAuth 2.0), for back-end service applications in a secure environment  More information about using these flows are in the [`authorize`](#op-authorize) and [`getToken`](#op-getToken) operations below. ### OpenID Connect Authorization Code Flow This interactive flow involves browser redirection to the Apiture Identity Provider URL (the OAuth _authorization server_) for secure user login and consent. After the first redirection, the user is redirected back to the requesting application using the callback URL associated with the client application in the [developer portal](https://developer.apiture.com).    1. The client requests user authentication via the [`authorize`](#op-authorize) operation, passing a unique random `state` value   1. The user authenticates by entering their credentials in the authorization server's form   1. The user may also be prompted to give consent to specific application access   1. If the client request and user authentication are valid, the authorization operation return a 302 response and `Location` header with the client redirect URI, a `code`, and the client `state` value   1. The client redirects to the redirect URI in order to process the response and code. The request handler should ensure the `state` matches the one passed in step #1.   1. If the `state` matches, the client exchanges the code for tokens via the [`getToken`](#op-getToken) operation to complete the flow  See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ### OAuth 2.0 Client Credentials Grant With this authentication method, the client [requests an authentication token](#op-getToken) passing the client ID and client secret that have been provisioned by the [developer portal](https://developer.apiture.com). Theis method does not use user authentication or credentials; hence the access token is not associated with a financial institution customer. This is _only_ suitable for **secure applications**, such as those in a financial institution's data center. Web or mobile applications must not use this method.  See [Secure Access](https://developer.apiture.com/docs/secure-access) for further details. ## Password reset flow It is possible to reset the user's password from an unauthenticated space by sending the user's key identifying information.    1. Start the process by issuing a [`POST` to `/passwordResetRequests`](#op-passwordResetRequest) with the user's username, taxId   and birthdate. A confirmation code is sent via the preconfigured delivery channel as a result   of this operation.   2. Use the confirmation code as part of a [`POST` request to `/passwordResets`](#op-passwordReset) along with the   user's username and the new desired password. A successful password reset will be acknowledged   with a 202 status code.  ## Changing the user's password To change a user's password, an already authenticated user should [`POST` to `/my/password`[#op-changeUserPassword). The client should encrypt the old and new password using client side encryption obtained from the [`GET /encryptionKeys`]{#op-getEncryptionKeys). ## Using the Tokens Upon successful authentication via the [`authorize`](#op-authorize) operation, use the [`getToken`](#op-getToken) operation to obtain a [`oauthToken`](#schema-oauthToken) response containing an `access_token` that can be used to call secured API endpoints. Each request to a secured endpoint must include the access token (also known a bearer token) as part of the `Authorization` header: `Authorization: Bearer {access_token}`.  The access token has an expiration time in milliseconds in the `expires_in` property in the response, and the the refresh token is in the the `refresh_token` property. To refresh an expiring or expired access tokenm, use the [`/oauth2/token#getToken`](#op-getToken) endpoint with the `grant_type` query parameter set to `refresh_token`, and the `refresh_token` query parameter set to the `refresh_token` obtained when the token was first issued. ## Devices For additional security, this API also manages the devices (such as cell phones, tablets, computers) that the user uses for digital banking. This allows the Apiture platform to notify the user if someone logs onto their account from an unknown device. Each device has a unique device ID.  Device management improves the multi-factor authentication (MFA) experience for users. If SMS-based MFA is enabled, end users must input a security code received via SMS in addition to entering their password during every sign-in . With device management, users can specify that a device is trusted and the authentication service will remember the device as trusted. Trusted devices can serve as a second factor of authentication instead of requiring a security code delivered via SMS.  This feature tracks each device/user combination separately, such as a husband and wife logging onto digital banking on a shared laptop or table. If the husband has chosen to trust the device, he may sign in using the device and not have to use secondary authentication such as an code sent via SMS. If the wife has not marked the device as trusted, when they sign in, they will need to use the secondary authentication such as an code sent via SMS.  A financial institution can disable tracking of trusted devices so that other secondary authentication such as SMS codes or biometrics must be used on each sign in. ## Identity Challenges The Challenges and Authenticator operations support additional user identity verification challenges to allow a user to verify they are who they claim to be, such as entering a code send via email or SMS. A challenge represents a resource for tracking this additional authentication.  For example, in the Users API, when a user tries to change their preferred mailing address, email address, or phone number, the operations may require an additional identity verification challenge. This helps prevent fraudulent use if someone gains access to an account and attempts to take it over without the owner's consent or knowledge by changing the account's contact information. Other APIs which may use the Challenge API include the Transfers API to confirm identity before transferring money higher than some user-level transfer threshold or much higher than historical transfers, or the Accounts API when adding or removing joint owners or authorized signers.  API services initiate challenges when required. If an operation requires a challenge, the initial operation fails with a 401 Unauthorized response with an `_error` object in the response. That [error response](http://developer.apiture.com/docs/concepts/errors) has the error type of `identityChallengeRequired`. The error object contains a `_embedded.challenge` object which describes the challenge (see the `challengeErrorResponse` schema).  A challenge consists of:    * a `contextUri` - the URI of a resource which the challenge is requested (such as the Transfers API,   or the Accounts API), a set of authentication types)   * an array of `authenticators` which the end user can select from   in order to verify their identity   * a `reason` that the service is requesting additional authentication   * the `userId` of the user who is being challenged   * `createdAt`, `verifiedAt`, and `failedAt`, and `redeemedAt` timestamps.   * the `state` of the challenge   * other data for limiting and tracking redemption (use) of a challenge   An authenticator contains   * the authentication `type` such as `sms` or `email`   * the authentication category such as `knowledge`, `biometric`, `device`   * additional authentication details in `attributes`   * a link to a JSON schema that describes the attributes   * a link to the challenge to which it relates   * `createdAt`, `verifiedAt`, and `failedAt` timestamps   * `maximumRetries` limits how many times an authenticator may be retried   For example, a `type` may be `sms` which means the authenticator will send an SMS message to the user's mobile device; the message contains a code (4 to 6 digits) which the user must enter in the application. The schema attached to `sms` will list the preferred mobile device number(s) for the user or account, and perhaps other allowed mobile device phone numbers. Other types include `email` (a similar code is sent to the user at the preferred email address.) Clients must be prepared to handle all the authenticator types.  The client should start the selected authenticators by using a `POST` to their `apiture:start` links (operation [`startAuthenticator`](#op-startAuthenticator). For example, for `sms` and `email` authenticator types, the service will send a code to the user's preferred mobile phone number or email address respectively. The `type` in the authenticator includes a JSON schema which describes the data that should be passed in the authenticator's `attributes`. The client should collect data from the user and then post the authenticator resource (with the user data in the `attributes`) to the `verifyAuthenticator` operation. This validates the data and either completes the authenticator (and challenge) or fails.  After the required authenticators are verified and the challenge has been completed, the client application should retry the initial operation that failed with the 401 error. The client should pass the `_id` of the challenge resource in the `Apiture-Challenge` request header on this operation retry. Operations which participate in the Challenge protocol will document the optional `Apiture-Challenge` request header as one of the operation's parameters.  Challenges and authenticators expire and they are automatically deleted after a delay of several minutes. ## Session Tracking You may use the Authentication API to track user sessions. There are operations to mark the beginning, continuation, and ending of a user session (log on, refresh a user's access token, log off). See the `startUserSession`, `continueUserSession`, `endUserSession` operations.  # Error Types      Error responses in this API may have one of the following `type` values.        <h2 class='errorType' id=\"err-accountAlreadyConfirmed\">accountAlreadyConfirmed</h2>  Description: A user has already confirmed this login account.  Remediation: Your login account is ready for use. You can login or use the Forgot Password option if you have forgotten your username.   <h2 class='errorType' id=\"err-getTokenAccessDenied\">getTokenAccessDenied</h2>  Description: The client is not authorized to generate this token.  Remediation: Make sure the client credentials are valid.   <h2 class='errorType' id=\"err-invalidGrant\">invalidGrant</h2>  Description: The provided code is not valid.  Remediation: Check the provided code.   <h2 class='errorType' id=\"err-postTokenAccessDenied\">postTokenAccessDenied</h2>  Description: The client is not authorized to generate this token.  Remediation: Make sure the client is authorized.   <h2 class='errorType' id=\"err-invalidSymbolForNonEmailUsernameFormat\">invalidSymbolForNonEmailUsernameFormat</h2>  Description: Username cannot contain the ‘@’ symbol.  Remediation: Choose a new username without the ‘@’ symbol.   <h2 class='errorType' id=\"err-usernameRequestConflict\">usernameRequestConflict</h2>  Description: There was a conflict requesting the username.  Remediation: Make sure the supplied information is correct.   <h2 class='errorType' id=\"err-invalidUsernameRequest\">invalidUsernameRequest</h2>  Description: The username request was not processed.  Remediation: Check that the user exists and that the attributes match the request.   <h2 class='errorType' id=\"err-invalidNewPassword\">invalidNewPassword</h2>  Description: The new password is not valid.  Remediation: Check that the new password conforms to password policy.   <h2 class='errorType' id=\"err-dataNotEncrypted\">dataNotEncrypted</h2>  Description: The data in request was not encrypted or it was encrypted with obsolete keys.  Remediation: Encrypt the data using valid encryption keys.   <h2 class='errorType' id=\"err-invalidUsername\">invalidUsername</h2>  Description: For your security, we recommend choosing a more complex username with at least one special character.  Remediation: Choose a new username that satisfies the financial institution's policies or is more complex, such as including special characters.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>specialCharacters</td><td>string</td><td>A string containing recommended special characters.</td></tr> </table>  <h2 class='errorType' id=\"err-challengedNotVerified\">challengedNotVerified</h2>  Description: The challenge has not been verified, has expired, or has been redeemed too many times.  Remediation: Pass a valid and verified challenge resource in the Apiture-Challenge request header.   <h2 class='errorType' id=\"err-accessDenied\">accessDenied</h2>  Description: The credentials supplied in the request are insufficient to grant access.  Remediation: Check the supplied credentials for validity.   <h2 class='errorType' id=\"err-currentPasswordDoesNotMatch\">currentPasswordDoesNotMatch</h2>  Description: The current password does not match.  Remediation: Check that the current password in the request match the user's current password.   <h2 class='errorType' id=\"err-noSuchUser\">noSuchUser</h2>  Description: No users were found for the specified userId.  Remediation: Ensure the supplied userId corresponds to an Apiture user.   <h2 class='errorType' id=\"err-challengeNotFound\">challengeNotFound</h2>  Description: No Challenge was found for the specified challengeId.  Remediation: Ensure the supplied challengeId corresponds to a valid challenge resource.   <h2 class='errorType' id=\"err-authenticatorNotFound\">authenticatorNotFound</h2>  Description: No authenticators were found for the specified authenticatorId and challengeId combination.  Remediation: Ensure the supplied authenticatorId corresponds to a valid authenticator resource.   <h2 class='errorType' id=\"err-noSuchDevice\">noSuchDevice</h2>  Description: No devices were found for the specified userId.  Remediation: Verify that the device exists for the user and resubmit.   <h2 class='errorType' id=\"err-invalidAuthenticatorState\">invalidAuthenticatorState</h2>  Description: The operation is not allowed from the authenticator’s current state.  Remediation: Ensure the supplied authenticatorId corresponds to an Apiture authenticator resource in the correct state.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>currentState</td><td>string</td><td>undefined</td></tr> <tr><td>allowedStates</td><td>array</td><td>undefined</td></tr> </table>  <h2 class='errorType' id=\"err-authenticatorAttemptsExceeded\">authenticatorAttemptsExceeded</h2>  Description: User has exceeded the allowed number of retry attempts.  Remediation: Consider locking this user or device in order to prevent fraud.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>authenticatorId</td><td>string</td><td>undefined</td></tr> <tr><td>maximumRetries</td><td>number</td><td>undefined</td></tr> <tr><td>retryCount</td><td>number</td><td>undefined</td></tr> </table>  <h2 class='errorType' id=\"err-authenticatorTypeInUse\">authenticatorTypeInUse</h2>  Description: An update to the authenticator types omits one or more types that are in use.  Remediation: Include all in-use type names.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>typeNames</td><td>array</td><td>The list of authenticator types that are in use but missing from the request.<br>Example: `sms,email`</td></tr> </table>  <h2 class='errorType' id=\"err-redeemChallengeConflict\">redeemChallengeConflict</h2>  Description: No `Apiture-Challenge` request header was passed when expected, or the challenge has not been verified, has expired, or has been redeemed too many times.  Remediation: Ensure the supplied challengeId corresponds to a valid challenge resource.   <h2 class='errorType' id=\"err-authenticatorNotCompletable\">authenticatorNotCompletable</h2>  Description: The authenticator is not in a state that allows completing.  Remediation: Only verify an authenticator if the `apiture:verify` link exists.   <h2 class='errorType' id=\"err-invalidAuthenticatorAttributes\">invalidAuthenticatorAttributes</h2>  Description: The `attributes` in the authenticator do not conform to the schema for the authenticator type.  Remediation: Pass `attributes` that satisfy the JSON schema for the authenticator's type.   <h2 class='errorType' id=\"err-invalidSession\">invalidSession</h2>  Description: No session was found.  Remediation: Resubmit request with a valid session.   <h2 class='errorType' id=\"err-challengeRefNotFound\">challengeRefNotFound</h2>  Description: There is no challence resource corresponding to the referenced challenge.  Remediation: Pass a reference to a valid challence resource.   <h2 class='errorType' id=\"err-authenticatorRefNotFound\">authenticatorRefNotFound</h2>  Description: There is no authentictor resource corresponding to the referenced authentictor.  Remediation: Pass a reference to a valid authentictor resource.   <h2 class='errorType' id=\"err-missingApitureChallengeHeader\">missingApitureChallengeHeader</h2>  Description: The Apiture-Challenge request header is missing.  Remediation: Pass a reference to a valid challence resource in the Apiture-Challenge header.   <h2 class='errorType' id=\"err-challengedAlreadyRedeemed\">challengedAlreadyRedeemed</h2>  Description: The challenge resource has already been redeemed.  Remediation: Use the most recently issued challenge.   <h2 class='errorType' id=\"err-challengedExpired\">challengedExpired</h2>  Description: The challenge resource has expired.  Remediation: Use the most recently issued challenge and complete the authenticators before the challenge expires.   <h2 class='errorType' id=\"err-postTokenForbidden\">postTokenForbidden</h2>  Description: The client is not authorized to generate a new token.  Remediation: Use the most recently issued challenge.
 *
 * OpenAPI spec version: 0.17.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/auth'.replace(/\/+$/, '');

export const API_VERSION = '0.17.1';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A map of (name, value) pairs which describe then the [OpenID Provider metadata](https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata).
 * @export
 * @interface AuthMetadata
 */
export interface AuthMetadata {}

/**
 * Representation of authenticators which verify a user's identity.   <h3 class='schema-links' id=\"authenticator-links\" >Links</h3>  Response and request bodies using this <strong><code>authenticator</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-retryAuthenticator'><strong><code>apiture:retry</code></strong></a></td><td>Retry an authenticator</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-startAuthenticator'><strong><code>apiture:start</code></strong></a></td><td>Start an authenticator</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-verifyAuthenticator'><strong><code>apiture:verify</code></strong></a></td><td>Verify a user's identity</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-getChallenge'><strong><code>apiture:challenge</code></strong></a></td><td>Fetch a representation of this challenge</td><td><code>GET</code></td> </tr> </table>
 * @export
 * @interface Authenticator
 */
export interface Authenticator extends AbstractResource, AuthenticatorFields {
  /**
   * The unique identifier for this authenticator resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof Authenticator
   */
  _id?: string;
  /**
   * The user ID of the user who is requested to verify their identity.
   * @type {string}
   * @memberof Authenticator
   */
  userId?: string;
  /**
   * The state of this authenticator. This is derived and read-only.
   * @type {AuthenticatorState}
   * @memberof Authenticator
   */
  state?: AuthenticatorState;
  /**
   * The actual number of times a user has retried this authenticator.
   * @type {number}
   * @memberof Authenticator
   */
  retryCount?: number;
  /**
   * Data collected from the user that is used to verify this authenticator. This data conforms to the schema defined in the `type`. For example, for `sms`, the `attributes` must contains a `code`.
   * @type {any}
   * @memberof Authenticator
   */
  attributes?: any;
  /**
   * The time stamp when authenticator was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  createdAt?: Date;
  /**
   * The time stamp when authenticator was verified in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  verifiedAt?: Date;
  /**
   * The time stamp when the user failed to verify their identity verification (authentication) for this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  failedAt?: Date;
  /**
   * The time stamp when the this challenge expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  expiresAt?: Date;
}

/**
 * Categories which help classify and organize different authenticator types:   * `knowledge` - Something you know, such as a password or   answers to personal questions.   * `biometric` - Something you are, such as   facial recognition or fingerprints.   * `device` - Something you have, such as a mobile phone   (for confirmation via a code sent via text message) or an electronic key.  <strong><code>authenticatorCategory</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named authenticatorCategory)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>knowledge</code></strong></td><td>Knowledge: Authenticate with information the user knows, such as a password or answers to personal questions.</td>     </tr> <tr>     <td><strong><code>biometric</code></strong></td><td>Biometric: Authenticate with physical characteristics of the user, such as fingerprints, voiceprint, or faceprint.</td>     </tr> <tr>     <td><strong><code>device</code></strong></td><td>Device: Authenticate with a device that the user has, such as a mobile phone or an electronic key.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum AuthenticatorCategory {
  Knowledge = 'knowledge',
  Biometric = 'biometric',
  Device = 'device',
}

/**
 * Common fields of an authenticator.
 * @export
 * @interface AuthenticatorFields
 */
export interface AuthenticatorFields {
  /**
   * The type of this authenticator. This must be one of the items in the `/authenticatorTypes` resource.
   * @type {AuthenticatorType}
   * @memberof AuthenticatorFields
   */
  type?: AuthenticatorType;
  /**
   * The maximum number of times the user may retry this authenticator. If `0`, the user must authenticate correctly on the first try. When an authenticator is retried, the client should `POST` to the `apiture:retry` link on the authenticators; absence of the link means the user cannot retry the authenticator. The default is `3`.
   * @type {number}
   * @memberof AuthenticatorFields
   */
  maximumRetries?: number;
}

/**
 * The state of a challenge authenticator resource.    * The `startAuthenticator` operation (link `apiture:start`) changes the state     from `pending` to `started`.   * The `retryAuthenticator` operation (link `apiture:retry`) changes the state     to `started` and is only allowed if the authenticator has more retries available.   * The `verifyAuthenticator` operation (link `apiture:verify`) validates     the `attributes` and changes the state     to `verified` if valid or     to `failed` if invalid.  <strong><code>authenticatorState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named authenticatorState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending: The authenticator is created but not yet started.</td>     </tr> <tr>     <td><strong><code>started</code></strong></td><td>Started: The user has started the authenticator.</td>     </tr> <tr>     <td><strong><code>verified</code></strong></td><td>Verified: The user corresponding verified the authenticator.</td>     </tr> <tr>     <td><strong><code>failed</code></strong></td><td>Failed: The user failed the authenticators criteria.</td>     </tr> <tr>     <td><strong><code>expired</code></strong></td><td>Expired: The authenticator expired before the user completed the criteria.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum AuthenticatorState {
  Pending = 'pending',
  Started = 'started',
  Verified = 'verified',
  Failed = 'failed',
  Expired = 'expired',
}

/**
 * An authenticator type description.
 * @export
 * @interface AuthenticatorType
 */
export interface AuthenticatorType {
  /**
   * The name of this authenticator; also the key in the `authenticatorTypes` object.
   * @type {string}
   * @memberof AuthenticatorType
   */
  name?: string;
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof AuthenticatorType
   */
  label?: string;
  /**
   * A more detailed localized description of an authenticator type.
   * @type {string}
   * @memberof AuthenticatorType
   */
  description?: string;
  /**
   * The actual natural language tag to which this authentication type description is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1). If omitted, this serves as the _default_.
   * @type {string}
   * @memberof AuthenticatorType
   */
  language?: string;
  /**
   * The authentication category.
   * @type {AuthenticatorCategory}
   * @memberof AuthenticatorType
   */
  category?: AuthenticatorCategory;
  /**
   * The JSON schema which describe the `attributes` object for all authenticators of this type. For example, for `sms`, the schema defines a required `code` string.
   * @type {any}
   * @memberof AuthenticatorType
   */
  schema?: any;
}

/**
 * A set of methods by which a user can authenticate in order to verify their identity. The `type` property of an `authentication` must match one of the keys in this object. The keys in this object are names of the authenticators.
 * @export
 * @interface AuthenticatorTypes
 */
export interface AuthenticatorTypes {
  [key: string]: AuthenticatorType;
}

/**
 * A resource which represents an identity verification challenge to a user. The user must verify one or more of the authentication methods defined in this challenge in order to proceed with a banking operation (such as scheduling a larger than normal transfer, adding a joint owner or authorized signer to an account, or changing their mailing address or mobile phone number).   <h3 class='schema-links' id=\"challenge-links\" >Links</h3>  Response and request bodies using this <strong><code>challenge</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-redeemChallenge'><strong><code>apiture:redeem</code></strong></a></td><td>Redeem or use a challenge</td><td><code>POST</code></td> </tr> </table>
 * @export
 * @interface Challenge
 */
export interface Challenge extends AbstractResource, SummaryChallenge {
  /**
   * The unique identifier for this challenge resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof Challenge
   */
  _id?: string;
  /**
   * An array of authenticators with which the user can verify their identity. This is derived; the array and the authenticators are constructed in the `createChallenge` operation.
   * @type {Array<Authenticator>}
   * @memberof Challenge
   */
  authenticators?: Array<Authenticator>;
  /**
   * `true` if and only if the challenge may be redeemed. This is derived from the states of the challenge's authenticators; if the number of `verified` authenticators meets or exceeds the `minimumAuthenticatorCount`, the challenge becomes `verified` and may be redeemed via a `POST` to href in the challenge's `apiture:redeem` link.
   * @type {boolean}
   * @memberof Challenge
   */
  redeemable?: boolean;
  /**
   * The time stamp when challenge was verified in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  verifiedAt?: Date;
  /**
   * The time stamp when the user failed to verify their identity verification (authentication) for this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  failedAt?: Date;
  /**
   * The time stamp when the this challenge expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  expiresAt?: Date;
  /**
   * The time stamps when a service or operation redeemed this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). Item 0 is the time stamp the challenge was first redeemed, item 1 is the time stamp of the next redemption, and so on.
   * @type {Array<Date>}
   * @memberof Challenge
   */
  redemptionHistory?: Array<Date>;
  /**
   * An optional authentication code which is only returned in the challenge resource if both a) the platform assigned the `code` when [constructing the challenge](#op-createChallenge)), _and_ b) the user has successfully verified the challenge. The client must [re-fetch the verified challenge](#op-getChallenge) in order to access this property.
   * @type {string}
   * @memberof Challenge
   */
  code?: string;
}

/**
 * The operation error description with an embedded identity challenge.
 * @export
 * @interface ChallengeError
 */
export interface ChallengeError extends Error {
  /**
   * Embedded objects
   * @type {any}
   * @memberof ChallengeError
   */
  _embedded?: any;
}

/**
 * When an operation requires an additional identity verification challenge, it returns a 401 Unauthorized response status code and an error response with a challenge resource embedded in the `_error._embedded.challenge`. This informs the caller that they should verify the challenge via one or more of its `authenticators`, then retry the operation with the `Apiture-Challenge` header that references the challenge's `_id`.
 * @export
 * @interface ChallengeErrorResponse
 */
export interface ChallengeErrorResponse extends ErrorResponse {
  /**
   * The description of the error.
   * @type {ChallengeError}
   * @memberof ChallengeErrorResponse
   */
  _error?: ChallengeError;
}

/**
 * Properties of challenge objects.
 * @export
 * @interface ChallengeFields
 */
export interface ChallengeFields {
  /**
   * The reason the application or service has issued a challenge requesting the user verify their identity. This is for labeling or informational purposes.
   * @type {string}
   * @memberof ChallengeFields
   */
  reason?: string;
  /**
   * The URI of a resource that establishes the context in which the user is asked to authenticate their identity. For example, for this may be for a pending transfer, a user's mailing address, or an account if adding a joint owner.
   * @type {string}
   * @memberof ChallengeFields
   */
  contextUri?: string;
  /**
   * The user ID of the user who is requested to verify their identity. The default is the userID of the authenticated person creating the challenge.
   * @type {string}
   * @memberof ChallengeFields
   */
  userId?: string;
  /**
   * The minimum number of different authenticators the user must verify in order to satisfy the identity challenge. The default is 1.
   * @type {number}
   * @memberof ChallengeFields
   */
  minimumAuthenticatorCount?: number;
  /**
   * The maximum number of times the challenge may be used or redeemed. The default is 1.
   * @type {number}
   * @memberof ChallengeFields
   */
  maximumRedemptionCount?: number;
}

/**
 * The state of an identity challenge resource. This is derived based on the state of the challenge's authenticators.  <strong><code>challengeState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named challengeState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending: The challenge is created but not yet started.</td>     </tr> <tr>     <td><strong><code>started</code></strong></td><td>Started: The user has started the challenge and associated authenticator(s).</td>     </tr> <tr>     <td><strong><code>verified</code></strong></td><td>Verified: The user correctly verified the corresponding authenticator(s), marking the challenge as verified.</td>     </tr> <tr>     <td><strong><code>failed</code></strong></td><td>Failed: The challenge has failed, often because the user failed one or more of the authenticators.</td>     </tr> <tr>     <td><strong><code>redeemed</code></strong></td><td>Redeemed: The user has redeemed (used) the challenge.</td>     </tr> <tr>     <td><strong><code>expired</code></strong></td><td>Expired: The challenge has expired without being verified.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum ChallengeState {
  Pending = 'pending',
  Started = 'started',
  Verified = 'verified',
  Failed = 'failed',
  Redeemed = 'redeemed',
  Expired = 'expired',
}

/**
 * Collection of challenges. The items in the collection are ordered in the `_embedded.items` array; the `name` is `challenges`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`.)
 * @export
 * @interface Challenges
 */
export interface Challenges extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Challenges
   */
  _embedded?: any;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Device properties shared by other schemas.
 * @export
 * @interface CommonDeviceFields
 */
export interface CommonDeviceFields {
  /**
   * The device unique identifier.
   * @type {string}
   * @memberof CommonDeviceFields
   */
  _id?: string;
  /**
   * The operating system of the device, if known. iOS, Android, macOS, Windows, Linux are examples. An empty or omitted value indicates the value could not be determined.
   * @type {string}
   * @memberof CommonDeviceFields
   */
  operatingSystem?: string;
  /**
   * The vendor of the device, if known. Apple, Google, Samsung, LG are examples. An empty or omitted value indicates the value could not be determined.
   * @type {string}
   * @memberof CommonDeviceFields
   */
  vendor?: string;
  /**
   * An additional unique host-defined device identifier, for example a unique ID for advertising or other purposes.
   * @type {string}
   * @memberof CommonDeviceFields
   */
  secondaryId?: string;
}

/**
 * Representation used to confirm a password reset flow.
 * @export
 * @interface ConfirmPasswordReset
 */
export interface ConfirmPasswordReset extends AbstractRequest {
  /**
   * The user's encrypted new password. The client should prompt the user for their new password, then encrypt it with the `secret` encryption key.
   * @type {string}
   * @memberof ConfirmPasswordReset
   */
  newPassword: string;
  /**
   * A confirmation code send when the user initiated password reset.
   * @type {string}
   * @memberof ConfirmPasswordReset
   */
  confirmationCode: string;
  /**
   * The username.
   * @type {string}
   * @memberof ConfirmPasswordReset
   */
  username: string;
  /**
   * Metadata about the encrypted `newPassword` property.
   * @type {EncryptionMetadata}
   * @memberof ConfirmPasswordReset
   */
  _encryption?: EncryptionMetadata;
}

/**
 * A request to create a new authenticator.
 * @export
 * @interface CreateAuthenticator
 */
export interface CreateAuthenticator extends AbstractResource, AuthenticatorFields {}

/**
 * A request to create a user authentication challenge.
 * @export
 * @interface CreateChallenge
 */
export interface CreateChallenge extends AbstractResource, ChallengeFields {
  /**
   * An optional opaque code string which a service may assign when using the Challenge API to satisfy the deployment's authentication challenge. This code is returned in the [challenge resource](#op-getChallenge) only when the user has successfully verified the challenge. The client may use this code to complete the authentication provider's authentication flow.
   * @type {string}
   * @memberof CreateChallenge
   */
  code?: string;
}

/**
 * A new user's requested username and password.  **Warning**: The schema `credentials` is **deprecated**. The schema `credentials` was deprecated on version `v0.13.2` of the API. `credentials` will be removed on version `v1.0.0` of the API.
 * @export
 * @interface Credentials
 */
export interface Credentials extends AbstractRequest {
  /**
   * A new user's password.
   * @type {string}
   * @memberof Credentials
   */
  password: string;
  /**
   * The user's requested username.
   * @type {string}
   * @memberof Credentials
   */
  username: string;
}

/**
 * Response from submitting new username and password for a new user login account.
 * @export
 * @interface CredentialsResponse
 */
export interface CredentialsResponse extends AbstractResource {}

/**
 * A device which the user has used to sign in to digital banking.
 * @export
 * @interface Device
 */
export interface Device extends AbstractResource, CommonDeviceFields {
  /**
   * The name of the device, derived from the authentication flow.
   * @type {string}
   * @memberof Device
   */
  name?: string;
  /**
   * The type (category) of the device, if known. 'mobile', 'desktop' are examples. An empty or omitted value indicates the value could not be determined.
   * @type {string}
   * @memberof Device
   */
  type?: string;
  /**
   * The IP address used when the user last logged in with this device.
   * @type {string}
   * @memberof Device
   */
  lastIpAddress?: string;
  /**
   * If `true`, the user indicated that the device is trusted when signing in on the device. Future sign ins on the device will not require alternate multi-factor authentication such as entering a code sent by the financial institution via SMS. If `false`, the user has not indicated the specific device is trusted.
   * @type {boolean}
   * @memberof Device
   */
  trusted?: boolean;
  /**
   * The timestamp of last login. This is in [RFC 3339](https://tools.ietf.org/html/rfc3339)  format, `YYYY-MM-DDThh:mm:ss.sssZ`
   * @type {Date}
   * @memberof Device
   */
  lastLoggedInAt?: Date;
  /**
   * The user identified by `userId`.
   * @type {string}
   * @memberof Device
   */
  userId?: string;
}

/**
 * A collection of devices which user uses to sign in.
 * @export
 * @interface Devices
 */
export interface Devices extends Collection {
  /**
   * Embedded device objects.
   * @type {any}
   * @memberof Devices
   */
  _embedded?: any;
}

/**
 * A rotating public encryption key.
 * @export
 * @interface EncryptionKey
 */
export interface EncryptionKey {
  /**
   * An encryption key name identifies the type of data that the client wishes to encrypt, such as `pii` for personally identifying information, `secret` for passwords or other secret data. The type name is chosen by the client when requesting encryption keys.
   * @type {string}
   * @memberof EncryptionKey
   */
  name?: string;
  /**
   * The ASCII encoded public encryption key that the client uses to encrypt data. This is half of the asymmetric public/private key pair. This is a mult-line string with key bopokends and embedded line breaks.
   * @type {string}
   * @memberof EncryptionKey
   */
  publicKey?: string;
  /**
   * An alias or proxy for the actual rotating key. Keys rotate every few minutes. The alias identifies a specific active public/private key pair. This alias should be used in the `_encryption` metadata (see [`encryptionMetadata`](#schema-encryptionMetadata)). The value of the alias is the concatenation of the `name`, a dash `-`, and some additional characters which identify the specific key rotation.
   * @type {string}
   * @memberof EncryptionKey
   */
  alias?: string;
  /**
   * The date-time when the encryption key was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) date-time format.
   * @type {Date}
   * @memberof EncryptionKey
   */
  createdAt?: Date;
  /**
   * The date-time when the encryption key will expire. If this expiration time has passed or is less than 60 seconds away, the client should fetch updated encryption keys. [RFC 3339](https://tools.ietf.org/html/rfc3339) date-time format.
   * @type {Date}
   * @memberof EncryptionKey
   */
  expiresAt?: Date;
}

/**
 * A set of rotating public encryption keys that the client may use to encrypt sensitive or secret data before sending it to the service. The client only has access to the public key and only the service can decrypt the data. Such keys typically expire after several minutes.
 * @export
 * @interface EncryptionKeys
 */
export interface EncryptionKeys extends AbstractResource {
  /**
   * A map of encryption keys. The map's keys are the key `name`; the values are encryption key objects.
   * @type {{ [key: string]: EncryptionKey; }}
   * @memberof EncryptionKeys
   */
  keys?: { [key: string]: EncryptionKey };
}

/**
 * Metadata about encrypted data within a JSON object in a request body. This `_encryption` object is a peer of the encrypted data. Each nested object that contains encrypted properties has it's own `_encryption` object.   This object is a map of `string` &rarr; `string`. The keys are names of the encrypted property; each value is the `alias` of the rotating public encryption key that the client used to encrypt the named property. For example, for the original request body payload below, the client encrypts the `password` properties with the `secret` key and the `hint` properties with the `sensitive` key.  <code>{</code><br> <code>&nbsp;&nbsp;\"old\" : { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"noise-tube-branch-4183\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"bang nano twig ext\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-01-09T050:00.00Z\"</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp;&nbsp;\"new\" : { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"mile-leave-began-9315\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"1600 take-your \",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-03-09T08:00:00.000Z\"</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp; \"reason\" : \"I forgot my password\"</code><br> <code>}</code>  At the time of the encryption, the `secret` key has the alias `secret-48729783` and the `sensitive` key has the alias `sensitive-47839398`, so the `_encryption` metadata shows those aliases for the `password` and `hint` properties. Other data is not encrypted.  <code>{</code><br> <code>&nbsp;&nbsp;\"old\": { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"E389478492\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"E487903092478\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-01-09T050:00.00Z\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"_encryption\": {</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"password\" : \"secret-48729783\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"hint\" : \"sensitive-47839398\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;}</code><br> <code>&nbsp;&nbsp;},</code><br> <code>&nbsp;&nbsp;\"new\": { </code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"password\": \"E320480203\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"hint\": \"E489229004\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"effectiveAt\" : \"2020-03-09T08:00:00.000Z\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;\"_encryption\": {</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"password\" : \"secret-48729783\",</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;\"hint\" : \"sensitive-47839398\"</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;}</code><br> <code>&nbsp;&nbsp;&nbsp;&nbsp;</code><br> <code>&nbsp;&nbsp;\"reason\" : \"I forgot my password\"</code><br> <code>}</code>  For brevity, the encrypted data is represented as `\"Ennnn\"` but in reality, encrypted data will be longer ASCII data.
 * @export
 * @interface EncryptionMetadata
 */
export interface EncryptionMetadata {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Map coordinates (latitudes, longitude) of a geographical point.
 * @export
 * @interface GpsCoordinates
 */
export interface GpsCoordinates {
  /**
   * Latitude of a geographical point on the map. Represented in decimal notation.
   * @type {number}
   * @memberof GpsCoordinates
   */
  latitude: number;
  /**
   * Longitude of a geographical point on the map. Represented in decimal notation.
   * @type {number}
   * @memberof GpsCoordinates
   */
  longitude: number;
}

/**
 *
 * @export
 * @interface InlineResponse200
 */
export interface InlineResponse200 {
  /**
   *
   * @type {Devices}
   * @memberof InlineResponse200
   */
  devices?: Devices;
}

/**
 *
 * @export
 * @interface InlineResponse2001
 */
export interface InlineResponse2001 {
  /**
   *
   * @type {Device}
   * @memberof InlineResponse2001
   */
  device?: Device;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Information about the mobile device, if the user session is from a native mobile application.
 * @export
 * @interface MobileDevice
 */
export interface MobileDevice extends CommonDeviceFields {
  /**
   * The GPS coordinates at the time the request is made. This may be blank if the user has not granted the application access to the device GPS or the device does not have GPS. The format is \"lat,long\" where each of `latitude` and `longitude`
   * @type {GpsCoordinates}
   * @memberof MobileDevice
   */
  gpsCoordinates?: GpsCoordinates;
  /**
   * Indicates if device analysis shows the device may be compromised, such as rooted or jailbroken.
   * @type {boolean}
   * @memberof MobileDevice
   */
  compromised?: boolean;
  /**
   * The version of the client application.
   * @type {string}
   * @memberof MobileDevice
   */
  clientApplicationVersion?: string;
  /**
   * The version of the device's native operating system
   * @type {string}
   * @memberof MobileDevice
   */
  operatingSystemVersion?: string;
}

/**
 * A response from a credentialed request for tokens.
 * @export
 * @interface OauthToken
 */
export interface OauthToken {
  /**
   * An opaque string which should be passed (along with the `token_type`) to subsequent API calls which require authentication.  Normally this is done via the the `Authorization` header of the request: from this response: <p> `Authorization:` _`token_type` `access_token`_
   * @type {string}
   * @memberof OauthToken
   */
  access_token?: string;
  /**
   * The form of token returned. This is typically the string `Bearer` and is the key which subsequent calls should use (along with the `access_token` above) in the `Authorization` header when making authenticated API requests.
   * @type {string}
   * @memberof OauthToken
   */
  token_type?: string;
  /**
   * The number of seconds until the `access_token` expires. When it expires, use the `refresh_token` to request a new access token.
   * @type {number}
   * @memberof OauthToken
   */
  expires_in?: number;
  /**
   * A token to use when the `access_token` expires. The client should retain this securely so it can obtain a new `access_token` later when the access token expires.
   * @type {string}
   * @memberof OauthToken
   */
  refresh_token?: string;
}

/**
 * Representation used to change a user password. The request must contain the `currentPassword`, the `newPassword`. The client encrypts these values using the [`secret` encryption key](#op-getEncryptionKeys) and store the corresponding encryption key aliases in the [`_encryption` metadata](https://developer.apiture.com/doc/concepts/encryption) property.
 * @export
 * @interface PasswordChange
 */
export interface PasswordChange extends AbstractResource {
  /**
   * The user's current encrypted user password. The client should prompt the user for their current password, then encrypt it with the `secret` encryption key.
   * @type {string}
   * @memberof PasswordChange
   */
  currentPassword: string;
  /**
   * The user's encrypted new password.  The client should prompt the user for their new password,  then encrypt it with the `secret` encryption key.
   * @type {string}
   * @memberof PasswordChange
   */
  newPassword: string;
  /**
   * Metadata about the encrypted `currentPassword` and `newPassword` properties.
   * @type {EncryptionMetadata}
   * @memberof PasswordChange
   */
  _encryption?: EncryptionMetadata;
}

/**
 * Password reset resource.
 * @export
 * @interface PasswordReset
 */
export interface PasswordReset {
  /**
   * Confirmation code delivery method.
   * @type {string}
   * @memberof PasswordReset
   */
  codeDeliveryMethod?: PasswordReset.CodeDeliveryMethodEnum;
  /**
   * Masked email address or phone number the confirmation code is sent to.
   * @type {string}
   * @memberof PasswordReset
   */
  codeDestination?: string;
}

/**
 * @export
 * @namespace PasswordReset
 */
export namespace PasswordReset {
  /**
   * @export
   * @enum {string}
   */
  export enum CodeDeliveryMethodEnum {
    Sms = 'sms',
    Email = 'email',
  }
}

/**
 * Create a new password reset.
 * @export
 * @interface PasswordResetRequest
 */
export interface PasswordResetRequest {
  /**
   * The user's username.
   * @type {string}
   * @memberof PasswordResetRequest
   */
  username?: string;
  /**
   * Last 4 digits of the user tax ID.
   * @type {string}
   * @memberof PasswordResetRequest
   */
  taxId?: string;
  /**
   * The user's birth date in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` date format.
   * @type {string}
   * @memberof PasswordResetRequest
   */
  birthdate?: string;
}

/**
 * A new user's requested username.
 * @export
 * @interface PreferredUsername
 */
export interface PreferredUsername extends AbstractRequest {
  /**
   * The user's requested username.
   * @type {string}
   * @memberof PreferredUsername
   */
  username: string;
}

/**
 * Response from submitting new username for a new user login account.
 * @export
 * @interface PreferredUsernameResponse
 */
export interface PreferredUsernameResponse extends AbstractResource {
  /**
   * The temporary password created by the service.
   * @type {string}
   * @memberof PreferredUsernameResponse
   */
  temporaryPassword?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Information related to the multi-factor authentication used to verify the user's log in.
 * @export
 * @interface StartSessionMfa
 */
export interface StartSessionMfa {
  /**
   * If `true`, the client participated in and completed the MFA flow. If `false`, the log in either did not require MFA, or it performed the MFA flow such that the client was unaware of it.
   * @type {boolean}
   * @memberof StartSessionMfa
   */
  performed: boolean;
  /**
   * The number of times the user tried to authenticate with MFA for this session. This value only applies if `performed` is `true`.
   * @type {number}
   * @memberof StartSessionMfa
   */
  tryCount?: number;
}

/**
 * Summary representation of a challenge, used in the challenge collection.
 * @export
 * @interface SummaryChallenge
 */
export interface SummaryChallenge extends AbstractResource, ChallengeFields {
  /**
   * The unique identifier for this challenge resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof SummaryChallenge
   */
  _id?: string;
  /**
   * How many times the challenge has been redeemed.
   * @type {number}
   * @memberof SummaryChallenge
   */
  redemptionCount?: number;
  /**
   * The state of this authenticator.
   * @type {ChallengeState}
   * @memberof SummaryChallenge
   */
  state?: ChallengeState;
  /**
   * The time stamp when challenge was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof SummaryChallenge
   */
  createdAt?: Date;
}

/**
 * User data which confirms a customer has a banking account at the financial institution. The service does not persist this data.
 * @export
 * @interface UserConfirmation
 */
export interface UserConfirmation extends AbstractRequest {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof UserConfirmation
   */
  firstName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof UserConfirmation
   */
  lastName?: string;
  /**
   * The contact's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof UserConfirmation
   */
  birthdate?: string;
  /**
   * Official government identification (tax ID) for this person.
   * @type {string}
   * @memberof UserConfirmation
   */
  taxId?: string;
}

/**
 * Response from confirming a user within the platform. If the request was well formed, the response contain a [Challenge](#schema-challenge)'s resource with one or more [`authenticators`](schema-authenticator). The client should start one of the challenge's authenticators, and after verifying the chosen authenticator, the client should pass the value of the challenge's `_id` as the `Apiture-Challenge` header on the [createUsername](#op-createUsername) operation which requires an identity challenge/verification. This response does not confirm or deny that the customer exists.  If the request was ill-formed, the `_error` describes the problem.   <h3 class='schema-links' id=\"userConfirmationResponse-links\" >Links</h3>  Response and request bodies using this <strong><code>userConfirmationResponse</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-createUsername'><strong><code>apiture:createUsername</code></strong></a></td><td>Assign a username for a new digital banking platform user</td><td><code>POST</code></td> </tr> </table>
 * @export
 * @interface UserConfirmationResponse
 */
export interface UserConfirmationResponse extends AbstractResource {
  /**
   * A Challenge resource.
   * @type {Challenge}
   * @memberof UserConfirmationResponse
   */
  challenge?: Challenge;
}

/**
 * A user session. This representation contains links to continued the user session (`POST`) or end this user session (`POST`); the request and response body for both is a `userSession' object.   <h3 class='schema-links' id=\"userSession-links\" >Links</h3>  Response and request bodies using this <strong><code>userSession</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-continueUserSession'><strong><code>apiture:continueUserSession</code></strong></a></td><td>continueUserSession</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-endUserSession'><strong><code>apiture:endUserSession</code></strong></a></td><td>endUserSession</td><td><code>POST</code></td> </tr> </table>
 * @export
 * @interface UserSession
 */
export interface UserSession extends AbstractResource {
  /**
   * The user session identifier.
   * @type {string}
   * @memberof UserSession
   */
  _id: string;
}

/**
 * Client information for starting the new user session. The request should include the `mobileDevice` object if the client is a mobile device.
 * @export
 * @interface UserSessionStart
 */
export interface UserSessionStart extends AbstractRequest {
  /**
   * Information about the mobile device, if the user session is from a native mobile application.
   * @type {MobileDevice}
   * @memberof UserSessionStart
   */
  mobileDevice?: MobileDevice;
  /**
   * Information related to the multi-factor authentication used to validate the user's login.
   * @type {StartSessionMfa}
   * @memberof UserSessionStart
   */
  mfa: StartSessionMfa;
}

/**
 * A request to send a forgotten login username to a user. The user must provide some personal data which helps locate the user.
 * @export
 * @interface UsernameRequest
 */
export interface UsernameRequest extends AbstractRequest {
  /**
   * The user's last name(case sensitive).
   * @type {string}
   * @memberof UsernameRequest
   */
  lastName?: string;
  /**
   * Last 4 digits of the user tax ID.
   * @type {string}
   * @memberof UsernameRequest
   */
  taxId?: string;
  /**
   * The user's birth date in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` date format.
   * @type {string}
   * @memberof UsernameRequest
   */
  birthdate?: string;
}

/**
 * Username request resource.
 * @export
 * @interface UsernameRequestNotification
 */
export interface UsernameRequestNotification {
  /**
   * Last name of user
   * @type {string}
   * @memberof UsernameRequestNotification
   */
  lastName?: string;
  /**
   * Last 4 digits of the user tax ID.
   * @type {string}
   * @memberof UsernameRequestNotification
   */
  taxId?: string;
  /**
   * The user's birth date in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` date format.
   * @type {string}
   * @memberof UsernameRequestNotification
   */
  birthdate?: string;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AuthenticatorApi - axios parameter creator
 * @export
 */
export const AuthenticatorApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new authenticator. This is only called during the creation of a new challenge resource, from the `createChallenge` operation. End users cannot call this operation.
     * @summary Create a new authenticator
     * @param {CreateAuthenticator} CreateAuthenticator The data necessary to create a new authenticator.
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthenticator(
      CreateAuthenticator: CreateAuthenticator,
      challengeId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'challengeId' is not null or undefined
      if (challengeId === null || challengeId === undefined) {
        throw new RequiredError(
          'challengeId',
          'Required parameter challengeId was null or undefined when calling createAuthenticator.',
        );
      }
      // verify required parameter 'CreateAuthenticator' is not null or undefined
      if (CreateAuthenticator === null || CreateAuthenticator === undefined) {
        throw new RequiredError(
          'CreateAuthenticator',
          'Required parameter CreateAuthenticator was null or undefined when calling createAuthenticator.',
        );
      }
      const localVarPath = `/challenges/{challengeId}/authenticators`.replace(
        `{${'challengeId'}}`,
        encodeURIComponent(String(challengeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateAuthenticator' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateAuthenticator || {})
        : CreateAuthenticator || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this authenticator resource and any resources that are owned by it. Authenticators are deleted automatically when the challenge is deleted.
     * @summary Delete this authenticator resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAuthenticator(
      challengeId: string,
      authenticatorId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'challengeId' is not null or undefined
      if (challengeId === null || challengeId === undefined) {
        throw new RequiredError(
          'challengeId',
          'Required parameter challengeId was null or undefined when calling deleteAuthenticator.',
        );
      }
      // verify required parameter 'authenticatorId' is not null or undefined
      if (authenticatorId === null || authenticatorId === undefined) {
        throw new RequiredError(
          'authenticatorId',
          'Required parameter authenticatorId was null or undefined when calling deleteAuthenticator.',
        );
      }
      const localVarPath = `/challenges/{challengeId}/authenticators/{authenticatorId}`
        .replace(`{${'challengeId'}}`, encodeURIComponent(String(challengeId)))
        .replace(`{${'authenticatorId'}}`, encodeURIComponent(String(authenticatorId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this authenticator resource. This `GET` operation is available via the `self` link of the authenticators inside a challenge resource.
     * @summary Fetch a representation of this authenticator
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticator(
      challengeId: string,
      authenticatorId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'challengeId' is not null or undefined
      if (challengeId === null || challengeId === undefined) {
        throw new RequiredError(
          'challengeId',
          'Required parameter challengeId was null or undefined when calling getAuthenticator.',
        );
      }
      // verify required parameter 'authenticatorId' is not null or undefined
      if (authenticatorId === null || authenticatorId === undefined) {
        throw new RequiredError(
          'authenticatorId',
          'Required parameter authenticatorId was null or undefined when calling getAuthenticator.',
        );
      }
      const localVarPath = `/challenges/{challengeId}/authenticators/{authenticatorId}`
        .replace(`{${'challengeId'}}`, encodeURIComponent(String(challengeId)))
        .replace(`{${'authenticatorId'}}`, encodeURIComponent(String(authenticatorId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the set of reserved authenticator type names. The `type` property of a authenticator must be one of these values. This set may be updated by the financial institution via the `updateAuthenticatorTypes` operation. The default list includes the following types:    * `sms`   * `email`
     * @summary Retrieve the set of authenticator types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticatorTypes(options: any = {}): RequestArgs {
      const localVarPath = `/authenticatorTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Retry or restart an authenticator, for example, if the authentication process failed or if the user never received confirmation. This changes the `state` property of the authenticator to `started`. This fails operation if the authenticator has been retried more than the allowed number of retries.  This operation is available via the `apiture:retry` link on the authenticator resource, if and only if the authenticator is eligible for the retry operation. The response is the updated representation of the authenticator.
     * @summary Retry an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    retryAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { authenticator } = query;
      const { If_Match } = headers;

      // verify required parameter 'authenticator' is not null or undefined
      if (authenticator === null || authenticator === undefined) {
        throw new RequiredError(
          'authenticator',
          'Required parameter authenticator was null or undefined when calling retryAuthenticator.',
        );
      }
      const localVarPath = `/retriedAuthenticators`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (authenticator !== undefined) {
        localVarQueryParameter['authenticator'] = authenticator;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Start a `pending` authenticator, initiating the identity verification. For example, starting a `sms` or `email` authenticator will send a unique code to the user via that channel. This changes the `state` property of the authenticator to `started` and resets the `attributes` data. A started authenticator should be verified via the `verifiedAuthenticator` operation. This operation is available via the `apiture:start` link on the authenticator resource, if and only if the authenticator is eligible for the start operation. The response is the updated representation of the authenticator.
     * @summary Start an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { authenticator } = query;
      const { If_Match } = headers;

      // verify required parameter 'authenticator' is not null or undefined
      if (authenticator === null || authenticator === undefined) {
        throw new RequiredError(
          'authenticator',
          'Required parameter authenticator was null or undefined when calling startAuthenticator.',
        );
      }
      const localVarPath = `/startedAuthenticators`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (authenticator !== undefined) {
        localVarQueryParameter['authenticator'] = authenticator;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * A financial institution can use this operation to register additional types of authenticators that they may issue to their users when a service needs to issue an identify verification challenge to the user. The `type` property of an authenticator must be one of these reserved names. This operation completely replaces the set of reserved authenticator type names, so it should include all items from the `getAuthenticatorTypes` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of authenticator types
     * @param {{ [key: string]: AuthenticatorType; }} request_body The set of authenticator types.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthenticatorTypes(
      request_body: { [key: string]: AuthenticatorType },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateAuthenticatorTypes.',
        );
      }
      const localVarPath = `/authenticatorTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: AuthenticatorType; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Complete the verification of a user's identity by `POST`ing the authenticator to this path, passing the authentication data in the authenticator's `attributes`. For example, to verify an `sms` or `email` authenticator, the client should send the code that was sent to the user via SMS or email in `attributes.code`. If the authentication data is valid, this changes the `state` property of the authenticator to `verified`. In addition, if all the challenges' authenticators have been verified successfully, the challenge is also marked as `verified`. If the `attributes` data are invalid, the authenticator is marked `failed`. Failed authenticators may be retried (restarted) via the `retryAuthenticator` operation. This operation is available via the `apiture:verify` link on the authenticator resource, if and only if the authenticator is eligible for the `apiture:verify` operation. The authenticator must have been started (see the `startAuthenticator` operation and the `apiture:start` link) before being verified. The response is the updated representation of the authenticator.
     * @summary Verify a user's identity
     * @param {Authenticator} Authenticator The body is the authenticator object, with the &#x60;attributes&#x60; set as per the authenticator type.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyAuthenticator(
      Authenticator: Authenticator,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'Authenticator' is not null or undefined
      if (Authenticator === null || Authenticator === undefined) {
        throw new RequiredError(
          'Authenticator',
          'Required parameter Authenticator was null or undefined when calling verifyAuthenticator.',
        );
      }
      const localVarPath = `/verifiedAuthenticators`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Authenticator' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Authenticator || {})
        : Authenticator || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AuthenticatorApi - functional programming interface
 * @export
 */
export const AuthenticatorApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new authenticator. This is only called during the creation of a new challenge resource, from the `createChallenge` operation. End users cannot call this operation.
     * @summary Create a new authenticator
     * @param {CreateAuthenticator} CreateAuthenticator The data necessary to create a new authenticator.
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthenticator(
      CreateAuthenticator: CreateAuthenticator,
      challengeId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Authenticator> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(
        configuration,
      ).createAuthenticator(
        CreateAuthenticator ? CreateAuthenticator : null,
        challengeId ? challengeId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this authenticator resource and any resources that are owned by it. Authenticators are deleted automatically when the challenge is deleted.
     * @summary Delete this authenticator resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAuthenticator(
      challengeId: string,
      authenticatorId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(
        configuration,
      ).deleteAuthenticator(
        challengeId ? challengeId : null,
        authenticatorId ? authenticatorId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this authenticator resource. This `GET` operation is available via the `self` link of the authenticators inside a challenge resource.
     * @summary Fetch a representation of this authenticator
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticator(
      challengeId: string,
      authenticatorId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Authenticator> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(configuration).getAuthenticator(
        challengeId ? challengeId : null,
        authenticatorId ? authenticatorId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the set of reserved authenticator type names. The `type` property of a authenticator must be one of these values. This set may be updated by the financial institution via the `updateAuthenticatorTypes` operation. The default list includes the following types:    * `sms`   * `email`
     * @summary Retrieve the set of authenticator types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticatorTypes(
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: AuthenticatorType }> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(
        configuration,
      ).getAuthenticatorTypes(options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Retry or restart an authenticator, for example, if the authentication process failed or if the user never received confirmation. This changes the `state` property of the authenticator to `started`. This fails operation if the authenticator has been retried more than the allowed number of retries.  This operation is available via the `apiture:retry` link on the authenticator resource, if and only if the authenticator is eligible for the retry operation. The response is the updated representation of the authenticator.
     * @summary Retry an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    retryAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Authenticator> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(configuration).retryAuthenticator(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Start a `pending` authenticator, initiating the identity verification. For example, starting a `sms` or `email` authenticator will send a unique code to the user via that channel. This changes the `state` property of the authenticator to `started` and resets the `attributes` data. A started authenticator should be verified via the `verifiedAuthenticator` operation. This operation is available via the `apiture:start` link on the authenticator resource, if and only if the authenticator is eligible for the start operation. The response is the updated representation of the authenticator.
     * @summary Start an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Authenticator> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(configuration).startAuthenticator(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * A financial institution can use this operation to register additional types of authenticators that they may issue to their users when a service needs to issue an identify verification challenge to the user. The `type` property of an authenticator must be one of these reserved names. This operation completely replaces the set of reserved authenticator type names, so it should include all items from the `getAuthenticatorTypes` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of authenticator types
     * @param {{ [key: string]: AuthenticatorType; }} request_body The set of authenticator types.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthenticatorTypes(
      request_body: { [key: string]: AuthenticatorType },
      headers?: { If_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: AuthenticatorType }> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(
        configuration,
      ).updateAuthenticatorTypes(
        request_body ? request_body : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Complete the verification of a user's identity by `POST`ing the authenticator to this path, passing the authentication data in the authenticator's `attributes`. For example, to verify an `sms` or `email` authenticator, the client should send the code that was sent to the user via SMS or email in `attributes.code`. If the authentication data is valid, this changes the `state` property of the authenticator to `verified`. In addition, if all the challenges' authenticators have been verified successfully, the challenge is also marked as `verified`. If the `attributes` data are invalid, the authenticator is marked `failed`. Failed authenticators may be retried (restarted) via the `retryAuthenticator` operation. This operation is available via the `apiture:verify` link on the authenticator resource, if and only if the authenticator is eligible for the `apiture:verify` operation. The authenticator must have been started (see the `startAuthenticator` operation and the `apiture:start` link) before being verified. The response is the updated representation of the authenticator.
     * @summary Verify a user's identity
     * @param {Authenticator} Authenticator The body is the authenticator object, with the &#x60;attributes&#x60; set as per the authenticator type.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyAuthenticator(
      Authenticator: Authenticator,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Authenticator> {
      const localVarAxiosArgs = AuthenticatorApiAxiosParamCreator(
        configuration,
      ).verifyAuthenticator(
        Authenticator ? Authenticator : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AuthenticatorApi - factory interface
 * @export
 */
export const AuthenticatorApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new authenticator. This is only called during the creation of a new challenge resource, from the `createChallenge` operation. End users cannot call this operation.
     * @summary Create a new authenticator
     * @param {CreateAuthenticator} CreateAuthenticator The data necessary to create a new authenticator.
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthenticator(
      CreateAuthenticator: CreateAuthenticator,
      challengeId: string,
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).createAuthenticator(
        CreateAuthenticator ? CreateAuthenticator : null,
        challengeId ? challengeId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this authenticator resource and any resources that are owned by it. Authenticators are deleted automatically when the challenge is deleted.
     * @summary Delete this authenticator resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAuthenticator(challengeId: string, authenticatorId: string, options?: any) {
      return AuthenticatorApiFp(configuration).deleteAuthenticator(
        challengeId ? challengeId : null,
        authenticatorId ? authenticatorId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this authenticator resource. This `GET` operation is available via the `self` link of the authenticators inside a challenge resource.
     * @summary Fetch a representation of this authenticator
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticator(
      challengeId: string,
      authenticatorId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).getAuthenticator(
        challengeId ? challengeId : null,
        authenticatorId ? authenticatorId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the set of reserved authenticator type names. The `type` property of a authenticator must be one of these values. This set may be updated by the financial institution via the `updateAuthenticatorTypes` operation. The default list includes the following types:    * `sms`   * `email`
     * @summary Retrieve the set of authenticator types
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthenticatorTypes(options?: any) {
      return AuthenticatorApiFp(configuration).getAuthenticatorTypes(options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Retry or restart an authenticator, for example, if the authentication process failed or if the user never received confirmation. This changes the `state` property of the authenticator to `started`. This fails operation if the authenticator has been retried more than the allowed number of retries.  This operation is available via the `apiture:retry` link on the authenticator resource, if and only if the authenticator is eligible for the retry operation. The response is the updated representation of the authenticator.
     * @summary Retry an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    retryAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).retryAuthenticator(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Start a `pending` authenticator, initiating the identity verification. For example, starting a `sms` or `email` authenticator will send a unique code to the user via that channel. This changes the `state` property of the authenticator to `started` and resets the `attributes` data. A started authenticator should be verified via the `verifiedAuthenticator` operation. This operation is available via the `apiture:start` link on the authenticator resource, if and only if the authenticator is eligible for the start operation. The response is the updated representation of the authenticator.
     * @summary Start an authenticator
     * @param {Object} [query] Query object
     * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startAuthenticator(
      query?: { authenticator?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).startAuthenticator(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * A financial institution can use this operation to register additional types of authenticators that they may issue to their users when a service needs to issue an identify verification challenge to the user. The `type` property of an authenticator must be one of these reserved names. This operation completely replaces the set of reserved authenticator type names, so it should include all items from the `getAuthenticatorTypes` that are in use. This operation is only available to financial institution administrators.
     * @summary Replace the set of authenticator types
     * @param {{ [key: string]: AuthenticatorType; }} request_body The set of authenticator types.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateAuthenticatorTypes(
      request_body: { [key: string]: AuthenticatorType },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).updateAuthenticatorTypes(
        request_body ? request_body : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Complete the verification of a user's identity by `POST`ing the authenticator to this path, passing the authentication data in the authenticator's `attributes`. For example, to verify an `sms` or `email` authenticator, the client should send the code that was sent to the user via SMS or email in `attributes.code`. If the authentication data is valid, this changes the `state` property of the authenticator to `verified`. In addition, if all the challenges' authenticators have been verified successfully, the challenge is also marked as `verified`. If the `attributes` data are invalid, the authenticator is marked `failed`. Failed authenticators may be retried (restarted) via the `retryAuthenticator` operation. This operation is available via the `apiture:verify` link on the authenticator resource, if and only if the authenticator is eligible for the `apiture:verify` operation. The authenticator must have been started (see the `startAuthenticator` operation and the `apiture:start` link) before being verified. The response is the updated representation of the authenticator.
     * @summary Verify a user's identity
     * @param {Authenticator} Authenticator The body is the authenticator object, with the &#x60;attributes&#x60; set as per the authenticator type.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    verifyAuthenticator(
      Authenticator: Authenticator,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return AuthenticatorApiFp(configuration).verifyAuthenticator(
        Authenticator ? Authenticator : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AuthenticatorApi - object-oriented interface
 * @export
 * @class AuthenticatorApi
 * @extends {BaseAPI}
 */
export class AuthenticatorApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new authenticator. This is only called during the creation of a new challenge resource, from the `createChallenge` operation. End users cannot call this operation.
   * @summary Create a new authenticator
   * @param {CreateAuthenticator} CreateAuthenticator The data necessary to create a new authenticator.
   * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Authenticator}
   * @memberof AuthenticatorApi
   */
  public createAuthenticator(
    CreateAuthenticator: CreateAuthenticator,
    challengeId: string,
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).createAuthenticator(
      CreateAuthenticator ? CreateAuthenticator : null,
      challengeId ? challengeId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this authenticator resource and any resources that are owned by it. Authenticators are deleted automatically when the challenge is deleted.
   * @summary Delete this authenticator resource
   * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
   * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AuthenticatorApi
   */
  public deleteAuthenticator(challengeId: string, authenticatorId: string, options?: any) {
    return AuthenticatorApiFp(this.configuration).deleteAuthenticator(
      challengeId ? challengeId : null,
      authenticatorId ? authenticatorId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this authenticator resource. This `GET` operation is available via the `self` link of the authenticators inside a challenge resource.
   * @summary Fetch a representation of this authenticator
   * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
   * @param {string} authenticatorId The unique identifier of this authenticator. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Authenticator}
   * @memberof AuthenticatorApi
   */
  public getAuthenticator(
    challengeId: string,
    authenticatorId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).getAuthenticator(
      challengeId ? challengeId : null,
      authenticatorId ? authenticatorId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the set of reserved authenticator type names. The `type` property of a authenticator must be one of these values. This set may be updated by the financial institution via the `updateAuthenticatorTypes` operation. The default list includes the following types:    * `sms`   * `email`
   * @summary Retrieve the set of authenticator types
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthenticatorType}
   * @memberof AuthenticatorApi
   */
  public getAuthenticatorTypes(options?: any) {
    return AuthenticatorApiFp(this.configuration).getAuthenticatorTypes(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Retry or restart an authenticator, for example, if the authentication process failed or if the user never received confirmation. This changes the `state` property of the authenticator to `started`. This fails operation if the authenticator has been retried more than the allowed number of retries.  This operation is available via the `apiture:retry` link on the authenticator resource, if and only if the authenticator is eligible for the retry operation. The response is the updated representation of the authenticator.
   * @summary Retry an authenticator
   * @param {Object} [query] Query object
   * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Authenticator}
   * @memberof AuthenticatorApi
   */
  public retryAuthenticator(
    query?: { authenticator?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).retryAuthenticator(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Start a `pending` authenticator, initiating the identity verification. For example, starting a `sms` or `email` authenticator will send a unique code to the user via that channel. This changes the `state` property of the authenticator to `started` and resets the `attributes` data. A started authenticator should be verified via the `verifiedAuthenticator` operation. This operation is available via the `apiture:start` link on the authenticator resource, if and only if the authenticator is eligible for the start operation. The response is the updated representation of the authenticator.
   * @summary Start an authenticator
   * @param {Object} [query] Query object
   * @param {string} [query.authenticator] A string which uniquely identifies an authenticator. This may be the unique &#x60;_id&#x60; of the authenticator or the URI of the authenticator.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Authenticator}
   * @memberof AuthenticatorApi
   */
  public startAuthenticator(
    query?: { authenticator?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).startAuthenticator(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * A financial institution can use this operation to register additional types of authenticators that they may issue to their users when a service needs to issue an identify verification challenge to the user. The `type` property of an authenticator must be one of these reserved names. This operation completely replaces the set of reserved authenticator type names, so it should include all items from the `getAuthenticatorTypes` that are in use. This operation is only available to financial institution administrators.
   * @summary Replace the set of authenticator types
   * @param {{ [key: string]: AuthenticatorType; }} request_body The set of authenticator types.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthenticatorType}
   * @memberof AuthenticatorApi
   */
  public updateAuthenticatorTypes(
    request_body: { [key: string]: AuthenticatorType },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).updateAuthenticatorTypes(
      request_body ? request_body : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Complete the verification of a user's identity by `POST`ing the authenticator to this path, passing the authentication data in the authenticator's `attributes`. For example, to verify an `sms` or `email` authenticator, the client should send the code that was sent to the user via SMS or email in `attributes.code`. If the authentication data is valid, this changes the `state` property of the authenticator to `verified`. In addition, if all the challenges' authenticators have been verified successfully, the challenge is also marked as `verified`. If the `attributes` data are invalid, the authenticator is marked `failed`. Failed authenticators may be retried (restarted) via the `retryAuthenticator` operation. This operation is available via the `apiture:verify` link on the authenticator resource, if and only if the authenticator is eligible for the `apiture:verify` operation. The authenticator must have been started (see the `startAuthenticator` operation and the `apiture:start` link) before being verified. The response is the updated representation of the authenticator.
   * @summary Verify a user's identity
   * @param {Authenticator} Authenticator The body is the authenticator object, with the &#x60;attributes&#x60; set as per the authenticator type.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Authenticator}
   * @memberof AuthenticatorApi
   */
  public verifyAuthenticator(
    Authenticator: Authenticator,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return AuthenticatorApiFp(this.configuration).verifyAuthenticator(
      Authenticator ? Authenticator : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ChallengeApi - axios parameter creator
 * @export
 */
export const ChallengeApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new challenge. This is called from service code when an operations requires additional user verification. By default, the resulting challenge resource will contain a list of authenticators, one for each authenticator type (see the `getAuthenticatorTypes` operation). When creating a challenge, the service can exclude authenticators with either or both `?exclude=` or specify the exact authenticator types to use with `?include=`.  When an operation fails with a 401 due to required authentication response, the services embeds the challenge as the `_error._embedded.challenge` object in the response. See also the `getAuthenticator` operation and the `challenge` and `authenticator` schemas for additional details.  A user may have only one active challenge at a time. Creating a new challenge for a user will delete any outstanding challenge resources for that user and any authenticators associated with those challenges. End users cannot call this operation.  Challenges (and their authenticators) expire automatically some time after creation. At a later time, expired, failed, and verified challenges and authenticators are automatically deleted.
     * @summary Create a new challenge
     * @param {CreateChallenge} CreateChallenge The data necessary to create a new challenge.
     * @param {Object} [query] Query object
     * @param {string} [query.include] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. This may be combined with the other filters, but excludes take precedent over &#x60;?include&#x60;. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {string} [query.exclude] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. If both &#x60;?include&#x3D;&#x60;  and &#x60;?exclude&#x3D;&#x60; are used, the exclusions take precedence inclusions. That is, for &#x60;?include&#x3D;sms&amp;exclude&#x3D;sms&#x60;, the &#x60;sms&#x60; authenticator will not be used. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createChallenge(
      CreateChallenge: CreateChallenge,
      query?: { include?: string; exclude?: string },
      options: any = {},
    ): RequestArgs {
      const { include, exclude } = query;

      // verify required parameter 'CreateChallenge' is not null or undefined
      if (CreateChallenge === null || CreateChallenge === undefined) {
        throw new RequiredError(
          'CreateChallenge',
          'Required parameter CreateChallenge was null or undefined when calling createChallenge.',
        );
      }
      const localVarPath = `/challenges`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (include !== undefined) {
        localVarQueryParameter['include'] = include;
      }

      if (exclude !== undefined) {
        localVarQueryParameter['exclude'] = exclude;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateChallenge' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateChallenge || {})
        : CreateChallenge || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this challenge resource and any authenticators that are owned by it. Challenges are also deleted at some interval after they have expired or at an interval after they have been redeemed.
     * @summary Delete this challenge resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteChallenge(challengeId: string, options: any = {}): RequestArgs {
      // verify required parameter 'challengeId' is not null or undefined
      if (challengeId === null || challengeId === undefined) {
        throw new RequiredError(
          'challengeId',
          'Required parameter challengeId was null or undefined when calling deleteChallenge.',
        );
      }
      const localVarPath = `/challenges/{challengeId}`.replace(
        `{${'challengeId'}}`,
        encodeURIComponent(String(challengeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this challenge resource.
     * @summary Fetch a representation of this challenge
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenge(
      challengeId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'challengeId' is not null or undefined
      if (challengeId === null || challengeId === undefined) {
        throw new RequiredError(
          'challengeId',
          'Required parameter challengeId was null or undefined when calling getChallenge.',
        );
      }
      const localVarPath = `/challenges/{challengeId}`.replace(
        `{${'challengeId'}}`,
        encodeURIComponent(String(challengeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of challenges. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of challenges
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first challenge item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of challenge representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.userId] Subset to challenges for the specified user. The value should be the unique &#x60;{userId}&#x60; (the &#x60;_id&#x60; of a User resource).
     * @param {'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired'} [query.state] Subset the challenges to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;started&#x60; matches only items whose &#x60;state&#x60; is &#x60;started&#x60;; &#x60;?state&#x3D;verified|failed&#x60; matches items whose &#x60;state&#x60; is &#x60;verified&#x60; or &#x60;failed&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenges(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        userId?: string;
        state?: 'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired';
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, userId, state } = query;

      const localVarPath = `/challenges`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (userId !== undefined) {
        localVarQueryParameter['userId'] = userId;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * When an operation that requires an identity challenge (passed via the `Apiture-Challenge` request header), it _redeems_ the challenge to mark it as used. Challenges have a maximum number of times that they may be redeemed. This changes the `state` property of the authenticator to `redeemed`. This operation is available via the `apiture:redeem` link on the challenge resource, if and only if the challenge is eligible for the redeem operation. The response is the updated representation of the challenge.
     * @summary Redeem or use a challenge
     * @param {Object} [query] Query object
     * @param {string} [query.challenge] A string which uniquely identifies an challenge. This may be the unique &#x60;_id&#x60; of the challenge resource or the URI of the challenge.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    redeemChallenge(
      query?: { challenge?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { challenge } = query;
      const { If_Match } = headers;

      // verify required parameter 'challenge' is not null or undefined
      if (challenge === null || challenge === undefined) {
        throw new RequiredError(
          'challenge',
          'Required parameter challenge was null or undefined when calling redeemChallenge.',
        );
      }
      const localVarPath = `/redeemedChallenges`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (challenge !== undefined) {
        localVarQueryParameter['challenge'] = challenge;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ChallengeApi - functional programming interface
 * @export
 */
export const ChallengeApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new challenge. This is called from service code when an operations requires additional user verification. By default, the resulting challenge resource will contain a list of authenticators, one for each authenticator type (see the `getAuthenticatorTypes` operation). When creating a challenge, the service can exclude authenticators with either or both `?exclude=` or specify the exact authenticator types to use with `?include=`.  When an operation fails with a 401 due to required authentication response, the services embeds the challenge as the `_error._embedded.challenge` object in the response. See also the `getAuthenticator` operation and the `challenge` and `authenticator` schemas for additional details.  A user may have only one active challenge at a time. Creating a new challenge for a user will delete any outstanding challenge resources for that user and any authenticators associated with those challenges. End users cannot call this operation.  Challenges (and their authenticators) expire automatically some time after creation. At a later time, expired, failed, and verified challenges and authenticators are automatically deleted.
     * @summary Create a new challenge
     * @param {CreateChallenge} CreateChallenge The data necessary to create a new challenge.
     * @param {Object} [query] Query object
     * @param {string} [query.include] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. This may be combined with the other filters, but excludes take precedent over &#x60;?include&#x60;. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {string} [query.exclude] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. If both &#x60;?include&#x3D;&#x60;  and &#x60;?exclude&#x3D;&#x60; are used, the exclusions take precedence inclusions. That is, for &#x60;?include&#x3D;sms&amp;exclude&#x3D;sms&#x60;, the &#x60;sms&#x60; authenticator will not be used. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createChallenge(
      CreateChallenge: CreateChallenge,
      query?: { include?: string; exclude?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Challenge> {
      const localVarAxiosArgs = ChallengeApiAxiosParamCreator(configuration).createChallenge(
        CreateChallenge ? CreateChallenge : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this challenge resource and any authenticators that are owned by it. Challenges are also deleted at some interval after they have expired or at an interval after they have been redeemed.
     * @summary Delete this challenge resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteChallenge(
      challengeId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ChallengeApiAxiosParamCreator(configuration).deleteChallenge(
        challengeId ? challengeId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this challenge resource.
     * @summary Fetch a representation of this challenge
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenge(
      challengeId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Challenge> {
      const localVarAxiosArgs = ChallengeApiAxiosParamCreator(configuration).getChallenge(
        challengeId ? challengeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of challenges. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of challenges
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first challenge item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of challenge representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.userId] Subset to challenges for the specified user. The value should be the unique &#x60;{userId}&#x60; (the &#x60;_id&#x60; of a User resource).
     * @param {'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired'} [query.state] Subset the challenges to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;started&#x60; matches only items whose &#x60;state&#x60; is &#x60;started&#x60;; &#x60;?state&#x3D;verified|failed&#x60; matches items whose &#x60;state&#x60; is &#x60;verified&#x60; or &#x60;failed&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenges(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        userId?: string;
        state?: 'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired';
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Challenges> {
      const localVarAxiosArgs = ChallengeApiAxiosParamCreator(configuration).getChallenges(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * When an operation that requires an identity challenge (passed via the `Apiture-Challenge` request header), it _redeems_ the challenge to mark it as used. Challenges have a maximum number of times that they may be redeemed. This changes the `state` property of the authenticator to `redeemed`. This operation is available via the `apiture:redeem` link on the challenge resource, if and only if the challenge is eligible for the redeem operation. The response is the updated representation of the challenge.
     * @summary Redeem or use a challenge
     * @param {Object} [query] Query object
     * @param {string} [query.challenge] A string which uniquely identifies an challenge. This may be the unique &#x60;_id&#x60; of the challenge resource or the URI of the challenge.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    redeemChallenge(
      query?: { challenge?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Challenge> {
      const localVarAxiosArgs = ChallengeApiAxiosParamCreator(configuration).redeemChallenge(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ChallengeApi - factory interface
 * @export
 */
export const ChallengeApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new challenge. This is called from service code when an operations requires additional user verification. By default, the resulting challenge resource will contain a list of authenticators, one for each authenticator type (see the `getAuthenticatorTypes` operation). When creating a challenge, the service can exclude authenticators with either or both `?exclude=` or specify the exact authenticator types to use with `?include=`.  When an operation fails with a 401 due to required authentication response, the services embeds the challenge as the `_error._embedded.challenge` object in the response. See also the `getAuthenticator` operation and the `challenge` and `authenticator` schemas for additional details.  A user may have only one active challenge at a time. Creating a new challenge for a user will delete any outstanding challenge resources for that user and any authenticators associated with those challenges. End users cannot call this operation.  Challenges (and their authenticators) expire automatically some time after creation. At a later time, expired, failed, and verified challenges and authenticators are automatically deleted.
     * @summary Create a new challenge
     * @param {CreateChallenge} CreateChallenge The data necessary to create a new challenge.
     * @param {Object} [query] Query object
     * @param {string} [query.include] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. This may be combined with the other filters, but excludes take precedent over &#x60;?include&#x60;. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {string} [query.exclude] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. If both &#x60;?include&#x3D;&#x60;  and &#x60;?exclude&#x3D;&#x60; are used, the exclusions take precedence inclusions. That is, for &#x60;?include&#x3D;sms&amp;exclude&#x3D;sms&#x60;, the &#x60;sms&#x60; authenticator will not be used. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createChallenge(
      CreateChallenge: CreateChallenge,
      query?: { include?: string; exclude?: string },
      options?: any,
    ) {
      return ChallengeApiFp(configuration).createChallenge(
        CreateChallenge ? CreateChallenge : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this challenge resource and any authenticators that are owned by it. Challenges are also deleted at some interval after they have expired or at an interval after they have been redeemed.
     * @summary Delete this challenge resource
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteChallenge(challengeId: string, options?: any) {
      return ChallengeApiFp(configuration).deleteChallenge(
        challengeId ? challengeId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this challenge resource.
     * @summary Fetch a representation of this challenge
     * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenge(challengeId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ChallengeApiFp(configuration).getChallenge(
        challengeId ? challengeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of challenges. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of challenges
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first challenge item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of challenge representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.userId] Subset to challenges for the specified user. The value should be the unique &#x60;{userId}&#x60; (the &#x60;_id&#x60; of a User resource).
     * @param {'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired'} [query.state] Subset the challenges to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;started&#x60; matches only items whose &#x60;state&#x60; is &#x60;started&#x60;; &#x60;?state&#x3D;verified|failed&#x60; matches items whose &#x60;state&#x60; is &#x60;verified&#x60; or &#x60;failed&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getChallenges(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        userId?: string;
        state?: 'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired';
      },
      options?: any,
    ) {
      return ChallengeApiFp(configuration).getChallenges(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * When an operation that requires an identity challenge (passed via the `Apiture-Challenge` request header), it _redeems_ the challenge to mark it as used. Challenges have a maximum number of times that they may be redeemed. This changes the `state` property of the authenticator to `redeemed`. This operation is available via the `apiture:redeem` link on the challenge resource, if and only if the challenge is eligible for the redeem operation. The response is the updated representation of the challenge.
     * @summary Redeem or use a challenge
     * @param {Object} [query] Query object
     * @param {string} [query.challenge] A string which uniquely identifies an challenge. This may be the unique &#x60;_id&#x60; of the challenge resource or the URI of the challenge.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    redeemChallenge(
      query?: { challenge?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ChallengeApiFp(configuration).redeemChallenge(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ChallengeApi - object-oriented interface
 * @export
 * @class ChallengeApi
 * @extends {BaseAPI}
 */
export class ChallengeApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new challenge. This is called from service code when an operations requires additional user verification. By default, the resulting challenge resource will contain a list of authenticators, one for each authenticator type (see the `getAuthenticatorTypes` operation). When creating a challenge, the service can exclude authenticators with either or both `?exclude=` or specify the exact authenticator types to use with `?include=`.  When an operation fails with a 401 due to required authentication response, the services embeds the challenge as the `_error._embedded.challenge` object in the response. See also the `getAuthenticator` operation and the `challenge` and `authenticator` schemas for additional details.  A user may have only one active challenge at a time. Creating a new challenge for a user will delete any outstanding challenge resources for that user and any authenticators associated with those challenges. End users cannot call this operation.  Challenges (and their authenticators) expire automatically some time after creation. At a later time, expired, failed, and verified challenges and authenticators are automatically deleted.
   * @summary Create a new challenge
   * @param {CreateChallenge} CreateChallenge The data necessary to create a new challenge.
   * @param {Object} [query] Query object
   * @param {string} [query.include] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. This may be combined with the other filters, but excludes take precedent over &#x60;?include&#x60;. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
   * @param {string} [query.exclude] One or more authenticator _types_ or _categories_ which the challenge should exclude from its authenticators. Type names are from the &#x60;name&#x60; or &#x60;category&#x60; property of the authenticator types resource, such as &#x60;?exclude&#x3D;sms&#x60;. Multiple types may be specified, separated by commas: &#x60;?exclude&#x3D;sms,biometric&#x60;. If both &#x60;?include&#x3D;&#x60;  and &#x60;?exclude&#x3D;&#x60; are used, the exclusions take precedence inclusions. That is, for &#x60;?include&#x3D;sms&amp;exclude&#x3D;sms&#x60;, the &#x60;sms&#x60; authenticator will not be used. (This notation may be extended in the future to allow additional filter constraints based on authenticator type properties.)
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Challenge}
   * @memberof ChallengeApi
   */
  public createChallenge(
    CreateChallenge: CreateChallenge,
    query?: { include?: string; exclude?: string },
    options?: any,
  ) {
    return ChallengeApiFp(this.configuration).createChallenge(
      CreateChallenge ? CreateChallenge : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this challenge resource and any authenticators that are owned by it. Challenges are also deleted at some interval after they have expired or at an interval after they have been redeemed.
   * @summary Delete this challenge resource
   * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ChallengeApi
   */
  public deleteChallenge(challengeId: string, options?: any) {
    return ChallengeApiFp(this.configuration).deleteChallenge(
      challengeId ? challengeId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this challenge resource.
   * @summary Fetch a representation of this challenge
   * @param {string} challengeId The unique identifier of this challenge. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Challenge}
   * @memberof ChallengeApi
   */
  public getChallenge(challengeId: string, headers?: { If_None_Match?: string }, options?: any) {
    return ChallengeApiFp(this.configuration).getChallenge(
      challengeId ? challengeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](http://developer.apiture.com/docs/concepts/pagination) [sortable](http://developer.apiture.com/docs/concepts/sorting) [filterable](http://developer.apiture.com/docs/concepts/filtering) [searchable](http://developer.apiture.com/docs/concepts/searching) collection of challenges. The [links](http://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of challenges
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first challenge item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of challenge representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](http://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](http://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](http://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.userId] Subset to challenges for the specified user. The value should be the unique &#x60;{userId}&#x60; (the &#x60;_id&#x60; of a User resource).
   * @param {'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired'} [query.state] Subset the challenges to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;started&#x60; matches only items whose &#x60;state&#x60; is &#x60;started&#x60;; &#x60;?state&#x3D;verified|failed&#x60; matches items whose &#x60;state&#x60; is &#x60;verified&#x60; or &#x60;failed&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Challenges}
   * @memberof ChallengeApi
   */
  public getChallenges(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      userId?: string;
      state?: 'pending' | 'started' | 'verified' | 'failed' | 'redeemed' | 'expired';
    },
    options?: any,
  ) {
    return ChallengeApiFp(this.configuration).getChallenges(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * When an operation that requires an identity challenge (passed via the `Apiture-Challenge` request header), it _redeems_ the challenge to mark it as used. Challenges have a maximum number of times that they may be redeemed. This changes the `state` property of the authenticator to `redeemed`. This operation is available via the `apiture:redeem` link on the challenge resource, if and only if the challenge is eligible for the redeem operation. The response is the updated representation of the challenge.
   * @summary Redeem or use a challenge
   * @param {Object} [query] Query object
   * @param {string} [query.challenge] A string which uniquely identifies an challenge. This may be the unique &#x60;_id&#x60; of the challenge resource or the URI of the challenge.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. The &#x60;If-Match&#x60; header is optional, but if passed, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Challenge}
   * @memberof ChallengeApi
   */
  public redeemChallenge(
    query?: { challenge?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ChallengeApiFp(this.configuration).redeemChallenge(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * DevicesApi - axios parameter creator
 * @export
 */
export const DevicesApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete a specific device registration which tracks the use of a device for a user. Once deleted, the user will have to use another secondary authentication method, such as entering a code sent by SMS, when signing in.
     * @summary Delete a device registration
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteDevice(userId: string, deviceId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling deleteDevice.',
        );
      }
      // verify required parameter 'deviceId' is not null or undefined
      if (deviceId === null || deviceId === undefined) {
        throw new RequiredError(
          'deviceId',
          'Required parameter deviceId was null or undefined when calling deleteDevice.',
        );
      }
      const localVarPath = `/users/{userId}/devices/{deviceId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'deviceId'}}`, encodeURIComponent(String(deviceId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a specific device for a user. The `deviceId` is the unique identifier of a device resource. This operation is typically called via the `self` link for an item in the `getDevices` collection response.
     * @summary Return a device for the user
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevice(userId: string, deviceId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getDevice.',
        );
      }
      // verify required parameter 'deviceId' is not null or undefined
      if (deviceId === null || deviceId === undefined) {
        throw new RequiredError(
          'deviceId',
          'Required parameter deviceId was null or undefined when calling getDevice.',
        );
      }
      const localVarPath = `/users/{userId}/devices/{deviceId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'deviceId'}}`, encodeURIComponent(String(deviceId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a collection of devices that the user has used to sign in. This collection is small, so this operation does not support filtering, pagination, sorting, or searching. The Authentication API's `getRoot` operation (`GET /auth/`) will include a link `apiture:getDevices`. This link's `href` will resolve the `{userId}` for the currently authenticated user.
     * @summary Return a collection of devices
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevices(userId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getDevices.',
        );
      }
      const localVarPath = `/users/{userId}/devices`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * DevicesApi - functional programming interface
 * @export
 */
export const DevicesApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Delete a specific device registration which tracks the use of a device for a user. Once deleted, the user will have to use another secondary authentication method, such as entering a code sent by SMS, when signing in.
     * @summary Delete a device registration
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteDevice(
      userId: string,
      deviceId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = DevicesApiAxiosParamCreator(configuration).deleteDevice(
        userId ? userId : null,
        deviceId ? deviceId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a specific device for a user. The `deviceId` is the unique identifier of a device resource. This operation is typically called via the `self` link for an item in the `getDevices` collection response.
     * @summary Return a device for the user
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevice(
      userId: string,
      deviceId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse2001> {
      const localVarAxiosArgs = DevicesApiAxiosParamCreator(configuration).getDevice(
        userId ? userId : null,
        deviceId ? deviceId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a collection of devices that the user has used to sign in. This collection is small, so this operation does not support filtering, pagination, sorting, or searching. The Authentication API's `getRoot` operation (`GET /auth/`) will include a link `apiture:getDevices`. This link's `href` will resolve the `{userId}` for the currently authenticated user.
     * @summary Return a collection of devices
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevices(
      userId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = DevicesApiAxiosParamCreator(configuration).getDevices(
        userId ? userId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * DevicesApi - factory interface
 * @export
 */
export const DevicesApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Delete a specific device registration which tracks the use of a device for a user. Once deleted, the user will have to use another secondary authentication method, such as entering a code sent by SMS, when signing in.
     * @summary Delete a device registration
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteDevice(userId: string, deviceId: string, options?: any) {
      return DevicesApiFp(configuration).deleteDevice(
        userId ? userId : null,
        deviceId ? deviceId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a specific device for a user. The `deviceId` is the unique identifier of a device resource. This operation is typically called via the `self` link for an item in the `getDevices` collection response.
     * @summary Return a device for the user
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {string} deviceId The unique identifier of the device.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevice(userId: string, deviceId: string, options?: any) {
      return DevicesApiFp(configuration).getDevice(
        userId ? userId : null,
        deviceId ? deviceId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a collection of devices that the user has used to sign in. This collection is small, so this operation does not support filtering, pagination, sorting, or searching. The Authentication API's `getRoot` operation (`GET /auth/`) will include a link `apiture:getDevices`. This link's `href` will resolve the `{userId}` for the currently authenticated user.
     * @summary Return a collection of devices
     * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getDevices(userId: string, options?: any) {
      return DevicesApiFp(configuration).getDevices(
        userId ? userId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * DevicesApi - object-oriented interface
 * @export
 * @class DevicesApi
 * @extends {BaseAPI}
 */
export class DevicesApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Delete a specific device registration which tracks the use of a device for a user. Once deleted, the user will have to use another secondary authentication method, such as entering a code sent by SMS, when signing in.
   * @summary Delete a device registration
   * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
   * @param {string} deviceId The unique identifier of the device.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof DevicesApi
   */
  public deleteDevice(userId: string, deviceId: string, options?: any) {
    return DevicesApiFp(this.configuration).deleteDevice(
      userId ? userId : null,
      deviceId ? deviceId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a specific device for a user. The `deviceId` is the unique identifier of a device resource. This operation is typically called via the `self` link for an item in the `getDevices` collection response.
   * @summary Return a device for the user
   * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
   * @param {string} deviceId The unique identifier of the device.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse2001}
   * @memberof DevicesApi
   */
  public getDevice(userId: string, deviceId: string, options?: any) {
    return DevicesApiFp(this.configuration).getDevice(
      userId ? userId : null,
      deviceId ? deviceId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a collection of devices that the user has used to sign in. This collection is small, so this operation does not support filtering, pagination, sorting, or searching. The Authentication API's `getRoot` operation (`GET /auth/`) will include a link `apiture:getDevices`. This link's `href` will resolve the `{userId}` for the currently authenticated user.
   * @summary Return a collection of devices
   * @param {string} userId The user ID of a user. An authenticated user can only view their own devices.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof DevicesApi
   */
  public getDevices(userId: string, options?: any) {
    return DevicesApiFp(this.configuration).getDevices(
      userId ? userId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EncryptionApi - axios parameter creator
 * @export
 */
export const EncryptionApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Get encryption keys that the client should use to encrypt sensitive data such as personally identifiable information (PII) and passwords. This adds security on top of transport layer security (TLS/HTTPS) so that sensitive data is not represented as plain text in request bodies. Clients should [encrypt properties](https://developer.apiture.com/doc/concepts/encryption) that have a <code>x-apiture-encrypt: {<em>keyName</em>}</code> annotation in the schema. The client adds metadata in an `_encryption` object next to the encrypted properties in the request body.
     * @summary Get client-side encryption keys
     * @param {Object} [query] Query object
     * @param {Array<string>} [query.keys] A list of encryption key names necessary to encrypt one or more properties in a request body. For example, if the request body schema contains two fields that are tagged &#x60;x-apiture-encrypt: secret&#x60;, use &#x60;?keys&#x3D;secret&#x60;. If the schema contain two fields, one encrypted with &#x60;password&#x60; and one with the key named &#x60;pii&#x60;, use &#x60;?keys&#x3D;secret,pii&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEncryptionKeys(query?: { keys?: Array<string> }, options: any = {}): RequestArgs {
      const { keys } = query;

      // verify required parameter 'keys' is not null or undefined
      if (keys === null || keys === undefined) {
        throw new RequiredError(
          'keys',
          'Required parameter keys was null or undefined when calling getEncryptionKeys.',
        );
      }
      const localVarPath = `/encryptionKeys`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (keys) {
        localVarQueryParameter['keys'] = keys.join(COLLECTION_FORMATS['csv']);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EncryptionApi - functional programming interface
 * @export
 */
export const EncryptionApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Get encryption keys that the client should use to encrypt sensitive data such as personally identifiable information (PII) and passwords. This adds security on top of transport layer security (TLS/HTTPS) so that sensitive data is not represented as plain text in request bodies. Clients should [encrypt properties](https://developer.apiture.com/doc/concepts/encryption) that have a <code>x-apiture-encrypt: {<em>keyName</em>}</code> annotation in the schema. The client adds metadata in an `_encryption` object next to the encrypted properties in the request body.
     * @summary Get client-side encryption keys
     * @param {Object} [query] Query object
     * @param {Array<string>} [query.keys] A list of encryption key names necessary to encrypt one or more properties in a request body. For example, if the request body schema contains two fields that are tagged &#x60;x-apiture-encrypt: secret&#x60;, use &#x60;?keys&#x3D;secret&#x60;. If the schema contain two fields, one encrypted with &#x60;password&#x60; and one with the key named &#x60;pii&#x60;, use &#x60;?keys&#x3D;secret,pii&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEncryptionKeys(
      query?: { keys?: Array<string> },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<EncryptionKeys> {
      const localVarAxiosArgs = EncryptionApiAxiosParamCreator(configuration).getEncryptionKeys(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EncryptionApi - factory interface
 * @export
 */
export const EncryptionApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Get encryption keys that the client should use to encrypt sensitive data such as personally identifiable information (PII) and passwords. This adds security on top of transport layer security (TLS/HTTPS) so that sensitive data is not represented as plain text in request bodies. Clients should [encrypt properties](https://developer.apiture.com/doc/concepts/encryption) that have a <code>x-apiture-encrypt: {<em>keyName</em>}</code> annotation in the schema. The client adds metadata in an `_encryption` object next to the encrypted properties in the request body.
     * @summary Get client-side encryption keys
     * @param {Object} [query] Query object
     * @param {Array<string>} [query.keys] A list of encryption key names necessary to encrypt one or more properties in a request body. For example, if the request body schema contains two fields that are tagged &#x60;x-apiture-encrypt: secret&#x60;, use &#x60;?keys&#x3D;secret&#x60;. If the schema contain two fields, one encrypted with &#x60;password&#x60; and one with the key named &#x60;pii&#x60;, use &#x60;?keys&#x3D;secret,pii&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEncryptionKeys(query?: { keys?: Array<string> }, options?: any) {
      return EncryptionApiFp(configuration).getEncryptionKeys(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EncryptionApi - object-oriented interface
 * @export
 * @class EncryptionApi
 * @extends {BaseAPI}
 */
export class EncryptionApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Get encryption keys that the client should use to encrypt sensitive data such as personally identifiable information (PII) and passwords. This adds security on top of transport layer security (TLS/HTTPS) so that sensitive data is not represented as plain text in request bodies. Clients should [encrypt properties](https://developer.apiture.com/doc/concepts/encryption) that have a <code>x-apiture-encrypt: {<em>keyName</em>}</code> annotation in the schema. The client adds metadata in an `_encryption` object next to the encrypted properties in the request body.
   * @summary Get client-side encryption keys
   * @param {Object} [query] Query object
   * @param {Array<string>} [query.keys] A list of encryption key names necessary to encrypt one or more properties in a request body. For example, if the request body schema contains two fields that are tagged &#x60;x-apiture-encrypt: secret&#x60;, use &#x60;?keys&#x3D;secret&#x60;. If the schema contain two fields, one encrypted with &#x60;password&#x60; and one with the key named &#x60;pii&#x60;, use &#x60;?keys&#x3D;secret,pii&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {EncryptionKeys}
   * @memberof EncryptionApi
   */
  public getEncryptionKeys(query?: { keys?: Array<string> }, options?: any) {
    return EncryptionApiFp(this.configuration).getEncryptionKeys(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * OpenIDConnectApi - axios parameter creator
 * @export
 */
export const OpenIDConnectApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Start OpenID Connect Authorization Code Flow by requesting client application authorization and user authentication. This request redirects the user to the identity provider login page to authenticate by securely entering their credentials. Upon a successful 302 response, the client should validate the `Location` URI then redirect to that URI.
     * @summary Redirect to the authorization server for secure user login
     * @param {Object} [query] Query object
     * @param {'code' | 'client_credentials'} [query.response_type] Indicates the authentication flow to be used. Use &#x60;code&#x60; to specify the usage of the OAuth 2.0 Authorization code flow and &#x60;client_credentials&#x60; for the OAuth 2.0 Client Credentials flow.
     * @param {string} [query.scope] This must be set to &#x60;openid&#x60; to indicate a request for OpenID authentication and ID token.
     * @param {string} [query.client_id] This must be set to the client ID value obtained from the client application registration process in the developer portal.
     * @param {string} [query.state] An arbitrary value set by the client to maintain state between the authorization request and the callback.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process.  The callback url will be called with the authorization code provided as a parameter. Required if using the authorization_code flow.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    authorize(
      query?: {
        response_type?: 'code' | 'client_credentials';
        scope?: string;
        client_id?: string;
        state?: string;
        redirect_uri?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { response_type, scope, client_id, state, redirect_uri } = query;

      // verify required parameter 'client_id' is not null or undefined
      if (client_id === null || client_id === undefined) {
        throw new RequiredError(
          'client_id',
          'Required parameter client_id was null or undefined when calling authorize.',
        );
      }
      // verify required parameter 'redirect_uri' is not null or undefined
      if (redirect_uri === null || redirect_uri === undefined) {
        throw new RequiredError(
          'redirect_uri',
          'Required parameter redirect_uri was null or undefined when calling authorize.',
        );
      }
      const localVarPath = `/oauth2/authorize`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (response_type !== undefined) {
        localVarQueryParameter['response_type'] = response_type;
      }

      if (scope !== undefined) {
        localVarQueryParameter['scope'] = scope;
      }

      if (client_id !== undefined) {
        localVarQueryParameter['client_id'] = client_id;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (redirect_uri !== undefined) {
        localVarQueryParameter['redirect_uri'] = redirect_uri;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This request returns a JSON structure containing scopes.
     * @summary Returns OpenID Connect Discovery metadata.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMetadata(options: any = {}): RequestArgs {
      const localVarPath = `/openid/metadata`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create or refresh an access token for client use. Depending on the value of the `grant_type` query parameter, this operation issues a new access token and a refresh token at the end of the initial authentication flow, or it can refresh an expired or expiring access token.   * To issue the initial token for interactive clients, use `?grant_type=authorization_code`, passing the `code` obtained from the [`authorize`](#op-authorize) operation and the `redirect_uri` query parameters. (Both the `code` and `redirect_uri` query parameters are required for this grant type.) Clients should save the `refresh_token` from the response. * For trusted (non-web, non-mobile) clients, use `?grant_type=client_credentials` and the `authorization` header. * To refresh an expiring/expired access token, use `?grant_type=refresh_token&refresh_token={refresh_token}`, using the required `{refresh_token}` that was returned in the _original_ [`oauthToken`](#schema-oauthToken) response from the earlier call to this operation.  All calls require the `Authorization` header.
     * @summary Obtain a secure access token.
     * @param {Object} [query] Query object
     * @param {'authorization_code' | 'client_credentials' | 'refresh_token'} [query.grant_type] This must be set to one of the following:&lt;br&gt; &amp;bullet; &#x60;authorization_code&#x60; if using the OAuth 2.0 Authorization code flow&lt;br&gt; &amp;bullet; &#x60;client_credentials&#x60; when using client-supplied credentials (key and secret)&lt;br&gt; &amp;bullet; &#x60;refresh_token&#x60; when refreshing an expired or expiring access token.
     * @param {string} [query.code] This must be set to the authorization code returned via a callback redirect after calling the [&#x60;authorize&#x60;](#op-authorize) operation whenusing the OAuth 2.0 Authorization code flow. This is required if &#x60;grant_type&#x60; is &#x60;authorization_code&#x60;.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process and the value passed to [&#x60;authorize&#x60;](#op-authorize). Required if using the &#x60;authorization_code&#x60; flow.
     * @param {string} [query.refresh_token] The value of the &#x60;refresh_token&#x60; obtained with the original or expiring/expired access token. Required if &#x60;?grant_type&#x3D;refresh_token&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Authorization] Authorization credentials in the form &lt;br&gt; &#x60;Basic {encoded-credentials}&#x60;&lt;br&gt; where &#x60;{encoded-credentials}&#x60; is a Base 64 encoding of the text _&#x60;client-id:client-secret&#x60;_ for the registered client. If these client credentials are supplied when using the &#x60;client_credentials&#x60; grant, the OpenID Connect handshake is shortened and no interactive redirect is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getToken(
      query?: {
        grant_type?: 'authorization_code' | 'client_credentials' | 'refresh_token';
        code?: string;
        redirect_uri?: string;
        refresh_token?: string;
      },
      headers?: { Authorization?: string },
      options: any = {},
    ): RequestArgs {
      const { grant_type, code, redirect_uri, refresh_token } = query;
      const { Authorization } = headers;

      // verify required parameter 'grant_type' is not null or undefined
      if (grant_type === null || grant_type === undefined) {
        throw new RequiredError(
          'grant_type',
          'Required parameter grant_type was null or undefined when calling getToken.',
        );
      }
      // verify required parameter 'Authorization' is not null or undefined
      if (Authorization === null || Authorization === undefined) {
        throw new RequiredError(
          'Authorization',
          'Required parameter Authorization was null or undefined when calling getToken.',
        );
      }
      const localVarPath = `/oauth2/token`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (grant_type !== undefined) {
        localVarQueryParameter['grant_type'] = grant_type;
      }

      if (code !== undefined) {
        localVarQueryParameter['code'] = code;
      }

      if (redirect_uri !== undefined) {
        localVarQueryParameter['redirect_uri'] = redirect_uri;
      }

      if (refresh_token !== undefined) {
        localVarQueryParameter['refresh_token'] = refresh_token;
      }

      if (Authorization !== undefined && Authorization !== null) {
        localVarHeaderParameter['Authorization'] = String(Authorization);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * OpenIDConnectApi - functional programming interface
 * @export
 */
export const OpenIDConnectApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Start OpenID Connect Authorization Code Flow by requesting client application authorization and user authentication. This request redirects the user to the identity provider login page to authenticate by securely entering their credentials. Upon a successful 302 response, the client should validate the `Location` URI then redirect to that URI.
     * @summary Redirect to the authorization server for secure user login
     * @param {Object} [query] Query object
     * @param {'code' | 'client_credentials'} [query.response_type] Indicates the authentication flow to be used. Use &#x60;code&#x60; to specify the usage of the OAuth 2.0 Authorization code flow and &#x60;client_credentials&#x60; for the OAuth 2.0 Client Credentials flow.
     * @param {string} [query.scope] This must be set to &#x60;openid&#x60; to indicate a request for OpenID authentication and ID token.
     * @param {string} [query.client_id] This must be set to the client ID value obtained from the client application registration process in the developer portal.
     * @param {string} [query.state] An arbitrary value set by the client to maintain state between the authorization request and the callback.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process.  The callback url will be called with the authorization code provided as a parameter. Required if using the authorization_code flow.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    authorize(
      query?: {
        response_type?: 'code' | 'client_credentials';
        scope?: string;
        client_id?: string;
        state?: string;
        redirect_uri?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = OpenIDConnectApiAxiosParamCreator(configuration).authorize(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This request returns a JSON structure containing scopes.
     * @summary Returns OpenID Connect Discovery metadata.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMetadata(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<AuthMetadata> {
      const localVarAxiosArgs = OpenIDConnectApiAxiosParamCreator(configuration).getMetadata(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create or refresh an access token for client use. Depending on the value of the `grant_type` query parameter, this operation issues a new access token and a refresh token at the end of the initial authentication flow, or it can refresh an expired or expiring access token.   * To issue the initial token for interactive clients, use `?grant_type=authorization_code`, passing the `code` obtained from the [`authorize`](#op-authorize) operation and the `redirect_uri` query parameters. (Both the `code` and `redirect_uri` query parameters are required for this grant type.) Clients should save the `refresh_token` from the response. * For trusted (non-web, non-mobile) clients, use `?grant_type=client_credentials` and the `authorization` header. * To refresh an expiring/expired access token, use `?grant_type=refresh_token&refresh_token={refresh_token}`, using the required `{refresh_token}` that was returned in the _original_ [`oauthToken`](#schema-oauthToken) response from the earlier call to this operation.  All calls require the `Authorization` header.
     * @summary Obtain a secure access token.
     * @param {Object} [query] Query object
     * @param {'authorization_code' | 'client_credentials' | 'refresh_token'} [query.grant_type] This must be set to one of the following:&lt;br&gt; &amp;bullet; &#x60;authorization_code&#x60; if using the OAuth 2.0 Authorization code flow&lt;br&gt; &amp;bullet; &#x60;client_credentials&#x60; when using client-supplied credentials (key and secret)&lt;br&gt; &amp;bullet; &#x60;refresh_token&#x60; when refreshing an expired or expiring access token.
     * @param {string} [query.code] This must be set to the authorization code returned via a callback redirect after calling the [&#x60;authorize&#x60;](#op-authorize) operation whenusing the OAuth 2.0 Authorization code flow. This is required if &#x60;grant_type&#x60; is &#x60;authorization_code&#x60;.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process and the value passed to [&#x60;authorize&#x60;](#op-authorize). Required if using the &#x60;authorization_code&#x60; flow.
     * @param {string} [query.refresh_token] The value of the &#x60;refresh_token&#x60; obtained with the original or expiring/expired access token. Required if &#x60;?grant_type&#x3D;refresh_token&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Authorization] Authorization credentials in the form &lt;br&gt; &#x60;Basic {encoded-credentials}&#x60;&lt;br&gt; where &#x60;{encoded-credentials}&#x60; is a Base 64 encoding of the text _&#x60;client-id:client-secret&#x60;_ for the registered client. If these client credentials are supplied when using the &#x60;client_credentials&#x60; grant, the OpenID Connect handshake is shortened and no interactive redirect is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getToken(
      query?: {
        grant_type?: 'authorization_code' | 'client_credentials' | 'refresh_token';
        code?: string;
        redirect_uri?: string;
        refresh_token?: string;
      },
      headers?: { Authorization?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OauthToken> {
      const localVarAxiosArgs = OpenIDConnectApiAxiosParamCreator(configuration).getToken(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * OpenIDConnectApi - factory interface
 * @export
 */
export const OpenIDConnectApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Start OpenID Connect Authorization Code Flow by requesting client application authorization and user authentication. This request redirects the user to the identity provider login page to authenticate by securely entering their credentials. Upon a successful 302 response, the client should validate the `Location` URI then redirect to that URI.
     * @summary Redirect to the authorization server for secure user login
     * @param {Object} [query] Query object
     * @param {'code' | 'client_credentials'} [query.response_type] Indicates the authentication flow to be used. Use &#x60;code&#x60; to specify the usage of the OAuth 2.0 Authorization code flow and &#x60;client_credentials&#x60; for the OAuth 2.0 Client Credentials flow.
     * @param {string} [query.scope] This must be set to &#x60;openid&#x60; to indicate a request for OpenID authentication and ID token.
     * @param {string} [query.client_id] This must be set to the client ID value obtained from the client application registration process in the developer portal.
     * @param {string} [query.state] An arbitrary value set by the client to maintain state between the authorization request and the callback.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process.  The callback url will be called with the authorization code provided as a parameter. Required if using the authorization_code flow.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    authorize(
      query?: {
        response_type?: 'code' | 'client_credentials';
        scope?: string;
        client_id?: string;
        state?: string;
        redirect_uri?: string;
      },
      options?: any,
    ) {
      return OpenIDConnectApiFp(configuration).authorize(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This request returns a JSON structure containing scopes.
     * @summary Returns OpenID Connect Discovery metadata.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getMetadata(options?: any) {
      return OpenIDConnectApiFp(configuration).getMetadata(options ? options : {})(axios, basePath);
    },
    /**
     * Create or refresh an access token for client use. Depending on the value of the `grant_type` query parameter, this operation issues a new access token and a refresh token at the end of the initial authentication flow, or it can refresh an expired or expiring access token.   * To issue the initial token for interactive clients, use `?grant_type=authorization_code`, passing the `code` obtained from the [`authorize`](#op-authorize) operation and the `redirect_uri` query parameters. (Both the `code` and `redirect_uri` query parameters are required for this grant type.) Clients should save the `refresh_token` from the response. * For trusted (non-web, non-mobile) clients, use `?grant_type=client_credentials` and the `authorization` header. * To refresh an expiring/expired access token, use `?grant_type=refresh_token&refresh_token={refresh_token}`, using the required `{refresh_token}` that was returned in the _original_ [`oauthToken`](#schema-oauthToken) response from the earlier call to this operation.  All calls require the `Authorization` header.
     * @summary Obtain a secure access token.
     * @param {Object} [query] Query object
     * @param {'authorization_code' | 'client_credentials' | 'refresh_token'} [query.grant_type] This must be set to one of the following:&lt;br&gt; &amp;bullet; &#x60;authorization_code&#x60; if using the OAuth 2.0 Authorization code flow&lt;br&gt; &amp;bullet; &#x60;client_credentials&#x60; when using client-supplied credentials (key and secret)&lt;br&gt; &amp;bullet; &#x60;refresh_token&#x60; when refreshing an expired or expiring access token.
     * @param {string} [query.code] This must be set to the authorization code returned via a callback redirect after calling the [&#x60;authorize&#x60;](#op-authorize) operation whenusing the OAuth 2.0 Authorization code flow. This is required if &#x60;grant_type&#x60; is &#x60;authorization_code&#x60;.
     * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process and the value passed to [&#x60;authorize&#x60;](#op-authorize). Required if using the &#x60;authorization_code&#x60; flow.
     * @param {string} [query.refresh_token] The value of the &#x60;refresh_token&#x60; obtained with the original or expiring/expired access token. Required if &#x60;?grant_type&#x3D;refresh_token&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Authorization] Authorization credentials in the form &lt;br&gt; &#x60;Basic {encoded-credentials}&#x60;&lt;br&gt; where &#x60;{encoded-credentials}&#x60; is a Base 64 encoding of the text _&#x60;client-id:client-secret&#x60;_ for the registered client. If these client credentials are supplied when using the &#x60;client_credentials&#x60; grant, the OpenID Connect handshake is shortened and no interactive redirect is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getToken(
      query?: {
        grant_type?: 'authorization_code' | 'client_credentials' | 'refresh_token';
        code?: string;
        redirect_uri?: string;
        refresh_token?: string;
      },
      headers?: { Authorization?: string },
      options?: any,
    ) {
      return OpenIDConnectApiFp(configuration).getToken(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * OpenIDConnectApi - object-oriented interface
 * @export
 * @class OpenIDConnectApi
 * @extends {BaseAPI}
 */
export class OpenIDConnectApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Start OpenID Connect Authorization Code Flow by requesting client application authorization and user authentication. This request redirects the user to the identity provider login page to authenticate by securely entering their credentials. Upon a successful 302 response, the client should validate the `Location` URI then redirect to that URI.
   * @summary Redirect to the authorization server for secure user login
   * @param {Object} [query] Query object
   * @param {'code' | 'client_credentials'} [query.response_type] Indicates the authentication flow to be used. Use &#x60;code&#x60; to specify the usage of the OAuth 2.0 Authorization code flow and &#x60;client_credentials&#x60; for the OAuth 2.0 Client Credentials flow.
   * @param {string} [query.scope] This must be set to &#x60;openid&#x60; to indicate a request for OpenID authentication and ID token.
   * @param {string} [query.client_id] This must be set to the client ID value obtained from the client application registration process in the developer portal.
   * @param {string} [query.state] An arbitrary value set by the client to maintain state between the authorization request and the callback.
   * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process.  The callback url will be called with the authorization code provided as a parameter. Required if using the authorization_code flow.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof OpenIDConnectApi
   */
  public authorize(
    query?: {
      response_type?: 'code' | 'client_credentials';
      scope?: string;
      client_id?: string;
      state?: string;
      redirect_uri?: string;
    },
    options?: any,
  ) {
    return OpenIDConnectApiFp(this.configuration).authorize(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This request returns a JSON structure containing scopes.
   * @summary Returns OpenID Connect Discovery metadata.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthMetadata}
   * @memberof OpenIDConnectApi
   */
  public getMetadata(options?: any) {
    return OpenIDConnectApiFp(this.configuration).getMetadata(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Create or refresh an access token for client use. Depending on the value of the `grant_type` query parameter, this operation issues a new access token and a refresh token at the end of the initial authentication flow, or it can refresh an expired or expiring access token.   * To issue the initial token for interactive clients, use `?grant_type=authorization_code`, passing the `code` obtained from the [`authorize`](#op-authorize) operation and the `redirect_uri` query parameters. (Both the `code` and `redirect_uri` query parameters are required for this grant type.) Clients should save the `refresh_token` from the response. * For trusted (non-web, non-mobile) clients, use `?grant_type=client_credentials` and the `authorization` header. * To refresh an expiring/expired access token, use `?grant_type=refresh_token&refresh_token={refresh_token}`, using the required `{refresh_token}` that was returned in the _original_ [`oauthToken`](#schema-oauthToken) response from the earlier call to this operation.  All calls require the `Authorization` header.
   * @summary Obtain a secure access token.
   * @param {Object} [query] Query object
   * @param {'authorization_code' | 'client_credentials' | 'refresh_token'} [query.grant_type] This must be set to one of the following:&lt;br&gt; &amp;bullet; &#x60;authorization_code&#x60; if using the OAuth 2.0 Authorization code flow&lt;br&gt; &amp;bullet; &#x60;client_credentials&#x60; when using client-supplied credentials (key and secret)&lt;br&gt; &amp;bullet; &#x60;refresh_token&#x60; when refreshing an expired or expiring access token.
   * @param {string} [query.code] This must be set to the authorization code returned via a callback redirect after calling the [&#x60;authorize&#x60;](#op-authorize) operation whenusing the OAuth 2.0 Authorization code flow. This is required if &#x60;grant_type&#x60; is &#x60;authorization_code&#x60;.
   * @param {string} [query.redirect_uri] The callback url that the user will be redirected to after successful login and consent with the Apiture Identity Provider. This value must match the value used during the client application registration process and the value passed to [&#x60;authorize&#x60;](#op-authorize). Required if using the &#x60;authorization_code&#x60; flow.
   * @param {string} [query.refresh_token] The value of the &#x60;refresh_token&#x60; obtained with the original or expiring/expired access token. Required if &#x60;?grant_type&#x3D;refresh_token&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Authorization] Authorization credentials in the form &lt;br&gt; &#x60;Basic {encoded-credentials}&#x60;&lt;br&gt; where &#x60;{encoded-credentials}&#x60; is a Base 64 encoding of the text _&#x60;client-id:client-secret&#x60;_ for the registered client. If these client credentials are supplied when using the &#x60;client_credentials&#x60; grant, the OpenID Connect handshake is shortened and no interactive redirect is used.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OauthToken}
   * @memberof OpenIDConnectApi
   */
  public getToken(
    query?: {
      grant_type?: 'authorization_code' | 'client_credentials' | 'refresh_token';
      code?: string;
      redirect_uri?: string;
      refresh_token?: string;
    },
    headers?: { Authorization?: string },
    options?: any,
  ) {
    return OpenIDConnectApiFp(this.configuration).getToken(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * PasswordApi - axios parameter creator
 * @export
 */
export const PasswordApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * An authenticated user must encrypt (see [`GET /encryptionKeys`]{#op-getEncryptionKeys)) and pass `currentPassword` and `newPassword` in the request body to change its password. This operation requires both `apiKey` and `accessToken` security. This operation will return 202 Accepted if the request is valid. If the request fails, and the user does not know the current password, they can request a password reset by using `/passwordResetRequests`. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation only validates the `newPassword` against the password policies and returns an `_error` in the response with details of any password policy violations.
     * @summary Change the user password
     * @param {PasswordChange} PasswordChange
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation only of the &#x60;newPassword&#x60; and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    changeUserPassword(
      PasswordChange: PasswordChange,
      query?: { preFlightValidate?: boolean },
      options: any = {},
    ): RequestArgs {
      const { preFlightValidate } = query;

      // verify required parameter 'PasswordChange' is not null or undefined
      if (PasswordChange === null || PasswordChange === undefined) {
        throw new RequiredError(
          'PasswordChange',
          'Required parameter PasswordChange was null or undefined when calling changeUserPassword.',
        );
      }
      const localVarPath = `/my/password`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (preFlightValidate !== undefined) {
        localVarQueryParameter['preFlightValidate'] = preFlightValidate;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'PasswordChange' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(PasswordChange || {})
        : PasswordChange || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Complete an unauthenticated password reset flow by passing `username`,`confirmationCode`, and `newPassword` in the request.  This operation will return 202 Accepted if the request is valid. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation validates the `confirmationCode` against the generated code, validates the new password to ensure it complies with the financial institution’s password policy, and returns an `_error` in the response if there is not a match in the codes or with details of any password policy violations.
     * @summary Complete a password reset flow.
     * @param {ConfirmPasswordReset} ConfirmPasswordReset The data necessary to confirm a password reset
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordReset(
      ConfirmPasswordReset: ConfirmPasswordReset,
      query?: { preFlightValidate?: boolean },
      options: any = {},
    ): RequestArgs {
      const { preFlightValidate } = query;

      // verify required parameter 'ConfirmPasswordReset' is not null or undefined
      if (ConfirmPasswordReset === null || ConfirmPasswordReset === undefined) {
        throw new RequiredError(
          'ConfirmPasswordReset',
          'Required parameter ConfirmPasswordReset was null or undefined when calling passwordReset.',
        );
      }
      const localVarPath = `/passwordResets`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (preFlightValidate !== undefined) {
        localVarQueryParameter['preFlightValidate'] = preFlightValidate;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ConfirmPasswordReset' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ConfirmPasswordReset || {})
        : ConfirmPasswordReset || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Initiate a password reset flow by sending the user's key identifying information. A confirmation code is sent to the user via text message or email as a result of this operation if the information matches. In order to complete the flow, a `POST` request to `/passwordReset` must contain the confirmation code as well as the username and the desired new password. This operation does not create a new persistent resource; the password reset is transient and returned in the response body only.
     * @summary Initiate a password reset flow.
     * @param {PasswordResetRequest} PasswordResetRequest The data necessary to create a password reset resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordResetRequest(
      PasswordResetRequest: PasswordResetRequest,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'PasswordResetRequest' is not null or undefined
      if (PasswordResetRequest === null || PasswordResetRequest === undefined) {
        throw new RequiredError(
          'PasswordResetRequest',
          'Required parameter PasswordResetRequest was null or undefined when calling passwordResetRequest.',
        );
      }
      const localVarPath = `/passwordResetRequests`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'PasswordResetRequest' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(PasswordResetRequest || {})
        : PasswordResetRequest || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PasswordApi - functional programming interface
 * @export
 */
export const PasswordApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * An authenticated user must encrypt (see [`GET /encryptionKeys`]{#op-getEncryptionKeys)) and pass `currentPassword` and `newPassword` in the request body to change its password. This operation requires both `apiKey` and `accessToken` security. This operation will return 202 Accepted if the request is valid. If the request fails, and the user does not know the current password, they can request a password reset by using `/passwordResetRequests`. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation only validates the `newPassword` against the password policies and returns an `_error` in the response with details of any password policy violations.
     * @summary Change the user password
     * @param {PasswordChange} PasswordChange
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation only of the &#x60;newPassword&#x60; and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    changeUserPassword(
      PasswordChange: PasswordChange,
      query?: { preFlightValidate?: boolean },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<PasswordChange> {
      const localVarAxiosArgs = PasswordApiAxiosParamCreator(configuration).changeUserPassword(
        PasswordChange ? PasswordChange : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Complete an unauthenticated password reset flow by passing `username`,`confirmationCode`, and `newPassword` in the request.  This operation will return 202 Accepted if the request is valid. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation validates the `confirmationCode` against the generated code, validates the new password to ensure it complies with the financial institution’s password policy, and returns an `_error` in the response if there is not a match in the codes or with details of any password policy violations.
     * @summary Complete a password reset flow.
     * @param {ConfirmPasswordReset} ConfirmPasswordReset The data necessary to confirm a password reset
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordReset(
      ConfirmPasswordReset: ConfirmPasswordReset,
      query?: { preFlightValidate?: boolean },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = PasswordApiAxiosParamCreator(configuration).passwordReset(
        ConfirmPasswordReset ? ConfirmPasswordReset : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Initiate a password reset flow by sending the user's key identifying information. A confirmation code is sent to the user via text message or email as a result of this operation if the information matches. In order to complete the flow, a `POST` request to `/passwordReset` must contain the confirmation code as well as the username and the desired new password. This operation does not create a new persistent resource; the password reset is transient and returned in the response body only.
     * @summary Initiate a password reset flow.
     * @param {PasswordResetRequest} PasswordResetRequest The data necessary to create a password reset resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordResetRequest(
      PasswordResetRequest: PasswordResetRequest,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<PasswordReset> {
      const localVarAxiosArgs = PasswordApiAxiosParamCreator(configuration).passwordResetRequest(
        PasswordResetRequest ? PasswordResetRequest : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PasswordApi - factory interface
 * @export
 */
export const PasswordApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * An authenticated user must encrypt (see [`GET /encryptionKeys`]{#op-getEncryptionKeys)) and pass `currentPassword` and `newPassword` in the request body to change its password. This operation requires both `apiKey` and `accessToken` security. This operation will return 202 Accepted if the request is valid. If the request fails, and the user does not know the current password, they can request a password reset by using `/passwordResetRequests`. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation only validates the `newPassword` against the password policies and returns an `_error` in the response with details of any password policy violations.
     * @summary Change the user password
     * @param {PasswordChange} PasswordChange
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation only of the &#x60;newPassword&#x60; and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    changeUserPassword(
      PasswordChange: PasswordChange,
      query?: { preFlightValidate?: boolean },
      options?: any,
    ) {
      return PasswordApiFp(configuration).changeUserPassword(
        PasswordChange ? PasswordChange : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Complete an unauthenticated password reset flow by passing `username`,`confirmationCode`, and `newPassword` in the request.  This operation will return 202 Accepted if the request is valid. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation validates the `confirmationCode` against the generated code, validates the new password to ensure it complies with the financial institution’s password policy, and returns an `_error` in the response if there is not a match in the codes or with details of any password policy violations.
     * @summary Complete a password reset flow.
     * @param {ConfirmPasswordReset} ConfirmPasswordReset The data necessary to confirm a password reset
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to update the user&#39;s password.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordReset(
      ConfirmPasswordReset: ConfirmPasswordReset,
      query?: { preFlightValidate?: boolean },
      options?: any,
    ) {
      return PasswordApiFp(configuration).passwordReset(
        ConfirmPasswordReset ? ConfirmPasswordReset : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Initiate a password reset flow by sending the user's key identifying information. A confirmation code is sent to the user via text message or email as a result of this operation if the information matches. In order to complete the flow, a `POST` request to `/passwordReset` must contain the confirmation code as well as the username and the desired new password. This operation does not create a new persistent resource; the password reset is transient and returned in the response body only.
     * @summary Initiate a password reset flow.
     * @param {PasswordResetRequest} PasswordResetRequest The data necessary to create a password reset resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    passwordResetRequest(PasswordResetRequest: PasswordResetRequest, options?: any) {
      return PasswordApiFp(configuration).passwordResetRequest(
        PasswordResetRequest ? PasswordResetRequest : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PasswordApi - object-oriented interface
 * @export
 * @class PasswordApi
 * @extends {BaseAPI}
 */
export class PasswordApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * An authenticated user must encrypt (see [`GET /encryptionKeys`]{#op-getEncryptionKeys)) and pass `currentPassword` and `newPassword` in the request body to change its password. This operation requires both `apiKey` and `accessToken` security. This operation will return 202 Accepted if the request is valid. If the request fails, and the user does not know the current password, they can request a password reset by using `/passwordResetRequests`. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation only validates the `newPassword` against the password policies and returns an `_error` in the response with details of any password policy violations.
   * @summary Change the user password
   * @param {PasswordChange} PasswordChange
   * @param {Object} [query] Query object
   * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation only of the &#x60;newPassword&#x60; and it does not attempt to update the user&#39;s password.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {PasswordChange}
   * @memberof PasswordApi
   */
  public changeUserPassword(
    PasswordChange: PasswordChange,
    query?: { preFlightValidate?: boolean },
    options?: any,
  ) {
    return PasswordApiFp(this.configuration).changeUserPassword(
      PasswordChange ? PasswordChange : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Complete an unauthenticated password reset flow by passing `username`,`confirmationCode`, and `newPassword` in the request.  This operation will return 202 Accepted if the request is valid. This operation supports _pre-flight validation_. If invoked with the `preFlightValidate=true` query parameter, the operation validates the `confirmationCode` against the generated code, validates the new password to ensure it complies with the financial institution’s password policy, and returns an `_error` in the response if there is not a match in the codes or with details of any password policy violations.
   * @summary Complete a password reset flow.
   * @param {ConfirmPasswordReset} ConfirmPasswordReset The data necessary to confirm a password reset
   * @param {Object} [query] Query object
   * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to update the user&#39;s password.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof PasswordApi
   */
  public passwordReset(
    ConfirmPasswordReset: ConfirmPasswordReset,
    query?: { preFlightValidate?: boolean },
    options?: any,
  ) {
    return PasswordApiFp(this.configuration).passwordReset(
      ConfirmPasswordReset ? ConfirmPasswordReset : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Initiate a password reset flow by sending the user's key identifying information. A confirmation code is sent to the user via text message or email as a result of this operation if the information matches. In order to complete the flow, a `POST` request to `/passwordReset` must contain the confirmation code as well as the username and the desired new password. This operation does not create a new persistent resource; the password reset is transient and returned in the response body only.
   * @summary Initiate a password reset flow.
   * @param {PasswordResetRequest} PasswordResetRequest The data necessary to create a password reset resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {PasswordReset}
   * @memberof PasswordApi
   */
  public passwordResetRequest(PasswordResetRequest: PasswordResetRequest, options?: any) {
    return PasswordApiFp(this.configuration).passwordResetRequest(
      PasswordResetRequest ? PasswordResetRequest : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * UserApi - axios parameter creator
 * @export
 */
export const UserApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * After enabling the Apiture platform and importing customers from the banking core, a client application can use this operation to confirm and create a user's login account. The client application should prompt the user for their first and last name, date of birth, and tax identification number (such as a social security number) and submit the data here. A successful operation (the request was well formed) returns a [Challenge](#schema-challenge) resource. If this data matches a customer registered in the core, the system will connect the user resource to that customer in the banking core and create a new login account.   The client should then use one of the returned challenge's [authenticators](schema-authenticator) to verify the user identity. If verified, the user enters their new username in the client application. The client should then use the [`username`](#op-createUsername) operation to validate and submit the user's new username to create the user's login account.   This operation returns an error response if the data is not well formed. Since this operation is unauthenticated, the response for a well-formed request does _not_ indicate success or failure. Thus, this operation cannot be used to confirm if a customer exists or not.
     * @summary Convert a user to new digital banking platform
     * @param {UserConfirmation} UserConfirmation
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    confirmUser(UserConfirmation: UserConfirmation, options: any = {}): RequestArgs {
      // verify required parameter 'UserConfirmation' is not null or undefined
      if (UserConfirmation === null || UserConfirmation === undefined) {
        throw new RequiredError(
          'UserConfirmation',
          'Required parameter UserConfirmation was null or undefined when calling confirmUser.',
        );
      }
      const localVarPath = `/confirmedUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserConfirmation' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserConfirmation || {})
        : UserConfirmation || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username and password with this operation.   If there are no errors in the request, the user login account is completed with the requested username and password; the end user may now log in.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.  **Warning**: This operation is **deprecated** and will be removed in a future release.
     * @summary Create credentials for a new digital banking platform user
     * @param {Credentials} Credentials
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCredentials(
      Credentials: Credentials,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { preFlightValidate } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'Credentials' is not null or undefined
      if (Credentials === null || Credentials === undefined) {
        throw new RequiredError(
          'Credentials',
          'Required parameter Credentials was null or undefined when calling createCredentials.',
        );
      }
      const localVarPath = `/credentials`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (preFlightValidate !== undefined) {
        localVarQueryParameter['preFlightValidate'] = preFlightValidate;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Credentials' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Credentials || {})
        : Credentials || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username with this operation.   If there are no errors in the request, the Authentication service returns a temporary password to the user. The user should login with the temporary password, then change the password to one of their choosing.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.
     * @summary Assign a username for a new digital banking platform user
     * @param {PreferredUsername} PreferredUsername
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUsername(
      PreferredUsername: PreferredUsername,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { preFlightValidate } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'PreferredUsername' is not null or undefined
      if (PreferredUsername === null || PreferredUsername === undefined) {
        throw new RequiredError(
          'PreferredUsername',
          'Required parameter PreferredUsername was null or undefined when calling createUsername.',
        );
      }
      const localVarPath = `/username`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (preFlightValidate !== undefined) {
        localVarQueryParameter['preFlightValidate'] = preFlightValidate;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'PreferredUsername' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(PreferredUsername || {})
        : PreferredUsername || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Request sending the user an email containing their forgotten username by submitting the user's key identifying information. (This operation does not create a resource.) An email containing the username is sent to the user as a result of this operation.
     * @summary Request sending the user an email containing their forgotten username.
     * @param {UsernameRequest} UsernameRequest The data necessary to request the user&#39;s username be sent to them.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    usernameRequests(UsernameRequest: UsernameRequest, options: any = {}): RequestArgs {
      // verify required parameter 'UsernameRequest' is not null or undefined
      if (UsernameRequest === null || UsernameRequest === undefined) {
        throw new RequiredError(
          'UsernameRequest',
          'Required parameter UsernameRequest was null or undefined when calling usernameRequests.',
        );
      }
      const localVarPath = `/usernameRequests`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UsernameRequest' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UsernameRequest || {})
        : UsernameRequest || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * UserApi - functional programming interface
 * @export
 */
export const UserApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * After enabling the Apiture platform and importing customers from the banking core, a client application can use this operation to confirm and create a user's login account. The client application should prompt the user for their first and last name, date of birth, and tax identification number (such as a social security number) and submit the data here. A successful operation (the request was well formed) returns a [Challenge](#schema-challenge) resource. If this data matches a customer registered in the core, the system will connect the user resource to that customer in the banking core and create a new login account.   The client should then use one of the returned challenge's [authenticators](schema-authenticator) to verify the user identity. If verified, the user enters their new username in the client application. The client should then use the [`username`](#op-createUsername) operation to validate and submit the user's new username to create the user's login account.   This operation returns an error response if the data is not well formed. Since this operation is unauthenticated, the response for a well-formed request does _not_ indicate success or failure. Thus, this operation cannot be used to confirm if a customer exists or not.
     * @summary Convert a user to new digital banking platform
     * @param {UserConfirmation} UserConfirmation
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    confirmUser(
      UserConfirmation: UserConfirmation,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserConfirmationResponse> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).confirmUser(
        UserConfirmation ? UserConfirmation : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username and password with this operation.   If there are no errors in the request, the user login account is completed with the requested username and password; the end user may now log in.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.  **Warning**: This operation is **deprecated** and will be removed in a future release.
     * @summary Create credentials for a new digital banking platform user
     * @param {Credentials} Credentials
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCredentials(
      Credentials: Credentials,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CredentialsResponse> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).createCredentials(
        Credentials ? Credentials : null,

        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username with this operation.   If there are no errors in the request, the Authentication service returns a temporary password to the user. The user should login with the temporary password, then change the password to one of their choosing.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.
     * @summary Assign a username for a new digital banking platform user
     * @param {PreferredUsername} PreferredUsername
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUsername(
      PreferredUsername: PreferredUsername,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<PreferredUsernameResponse> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).createUsername(
        PreferredUsername ? PreferredUsername : null,

        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Request sending the user an email containing their forgotten username by submitting the user's key identifying information. (This operation does not create a resource.) An email containing the username is sent to the user as a result of this operation.
     * @summary Request sending the user an email containing their forgotten username.
     * @param {UsernameRequest} UsernameRequest The data necessary to request the user&#39;s username be sent to them.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    usernameRequests(
      UsernameRequest: UsernameRequest,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UsernameRequestNotification> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).usernameRequests(
        UsernameRequest ? UsernameRequest : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * UserApi - factory interface
 * @export
 */
export const UserApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * After enabling the Apiture platform and importing customers from the banking core, a client application can use this operation to confirm and create a user's login account. The client application should prompt the user for their first and last name, date of birth, and tax identification number (such as a social security number) and submit the data here. A successful operation (the request was well formed) returns a [Challenge](#schema-challenge) resource. If this data matches a customer registered in the core, the system will connect the user resource to that customer in the banking core and create a new login account.   The client should then use one of the returned challenge's [authenticators](schema-authenticator) to verify the user identity. If verified, the user enters their new username in the client application. The client should then use the [`username`](#op-createUsername) operation to validate and submit the user's new username to create the user's login account.   This operation returns an error response if the data is not well formed. Since this operation is unauthenticated, the response for a well-formed request does _not_ indicate success or failure. Thus, this operation cannot be used to confirm if a customer exists or not.
     * @summary Convert a user to new digital banking platform
     * @param {UserConfirmation} UserConfirmation
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    confirmUser(UserConfirmation: UserConfirmation, options?: any) {
      return UserApiFp(configuration).confirmUser(
        UserConfirmation ? UserConfirmation : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username and password with this operation.   If there are no errors in the request, the user login account is completed with the requested username and password; the end user may now log in.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.  **Warning**: This operation is **deprecated** and will be removed in a future release.
     * @summary Create credentials for a new digital banking platform user
     * @param {Credentials} Credentials
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createCredentials(
      Credentials: Credentials,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return UserApiFp(configuration).createCredentials(
        Credentials ? Credentials : null,

        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username with this operation.   If there are no errors in the request, the Authentication service returns a temporary password to the user. The user should login with the temporary password, then change the password to one of their choosing.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.
     * @summary Assign a username for a new digital banking platform user
     * @param {PreferredUsername} PreferredUsername
     * @param {Object} [query] Query object
     * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUsername(
      PreferredUsername: PreferredUsername,
      query?: { preFlightValidate?: boolean },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return UserApiFp(configuration).createUsername(
        PreferredUsername ? PreferredUsername : null,

        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Request sending the user an email containing their forgotten username by submitting the user's key identifying information. (This operation does not create a resource.) An email containing the username is sent to the user as a result of this operation.
     * @summary Request sending the user an email containing their forgotten username.
     * @param {UsernameRequest} UsernameRequest The data necessary to request the user&#39;s username be sent to them.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    usernameRequests(UsernameRequest: UsernameRequest, options?: any) {
      return UserApiFp(configuration).usernameRequests(
        UsernameRequest ? UsernameRequest : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * UserApi - object-oriented interface
 * @export
 * @class UserApi
 * @extends {BaseAPI}
 */
export class UserApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * After enabling the Apiture platform and importing customers from the banking core, a client application can use this operation to confirm and create a user's login account. The client application should prompt the user for their first and last name, date of birth, and tax identification number (such as a social security number) and submit the data here. A successful operation (the request was well formed) returns a [Challenge](#schema-challenge) resource. If this data matches a customer registered in the core, the system will connect the user resource to that customer in the banking core and create a new login account.   The client should then use one of the returned challenge's [authenticators](schema-authenticator) to verify the user identity. If verified, the user enters their new username in the client application. The client should then use the [`username`](#op-createUsername) operation to validate and submit the user's new username to create the user's login account.   This operation returns an error response if the data is not well formed. Since this operation is unauthenticated, the response for a well-formed request does _not_ indicate success or failure. Thus, this operation cannot be used to confirm if a customer exists or not.
   * @summary Convert a user to new digital banking platform
   * @param {UserConfirmation} UserConfirmation
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserConfirmationResponse}
   * @memberof UserApi
   */
  public confirmUser(UserConfirmation: UserConfirmation, options?: any) {
    return UserApiFp(this.configuration).confirmUser(
      UserConfirmation ? UserConfirmation : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username and password with this operation.   If there are no errors in the request, the user login account is completed with the requested username and password; the end user may now log in.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.  **Warning**: This operation is **deprecated** and will be removed in a future release.
   * @summary Create credentials for a new digital banking platform user
   * @param {Credentials} Credentials
   * @param {Object} [query] Query object
   * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CredentialsResponse}
   * @memberof UserApi
   */
  public createCredentials(
    Credentials: Credentials,
    query?: { preFlightValidate?: boolean },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return UserApiFp(this.configuration).createCredentials(
      Credentials ? Credentials : null,

      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * After confirming the user's identity via the [`confirmUser`](#op-confirmUser) operation and completing the identity verification challenge, the user can submit their new username with this operation.   If there are no errors in the request, the Authentication service returns a temporary password to the user. The user should login with the temporary password, then change the password to one of their choosing.   This operation also supports _pre-flight validation_, via the `?preFlightValidate=true` option, to request that the server validate the credentials. The `_error` object in the 200 `OK` response will list any such errors, such as username already in use, the password does not conform to the password policies, or the [Challenge ID](#schema-challenge) is invalid or expired or has already been redeemed. If the request is valid, there is no `_error` object in the pre-flight validation response. Validating the request does not count towards the challenge's maximum redemption count.   This operation requires passing a valid Challenge ID in the `Apiture-Challenge` request header.
   * @summary Assign a username for a new digital banking platform user
   * @param {PreferredUsername} PreferredUsername
   * @param {Object} [query] Query object
   * @param {boolean} [query.preFlightValidate] If &#x60;true&#x60;, the operation performs pre-flight validation of the request body and it does not attempt to create a login account and credentials for the user.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {PreferredUsernameResponse}
   * @memberof UserApi
   */
  public createUsername(
    PreferredUsername: PreferredUsername,
    query?: { preFlightValidate?: boolean },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return UserApiFp(this.configuration).createUsername(
      PreferredUsername ? PreferredUsername : null,

      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Request sending the user an email containing their forgotten username by submitting the user's key identifying information. (This operation does not create a resource.) An email containing the username is sent to the user as a result of this operation.
   * @summary Request sending the user an email containing their forgotten username.
   * @param {UsernameRequest} UsernameRequest The data necessary to request the user&#39;s username be sent to them.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UsernameRequestNotification}
   * @memberof UserApi
   */
  public usernameRequests(UsernameRequest: UsernameRequest, options?: any) {
    return UserApiFp(this.configuration).usernameRequests(
      UsernameRequest ? UsernameRequest : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * UserSessionsApi - axios parameter creator
 * @export
 */
export const UserSessionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Continue a session. After the client refreshes the user's access token, it may post the user session to this path to indicate that it wishes to continue the virtual session, but associated with the new token. The client must call this operation with the new access token in the `Authorization` header.   This operation is idempotent. If the session has already been continued, this operation returns that session.
     * @param {UserSession} UserSession Client information for tracking the continuing user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startUserSession&#x60; operation or from the most recent call to &#x60;continueUserSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    continueUserSession(UserSession: UserSession, options: any = {}): RequestArgs {
      // verify required parameter 'UserSession' is not null or undefined
      if (UserSession === null || UserSession === undefined) {
        throw new RequiredError(
          'UserSession',
          'Required parameter UserSession was null or undefined when calling continueUserSession.',
        );
      }
      const localVarPath = `/continuedUserSessions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserSession' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserSession || {})
        : UserSession || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * End a user session. When the client wishes to end a user session, it can call this operation to inform the platform. The client may use an explicit logout operation, or it may end a session after a period of inactivity.   Upon ending a user session, the client should purge any local cached data associated with the user and discard their access token and the `userSession` object.
     * @param {UserSession} UserSession Client information for tracking the current user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startSession&#x60; operation or from the most recent call to &#x60;continueSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    endUserSession(UserSession: UserSession, options: any = {}): RequestArgs {
      // verify required parameter 'UserSession' is not null or undefined
      if (UserSession === null || UserSession === undefined) {
        throw new RequiredError(
          'UserSession',
          'Required parameter UserSession was null or undefined when calling endUserSession.',
        );
      }
      const localVarPath = `/completedSessions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserSession' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserSession || {})
        : UserSession || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Start a user's virtual session. Clients should call this to mark when a user logs in. This operation is not required, but using it allows the financial institution to monitor and audit users' sessions and help prevent fraudulent use. The operation returns a session identifer which the client should pass to continue or complete the session with the `continueUserSession` and `endUserSession` operations. The response contains links to these operations. The response for this operation is also passed directly to those other operations.   This operation is idempotent. If the session has already been started, this operation returns that session.
     * @param {UserSessionStart} UserSessionStart Client information for tracking the session.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startUserSession(UserSessionStart: UserSessionStart, options: any = {}): RequestArgs {
      // verify required parameter 'UserSessionStart' is not null or undefined
      if (UserSessionStart === null || UserSessionStart === undefined) {
        throw new RequiredError(
          'UserSessionStart',
          'Required parameter UserSessionStart was null or undefined when calling startUserSession.',
        );
      }
      const localVarPath = `/userSession`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/write',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserSessionStart' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserSessionStart || {})
        : UserSessionStart || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * UserSessionsApi - functional programming interface
 * @export
 */
export const UserSessionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Continue a session. After the client refreshes the user's access token, it may post the user session to this path to indicate that it wishes to continue the virtual session, but associated with the new token. The client must call this operation with the new access token in the `Authorization` header.   This operation is idempotent. If the session has already been continued, this operation returns that session.
     * @param {UserSession} UserSession Client information for tracking the continuing user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startUserSession&#x60; operation or from the most recent call to &#x60;continueUserSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    continueUserSession(
      UserSession: UserSession,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserSession> {
      const localVarAxiosArgs = UserSessionsApiAxiosParamCreator(configuration).continueUserSession(
        UserSession ? UserSession : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * End a user session. When the client wishes to end a user session, it can call this operation to inform the platform. The client may use an explicit logout operation, or it may end a session after a period of inactivity.   Upon ending a user session, the client should purge any local cached data associated with the user and discard their access token and the `userSession` object.
     * @param {UserSession} UserSession Client information for tracking the current user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startSession&#x60; operation or from the most recent call to &#x60;continueSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    endUserSession(
      UserSession: UserSession,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = UserSessionsApiAxiosParamCreator(configuration).endUserSession(
        UserSession ? UserSession : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Start a user's virtual session. Clients should call this to mark when a user logs in. This operation is not required, but using it allows the financial institution to monitor and audit users' sessions and help prevent fraudulent use. The operation returns a session identifer which the client should pass to continue or complete the session with the `continueUserSession` and `endUserSession` operations. The response contains links to these operations. The response for this operation is also passed directly to those other operations.   This operation is idempotent. If the session has already been started, this operation returns that session.
     * @param {UserSessionStart} UserSessionStart Client information for tracking the session.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startUserSession(
      UserSessionStart: UserSessionStart,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserSession> {
      const localVarAxiosArgs = UserSessionsApiAxiosParamCreator(configuration).startUserSession(
        UserSessionStart ? UserSessionStart : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * UserSessionsApi - factory interface
 * @export
 */
export const UserSessionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Continue a session. After the client refreshes the user's access token, it may post the user session to this path to indicate that it wishes to continue the virtual session, but associated with the new token. The client must call this operation with the new access token in the `Authorization` header.   This operation is idempotent. If the session has already been continued, this operation returns that session.
     * @param {UserSession} UserSession Client information for tracking the continuing user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startUserSession&#x60; operation or from the most recent call to &#x60;continueUserSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    continueUserSession(UserSession: UserSession, options?: any) {
      return UserSessionsApiFp(configuration).continueUserSession(
        UserSession ? UserSession : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * End a user session. When the client wishes to end a user session, it can call this operation to inform the platform. The client may use an explicit logout operation, or it may end a session after a period of inactivity.   Upon ending a user session, the client should purge any local cached data associated with the user and discard their access token and the `userSession` object.
     * @param {UserSession} UserSession Client information for tracking the current user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startSession&#x60; operation or from the most recent call to &#x60;continueSession&#x60; for this user, whichever was most recent.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    endUserSession(UserSession: UserSession, options?: any) {
      return UserSessionsApiFp(configuration).endUserSession(
        UserSession ? UserSession : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Start a user's virtual session. Clients should call this to mark when a user logs in. This operation is not required, but using it allows the financial institution to monitor and audit users' sessions and help prevent fraudulent use. The operation returns a session identifer which the client should pass to continue or complete the session with the `continueUserSession` and `endUserSession` operations. The response contains links to these operations. The response for this operation is also passed directly to those other operations.   This operation is idempotent. If the session has already been started, this operation returns that session.
     * @param {UserSessionStart} UserSessionStart Client information for tracking the session.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startUserSession(UserSessionStart: UserSessionStart, options?: any) {
      return UserSessionsApiFp(configuration).startUserSession(
        UserSessionStart ? UserSessionStart : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * UserSessionsApi - object-oriented interface
 * @export
 * @class UserSessionsApi
 * @extends {BaseAPI}
 */
export class UserSessionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Continue a session. After the client refreshes the user's access token, it may post the user session to this path to indicate that it wishes to continue the virtual session, but associated with the new token. The client must call this operation with the new access token in the `Authorization` header.   This operation is idempotent. If the session has already been continued, this operation returns that session.
   * @param {UserSession} UserSession Client information for tracking the continuing user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startUserSession&#x60; operation or from the most recent call to &#x60;continueUserSession&#x60; for this user, whichever was most recent.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserSession}
   * @memberof UserSessionsApi
   */
  public continueUserSession(UserSession: UserSession, options?: any) {
    return UserSessionsApiFp(this.configuration).continueUserSession(
      UserSession ? UserSession : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * End a user session. When the client wishes to end a user session, it can call this operation to inform the platform. The client may use an explicit logout operation, or it may end a session after a period of inactivity.   Upon ending a user session, the client should purge any local cached data associated with the user and discard their access token and the `userSession` object.
   * @param {UserSession} UserSession Client information for tracking the current user session. This is the &#x60;userSession&#x60; returned from either the &#x60;startSession&#x60; operation or from the most recent call to &#x60;continueSession&#x60; for this user, whichever was most recent.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof UserSessionsApi
   */
  public endUserSession(UserSession: UserSession, options?: any) {
    return UserSessionsApiFp(this.configuration).endUserSession(
      UserSession ? UserSession : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Start a user's virtual session. Clients should call this to mark when a user logs in. This operation is not required, but using it allows the financial institution to monitor and audit users' sessions and help prevent fraudulent use. The operation returns a session identifer which the client should pass to continue or complete the session with the `continueUserSession` and `endUserSession` operations. The response contains links to these operations. The response for this operation is also passed directly to those other operations.   This operation is idempotent. If the session has already been started, this operation returns that session.
   * @param {UserSessionStart} UserSessionStart Client information for tracking the session.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserSession}
   * @memberof UserSessionsApi
   */
  public startUserSession(UserSessionStart: UserSessionStart, options?: any) {
    return UserSessionsApiFp(this.configuration).startUserSession(
      UserSessionStart ? UserSessionStart : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}
