// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Organizations
 * Contact information for organizations (businesses, non-profits, trusts, etc.) within the Apiture Banking APIs. This API manages business names, addresses, phone numbers, and email addresses of organizations. This API also tracks additional regulatory information for organizations which conduct banking and own business accounts at the financial institution. This API also manages authorized signers for the accounts owned by the organization as well as the organization's beneficial owners, which are people who own at least 25% of the business.
 *
 * OpenAPI spec version: 0.26.2
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/organizations'.replace(/\/+$/, '');

export const API_VERSION = '0.26.2';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The purpose of the account.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `accountPurpose` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AccountPurpose {
  Unknown = 'unknown',
  CreditCardProcessing = 'creditCardProcessing',
  GeneralOperatingFunds = 'generalOperatingFunds',
  Lottery = 'lottery',
  Payroll = 'payroll',
  Savings = 'savings',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The type of this address.
   * @type {AddressType}
   * @memberof Address
   */
  type: AddressType;
  /**
   * A text label, suitable for presentation to the end user. This is derived from `type` or from `otherType` if `type` is `other`
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The actual address type if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  otherType?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
  /**
   * An identifier for this address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all addresses within the `addresses` array.
   * @type {string}
   * @memberof Address
   */
  _id?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A list of postal addresses and the preferred mailing address.
 * @export
 * @interface Addresses
 */
export interface Addresses {
  /**
   * An array of postal/mailing addresses.
   * @type {Array<Address>}
   * @memberof Addresses
   */
  addresses?: Array<Address>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array.
   * @type {string}
   * @memberof Addresses
   */
  preferredMailingAddressId?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Represents a person authorized for account access. This object contains key identification information for the person and the type of access or role that the person has in relation to the banking account or organization.
 * @export
 * @interface Authorization
 */
export interface Authorization extends IndividualIdentification {
  /**
   * The unique ID of the user. This is the `_id` value of the user resource from the Users API.
   * @type {string}
   * @memberof Authorization
   */
  userId?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof Authorization
   */
  customerId?: string;
  /**
   * The type of this account access authorization.  * *`primary`* the `contact` is the primary owner of a personal account. There may be only one  primary owner. The target of the authorization is a single personal account.  * *`joint`* the `contact` is a non-primary joint owner of a  personal account. The target of the authorization is a single personal account.  * *`authorizedSigner`* the `contact` is an authorized signer  for a business account. The target of the authorization is an  all business accounts owned by the organization.
   * @type {AuthorizationType}
   * @memberof Authorization
   */
  type?: AuthorizationType;
  /**
   * The person's role at the organization. This attribute is required when the authorization type is authorizedSigner.
   * @type {string}
   * @memberof Authorization
   */
  role?: string;
}

/**
 * The type of this account access authorization.  * *`primary`* the person is the primary owner of a personal account.  There may be only one primary owner.  * *`joint`* the person is a non-primary joint owner of a  personal account.  * *`authorizedSigner`* the person is an authorized signer  for all business accounts owned by the organization.
 * @export
 * @enum {string}
 */
export enum AuthorizationType {
  Primary = 'primary',
  Joint = 'joint',
  AuthorizedSigner = 'authorizedSigner',
}

/**
 * The list of users who are authorized to access the organization and its bank accounts.
 * @export
 * @interface AuthorizedSigners
 */
export interface AuthorizedSigners extends AbstractResource {
  /**
   * The array of authorized signers for this business and their role within the organization. These people have account access for all business accounts owned by the business. The items in this array must all have the `type` of `authorizedSigner`.
   * @type {Array<Authorization>}
   * @memberof AuthorizedSigners
   */
  items?: Array<Authorization>;
}

/**
 * A person who owns 25% or more of a business organization.
 * @export
 * @interface BeneficialOwner
 */
export interface BeneficialOwner extends SimpleContact {
  /**
   * The person's role at the organization.
   * @type {string}
   * @memberof BeneficialOwner
   */
  role?: string;
  /**
   * The percent of the business that this person owns.
   * @type {number}
   * @memberof BeneficialOwner
   */
  percentage?: number;
  /**
   * The beneficial's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof BeneficialOwner
   */
  birthdate?: string;
  /**
   * The `_id` of an existing contact resource associated with the beneficial owner. Create the beneficial owner contact resource using the Contacts API.
   * @type {string}
   * @memberof BeneficialOwner
   */
  contactId?: string;
}

/**
 * A list of people who own at least 25% of the business or who have a major role in the organization. The sum of the percentages may not exceed 100%. The percentage may be less than 25 for non-owners with a major role, or to retain other owners whose percentage may change to 25% in the future.
 * @export
 * @interface BeneficialOwners
 */
export interface BeneficialOwners extends AbstractResource {
  /**
   * A list of people who own at least 25% of the business, and the percentage owned.
   * @type {Array<BeneficialOwner>}
   * @memberof BeneficialOwners
   */
  items?: Array<BeneficialOwner>;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * The object representation of a newly created authorization. The fields listed will assist in the information needed to gain access to a bank account or organization. A link to the user must be passed in _links as `apiture:user` for implementations of this object as it explains the direct association.
 * @export
 * @interface CreateAuthorization
 */
export interface CreateAuthorization extends AbstractResource, Authorization {}

/**
 * The user authorized for organizational access.
 * @export
 * @interface CreateAuthorizedSigner
 */
export interface CreateAuthorizedSigner extends CreateAuthorization {}

/**
 * Representation used to create a new organization.
 * @export
 * @interface CreateOrganization
 */
export interface CreateOrganization extends AbstractResource, OrganizationFields {
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof CreateOrganization
   */
  attributes?: any;
}

/**
 * A list of email addresses and the preferred email address.
 * @export
 * @interface EmailAddresses
 */
export interface EmailAddresses {
  /**
   * An array of email addresses.
   * @type {Array<TypedEmailAddress>}
   * @memberof EmailAddresses
   */
  emailAddresses?: Array<TypedEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.
   * @type {string}
   * @memberof EmailAddresses
   */
  preferredEmailAddressId?: string;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Data necessary to generate an entity authorization form.
 * @export
 * @interface EntityAuthorizationFormRequest
 */
export interface EntityAuthorizationFormRequest extends AbstractResource {
  /**
   * A list of zero or more invited authorized signers. If empty or omitted, the form will list only existing authorized signers.
   * @type {Array<InvitedAuthorizedSigner>}
   * @memberof EntityAuthorizationFormRequest
   */
  invitees?: Array<InvitedAuthorizedSigner>;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * The estimated annual revenue in USD.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `estimatedAnnualRevenue` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EstimatedAnnualRevenue {
  Unknown = 'unknown',
  Under1Million = 'under1Million',
  From1to10Million = 'from1to10Million',
  From10to100Million = 'from10to100Million',
  Over100Million = 'over100Million',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Estimated monthly amounts for banking services.
 * @export
 * @interface EstimatedMonthlyAmounts
 */
export interface EstimatedMonthlyAmounts {
  /**
   * The percentage of gross revenue the organization derives from money services.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  percentGrossRevenue?: string;
  /**
   * Indicates the estimated monthly total amount to send by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentAch?: string;
  /**
   * Indicates the estimated monthly total amount to receive by ACH.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedAch?: string;
  /**
   * Indicates the estimated monthly minimum amount to deposit.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  mobileCheckDeposit?: string;
  /**
   * Indicates the estimated monthly minimum wires amount sent.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  sentWire?: string;
  /**
   * Indicates the estimated monthly minimum wires amount received.
   * @type {string}
   * @memberof EstimatedMonthlyAmounts
   */
  receivedWire?: string;
}

/**
 * Official identifying information associated with the contact.
 * @export
 * @interface Identification
 */
export interface Identification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof Identification
   */
  value: string;
  /**
   * The type of this form of identification.
   * @type {string}
   * @memberof Identification
   */
  type: Identification.TypeEnum;
  /**
   * The date when the form of identification expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` format.
   * @type {string}
   * @memberof Identification
   */
  expiration?: string;
}

/**
 * @export
 * @namespace Identification
 */
export namespace Identification {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    TaxId = 'taxId',
    PassportNumber = 'passportNumber',
  }
}

/**
 * This object contains key identification information for a person associated with digital banking.
 * @export
 * @interface IndividualIdentification
 */
export interface IndividualIdentification extends ContactName, Addresses {
  /**
   * Official government identification (tax ID) for this person.
   * @type {string}
   * @memberof IndividualIdentification
   */
  taxId?: string;
  /**
   * Indicates if the person is a (US) citizen.
   * @type {boolean}
   * @memberof IndividualIdentification
   */
  citizen?: boolean;
  /**
   * Optional email address.
   * @type {string}
   * @memberof IndividualIdentification
   */
  emailAddress?: string;
}

/**
 * The intermediary/non-bank financial institution services provided.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `intermediaryServices` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum IntermediaryServices {
  Unknown = 'unknown',
  Accounting = 'accounting',
  FundsManagement = 'fundsManagement',
  Insurance = 'insurance',
  Investment = 'investment',
  Legal = 'legal',
  Medical = 'medical',
  Notary = 'notary',
  RealEstate = 'realEstate',
  TaxPreparation = 'taxPreparation',
  TrustManagement = 'trustManagement',
  Gambling = 'gambling',
  Securities = 'securities',
  LoanFinance = 'loanFinance',
  PawnBrokerage = 'pawnBrokerage',
  TravelAgency = 'travelAgency',
  VehicleSales = 'vehicleSales',
  ForeignCurrency = 'foreignCurrency',
  PreciousMetals = 'preciousMetals',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The name and role of an individual who is being invited to the organization as an authorized signer.
 * @export
 * @interface InvitedAuthorizedSigner
 */
export interface InvitedAuthorizedSigner extends ContactName {
  /**
   * The role or job title that the individual holds within the organization.
   * @type {string}
   * @memberof InvitedAuthorizedSigner
   */
  role?: string;
}

/**
 * A map that defines labels for the items in a group. This is a map from each item *name* &rarr; *a [`labelItem`](#schema-labelitem) object*. For example, consider a JSON response that includes a property named `revenueEstimate`; the values for `revenueEstimate` must be one of the items in the group named `estimatedAnnualRevenue`, with options ranging `under1Million`, to `over100Million`. The item name is used as the selected value in an Apiture representation, such as `{ ..., \"revenueEstimate\" : \"from10to100Million\" , ...}`, and the item with the name `from10to100Million` defines the presentation labels for that item, as well as other metadata about that choice: this is the range `[10000000.00,100000000.00)`.  This allows the client to let the user select a value from a list, such as the following derivde from the labels in the example:    * Unknown   * Under $1M   * $1M to $10M   * $10M to $100M   * $100M or more  Note that the `other` item is hidden from the selection list, as that item is marked as `hidden`. For items which define numeric ranges, a client may instead let the customer *directly* enter their estimated annual revenue as a number, such as 4,500,000.00. The client can then match that number to one of ranges in the items and set the `revenueEstimate` to the corresponding item's name: `{ ..., \"revenueEstimate\" : \"from1to10Million\", ... }`.
 * @export
 * @interface LabelGroup
 */
export interface LabelGroup {
  [key: string]: LabelItem;
}

/**
 * A set of named groups of labels, each of which contains multiple item labels.   The abbreviated example shows two groups, one named `structure` and one named `estimatedAnnualRevenue`. The first has items with names such as `corporation`, `llc` and `soleProprietorship`, with text labels for each in the default and in French. The second has items for estimated revenue *ranges* but no localized labels. For example, the item named `from1to10Million` has the `label` \"$1M to $10M\" and the range `[1000000.00,10000000.00)`.
 * @export
 * @interface LabelGroups
 */
export interface LabelGroups extends AbstractResource {
  /**
   * Groups of localized labels. This maps *group names* &rarr; [*a group of labels*](#schema-labelgroup) within that group.
   * @type {any}
   * @memberof LabelGroups
   */
  groups?: any;
}

/**
 * An item in a [`labelGroup`](#schema-labelgroup), with a set of `variants` which contains different localized labels for the item. Each ([`simpleLabel`](#schema-simpleLabel)) variant defines the presentation text label and optional description for a language. Items may also have a lookup `code` to map to external syststems, a numeric range, and a `hidden` boolean to indicate the item is normally hidden in the UI.
 * @export
 * @interface LabelItem
 */
export interface LabelItem extends SimpleLabel {
  /**
   * The language-specific variants of this label. The keys in this object are [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1) language codes.
   * @type {{ [key: string]: SimpleLabel; }}
   * @memberof LabelItem
   */
  variants?: { [key: string]: SimpleLabel };
  /**
   * If the localized value is associated with an external standard or definition, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LabelItem
   */
  code?: string;
  /**
   * If `true`, this item is normally hidden from the User Interface.
   * @type {boolean}
   * @memberof LabelItem
   */
  hidden?: boolean;
  /**
   * The range of values, if the item describes a bounded numeric value. This is range notation such as `[min,max]`, `(exclusiveMin,max]`, `[min,exclusiveMax)`, or `(exclusiveMin,exclusiveMax)`. For example, `[0,100)` is the range greater than or equal to 0 and less than 100. If the *min* or *max* value are omitted, that end of the range is unbounded. For example, `(,1000.00)` means less than 1000.00 and `[20000.00,]` means 20000.00 or more. The ranges do not overlap or have gaps.
   * @type {string}
   * @memberof LabelItem
   */
  range?: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Representation of content and descriptive data (mailing addresses, phone numbers, email addresses) for an organization.  An organization which is used for a business banking account may have authorized signers, which are people authorized to perform banking operations on the business account(s) such as initiating funds transfers.  Regulations require identifying an organization's _beneficial owners_: people who own 25% or more of a business. These may be listed and updated with the `getBeneficialOwners` and `updateBeneficialOwners` operations.  An organization may have the following links in the `_links` object:   * **`apiture:activate`** - Activate a new, pending organization.   * **`apiture:deactivate`** - Deactivate an organization (if it   is pending or active).   * **`apiture:remove`** - Remove an inactive organization.   * **`apiture:authorizedSigners`** - List the authorized signers.   * **`apiture:beneficialOwners`** - List the beneficial owners.
 * @export
 * @interface Organization
 */
export interface Organization extends SummaryOrganization {
  /**
   * The date-time when the organization was created.
   * @type {Date}
   * @memberof Organization
   */
  createdAt?: Date;
  /**
   * The date-time when the organization was updated
   * @type {Date}
   * @memberof Organization
   */
  updatedAt?: Date;
  /**
   * An optional map of name/value pairs which provide additional metadata about the organization.
   * @type {any}
   * @memberof Organization
   */
  attributes?: any;
  /**
   * Embedded objects, as selected with the `?embed` query parameter.
   * @type {any}
   * @memberof Organization
   */
  _embedded?: any;
}

/**
 * Representation of an organization's address resource.
 * @export
 * @interface OrganizationAddress
 */
export interface OrganizationAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof OrganizationAddress
   */
  state?: ProfileItemState;
}

/**
 * The list of the organization's addresses.
 * @export
 * @interface OrganizationAddresses
 */
export interface OrganizationAddresses extends AbstractResource {
  /**
   * An array containing address items.
   * @type {Array<OrganizationAddress>}
   * @memberof OrganizationAddresses
   */
  items?: Array<OrganizationAddress>;
}

/**
 * Representation of email address resources. An email address is immutable, although organizations can add new email addresses.
 * @export
 * @interface OrganizationEmailAddress
 */
export interface OrganizationEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof OrganizationEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * The list of the organization's email addresses.
 * @export
 * @interface OrganizationEmailAddresses
 */
export interface OrganizationEmailAddresses extends AbstractResource {
  /**
   * An array containing email address items.
   * @type {Array<OrganizationEmailAddress>}
   * @memberof OrganizationEmailAddresses
   */
  items?: Array<OrganizationEmailAddress>;
}

/**
 * Common fields of the organization resource, for organizations which conduct banking.
 * @export
 * @interface OrganizationFields
 */
export interface OrganizationFields extends SimpleOrganization {
  /**
   * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
   * @type {OrganizationState}
   * @memberof OrganizationFields
   */
  state?: OrganizationState;
  /**
   * The trade name of the organization.
   * @type {string}
   * @memberof OrganizationFields
   */
  tradeName?: string;
  /**
   * Indicates whether the organization is a government-owned entity.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  governmentOwned?: boolean;
  /**
   * Indicates whether the organization is publicly held.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  publiclyHeld?: boolean;
  /**
   * Indicates whether the organization is classified as a small business
   * @type {boolean}
   * @memberof OrganizationFields
   */
  smallBusiness?: boolean;
  /**
   * Indicates whether the organization is the tax-exempt.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  taxExempt?: boolean;
  /**
   * Indicates the approximate number of employees, as a range.
   * @type {string}
   * @memberof OrganizationFields
   */
  employeeCountRange?: string;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountLowerBound?: number;
  /**
   * The lower bound of persons employed, derived from the range selected in `employeeCountRange`.
   * @type {number}
   * @memberof OrganizationFields
   */
  employeeCountUpperBound?: number;
  /**
   * The organization's home page.
   * @type {string}
   * @memberof OrganizationFields
   */
  homeUrl?: string;
  /**
   * Indicates what industry does this organization work within.
   * @type {string}
   * @memberof OrganizationFields
   */
  industry?: string;
  /**
   * The ISO 3166-1 country code for the organization's operation.
   * @type {string}
   * @memberof OrganizationFields
   */
  countryOfOperations?: string;
  /**
   * Answers to organization-specific regulatory questions.
   * @type {Regulatory}
   * @memberof OrganizationFields
   */
  regulatory?: Regulatory;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII. TODO: ISO 4217 defines three-character codes. However, ISO 4217 does not account for cryptocurrencies. Of note, DASH uses 4 characters.
   * @type {string}
   * @memberof OrganizationFields
   */
  currency?: string;
  /**
   * Indicates that the organization use mobile check deposits.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  mobileCheckDepositEnabled?: boolean;
  /**
   * Indicates that the organization use ACH transfers.
   * @type {boolean}
   * @memberof OrganizationFields
   */
  achEnabled?: boolean;
  /**
   * Estimated monthly amounts for banking services.
   * @type {EstimatedMonthlyAmounts}
   * @memberof OrganizationFields
   */
  estimatedMonthlyAmounts?: EstimatedMonthlyAmounts;
  /**
   * The purpose of the account.
   * @type {AccountPurpose}
   * @memberof OrganizationFields
   */
  accountPurpose?: AccountPurpose;
  /**
   * The US state or other region in which the organization is registered.
   * @type {string}
   * @memberof OrganizationFields
   */
  registeredIn?: string;
}

/**
 * The type and value of the organizations unique identification numbers.
 * @export
 * @interface OrganizationIdentification
 */
export interface OrganizationIdentification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof OrganizationIdentification
   */
  value: string;
  /**
   * The type of this form of identification. `taxId` is the only supported type at this time.
   * @type {OrganizationIdentificationType}
   * @memberof OrganizationIdentification
   */
  type: OrganizationIdentificationType;
  /**
   * The date when this form of identification expires.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiresOn?: string;
  /**
   * The date when this form of identification expires. **Note** This property is deprecated; use `expiresOn`.
   * @type {string}
   * @memberof OrganizationIdentification
   */
  expiration?: string;
}

/**
 * The type of the form of an organization's identification. `taxId` is the only supported type at this time.
 * @export
 * @enum {string}
 */
export enum OrganizationIdentificationType {
  TaxId = 'taxId',
  DunsNumber = 'dunsNumber',
}

/**
 * Representation of phone number resources.
 * @export
 * @interface OrganizationPhoneNumber
 */
export interface OrganizationPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof OrganizationPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * The list of the organization's phone numbers.
 * @export
 * @interface OrganizationPhoneNumbers
 */
export interface OrganizationPhoneNumbers extends AbstractResource {
  /**
   * An array containing phone number items.
   * @type {Array<OrganizationPhoneNumber>}
   * @memberof OrganizationPhoneNumbers
   */
  items?: Array<OrganizationPhoneNumber>;
}

/**
 * The state of this organization. The enumeration values are described by the `organizationState` value in the response of the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum OrganizationState {
  Pending = 'pending',
  Inactive = 'inactive',
  Active = 'active',
  Merged = 'merged',
  Removed = 'removed',
}

/**
 * Collection of organizations. The items in the collection are ordered in the `_embedded.items` array; the `name` is `organizations`.  The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Organizations
 */
export interface Organizations extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Organizations
   */
  _embedded?: any;
}

/**
 * The percentage of gross revenue the organization derives from money services.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `percentGrossRevenue` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PercentGrossRevenue {
  Unknown = 'unknown',
  From0to25Percent = 'from0to25Percent',
  From26to50Percent = 'from26to50Percent',
  From51to75Percent = 'from51to75Percent',
  From75to100Percent = 'from75to100Percent',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * A list of phone numbers and the preferred phone number.
 * @export
 * @interface PhoneNumbers
 */
export interface PhoneNumbers {
  /**
   * An array of phone numbers.
   * @type {Array<PhoneNumber>}
   * @memberof PhoneNumbers
   */
  phones?: Array<PhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array.
   * @type {string}
   * @memberof PhoneNumbers
   */
  preferredPhoneId?: string;
}

/**
 * The number of physical locations, branches, offices, or sites the organization owns.
 * @export
 * @enum {string}
 */
export enum PhysicalLocationsCount {
  Unknown = 'unknown',
  Under10 = 'under10',
  From10to50 = 'from10to50',
  From50to100 = 'from50to100',
  MoreThan100 = 'moreThan100',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The contact's preferred method of communication.
 * @export
 * @enum {string}
 */
export enum PreferredContactMethod {
  Unknown = 'unknown',
  Sms = 'sms',
  Email = 'email',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The state of an item (address, email address, or phone number) within the organization's profile. New addresses, email addresses, or phone numbers start with the state `pending`, which means approval by the financial institution is pending. After they have been verified, the state becomes `approved`. Some normalizing or sanitizing of the value may occur when this happens (for example, a ZIP code may change to ZIP+4 format). `pending` items may not be assigned as the preferred item.
 * @export
 * @enum {string}
 */
export enum ProfileItemState {
  Pending = 'pending',
  Approved = 'approved',
}

/**
 * Responses to regulatory-related questions.
 * @export
 * @interface Regulatory
 */
export interface Regulatory {
  [key: string]: RegulatoryValue | any;

  /**
   * The range of estimated revenue in US dollars.
   * @type {EstimatedAnnualRevenue}
   * @memberof Regulatory
   */
  estimatedAnnualRevenue?: EstimatedAnnualRevenue;
  /**
   * The organization operates automated teller machines (ATMs).
   * @type {boolean}
   * @memberof Regulatory
   */
  atmOperator?: boolean;
  /**
   * Some of the organization's income depends on a charity.
   * @type {boolean}
   * @memberof Regulatory
   */
  charity?: boolean;
  /**
   * The organization cashes checks for customers in amounts greater than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  cashesChecksMoreThan1000Usd?: boolean;
  /**
   * The organization derives income from internet gambling.
   * @type {boolean}
   * @memberof Regulatory
   */
  internetGamblingIncorporated?: boolean;
  /**
   * The organization derives income from marijuana or other drugs/controlled substances.
   * @type {boolean}
   * @memberof Regulatory
   */
  marijuanaBusiness?: boolean;
  /**
   * Individuals at the organization may request money orders of more than $1,000.
   * @type {boolean}
   * @memberof Regulatory
   */
  moneyOrderMoreThan1000Usd?: boolean;
  /**
   * The organization processes transactions on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  thirdPartyBenefit?: boolean;
  /**
   * The organization transmits funds on behalf of third parties.
   * @type {boolean}
   * @memberof Regulatory
   */
  transmitBehalfOfCustomer?: boolean;
  /**
   * The organization administers or exchanges virtual currency.
   * @type {boolean}
   * @memberof Regulatory
   */
  virtualCurrency?: boolean;
  /**
   * A list of intermediary/non-bank financial institution services provided the organization performs on behalf of others.
   * @type {Array<IntermediaryServices>}
   * @memberof Regulatory
   */
  intermediaryServices?: Array<IntermediaryServices>;
  /**
   * If `true`, the organization is subject to tax withholdings.
   * @type {boolean}
   * @memberof Regulatory
   */
  subjectToWithholdings?: boolean;
}

/**
 * The value associated with this regulatory property.
 * @export
 * @interface RegulatoryValue
 */
export interface RegulatoryValue {}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Basic contact and identification information for a person, consisting of the name, mailing address, phone numbers, email addresses, and government identification.
 * @export
 * @interface SimpleContact
 */
export interface SimpleContact
  extends ContactName,
    Addresses,
    EmailAddresses,
    PhoneNumbers,
    SimpleContactFields {}

/**
 * Additional properties for a person or contact.
 * @export
 * @interface SimpleContactFields
 */
export interface SimpleContactFields {
  /**
   * A title or honorific prefix such as Dr. or Fr.
   * @type {string}
   * @memberof SimpleContactFields
   */
  prefix?: string;
  /**
   * A title or honorific suffix such as PhD or DDS.
   * @type {string}
   * @memberof SimpleContactFields
   */
  suffix?: string;
  /**
   * The contact's preferred name. This is how the contact's name is presented to the user in the interface. The default is the contact's `firstName`.
   * @type {string}
   * @memberof SimpleContactFields
   */
  preferredName?: string;
  /**
   * A collection of official identifying information associated with the contact.
   * @type {Array<Identification>}
   * @memberof SimpleContactFields
   */
  identification?: Array<Identification>;
  /**
   * The contact's preferred method of communication.
   * @type {PreferredContactMethod}
   * @memberof SimpleContactFields
   */
  preferredContactMethod?: PreferredContactMethod;
}

/**
 * A text label and optional description.
 * @export
 * @interface SimpleLabel
 */
export interface SimpleLabel {
  /**
   * A label or title which may be used as labels or other UI controls which present a value.
   * @type {string}
   * @memberof SimpleLabel
   */
  label: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof SimpleLabel
   */
  description?: string;
}

/**
 * The simplest form of an organization.
 * @export
 * @interface SimpleOrganization
 */
export interface SimpleOrganization {
  /**
   * The organization's official full name
   * @type {string}
   * @memberof SimpleOrganization
   */
  name?: string;
  /**
   * The organization's common name.
   * @type {string}
   * @memberof SimpleOrganization
   */
  label?: string;
  /**
   * Indicates what type of organization this resource represents.   The enumeration values are described by the `organizationType` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  type?: string;
  /**
   * A refinement of the `type`.   The enumeration values are described by the `organizationSubtype` value in the response of the `getLabels` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  subtype?: string;
  /**
   * A collection of official identifying information associated with the organization. This currently only supports government tax ID.
   * @type {Array<OrganizationIdentification>}
   * @memberof SimpleOrganization
   */
  identification?: Array<OrganizationIdentification>;
  /**
   * An array containing address items.
   * @type {Array<OrganizationAddress>}
   * @memberof SimpleOrganization
   */
  addresses?: Array<OrganizationAddress>;
  /**
   * An array of phone numbers associated with the organization. The first item, if present, is the default (preferred) organization phone number.
   * @type {Array<OrganizationPhoneNumber>}
   * @memberof SimpleOrganization
   */
  phones?: Array<OrganizationPhoneNumber>;
  /**
   * An array of email addresses associated with the organization. The first item, if present, is the default (preferred) organization email.
   * @type {Array<OrganizationEmailAddress>}
   * @memberof SimpleOrganization
   */
  emailAddresses?: Array<OrganizationEmailAddress>;
  /**
   * The ID of the organization's preferred email address. This string is the `_id` of an email address in the `emailAddresses` array. This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredEmailAddressId?: string;
  /**
   * The ID of organization's preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredPhoneId?: string;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof SimpleOrganization
   */
  preferredMailingAddressId?: string;
  /**
   * The date the organization was established.
   * @type {string}
   * @memberof SimpleOrganization
   */
  establishedDate?: string;
}

/**
 * Summary representation of an organization resource in organizations collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryOrganization
 */
export interface SummaryOrganization extends AbstractResource, OrganizationFields {
  /**
   * The unique identifier for this organization resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryOrganization
   */
  _id?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the organization in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Organizations API).
   * @type {string}
   * @memberof SummaryOrganization
   */
  customerId?: string;
}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * The years the organization has owned/managed their business.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `yearsOwned` group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum YearsOwned {
  Unknown = 'unknown',
  One = 'one',
  Two = 'two',
  Three = 'three',
  FourOrMoreYears = 'fourOrMoreYears',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the organization&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the organization&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<LabelGroups> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the organization&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the organization&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LabelGroups}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AddressApi - axios parameter creator
 * @export
 */
export const AddressApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an address to the list of the organization's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new address.
     * @param {OrganizationAddress} OrganizationAddress The data necessary to create a new address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      OrganizationAddress: OrganizationAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling createAddress.',
        );
      }
      // verify required parameter 'OrganizationAddress' is not null or undefined
      if (OrganizationAddress === null || OrganizationAddress === undefined) {
        throw new RequiredError(
          'OrganizationAddress',
          'Required parameter OrganizationAddress was null or undefined when calling createAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/addresses`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'OrganizationAddress' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(OrganizationAddress || {})
        : OrganizationAddress || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the organization's preferred address.
     * @summary Delete this address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(organizationId: string, addressId: string, options: any = {}): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling deleteAddress.',
        );
      }
      // verify required parameter 'addressId' is not null or undefined
      if (addressId === null || addressId === undefined) {
        throw new RequiredError(
          'addressId',
          'Required parameter addressId was null or undefined when calling deleteAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/addresses/{addressId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'addressId'}}`, encodeURIComponent(String(addressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      organizationId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getAddress.',
        );
      }
      // verify required parameter 'addressId' is not null or undefined
      if (addressId === null || addressId === undefined) {
        throw new RequiredError(
          'addressId',
          'Required parameter addressId was null or undefined when calling getAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/addresses/{addressId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'addressId'}}`, encodeURIComponent(String(addressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the organization's addresses.
     * @summary Get an organization's addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(organizationId: string, options: any = {}): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getAddresses.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/addresses`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the organization's preferred mailing address. The organization may set their preferred address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.  No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} body The &#x60;_id&#x60; of the address to assign as the preferred address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling setPreferredAddress.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling setPreferredAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/preferredAddress`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AddressApi - functional programming interface
 * @export
 */
export const AddressApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an address to the list of the organization's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new address.
     * @param {OrganizationAddress} OrganizationAddress The data necessary to create a new address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      OrganizationAddress: OrganizationAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationAddress> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).createAddress(
        OrganizationAddress ? OrganizationAddress : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the organization's preferred address.
     * @summary Delete this address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(
      organizationId: string,
      addressId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).deleteAddress(
        organizationId ? organizationId : null,
        addressId ? addressId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      organizationId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationAddress> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).getAddress(
        organizationId ? organizationId : null,
        addressId ? addressId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the organization's addresses.
     * @summary Get an organization's addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(
      organizationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationAddresses> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).getAddresses(
        organizationId ? organizationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the organization's preferred mailing address. The organization may set their preferred address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.  No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} body The &#x60;_id&#x60; of the address to assign as the preferred address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).setPreferredAddress(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AddressApi - factory interface
 * @export
 */
export const AddressApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add an address to the list of the organization's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new address.
     * @param {OrganizationAddress} OrganizationAddress The data necessary to create a new address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      OrganizationAddress: OrganizationAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).createAddress(
        OrganizationAddress ? OrganizationAddress : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the organization's preferred address.
     * @summary Delete this address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(organizationId: string, addressId: string, options?: any) {
      return AddressApiFp(configuration).deleteAddress(
        organizationId ? organizationId : null,
        addressId ? addressId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      organizationId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).getAddress(
        organizationId ? organizationId : null,
        addressId ? addressId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the organization's addresses.
     * @summary Get an organization's addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(organizationId: string, options?: any) {
      return AddressApiFp(configuration).getAddresses(
        organizationId ? organizationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the organization's preferred mailing address. The organization may set their preferred address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.  No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} body The &#x60;_id&#x60; of the address to assign as the preferred address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).setPreferredAddress(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AddressApi - object-oriented interface
 * @export
 * @class AddressApi
 * @extends {BaseAPI}
 */
export class AddressApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add an address to the list of the organization's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
   * @summary Create a new address.
   * @param {OrganizationAddress} OrganizationAddress The data necessary to create a new address.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationAddress}
   * @memberof AddressApi
   */
  public createAddress(
    OrganizationAddress: OrganizationAddress,
    organizationId: string,
    query?: { replaceId?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).createAddress(
      OrganizationAddress ? OrganizationAddress : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this address. The address can only be deleted if it is _not_ the organization's preferred address.
   * @summary Delete this address resource
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} addressId The unique identifier of this address. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AddressApi
   */
  public deleteAddress(organizationId: string, addressId: string, options?: any) {
    return AddressApiFp(this.configuration).deleteAddress(
      organizationId ? organizationId : null,
      addressId ? addressId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
   * @summary Fetch a representation of this address
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} addressId The unique identifier of this address. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationAddress}
   * @memberof AddressApi
   */
  public getAddress(
    organizationId: string,
    addressId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).getAddress(
      organizationId ? organizationId : null,
      addressId ? addressId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the organization's addresses.
   * @summary Get an organization's addresses
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationAddresses}
   * @memberof AddressApi
   */
  public getAddresses(organizationId: string, options?: any) {
    return AddressApiFp(this.configuration).getAddresses(
      organizationId ? organizationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the organization's preferred mailing address. The organization may set their preferred address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.  No changes are made if the specified address is already the preferred address.
   * @summary Set Preferred mailing Address
   * @param {string} body The &#x60;_id&#x60; of the address to assign as the preferred address, as a JSON string (the value must be quoted).
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof AddressApi
   */
  public setPreferredAddress(
    body: string,
    organizationId: string,
    query?: { value?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).setPreferredAddress(
      body ? body : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * AuthorizedSignersApi - axios parameter creator
 * @export
 */
export const AuthorizedSignersApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * This operation will create a new authorized signer as well as associate and provide the user access to an organization. The signer must be a verified user and the user URI must be passed into _links as `apiture:user`. An authorized signer will be added through indirect operations such as a successful creation of an organization, or completion of an authorized signer invitation.
     * @summary Create a new authorized signer and associate it to an organization.
     * @param {CreateAuthorizedSigner} CreateAuthorizedSigner The authorized signer object.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthorizedSigner(
      CreateAuthorizedSigner: CreateAuthorizedSigner,
      organizationId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling createAuthorizedSigner.',
        );
      }
      // verify required parameter 'CreateAuthorizedSigner' is not null or undefined
      if (CreateAuthorizedSigner === null || CreateAuthorizedSigner === undefined) {
        throw new RequiredError(
          'CreateAuthorizedSigner',
          'Required parameter CreateAuthorizedSigner was null or undefined when calling createAuthorizedSigner.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/authorizedSigners`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateAuthorizedSigner' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateAuthorizedSigner || {})
        : CreateAuthorizedSigner || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.
     * @summary Fetch the organization's authorized signers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getAuthorizedSigners.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/authorizedSigners`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AuthorizedSignersApi - functional programming interface
 * @export
 */
export const AuthorizedSignersApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * This operation will create a new authorized signer as well as associate and provide the user access to an organization. The signer must be a verified user and the user URI must be passed into _links as `apiture:user`. An authorized signer will be added through indirect operations such as a successful creation of an organization, or completion of an authorized signer invitation.
     * @summary Create a new authorized signer and associate it to an organization.
     * @param {CreateAuthorizedSigner} CreateAuthorizedSigner The authorized signer object.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthorizedSigner(
      CreateAuthorizedSigner: CreateAuthorizedSigner,
      organizationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<CreateAuthorizedSigner> {
      const localVarAxiosArgs = AuthorizedSignersApiAxiosParamCreator(
        configuration,
      ).createAuthorizedSigner(
        CreateAuthorizedSigner ? CreateAuthorizedSigner : null,
        organizationId ? organizationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.
     * @summary Fetch the organization's authorized signers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<AuthorizedSigners> {
      const localVarAxiosArgs = AuthorizedSignersApiAxiosParamCreator(
        configuration,
      ).getAuthorizedSigners(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AuthorizedSignersApi - factory interface
 * @export
 */
export const AuthorizedSignersApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * This operation will create a new authorized signer as well as associate and provide the user access to an organization. The signer must be a verified user and the user URI must be passed into _links as `apiture:user`. An authorized signer will be added through indirect operations such as a successful creation of an organization, or completion of an authorized signer invitation.
     * @summary Create a new authorized signer and associate it to an organization.
     * @param {CreateAuthorizedSigner} CreateAuthorizedSigner The authorized signer object.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAuthorizedSigner(
      CreateAuthorizedSigner: CreateAuthorizedSigner,
      organizationId: string,
      options?: any,
    ) {
      return AuthorizedSignersApiFp(configuration).createAuthorizedSigner(
        CreateAuthorizedSigner ? CreateAuthorizedSigner : null,
        organizationId ? organizationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.
     * @summary Fetch the organization's authorized signers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAuthorizedSigners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AuthorizedSignersApiFp(configuration).getAuthorizedSigners(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AuthorizedSignersApi - object-oriented interface
 * @export
 * @class AuthorizedSignersApi
 * @extends {BaseAPI}
 */
export class AuthorizedSignersApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * This operation will create a new authorized signer as well as associate and provide the user access to an organization. The signer must be a verified user and the user URI must be passed into _links as `apiture:user`. An authorized signer will be added through indirect operations such as a successful creation of an organization, or completion of an authorized signer invitation.
   * @summary Create a new authorized signer and associate it to an organization.
   * @param {CreateAuthorizedSigner} CreateAuthorizedSigner The authorized signer object.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {CreateAuthorizedSigner}
   * @memberof AuthorizedSignersApi
   */
  public createAuthorizedSigner(
    CreateAuthorizedSigner: CreateAuthorizedSigner,
    organizationId: string,
    options?: any,
  ) {
    return AuthorizedSignersApiFp(this.configuration).createAuthorizedSigner(
      CreateAuthorizedSigner ? CreateAuthorizedSigner : null,
      organizationId ? organizationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the account's authorized signers.
   * @summary Fetch the organization's authorized signers
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {AuthorizedSigners}
   * @memberof AuthorizedSignersApi
   */
  public getAuthorizedSigners(
    organizationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AuthorizedSignersApiFp(this.configuration).getAuthorizedSigners(
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * BeneficialOwnersApi - axios parameter creator
 * @export
 */
export const BeneficialOwnersApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the organization's beneficial owners. This is a list of people who own 25% or more of the company. It is tracked for regulatory purposes for all organizations which own business accounts.
     * @summary Fetch the organization's beneficial owners
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficialOwners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getBeneficialOwners.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/beneficialOwners`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update the array of the beneficial owners. This is a list of people who own 25% or more of the company, and the percentage that they own, or who have a major role in the organization. This operation completely replaces the set of beneficial owners.
     * @summary Update the beneficial owners of an account
     * @param {BeneficialOwners} BeneficialOwners The array of beneficial signers.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateBeneficialOwners(
      BeneficialOwners: BeneficialOwners,
      organizationId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling updateBeneficialOwners.',
        );
      }
      // verify required parameter 'BeneficialOwners' is not null or undefined
      if (BeneficialOwners === null || BeneficialOwners === undefined) {
        throw new RequiredError(
          'BeneficialOwners',
          'Required parameter BeneficialOwners was null or undefined when calling updateBeneficialOwners.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/beneficialOwners`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'BeneficialOwners' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(BeneficialOwners || {})
        : BeneficialOwners || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * BeneficialOwnersApi - functional programming interface
 * @export
 */
export const BeneficialOwnersApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the organization's beneficial owners. This is a list of people who own 25% or more of the company. It is tracked for regulatory purposes for all organizations which own business accounts.
     * @summary Fetch the organization's beneficial owners
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficialOwners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<BeneficialOwners> {
      const localVarAxiosArgs = BeneficialOwnersApiAxiosParamCreator(
        configuration,
      ).getBeneficialOwners(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update the array of the beneficial owners. This is a list of people who own 25% or more of the company, and the percentage that they own, or who have a major role in the organization. This operation completely replaces the set of beneficial owners.
     * @summary Update the beneficial owners of an account
     * @param {BeneficialOwners} BeneficialOwners The array of beneficial signers.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateBeneficialOwners(
      BeneficialOwners: BeneficialOwners,
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<BeneficialOwners> {
      const localVarAxiosArgs = BeneficialOwnersApiAxiosParamCreator(
        configuration,
      ).updateBeneficialOwners(
        BeneficialOwners ? BeneficialOwners : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * BeneficialOwnersApi - factory interface
 * @export
 */
export const BeneficialOwnersApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the organization's beneficial owners. This is a list of people who own 25% or more of the company. It is tracked for regulatory purposes for all organizations which own business accounts.
     * @summary Fetch the organization's beneficial owners
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getBeneficialOwners(
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return BeneficialOwnersApiFp(configuration).getBeneficialOwners(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update the array of the beneficial owners. This is a list of people who own 25% or more of the company, and the percentage that they own, or who have a major role in the organization. This operation completely replaces the set of beneficial owners.
     * @summary Update the beneficial owners of an account
     * @param {BeneficialOwners} BeneficialOwners The array of beneficial signers.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateBeneficialOwners(
      BeneficialOwners: BeneficialOwners,
      organizationId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return BeneficialOwnersApiFp(configuration).updateBeneficialOwners(
        BeneficialOwners ? BeneficialOwners : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * BeneficialOwnersApi - object-oriented interface
 * @export
 * @class BeneficialOwnersApi
 * @extends {BaseAPI}
 */
export class BeneficialOwnersApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of the array of the organization's beneficial owners. This is a list of people who own 25% or more of the company. It is tracked for regulatory purposes for all organizations which own business accounts.
   * @summary Fetch the organization's beneficial owners
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {BeneficialOwners}
   * @memberof BeneficialOwnersApi
   */
  public getBeneficialOwners(
    organizationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return BeneficialOwnersApiFp(this.configuration).getBeneficialOwners(
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update the array of the beneficial owners. This is a list of people who own 25% or more of the company, and the percentage that they own, or who have a major role in the organization. This operation completely replaces the set of beneficial owners.
   * @summary Update the beneficial owners of an account
   * @param {BeneficialOwners} BeneficialOwners The array of beneficial signers.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {BeneficialOwners}
   * @memberof BeneficialOwnersApi
   */
  public updateBeneficialOwners(
    BeneficialOwners: BeneficialOwners,
    organizationId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return BeneficialOwnersApiFp(this.configuration).updateBeneficialOwners(
      BeneficialOwners ? BeneficialOwners : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EmailAddressApi - axios parameter creator
 * @export
 */
export const EmailAddressApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an email address to the list of the organization's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new email address
     * @param {OrganizationEmailAddress} OrganizationEmailAddress The data necessary to create a new email address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      OrganizationEmailAddress: OrganizationEmailAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling createEmailAddress.',
        );
      }
      // verify required parameter 'OrganizationEmailAddress' is not null or undefined
      if (OrganizationEmailAddress === null || OrganizationEmailAddress === undefined) {
        throw new RequiredError(
          'OrganizationEmailAddress',
          'Required parameter OrganizationEmailAddress was null or undefined when calling createEmailAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/emailAddresses`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'OrganizationEmailAddress' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(OrganizationEmailAddress || {})
        : OrganizationEmailAddress || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the organization's preferred email address.
     * @summary Delete this email address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(
      organizationId: string,
      emailAddressId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling deleteEmailAddress.',
        );
      }
      // verify required parameter 'emailAddressId' is not null or undefined
      if (emailAddressId === null || emailAddressId === undefined) {
        throw new RequiredError(
          'emailAddressId',
          'Required parameter emailAddressId was null or undefined when calling deleteEmailAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/emailAddresses/{emailAddressId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'emailAddressId'}}`, encodeURIComponent(String(emailAddressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      organizationId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getEmailAddress.',
        );
      }
      // verify required parameter 'emailAddressId' is not null or undefined
      if (emailAddressId === null || emailAddressId === undefined) {
        throw new RequiredError(
          'emailAddressId',
          'Required parameter emailAddressId was null or undefined when calling getEmailAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/emailAddresses/{emailAddressId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'emailAddressId'}}`, encodeURIComponent(String(emailAddressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the organization's email addresses.
     * @summary Get organization's email addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(organizationId: string, options: any = {}): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getEmailAddresses.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/emailAddresses`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the organization's preferred email address. The organization may set their preferred email address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredEmailAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.  No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} body The &#x60;_id&#x60; of the email address to assign as the preferred email address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling setPreferredEmailAddress.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling setPreferredEmailAddress.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/preferredEmailAddress`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EmailAddressApi - functional programming interface
 * @export
 */
export const EmailAddressApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an email address to the list of the organization's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new email address
     * @param {OrganizationEmailAddress} OrganizationEmailAddress The data necessary to create a new email address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      OrganizationEmailAddress: OrganizationEmailAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationEmailAddress> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).createEmailAddress(
        OrganizationEmailAddress ? OrganizationEmailAddress : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the organization's preferred email address.
     * @summary Delete this email address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(
      organizationId: string,
      emailAddressId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).deleteEmailAddress(
        organizationId ? organizationId : null,
        emailAddressId ? emailAddressId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      organizationId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationEmailAddress> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).getEmailAddress(
        organizationId ? organizationId : null,
        emailAddressId ? emailAddressId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the organization's email addresses.
     * @summary Get organization's email addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(
      organizationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationEmailAddresses> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).getEmailAddresses(
        organizationId ? organizationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the organization's preferred email address. The organization may set their preferred email address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredEmailAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.  No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} body The &#x60;_id&#x60; of the email address to assign as the preferred email address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(
        configuration,
      ).setPreferredEmailAddress(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EmailAddressApi - factory interface
 * @export
 */
export const EmailAddressApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add an email address to the list of the organization's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new email address
     * @param {OrganizationEmailAddress} OrganizationEmailAddress The data necessary to create a new email address.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      OrganizationEmailAddress: OrganizationEmailAddress,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).createEmailAddress(
        OrganizationEmailAddress ? OrganizationEmailAddress : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the organization's preferred email address.
     * @summary Delete this email address resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(organizationId: string, emailAddressId: string, options?: any) {
      return EmailAddressApiFp(configuration).deleteEmailAddress(
        organizationId ? organizationId : null,
        emailAddressId ? emailAddressId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      organizationId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).getEmailAddress(
        organizationId ? organizationId : null,
        emailAddressId ? emailAddressId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the organization's email addresses.
     * @summary Get organization's email addresses
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(organizationId: string, options?: any) {
      return EmailAddressApiFp(configuration).getEmailAddresses(
        organizationId ? organizationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the organization's preferred email address. The organization may set their preferred email address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredEmailAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.  No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} body The &#x60;_id&#x60; of the email address to assign as the preferred email address, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).setPreferredEmailAddress(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EmailAddressApi - object-oriented interface
 * @export
 * @class EmailAddressApi
 * @extends {BaseAPI}
 */
export class EmailAddressApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add an email address to the list of the organization's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
   * @summary Create a new email address
   * @param {OrganizationEmailAddress} OrganizationEmailAddress The data necessary to create a new email address.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationEmailAddress}
   * @memberof EmailAddressApi
   */
  public createEmailAddress(
    OrganizationEmailAddress: OrganizationEmailAddress,
    organizationId: string,
    query?: { replaceId?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).createEmailAddress(
      OrganizationEmailAddress ? OrganizationEmailAddress : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this email address. The email address can only be deleted if it is _not_ the organization's preferred email address.
   * @summary Delete this email address resource
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof EmailAddressApi
   */
  public deleteEmailAddress(organizationId: string, emailAddressId: string, options?: any) {
    return EmailAddressApiFp(this.configuration).deleteEmailAddress(
      organizationId ? organizationId : null,
      emailAddressId ? emailAddressId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
   * @summary Fetch a representation of this email address
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationEmailAddress}
   * @memberof EmailAddressApi
   */
  public getEmailAddress(
    organizationId: string,
    emailAddressId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).getEmailAddress(
      organizationId ? organizationId : null,
      emailAddressId ? emailAddressId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the organization's email addresses.
   * @summary Get organization's email addresses
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationEmailAddresses}
   * @memberof EmailAddressApi
   */
  public getEmailAddresses(organizationId: string, options?: any) {
    return EmailAddressApiFp(this.configuration).getEmailAddresses(
      organizationId ? organizationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the organization's preferred email address. The organization may set their preferred email address to an _approved_ address by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredEmailAddressId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.  No changes are made if the specified email address is already the preferred email address.
   * @summary Set Preferred Email Address
   * @param {string} body The &#x60;_id&#x60; of the email address to assign as the preferred email address, as a JSON string (the value must be quoted).
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof EmailAddressApi
   */
  public setPreferredEmailAddress(
    body: string,
    organizationId: string,
    query?: { value?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).setPreferredEmailAddress(
      body ? body : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EntityAuthorizationFormApi - axios parameter creator
 * @export
 */
export const EntityAuthorizationFormApiAxiosParamCreator = function(
  configuration?: SdkConfiguration,
) {
  return {
    /**
     * Generate an entity authorization form for this organization. The form will include:    * the name and role of the individual requesting the form     (derived from the user making the request)   * the names and roles of all existing authorized signers   * the names and roles of individuals being invited to     become authorized signers.   If the form has not been generated for this request data, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the form has been generated for this request, the operations returns 200 OK and the response body is the PDF formatted entity authorization form.   Only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate an entity authorization Form
     * @param {EntityAuthorizationFormRequest} EntityAuthorizationFormRequest
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateEntityAuthorizationForm(
      EntityAuthorizationFormRequest: EntityAuthorizationFormRequest,
      organizationId: string,
      headers?: { Accept?: string },
      options: any = {},
    ): RequestArgs {
      const { Accept } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling generateEntityAuthorizationForm.',
        );
      }
      // verify required parameter 'EntityAuthorizationFormRequest' is not null or undefined
      if (EntityAuthorizationFormRequest === null || EntityAuthorizationFormRequest === undefined) {
        throw new RequiredError(
          'EntityAuthorizationFormRequest',
          'Required parameter EntityAuthorizationFormRequest was null or undefined when calling generateEntityAuthorizationForm.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/entityAuthorizationForm`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept !== undefined && Accept !== null) {
        localVarHeaderParameter['Accept'] = String(Accept);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'EntityAuthorizationFormRequest' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(EntityAuthorizationFormRequest || {})
        : EntityAuthorizationFormRequest || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EntityAuthorizationFormApi - functional programming interface
 * @export
 */
export const EntityAuthorizationFormApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Generate an entity authorization form for this organization. The form will include:    * the name and role of the individual requesting the form     (derived from the user making the request)   * the names and roles of all existing authorized signers   * the names and roles of individuals being invited to     become authorized signers.   If the form has not been generated for this request data, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the form has been generated for this request, the operations returns 200 OK and the response body is the PDF formatted entity authorization form.   Only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate an entity authorization Form
     * @param {EntityAuthorizationFormRequest} EntityAuthorizationFormRequest
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateEntityAuthorizationForm(
      EntityAuthorizationFormRequest: EntityAuthorizationFormRequest,
      organizationId: string,
      headers?: { Accept?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = EntityAuthorizationFormApiAxiosParamCreator(
        configuration,
      ).generateEntityAuthorizationForm(
        EntityAuthorizationFormRequest ? EntityAuthorizationFormRequest : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EntityAuthorizationFormApi - factory interface
 * @export
 */
export const EntityAuthorizationFormApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Generate an entity authorization form for this organization. The form will include:    * the name and role of the individual requesting the form     (derived from the user making the request)   * the names and roles of all existing authorized signers   * the names and roles of individuals being invited to     become authorized signers.   If the form has not been generated for this request data, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the form has been generated for this request, the operations returns 200 OK and the response body is the PDF formatted entity authorization form.   Only the authorized signers associated with the owning business organization may invoke this operation.
     * @summary Generate an entity authorization Form
     * @param {EntityAuthorizationFormRequest} EntityAuthorizationFormRequest
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    generateEntityAuthorizationForm(
      EntityAuthorizationFormRequest: EntityAuthorizationFormRequest,
      organizationId: string,
      headers?: { Accept?: string },
      options?: any,
    ) {
      return EntityAuthorizationFormApiFp(configuration).generateEntityAuthorizationForm(
        EntityAuthorizationFormRequest ? EntityAuthorizationFormRequest : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EntityAuthorizationFormApi - object-oriented interface
 * @export
 * @class EntityAuthorizationFormApi
 * @extends {BaseAPI}
 */
export class EntityAuthorizationFormApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Generate an entity authorization form for this organization. The form will include:    * the name and role of the individual requesting the form     (derived from the user making the request)   * the names and roles of all existing authorized signers   * the names and roles of individuals being invited to     become authorized signers.   If the form has not been generated for this request data, this returns 202 Accepted and no response body. The response will include a `Retry-After` response header with a recommended retry interval in seconds.   If the form has been generated for this request, the operations returns 200 OK and the response body is the PDF formatted entity authorization form.   Only the authorized signers associated with the owning business organization may invoke this operation.
   * @summary Generate an entity authorization Form
   * @param {EntityAuthorizationFormRequest} EntityAuthorizationFormRequest
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept] Optional. Only &#x60;application/pdf&#x60; is currently supported.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof EntityAuthorizationFormApi
   */
  public generateEntityAuthorizationForm(
    EntityAuthorizationFormRequest: EntityAuthorizationFormRequest,
    organizationId: string,
    headers?: { Accept?: string },
    options?: any,
  ) {
    return EntityAuthorizationFormApiFp(this.configuration).generateEntityAuthorizationForm(
      EntityAuthorizationFormRequest ? EntityAuthorizationFormRequest : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * OrganizationApi - axios parameter creator
 * @export
 */
export const OrganizationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate an organization from an inactive state.   This operation is invoked from the `apiture:activate` link on an organization resource when that organization is eligible to be activated.   This changes the `state` to `active`.
     * @summary Activate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization, organizationUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling activateOrganization.',
        );
      }
      const localVarPath = `/activeOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (organizationUri !== undefined) {
        localVarQueryParameter['organizationUri'] = organizationUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(CreateOrganization: CreateOrganization, options: any = {}): RequestArgs {
      // verify required parameter 'CreateOrganization' is not null or undefined
      if (CreateOrganization === null || CreateOrganization === undefined) {
        throw new RequiredError(
          'CreateOrganization',
          'Required parameter CreateOrganization was null or undefined when calling createOrganization.',
        );
      }
      const localVarPath = `/organizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateOrganization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateOrganization || {})
        : CreateOrganization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate an organization from an active or pending state.   This operation is invoked from the `apiture:deactivate` link on an organization resource when that organization is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be deactivated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization, organizationUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling deactivateOrganization.',
        );
      }
      // verify required parameter 'organizationUri' is not null or undefined
      if (organizationUri === null || organizationUri === undefined) {
        throw new RequiredError(
          'organizationUri',
          'Required parameter organizationUri was null or undefined when calling deactivateOrganization.',
        );
      }
      const localVarPath = `/inactiveOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (organizationUri !== undefined) {
        localVarQueryParameter['organizationUri'] = organizationUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this organization resource.
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling deleteOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource.
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'authorizedSigners' | 'beneficialOwners'>} [query.embed] If set, the &#x60;_embedded&#x60; object in each organization in the &#x60;items&#x60; array will include additional embedded objects. This query parameter supports the &#x60;authorizedSigners&#x60; and &#x60;beneficialOwners&#x60; options. Examples:   * &#x60;?embed&#x3D;beneficialOwners&#x60;   * &#x60;?embed&#x3D;authorizedSigners,beneficialOwners&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(
      organizationId: string,
      query?: { embed?: Array<'authorizedSigners' | 'beneficialOwners'> },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { embed } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (embed) {
        localVarQueryParameter['embed'] = embed.join(COLLECTION_FORMATS['csv']);
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first organization item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; matches only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; matches items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'pending' | 'active' | 'inactive' | 'removed' | 'merged'} [query.state] Subset the organizations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the organization collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed' | 'merged';
        name?: string;
        customerId?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, type, state, name, customerId } = query;

      const localVarPath = `/organizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (customerId !== undefined) {
        localVarQueryParameter['customerId'] = customerId;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling patchOrganization.',
        );
      }
      // verify required parameter 'Organization' is not null or undefined
      if (Organization === null || Organization === undefined) {
        throw new RequiredError(
          'Organization',
          'Required parameter Organization was null or undefined when calling patchOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Organization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Organization || {})
        : Organization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove an organization by setting its state to `removed`.   This operation is invoked from the `apiture:remove` link on a organization resource when that organization is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization).   This changes the `state` to `removed`.
     * @summary Remove an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be removed. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { organization, organizationUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'organization' is not null or undefined
      if (organization === null || organization === undefined) {
        throw new RequiredError(
          'organization',
          'Required parameter organization was null or undefined when calling removeOrganization.',
        );
      }
      // verify required parameter 'organizationUri' is not null or undefined
      if (organizationUri === null || organizationUri === undefined) {
        throw new RequiredError(
          'organizationUri',
          'Required parameter organizationUri was null or undefined when calling removeOrganization.',
        );
      }
      const localVarPath = `/removedOrganizations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (organization !== undefined) {
        localVarQueryParameter['organization'] = organization;
      }

      if (organizationUri !== undefined) {
        localVarQueryParameter['organizationUri'] = organizationUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this organization.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling updateOrganization.',
        );
      }
      // verify required parameter 'Organization' is not null or undefined
      if (Organization === null || Organization === undefined) {
        throw new RequiredError(
          'Organization',
          'Required parameter Organization was null or undefined when calling updateOrganization.',
        );
      }
      const localVarPath = `/organizations/{organizationId}`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Organization' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Organization || {})
        : Organization || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * OrganizationApi - functional programming interface
 * @export
 */
export const OrganizationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate an organization from an inactive state.   This operation is invoked from the `apiture:activate` link on an organization resource when that organization is eligible to be activated.   This changes the `state` to `active`.
     * @summary Activate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(
        configuration,
      ).activateOrganization(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(
      CreateOrganization: CreateOrganization,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).createOrganization(
        CreateOrganization ? CreateOrganization : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate an organization from an active or pending state.   This operation is invoked from the `apiture:deactivate` link on an organization resource when that organization is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be deactivated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(
        configuration,
      ).deactivateOrganization(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this organization resource.
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).deleteOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource.
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'authorizedSigners' | 'beneficialOwners'>} [query.embed] If set, the &#x60;_embedded&#x60; object in each organization in the &#x60;items&#x60; array will include additional embedded objects. This query parameter supports the &#x60;authorizedSigners&#x60; and &#x60;beneficialOwners&#x60; options. Examples:   * &#x60;?embed&#x3D;beneficialOwners&#x60;   * &#x60;?embed&#x3D;authorizedSigners,beneficialOwners&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(
      organizationId: string,
      query?: { embed?: Array<'authorizedSigners' | 'beneficialOwners'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).getOrganization(
        organizationId ? organizationId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first organization item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; matches only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; matches items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'pending' | 'active' | 'inactive' | 'removed' | 'merged'} [query.state] Subset the organizations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the organization collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed' | 'merged';
        name?: string;
        customerId?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organizations> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).getOrganizations(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).patchOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove an organization by setting its state to `removed`.   This operation is invoked from the `apiture:remove` link on a organization resource when that organization is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization).   This changes the `state` to `removed`.
     * @summary Remove an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be removed. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).removeOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this organization.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = OrganizationApiAxiosParamCreator(configuration).updateOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * OrganizationApi - factory interface
 * @export
 */
export const OrganizationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate an organization from an inactive state.   This operation is invoked from the `apiture:activate` link on an organization resource when that organization is eligible to be activated.   This changes the `state` to `active`.
     * @summary Activate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).activateOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new organization in the organizations collection.
     * @summary Create a new organization
     * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createOrganization(CreateOrganization: CreateOrganization, options?: any) {
      return OrganizationApiFp(configuration).createOrganization(
        CreateOrganization ? CreateOrganization : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate an organization from an active or pending state.   This operation is invoked from the `apiture:deactivate` link on an organization resource when that organization is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be deactivated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).deactivateOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this organization resource.
     * @summary Delete this organization resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteOrganization(organizationId: string, headers?: { If_Match?: string }, options?: any) {
      return OrganizationApiFp(configuration).deleteOrganization(
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource.
     * @summary Fetch a representation of this organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {Array<'authorizedSigners' | 'beneficialOwners'>} [query.embed] If set, the &#x60;_embedded&#x60; object in each organization in the &#x60;items&#x60; array will include additional embedded objects. This query parameter supports the &#x60;authorizedSigners&#x60; and &#x60;beneficialOwners&#x60; options. Examples:   * &#x60;?embed&#x3D;beneficialOwners&#x60;   * &#x60;?embed&#x3D;authorizedSigners,beneficialOwners&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganization(
      organizationId: string,
      query?: { embed?: Array<'authorizedSigners' | 'beneficialOwners'> },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).getOrganization(
        organizationId ? organizationId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of organizations
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first organization item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of organization representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; matches only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; matches items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'pending' | 'active' | 'inactive' | 'removed' | 'merged'} [query.state] Subset the organizations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the organizations collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the organization collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getOrganizations(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        type?: string;
        state?: 'pending' | 'active' | 'inactive' | 'removed' | 'merged';
        name?: string;
        customerId?: string;
      },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).getOrganizations(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).patchOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove an organization by setting its state to `removed`.   This operation is invoked from the `apiture:remove` link on a organization resource when that organization is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization).   This changes the `state` to `removed`.
     * @summary Remove an organization.
     * @param {Object} [query] Query object
     * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
     * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be removed. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeOrganization(
      query?: { organization?: string; organizationUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).removeOrganization(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this organization.
     * @summary Update this organization
     * @param {Organization} Organization
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateOrganization(
      Organization: Organization,
      organizationId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return OrganizationApiFp(configuration).updateOrganization(
        Organization ? Organization : null,
        organizationId ? organizationId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * OrganizationApi - object-oriented interface
 * @export
 * @class OrganizationApi
 * @extends {BaseAPI}
 */
export class OrganizationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate an organization from an inactive state.   This operation is invoked from the `apiture:activate` link on an organization resource when that organization is eligible to be activated.   This changes the `state` to `active`.
   * @summary Activate an organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
   * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be activated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public activateOrganization(
    query?: { organization?: string; organizationUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).activateOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new organization in the organizations collection.
   * @summary Create a new organization
   * @param {CreateOrganization} CreateOrganization The data necessary to create a new organization.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public createOrganization(CreateOrganization: CreateOrganization, options?: any) {
    return OrganizationApiFp(this.configuration).createOrganization(
      CreateOrganization ? CreateOrganization : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate an organization from an active or pending state.   This operation is invoked from the `apiture:deactivate` link on an organization resource when that organization is eligible to be deactivated.   This changes the `state` to `inactive`.
   * @summary Deactivate an organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
   * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be deactivated. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public deactivateOrganization(
    query?: { organization?: string; organizationUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).deactivateOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this organization resource.
   * @summary Delete this organization resource
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof OrganizationApi
   */
  public deleteOrganization(
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).deleteOrganization(
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this organization resource.
   * @summary Fetch a representation of this organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {Array<'authorizedSigners' | 'beneficialOwners'>} [query.embed] If set, the &#x60;_embedded&#x60; object in each organization in the &#x60;items&#x60; array will include additional embedded objects. This query parameter supports the &#x60;authorizedSigners&#x60; and &#x60;beneficialOwners&#x60; options. Examples:   * &#x60;?embed&#x3D;beneficialOwners&#x60;   * &#x60;?embed&#x3D;authorizedSigners,beneficialOwners&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public getOrganization(
    organizationId: string,
    query?: { embed?: Array<'authorizedSigners' | 'beneficialOwners'> },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).getOrganization(
      organizationId ? organizationId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of organizations. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of organizations
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first organization item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of organization representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.type] Subset the organizations collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;corporation&#x60; matches only items whose type is &#x60;corporation&#x60;; &#x60;?type&#x3D;llp|llc&#x60; matches items whose type is &#x60;llp&#x60; or &#x60;llc&#x60;. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {'pending' | 'active' | 'inactive' | 'removed' | 'merged'} [query.state] Subset the organizations collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the organizations collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; matches only items whose name is Bartell; &#x60;?name&#x3D;Bartell|kirsten&#x60; matches items whose name is Bartell or kirsten. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.customerId] Subset the organization collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organizations}
   * @memberof OrganizationApi
   */
  public getOrganizations(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      type?: string;
      state?: 'pending' | 'active' | 'inactive' | 'removed' | 'merged';
      name?: string;
      customerId?: string;
    },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).getOrganizations(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this organization. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this organization
   * @param {Organization} Organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public patchOrganization(
    Organization: Organization,
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).patchOrganization(
      Organization ? Organization : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove an organization by setting its state to `removed`.   This operation is invoked from the `apiture:remove` link on a organization resource when that organization is eligible to be removed. The organization must not be in use (there may not be any active associations to the organization).   This changes the `state` to `removed`.
   * @summary Remove an organization.
   * @param {Object} [query] Query object
   * @param {string} [query.organization] A string which identifies existing organization whose state is being changed by &#x60;POST&#x60;ing it to a resource set. The server supplies this value when returning a link to operate on a specific organization. The value may be a &#x60;{organizationId}&#x60; or an organization URI.
   * @param {string} [query.organizationUri] The URI of an existing organization which is eligible to be removed. This parameter is **deprecated**. Use the &#x60;?organization&#x3D;&#x60; query parameter instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public removeOrganization(
    query?: { organization?: string; organizationUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).removeOrganization(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this organization.
   * @summary Update this organization
   * @param {Organization} Organization
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof OrganizationApi
   */
  public updateOrganization(
    Organization: Organization,
    organizationId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return OrganizationApiFp(this.configuration).updateOrganization(
      Organization ? Organization : null,
      organizationId ? organizationId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * PhoneNumberApi - axios parameter creator
 * @export
 */
export const PhoneNumberApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add a phone number to the list of the organization's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new phone number
     * @param {OrganizationPhoneNumber} OrganizationPhoneNumber The data necessary to create a new phone number.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      OrganizationPhoneNumber: OrganizationPhoneNumber,
      organizationId: string,
      query?: { replaceId?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling createPhoneNumber.',
        );
      }
      // verify required parameter 'OrganizationPhoneNumber' is not null or undefined
      if (OrganizationPhoneNumber === null || OrganizationPhoneNumber === undefined) {
        throw new RequiredError(
          'OrganizationPhoneNumber',
          'Required parameter OrganizationPhoneNumber was null or undefined when calling createPhoneNumber.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/phoneNumbers`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'OrganizationPhoneNumber' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(OrganizationPhoneNumber || {})
        : OrganizationPhoneNumber || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the organization's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(
      organizationId: string,
      phoneNumberId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling deletePhoneNumber.',
        );
      }
      // verify required parameter 'phoneNumberId' is not null or undefined
      if (phoneNumberId === null || phoneNumberId === undefined) {
        throw new RequiredError(
          'phoneNumberId',
          'Required parameter phoneNumberId was null or undefined when calling deletePhoneNumber.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/phoneNumbers/{phoneNumberId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'phoneNumberId'}}`, encodeURIComponent(String(phoneNumberId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      organizationId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getPhoneNumber.',
        );
      }
      // verify required parameter 'phoneNumberId' is not null or undefined
      if (phoneNumberId === null || phoneNumberId === undefined) {
        throw new RequiredError(
          'phoneNumberId',
          'Required parameter phoneNumberId was null or undefined when calling getPhoneNumber.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/phoneNumbers/{phoneNumberId}`
        .replace(`{${'organizationId'}}`, encodeURIComponent(String(organizationId)))
        .replace(`{${'phoneNumberId'}}`, encodeURIComponent(String(phoneNumberId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the organization's phone numbers
     * @summary Get organization's phone numbers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(organizationId: string, options: any = {}): RequestArgs {
      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling getPhoneNumbers.',
        );
      }
      const localVarPath = `/organizations/{organizationId}/phoneNumbers`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the organization's preferred phone number. The organization may set their preferred phone number to an _approved_ number by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredPhoneId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.  No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} body The &#x60;_id&#x60; of the number to assign as the preferred phone number, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;

      // verify required parameter 'organizationId' is not null or undefined
      if (organizationId === null || organizationId === undefined) {
        throw new RequiredError(
          'organizationId',
          'Required parameter organizationId was null or undefined when calling setPreferredPhoneNumber.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling setPreferredPhoneNumber.',
        );
      }
      const localVarPath = `/organization/{organizationId}/preferredPhoneNumber`.replace(
        `{${'organizationId'}}`,
        encodeURIComponent(String(organizationId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PhoneNumberApi - functional programming interface
 * @export
 */
export const PhoneNumberApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add a phone number to the list of the organization's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new phone number
     * @param {OrganizationPhoneNumber} OrganizationPhoneNumber The data necessary to create a new phone number.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      OrganizationPhoneNumber: OrganizationPhoneNumber,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationPhoneNumber> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).createPhoneNumber(
        OrganizationPhoneNumber ? OrganizationPhoneNumber : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the organization's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(
      organizationId: string,
      phoneNumberId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).deletePhoneNumber(
        organizationId ? organizationId : null,
        phoneNumberId ? phoneNumberId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      organizationId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationPhoneNumber> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).getPhoneNumber(
        organizationId ? organizationId : null,
        phoneNumberId ? phoneNumberId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the organization's phone numbers
     * @summary Get organization's phone numbers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(
      organizationId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrganizationPhoneNumbers> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).getPhoneNumbers(
        organizationId ? organizationId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the organization's preferred phone number. The organization may set their preferred phone number to an _approved_ number by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredPhoneId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.  No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} body The &#x60;_id&#x60; of the number to assign as the preferred phone number, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Organization> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(
        configuration,
      ).setPreferredPhoneNumber(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PhoneNumberApi - factory interface
 * @export
 */
export const PhoneNumberApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add a phone number to the list of the organization's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
     * @summary Create a new phone number
     * @param {OrganizationPhoneNumber} OrganizationPhoneNumber The data necessary to create a new phone number.
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      OrganizationPhoneNumber: OrganizationPhoneNumber,
      organizationId: string,
      query?: { replaceId?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).createPhoneNumber(
        OrganizationPhoneNumber ? OrganizationPhoneNumber : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the organization's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(organizationId: string, phoneNumberId: string, options?: any) {
      return PhoneNumberApiFp(configuration).deletePhoneNumber(
        organizationId ? organizationId : null,
        phoneNumberId ? phoneNumberId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      organizationId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).getPhoneNumber(
        organizationId ? organizationId : null,
        phoneNumberId ? phoneNumberId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the organization's phone numbers
     * @summary Get organization's phone numbers
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(organizationId: string, options?: any) {
      return PhoneNumberApiFp(configuration).getPhoneNumbers(
        organizationId ? organizationId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the organization's preferred phone number. The organization may set their preferred phone number to an _approved_ number by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredPhoneId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.  No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} body The &#x60;_id&#x60; of the number to assign as the preferred phone number, as a JSON string (the value must be quoted).
     * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      body: string,
      organizationId: string,
      query?: { value?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).setPreferredPhoneNumber(
        body ? body : null,
        organizationId ? organizationId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PhoneNumberApi - object-oriented interface
 * @export
 * @class PhoneNumberApi
 * @extends {BaseAPI}
 */
export class PhoneNumberApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add a phone number to the list of the organization's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.
   * @summary Create a new phone number
   * @param {OrganizationPhoneNumber} OrganizationPhoneNumber The data necessary to create a new phone number.
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved. If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationPhoneNumber}
   * @memberof PhoneNumberApi
   */
  public createPhoneNumber(
    OrganizationPhoneNumber: OrganizationPhoneNumber,
    organizationId: string,
    query?: { replaceId?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).createPhoneNumber(
      OrganizationPhoneNumber ? OrganizationPhoneNumber : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this phone number. The number can only be deleted if it is _not_ the organization's preferred phone number.
   * @summary Delete this phone number resource
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof PhoneNumberApi
   */
  public deletePhoneNumber(organizationId: string, phoneNumberId: string, options?: any) {
    return PhoneNumberApiFp(this.configuration).deletePhoneNumber(
      organizationId ? organizationId : null,
      phoneNumberId ? phoneNumberId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
   * @summary Fetch a representation of this phone number
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationPhoneNumber}
   * @memberof PhoneNumberApi
   */
  public getPhoneNumber(
    organizationId: string,
    phoneNumberId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).getPhoneNumber(
      organizationId ? organizationId : null,
      phoneNumberId ? phoneNumberId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the organization's phone numbers
   * @summary Get organization's phone numbers
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {OrganizationPhoneNumbers}
   * @memberof PhoneNumberApi
   */
  public getPhoneNumbers(organizationId: string, options?: any) {
    return PhoneNumberApiFp(this.configuration).getPhoneNumbers(
      organizationId ? organizationId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the organization's preferred phone number. The organization may set their preferred phone number to an _approved_ number by passing its unique `_id` in either the `value` query parameter or in the request body. This updates the `preferredPhoneId` property of the organization.  This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.  No changes are made if the specified phone number is already the preferred phone number.
   * @summary Set Preferred Phone Number
   * @param {string} body The &#x60;_id&#x60; of the number to assign as the preferred phone number, as a JSON string (the value must be quoted).
   * @param {string} organizationId The unique identifier of this organization. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Organization}
   * @memberof PhoneNumberApi
   */
  public setPreferredPhoneNumber(
    body: string,
    organizationId: string,
    query?: { value?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).setPreferredPhoneNumber(
      body ? body : null,
      organizationId ? organizationId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
