// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Banking Products
 * This API manages the set of banking products that a financial institution offers to its customers. Each bank _account_ is associated with a _product_. <p> Examples of products are a personal savings account product or a business checking account product. Each product also has a _product type_ (for example, DDA for a checking or demand deposit account) and a _subtype_ which is a more specific type, such as 'Interest Checking'. <p> Each account is attached to the product instance that was effective and active when account was created. Product types may also have subtypes, although subtypes may not have deeper subtypes. When the terms and conditions of a product changes, this constititutes a new _revision_ of the product. Business rules (which are not part of this service) dictate whether all accounts which are attached to the product remain attached to the previous revision of the product or are attached to the newer revision or when and how this occurs. Similarly, business rules and other services may provide notification to users of changes in terms of use, etc. Products and product types each have a `name`, a `description` a `label`, and a `state`. <p> The state may be one of the following:    * *`pending`* In creation, not yet used or available for use.   Only pending items may be deleted.   * *`active`* Active and in use or available for use   * *`inactive`* Not available for use (deactivated)   * *`removed`* Removed and archived. Removed items are not eligible to be activated.   When an account is removed, its name is changed so that the name   may be used for new products or product types. <p> After creating a product type or product subtype, which by default leaves the resource in the `pending` state, the caller should also activate it via the `apiture:activate` link in the response. Pending resources which have not been activated may be deleted after an expiration period. <p> Allowed state transitions are:    * `pending -> active`   * `pending -> inactive`   * `active -> inactive`   * `inactive -> active`   * `active -> removed`   * `inactive -> removed` <p> A product or product type may only be deleted if its `state` is `pending`. A product or type may only change to `inactive` if it is not currently in use by active accounts or active products. Products and product types include links which convey the allowed POST operations, such as `apiture:activate`, `apiture:deactivate`, or `apiture:remove`. <p> In addition, a product has `newAccountAvailability` which indicates if that product is available for opening new accounts. **TODO** The `newAccountAvailability` in the product resource is currently mutable but it will become immutable and derived only. The value is derived from the existence of the product in the `unlockedProducts` collection. <p> This resource is a copy of the banking product resources in the bank core. In some cases, the Apiture platform does not have programmatic access to that core, so when  when a financial institution updates the banking products in the core, they must *also* use this API to update the Apiture copy.  # Error Types      Error responses in this API may have one of the following `type` values.        <h2 class='errorType' id=\"err-accessDenied\">accessDenied</h2>  Description: The credentials supplied in the request are insufficient to grant access.  Remediation: Check the supplied credentials for validity.   <h2 class='errorType' id=\"err-invalidProductId\">invalidProductId</h2>  Description: No Products were found for the specified productId.  Remediation: Check to make sure that the supplied productId corresponds to an apiture product resource.   <h2 class='errorType' id=\"err-invalidProductTypeId\">invalidProductTypeId</h2>  Description: No product types were found for the specified productTypeId.  Remediation: Check to make sure that the supplied productType corresponds to an apiture product type resource.   <h2 class='errorType' id=\"err-ifMatchHeaderMissing\">ifMatchHeaderMissing</h2>  Description: Precondition Required. The request did not include the required if-Match header.  Remediation: Resubmit with the operation, supplying the value of the ETag and the most recent state of the resource.   <h2 class='errorType' id=\"err-ifMatchHeaderDoesntMatch\">ifMatchHeaderDoesntMatch</h2>  Description: The supplied `if-Match` header value does not match the most recent `ETag` response header value. The resource has changed in the interim.  Remediation: Resubmit the operation, supplying the value of the ETag and the most recent state of the resource.   <h2 class='errorType' id=\"err-malformedProduct\">malformedProduct</h2>  Description: The supplied product was malformed.  Remediation: Check to make sure that the supplied product parameter corresponds to an apiture product resource.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>product</td><td>string</td><td>The URI or the ID of an existing product</td></tr> </table>  <h2 class='errorType' id=\"err-malformedProductType\">malformedProductType</h2>  Description: The supplied productType was malformed.  Remediation: Check to make sure that the supplied productType corresponds to an apiture productType resource.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>productType</td><td>string</td><td>The invalid product type URI.</td></tr> </table>  <h2 class='errorType' id=\"err-malformedRequestBody\">malformedRequestBody</h2>  Description: The supplied request body was malformed.  Remediation: Check to make sure that your request body exists and that it does not contain syntax errors.   <h2 class='errorType' id=\"err-malformedCreateProductBody\">malformedCreateProductBody</h2>  Description: The supplied request body to create a product did not contain a description or label.  Remediation: Resubmit the request with a description and label in the body.   <h2 class='errorType' id=\"err-canOnlyLockUnlockActive\">canOnlyLockUnlockActive</h2>  Description: You can only lock or unlock a product if its state is `active`.  Remediation: Activate the product and resubmit the operation.   <h2 class='errorType' id=\"err-invalidProductState\">invalidProductState</h2>  Description: The supplied product state is invalid.  Remediation: Resubmit the operation, supplying a valid product state.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>validStates</td><td>array</td><td>The required states for this operation</td></tr> </table>  <h2 class='errorType' id=\"err-invalidAccountAvailability\">invalidAccountAvailability</h2>  Description: The product new account availability is not valid.  Remediation: Resubmit the operation and supply a valid product new account availability value.   <h2 class='errorType' id=\"err-invalidTransactionTypes\">invalidTransactionTypes</h2>  Description: The given transaction type is not valid.  Remediation: Resubmit the operation and supply a valid transaction type.   <h2 class='errorType' id=\"err-invalidConstraintMaxFundingAmount\">invalidConstraintMaxFundingAmount</h2>  Description: The given maximumFundingAmount value is not valid.  Remediation: Check to make sure the maximumFundingAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMaxTransferAmount\">invalidConstraintMaxTransferAmount</h2>  Description: The given maximumTransferAmount value is not valid.  Remediation: Check to make sure the maximumTransferAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinBalance\">invalidConstraintMinBalance</h2>  Description: The given minimumBalance value is not valid.  Remediation: Check to make sure the minimumBalance is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinFundingAmount\">invalidConstraintMinFundingAmount</h2>  Description: The given minimumFundingAmount value is not valid.  Remediation: Check to make sure the minimumFundingAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintMinTransferAmount\">invalidConstraintMinTransferAmount</h2>  Description: The given minimumTransferAmount value is not valid.  Remediation: Check to make sure the minimumTransferAmount is a valid numerical value. Also make sure the value is greater than minimum value and the value is greater than 0.   <h2 class='errorType' id=\"err-invalidConstraintItemAmount\">invalidConstraintItemAmount</h2>  Description: The given fees item amount value is not valid.  Remediation: Check to make sure the fees item amount is a valid numerical value. Also make sure the value is greater than 0.   <h2 class='errorType' id=\"err-invalidProductLinkToSubType\">invalidProductLinkToSubType</h2>  Description: A link to apiture:productSubtype is missing or is invalid.  Remediation: Check to make sure the product has a valid subtype or that the subtype exists.   <h2 class='errorType' id=\"err-invalidRateValues\">invalidRateValues</h2>  Description: The rate object contains invalid values.  Remediation: Check the values of the rate object and resubmit.   <h2 class='errorType' id=\"err-invalidFeesType\">invalidFeesType</h2>  Description: The fee must be an array.  Remediation: Check the type of the fee field and resubmit.   <h2 class='errorType' id=\"err-cannotPatchProductFields\">cannotPatchProductFields</h2>  Description: A products _id and newAccountAvailability cannot be patched.  Remediation: Remove the _id and newAccountAvailability from the request body and try again.   <h2 class='errorType' id=\"err-activateProductInvalidState\">activateProductInvalidState</h2>  Description: Products may only be activated if they are in an inactive or pending state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-removeProductInvalidState\">removeProductInvalidState</h2>  Description: Products may only be removed if they are in an inactive or active state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-deactivateProductInvalidState\">deactivateProductInvalidState</h2>  Description: Products may only be deactivated if they are in a pending or active state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-deleteProductInvalidState\">deleteProductInvalidState</h2>  Description: Products may only be deleted if they are in a pending state.  Remediation: Check the state of your Product and the applicable allowed state transitions in the Products API documentation.   <h2 class='errorType' id=\"err-cannotChangeRateType\">cannotChangeRateType</h2>  Description: The products rate type may not be changed once created.  Remediation: Remove the product and recreate it with the desired rate type or create a new product.   <h2 class='errorType' id=\"err-productStateCannotBeAltered\">productStateCannotBeAltered</h2>  Description: A products state cannot be altered using the PATCH operation.  Remediation: Check the API documentation for the /activeProducts, /inactiveProducts, /removedProducts, /lockedProducts, and /unlockedProducts endpoints.   <h2 class='errorType' id=\"err-productNameInUse\">productNameInUse</h2>  Description: The given product name is currently in use, and cannot be reused.  Remediation: Delete the product with the specified name, or use a different name.   <h2 class='errorType' id=\"err-productCodeInUse\">productCodeInUse</h2>  Description: The given product code is currently in use, and cannot be reused.  Remediation: Delete the product with the specified code, or use a different code.   <h2 class='errorType' id=\"err-activateProductSubTypeInvalidState\">activateProductSubTypeInvalidState</h2>  Description: The state of the resource may not be changed to active or inactive when the product type or subtype is still `pending`.  Remediation: Check the state of your product type and subtype and ensure it is not pending.   <h2 class='errorType' id=\"err-productTypeDoesNotExist\">productTypeDoesNotExist</h2>  Description: The given product type does not exist.  Remediation: Verify that the product type exists for the subtype or parent type and resubmit.   <h2 class='errorType' id=\"err-deleteProductTypeInvalidState\">deleteProductTypeInvalidState</h2>  Description: A product type may not be deleted if the state is anything other than pending, or if the type is used by a pending product.  Remediation: Check the state of the productType and ensure it is not pending. Also ensure that any products using the productType are not pending.   <h2 class='errorType' id=\"err-removeProductTypeInvalidState\">removeProductTypeInvalidState</h2>  Description: A product type may not be updated if the state is removed.  Remediation: Check the state of the productType and ensure it not removed.   <h2 class='errorType' id=\"err-updateProductTypeInvalidState\">updateProductTypeInvalidState</h2>  Description: A product type may not be removed if the state is anything other than inactive.  Remediation: Check the state of the productType and ensure it is inactive.   <h2 class='errorType' id=\"err-cannotChangeRemovedProductTypeState\">cannotChangeRemovedProductTypeState</h2>  Description: The state of a removed productType may not be changed.  Remediation: Check the state of the productType and ensure it is not removed.   <h2 class='errorType' id=\"err-cannotUpdateProductTypeState\">cannotUpdateProductTypeState</h2>  Description: The state of a productType cannot be changed using a PUT method.  Remediation: Check the API documentation for the /activeProductTypes, /inactiveProductTypes, and /removedProductTypes endpoints.   <h2 class='errorType' id=\"err-invalidQueryParameterCombination\">invalidQueryParameterCombination</h2>  Description: Do not use mutually exclusive query parameters.  Remediation: Use one or the other, but not both.  The `attributes` object in the error may have the following properties: <table class=\"table\"> <tr><th>Property</th><th>Type</th><th>Description</th></tr> <tr><td>type</td><td>undefined</td><td>undefined</td></tr> <tr><td>mutuallyExclusiveQueryParameters</td><td>array</td><td>undefined<br>Example: `state,openable`</td></tr> </table>
 *
 * OpenAPI spec version: 0.16.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/products'.replace(/\/+$/, '');

export const API_VERSION = '0.16.1';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Indicates how interest is accrued according to the `compoundPeriod`.  <strong><code>accrualType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named accrualType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `accrualType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>compounding</code></strong></td><td>Compounding interest</td>     </tr> <tr>     <td><strong><code>simple</code></strong></td><td>Simple interest</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum AccrualType {
  Compounding = 'compounding',
  Simple = 'simple',
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Configuration for whether the financial institution automatically orders new debit cards for primary applicants or other account holders. New cards are not ordered during user/account migration.  This schema is version `v1.0.0`.
 * @export
 * @interface AutoOrderCards
 */
export interface AutoOrderCards {
  /**
   * If `true`, the financial institution will automatically order a debit card for the primary applicant after opening a new account associated with this product via the digital account opening process.
   * @type {boolean}
   * @memberof AutoOrderCards
   */
  forDigitalAccountOpening?: boolean;
  /**
   * If `true`, the financial institution will automatically order a debit card for new joint owners when they become an account holder on a personal account associated with this product.
   * @type {boolean}
   * @memberof AutoOrderCards
   */
  forJointOwners?: boolean;
  /**
   * If `true`, the financial institution will automatically order a debit card for the organization's existing authorized signers or when a new authorized signer becomes an account holder on accounts associated with this product. If both `forDigitalAccountOpening` and `forAuthorizedSigners` are true, the applicant receives only one card even though they may be listed in the organization's authorized signers.
   * @type {boolean}
   * @memberof AutoOrderCards
   */
  forAuthorizedSigners?: boolean;
}

/**
 * Details of a debug card image for this product. The `height` and `width` are optional but should be provided if the `card.images` object contains more than one image, so that clients can choose the most appropriate image size. The image may have portrait or landscape orientation, but the maximum aspect ratio is 2:1 ([IEC 7810](https://en.wikipedia.org/wiki/ISO/IEC_7810#ID-1) is 85.60:53.98, approximately 1.6:1).  This schema is version `v1.0.0`.
 * @export
 * @interface CardImage
 */
export interface CardImage {
  /**
   * The image height, in pixels.
   * @type {number}
   * @memberof CardImage
   */
  height?: number;
  /**
   * The image width, in pixels.
   * @type {number}
   * @memberof CardImage
   */
  width?: number;
  /**
   * The image URI which a client can fetch in order to render the sample card image in the client. This resource does not require authentication.
   * @type {string}
   * @memberof CardImage
   */
  uri: string;
}

/**
 * Details of the debit card processor/provider.  This schema is version `v1.0.0`.
 * @export
 * @interface CardProvider
 */
export interface CardProvider {
  /**
   * The unique identifier for this product within the card provider's environment.
   * @type {string}
   * @memberof CardProvider
   */
  id: string;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Product constraints, such as minimum and maximum balances.  This schema is version `v1.0.0`.
 * @export
 * @interface Constraints
 */
export interface Constraints {
  /**
   * The types of transactions permitted for this account. Values which appear in this array are permitted.
   * @type {TransactionTypes}
   * @memberof Constraints
   */
  transactionTypes?: TransactionTypes;
  /**
   * The minimum balance for accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumBalance?: string;
  /**
   * The minimum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumFundingAmount?: string;
  /**
   * The maximum monetary value when funding a new account of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumFundingAmount?: string;
  /**
   * The minimum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  minimumTransferAmount?: string;
  /**
   * The maximum monetary value for new transfers from accounts of this product. The numeric value is represented as a string so that it can be exact with no loss of precision. This balance is in the `currency` for the product.
   * @type {string}
   * @memberof Constraints
   */
  maximumTransferAmount?: string;
  /**
   * The maximum number of withdrawals allowed per cycle. If not present, there is no hard limit.
   * @type {number}
   * @memberof Constraints
   */
  maximumWithdrawalCount?: number;
  /**
   * The time limit within which account opening funding must occur after account creation. This is expressed as an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  fundingTerm?: string;
  /**
   * If true, deposits are not allowed after the rollover grace period (see `gracePeriod`). This applies to time deposit products only.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterGracePeriod?: boolean;
  /**
   * If true, deposits are not allowed after the initial account funding has completed. This typically applies to time deposit products.
   * @type {boolean}
   * @memberof Constraints
   */
  depositsRestrictedAfterFunding?: boolean;
  /**
   * A period of time after account rollover when additional deposits are allowed. This is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration;  only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof Constraints
   */
  gracePeriod?: string;
}

/**
 * Representation used to create a new product. The request *must* include links in the `_links` object which refer to the product subtype. (The product's type will be the parent type of the named subtype).   * *`apiture:productSubtype`* A link to the product subtype resource for this product  This schema is version `v1.1.0`.
 * @export
 * @interface CreateProduct
 */
export interface CreateProduct extends AbstractResource, ProductFields, ProductDetails {
  /**
   * Debit card details associated with this product.
   * @type {ProductCard}
   * @memberof CreateProduct
   */
  card?: ProductCard;
  /**
   * An optional map of name/value pairs which provide additional metadata about the product.
   * @type {any}
   * @memberof CreateProduct
   */
  attributes?: any;
}

/**
 * Representation used to create a new product type. To create a `subtype`, the request may include a link in the `_links` object which refers to the parent product type.  This schema is version `v1.0.0`.
 * @export
 * @interface CreateProductType
 */
export interface CreateProductType extends AbstractResource, ProductTypeFields {
  /**
   * An optional map of name/value pairs which provide additional metadata about the product type.
   * @type {any}
   * @memberof CreateProductType
   */
  attributes?: any;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * Indicates if the bank customer can request expedited shipping for cards associated with the accounts for this product.  This schema is version `v1.0.0`.
 * @export
 * @interface ExpeditedShippingAllowed
 */
export interface ExpeditedShippingAllowed {
  /**
   * If `true`, expedited shipping is allowed for _new_ cards.
   * @type {boolean}
   * @memberof ExpeditedShippingAllowed
   */
  forNew?: boolean;
  /**
   * If `true`, expedited shipping is allowed for _replacement_ cards (reorders).
   * @type {boolean}
   * @memberof ExpeditedShippingAllowed
   */
  forReplacements?: boolean;
}

/**
 * Fees that are attached to accounts of this product.  This schema is version `v1.0.0`.
 * @export
 * @interface Fee
 */
export interface Fee {
  /**
   * The fee type.
   * @type {ProductFeeType}
   * @memberof Fee
   */
  type?: ProductFeeType;
  /**
   * The period at which the fee is assessed. If omitted, the fee is assessed per transaction. <p> This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the fee period in the number of years/months/weeks/days. For example, the values `P1d`, `P1W`, `P2W`, `P1M`, `P0.25Y`, `P0.5Y`, `P1Y` indicate a term of daily, weekly, by-weekly, monthly, quarterly, biannually, and annually, respectively, (although other periods may be allowed).
   * @type {string}
   * @memberof Fee
   */
  period?: string;
  /**
   * A description of the fee and its structure and period.
   * @type {string}
   * @memberof Fee
   */
  description?: string;
  /**
   * The fee structure for this fee
   * @type {FeeStructure}
   * @memberof Fee
   */
  structure?: FeeStructure;
  /**
   * The amount of the (fixed) fee, in the product's `currency`.
   * @type {string}
   * @memberof Fee
   */
  amount?: string;
}

/**
 * The fee structure. fixed fee, variable fee, or other. For example, the `service` fee or `atm` may be `fixed` (such as `\"amount\" : \"2.00\"`) but the `foreignTransactions` fee may be `variable`.  <strong><code>feeStructure</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named feeStructure)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `feeStructure` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>unknown</code></strong></td><td>Undetermined fee structure</td>     </tr> <tr>     <td><strong><code>variable</code></strong></td><td>A variable rate fee</td>     </tr> <tr>     <td><strong><code>fixed</code></strong></td><td>A fixed rate fee</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum FeeStructure {
  Unknown = 'unknown',
  Variable = 'variable',
  Fixed = 'fixed',
}

/**
 * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values. Labels and descriptions for the enumeration values are in the `ifxType` key in the response of the `getLabels` operation.  <strong><code>ifxType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named ifxType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `ifxType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>CCA</code></strong></td><td>Credit card account</td>     </tr> <tr>     <td><strong><code>CDA</code></strong></td><td>Certificate of deposit account (CD)</td>     </tr> <tr>     <td><strong><code>CLA</code></strong></td><td>Commercial loan account</td>     </tr> <tr>     <td><strong><code>CMA</code></strong></td><td>Cash management account</td>     </tr> <tr>     <td><strong><code>DDA</code></strong></td><td>Demand deposit account</td>     </tr> <tr>     <td><strong><code>EQU</code></strong></td><td>Home equity loan</td>     </tr> <tr>     <td><strong><code>GLA</code></strong></td><td>General ledger account</td>     </tr> <tr>     <td><strong><code>ILA</code></strong></td><td>Installment loan account</td>     </tr> <tr>     <td><strong><code>INV</code></strong></td><td>Investment account</td>     </tr> <tr>     <td><strong><code>IRA</code></strong></td><td>Individual retirement account</td>     </tr> <tr>     <td><strong><code>IRL</code></strong></td><td>Accounts held in Ireland</td>     </tr> <tr>     <td><strong><code>LOC</code></strong></td><td>Consumer line of credit</td>     </tr> <tr>     <td><strong><code>MLA</code></strong></td><td>Military Lending Account: Credit facility held by former US service member</td>     </tr> <tr>     <td><strong><code>MMA</code></strong></td><td>Money market account</td>     </tr> <tr>     <td><strong><code>PBA</code></strong></td><td>Packaged bank Account: Account with additional benefits that charges a fixed monthly fee.</td>     </tr> <tr>     <td><strong><code>PPA</code></strong></td><td>Private pension administrator</td>     </tr> <tr>     <td><strong><code>RWD</code></strong></td><td>Reward accounts</td>     </tr> <tr>     <td><strong><code>SDA</code></strong></td><td>Savings deposit account</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum IfxType {
  CCA = 'CCA',
  CDA = 'CDA',
  CLA = 'CLA',
  CMA = 'CMA',
  DDA = 'DDA',
  EQU = 'EQU',
  GLA = 'GLA',
  ILA = 'ILA',
  INV = 'INV',
  IRA = 'IRA',
  IRL = 'IRL',
  LOC = 'LOC',
  MLA = 'MLA',
  MMA = 'MMA',
  PBA = 'PBA',
  PPA = 'PPA',
  RWD = 'RWD',
  SDA = 'SDA',
}

/**
 * The rate type. The rate type may not be changed once it is set at product creation. Rate types are:   * *`apr`* - annual percentage rate   * *`apy`* - annual percentage yield  This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum InterestRateType {
  Apr = 'apr',
  Apy = 'apy',
}

/**
 * A map that defines labels for the items in a group. This is a map from each item *name* &rarr; *a [`labelItem`](#schema-labelitem) object*. For example, consider a JSON response that includes a property named `revenueEstimate`; the values for `revenueEstimate` must be one of the items in the group named `estimatedAnnualRevenue`, with options ranging `under1Million`, to `over100Million`. The item name is used as the selected value in an Apiture representation, such as `{ ..., \"revenueEstimate\" : \"from10to100Million\" , ...}`, and the item with the name `from10to100Million` defines the presentation labels for that item, as well as other metadata about that choice: this is the range `[10000000.00,100000000.00)`.  This allows the client to let the user select a value from a list, such as the following derivde from the labels in the example:    * Unknown   * Under $1M   * $1M to $10M   * $10M to $100M   * $100M or more  Note that the `other` item is hidden from the selection list, as that item is marked as `hidden`. For items which define numeric ranges, a client may instead let the customer *directly* enter their estimated annual revenue as a number, such as 4,500,000.00. The client can then match that number to one of ranges in the items and set the `revenueEstimate` to the corresponding item's name: `{ ..., \"revenueEstimate\" : \"from1to10Million\", ... }`.
 * @export
 * @interface LabelGroup
 */
export interface LabelGroup {
  [key: string]: LabelItem;
}

/**
 * A set of named groups of labels, each of which contains multiple item labels.   The abbreviated example shows two groups, one named `structure` and one named `estimatedAnnualRevenue`. The first has items with names such as `corporation`, `llc` and `soleProprietorship`, with text labels for each in the default and in French. The second has items for estimated revenue *ranges* but no localized labels. For example, the item named `from1to10Million` has the `label` \"$1M to $10M\" and the range `[1000000.00,10000000.00)`.
 * @export
 * @interface LabelGroups
 */
export interface LabelGroups extends AbstractResource {
  /**
   * Groups of localized labels. This maps *group names* &rarr; [*a group of labels*](#schema-labelgroup) within that group.
   * @type {any}
   * @memberof LabelGroups
   */
  groups?: any;
}

/**
 * An item in a [`labelGroup`](#schema-labelgroup), with a set of `variants` which contains different localized labels for the item. Each ([`simpleLabel`](#schema-simpleLabel)) variant defines the presentation text label and optional description for a language. Items may also have a lookup `code` to map to external syststems, a numeric range, and a `hidden` boolean to indicate the item is normally hidden in the UI.
 * @export
 * @interface LabelItem
 */
export interface LabelItem extends SimpleLabel {
  /**
   * The language-specific variants of this label. The keys in this object are [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1) language codes.
   * @type {{ [key: string]: SimpleLabel; }}
   * @memberof LabelItem
   */
  variants?: { [key: string]: SimpleLabel };
  /**
   * If the localized value is associated with an external standard or definition, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LabelItem
   */
  code?: string;
  /**
   * If `true`, this item is normally hidden from the User Interface.
   * @type {boolean}
   * @memberof LabelItem
   */
  hidden?: boolean;
  /**
   * The range of values, if the item describes a bounded numeric value. This is range notation such as `[min,max]`, `(exclusiveMin,max]`, `[min,exclusiveMax)`, or `(exclusiveMin,exclusiveMax)`. For example, `[0,100)` is the range greater than or equal to 0 and less than 100. If the *min* or *max* value are omitted, that end of the range is unbounded. For example, `(,1000.00)` means less than 1000.00 and `[20000.00,]` means 20000.00 or more. The ranges do not overlap or have gaps.
   * @type {string}
   * @memberof LabelItem
   */
  range?: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Indicates how the principal and interest are processed upon maturity. The values indicate whether to rollover (to a time deposit account of the same rate and term), transfer funds to another (possibly new) deposit account, or simply hold the funds in the current account (which may no longer accrue interest). Labels and descriptions for the enumeration values are in the `maturityPolicy` key in the response of the `getLabels` operation.  <strong><code>maturityPolicy</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named maturityPolicy)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `maturityPolicy` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>rolloverPrincipalAndInterest</code></strong></td><td>Rollover principal and interest to a new CD of the same product: Upon maturity, both principal and interest rollover into a specified banking product, such as a savings, checking, or other deposit account.</td>     </tr> <tr>     <td><strong><code>transferPrincipalAndInterest</code></strong></td><td>Transfer principal and interest to a deposit account: Upon maturity, the principal an interest are both transferred to an existing or new deposit account.</td>     </tr> <tr>     <td><strong><code>rolloverPrincipalAndTransferInterest</code></strong></td><td>Transfer interest to a new deposit account an rollover principal to a new CD of the same product: Upon maturity, the principal rolls over into a specified banking product and the interest is transferred to an existing deposit account.</td>     </tr> <tr>     <td><strong><code>holdPrincipalAndInterest</code></strong></td><td>Hold principal and accued interest in the CD account until withdrawal: Upon maturity, the principal and interest are held in the current time deposit account. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> <tr>     <td><strong><code>partialTransfer</code></strong></td><td>Partial Transfer: Upon maturity, any funds greater than the maturity threshold is transfered to an existing deposit account and the rest remains on deposit. The account may or may not accrue further interest, depending on the terms of the time deposit product. Funds may be withdrawn or transferred.</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum MaturityPolicy {
  RolloverPrincipalAndInterest = 'rolloverPrincipalAndInterest',
  TransferPrincipalAndInterest = 'transferPrincipalAndInterest',
  RolloverPrincipalAndTransferInterest = 'rolloverPrincipalAndTransferInterest',
  HoldPrincipalAndInterest = 'holdPrincipalAndInterest',
  PartialTransfer = 'partialTransfer',
}

/**
 * Describes if the product is available for opening new accounts.  <strong><code>newAccountAvailability</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named newAccountAvailability)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `newAccountAvailability` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>available</code></strong></td><td>Users may open new accounts of this type</td>     </tr> <tr>     <td><strong><code>notAvailable</code></strong></td><td>Users may not open new accounts of this type</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum NewAccountAvailability {
  Available = 'available',
  NotAvailable = 'notAvailable',
}

/**
 * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.  <strong><code>prodState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named prodState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `prodState` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>pending</code></strong></td><td>This product has been created in draft form but is not yet available</td>     </tr> <tr>     <td><strong><code>active</code></strong></td><td>This product is active and available for use</td>     </tr> <tr>     <td><strong><code>inactive</code></strong></td><td>This product is temporarily not available for use</td>     </tr> <tr>     <td><strong><code>removed</code></strong></td><td>This product has been removed and is permanently not available for use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProdState {
  Pending = 'pending',
  Active = 'active',
  Inactive = 'inactive',
  Removed = 'removed',
}

/**
 * Representation of product resources. The `_links` in a product may contain the following (which may be passed when creating a product via the `POST /products` operation or in `PATCH` operations to this product instance): The representation contains the product type and subtype in the `_embedded` objects.  This schema is version `v1.1.0`.   <h3 class='schema-links' id=\"product-links\" >Links</h3>  Response and request bodies using this <strong><code>product</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-getProduct'><strong><code>self</code></strong></a></td><td>Fetch a representation of this product</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProductType'><strong><code>apiture:productType</code></strong></a></td><td>Fetch a representation of this product type.</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProductType'><strong><code>apiture:productSubtype</code></strong></a></td><td>Fetch a representation of this product type.</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-activateProduct'><strong><code>apiture:activate</code></strong></a></td><td>Activate a product</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-deactivateProduct'><strong><code>apiture:deactivate</code></strong></a></td><td>Deactivate a product</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-removeProduct'><strong><code>apiture:remove</code></strong></a></td><td>Remove a product</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-lockProduct'><strong><code>apiture:lock</code></strong></a></td><td>Marks an active product as ineligible for new account opening</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-unlockProduct'><strong><code>apiture:unlock</code></strong></a></td><td>Marks an active product as eligible for new account opening</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-getProduct'><strong><code>prev</code></strong></a></td><td>Fetch a representation of this product</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProduct'><strong><code>next</code></strong></a></td><td>Fetch a representation of this product</td><td><code>GET</code></td> </tr> </table>
 * @export
 * @interface Product
 */
export interface Product extends SummaryProduct, ProductDetails {
  /**
   * The unique identifier for this product resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Product
   */
  _id?: string;
  /**
   * An optional map of name/value pairs which provide additional metadata about the product type.
   * @type {any}
   * @memberof Product
   */
  attributes?: any;
  /**
   * An optional map of nested resources,  mapping each nested resource name to a nested resource representation. A product contains summary representation of the product type and subtype.
   * @type {any}
   * @memberof Product
   */
  _embedded?: any;
  /**
   * The date-time when this product was created. This value is derived and immutable.
   * @type {Date}
   * @memberof Product
   */
  createdAt?: Date;
  /**
   * Debit card details associated with this product.
   * @type {ProductCard}
   * @memberof Product
   */
  card?: ProductCard;
}

/**
 * Debit card details associated with this product.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductCard
 */
export interface ProductCard {
  /**
   * Details of the card provider.
   * @type {CardProvider}
   * @memberof ProductCard
   */
  provider: CardProvider;
  /**
   * Image (JPEG or PNG) of a sample blank debit card for this product.
   * @type {Array<CardImage>}
   * @memberof ProductCard
   */
  images: Array<CardImage>;
  /**
   * After a card is issued, it must be activated before this many days before the card activation expires.
   * @type {number}
   * @memberof ProductCard
   */
  activationExpiration: number;
  /**
   * Indicates if the bank customer can request expedited shipping for cards associated with the accounts for this product.
   * @type {ExpeditedShippingAllowed}
   * @memberof ProductCard
   */
  expeditedShippingAllowed?: ExpeditedShippingAllowed;
  /**
   * Whether the financial institution will automatically order new debit cards for bank customers.
   * @type {AutoOrderCards}
   * @memberof ProductCard
   */
  autoOrder?: AutoOrderCards;
}

/**
 * Additional fields for a product which are not in the summary representation.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductDetails
 */
export interface ProductDetails {
  /**
   * The name of the financial institution
   * @type {string}
   * @memberof ProductDetails
   */
  institutionName?: string;
  /**
   * Identifies the underlying bank core system.
   * @type {string}
   * @memberof ProductDetails
   */
  coreType?: string;
  /**
   * `true` if this product is enabled and eligible for online banking.
   * @type {boolean}
   * @memberof ProductDetails
   */
  onlineBankingEnabled?: boolean;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this product.
   * @type {string}
   * @memberof ProductDetails
   */
  currency?: string;
  /**
   * Zero or more fees for accounts of this product. If the array is empty or not present, there are no fees.
   * @type {Array<Fee>}
   * @memberof ProductDetails
   */
  fees?: Array<Fee>;
  /**
   * The frequency with which statememts are issued for accounts of this product. This is expressed as an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) duration; only day and month periods are allowed, and the only allowed fractional value for months is 0.5, as in `P5D` or `P14D` or `P1M` or `P0.5M`.
   * @type {string}
   * @memberof ProductDetails
   */
  statementFrequency?: string;
  /**
   *
   * @type {TimeDeposit}
   * @memberof ProductDetails
   */
  timeDeposit?: TimeDeposit;
}

/**
 * A type identifier which indicates what type of fee exists for a banking product.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `productFeeType` group in the response from the [`getLabels`](#op-getLabels) operation.  This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProductFeeType {
  Servicing = 'servicing',
  MinimumBalance = 'minimumBalance',
  Overdraft = 'overdraft',
  ReturnedCheck = 'returnedCheck',
  StatementHardCopy = 'statementHardCopy',
  Atm = 'atm',
  ForeignTransaction = 'foreignTransaction',
  EarlyClosing = 'earlyClosing',
  EarlyWithdrawal = 'earlyWithdrawal',
  Other = 'other',
}

/**
 * Common fields of the product resource.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductFields
 */
export interface ProductFields extends ProductState {
  /**
   * The name of this product.
   * @type {string}
   * @memberof ProductFields
   */
  name?: string;
  /**
   * The text label for this product. This field may be localized.
   * @type {string}
   * @memberof ProductFields
   */
  label?: string;
  /**
   * A fuller description of this product. This field may be localized. The content is processed as  [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof ProductFields
   */
  description?: string;
  /**
   * The unique product code for this product, normally defined by the underlying banking core. The `code` cannot be changed once the `state` is beyond `pending`.
   * @type {string}
   * @memberof ProductFields
   */
  code?: string;
  /**
   * Indicates if the product is available for opening new accounts.   * *`available`* means the product may be selected for a new account application.   * *`notAvailable`* means the product may *not* be selected for a new account application. The default is `available`. Note that clients must check both the product `state` and the `newAccountAvailability` when listing products for new account opening. The `?openable=true` query parameter on `/accounts` combines these. Labels and descriptions for the enumeration values are in the `newAccountAvailability` key in the response of the `getLabels` operation.
   * @type {NewAccountAvailability}
   * @memberof ProductFields
   */
  newAccountAvailability?: NewAccountAvailability;
  /**
   * The product category name. This is a more readable form of the product's `type`.
   * @type {string}
   * @memberof ProductFields
   */
  category?: string;
  /**
   * The interest rate for this product.
   * @type {Rate}
   * @memberof ProductFields
   */
  rate?: Rate;
  /**
   * The revision string for this product. This property derived and immutable.
   * @type {string}
   * @memberof ProductFields
   */
  revision?: string;
  /**
   * The product IFX Account Type.
   * @type {IfxType}
   * @memberof ProductFields
   */
  ifxType?: IfxType;
  /**
   * Describes the target audience or consumer of the accounts, `personal` or `business`. Labels and descriptions for the enumeration values are in the `productTarget` key in the response of the `getLabels` operation.
   * @type {ProductTarget}
   * @memberof ProductFields
   */
  target?: ProductTarget;
}

/**
 * The state of a product or type.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductState
 */
export interface ProductState {
  /**
   * The state of this product or product type. New resources are `pending` by default and must be activated before they may be used.  The `state` property is immutable and derived and may not be changed via the `PUT` or `PATCH` operations. To change the state of a product or product type, use the `POST` operation using the `apiture:activate`, `apiture:deactivate` or `apiture:remove` links on the resource.
   * @type {ProdState}
   * @memberof ProductState
   */
  state?: ProdState;
}

/**
 * The target audience for this product.  <strong><code>productTarget</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named productTarget)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `productTarget` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>personal</code></strong></td><td>Banking products for personal use</td>     </tr> <tr>     <td><strong><code>business</code></strong></td><td>Banking products for business use</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum ProductTarget {
  Personal = 'personal',
  Business = 'business',
}

/**
 * Representation of a product type resource. If the type is a subtype, the `_embedded` resource contains the parent type.   <h3 class='schema-links' id=\"productType-links\" >Links</h3>  Response and request bodies using this <strong><code>productType</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-getProductType'><strong><code>self</code></strong></a></td><td>Fetch a representation of this product type.</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProductType'><strong><code>apiture:parent</code></strong></a></td><td>Fetch a representation of this product type.</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProductTypes'><strong><code>apiture:children</code></strong></a></td><td>Return a collection of product types</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-getProducts'><strong><code>apiture:products</code></strong></a></td><td>Return a collection of products</td><td><code>GET</code></td> </tr>  <tr> <td><a href='#op-activateProductType'><strong><code>apiture:activate</code></strong></a></td><td>Activate a product type</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-deactivateProductType'><strong><code>apiture:deactivate</code></strong></a></td><td>Deactivate a product type</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-removeProductType'><strong><code>apiture:remove</code></strong></a></td><td>Remove a product type</td><td><code>POST</code></td> </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @interface ProductType
 */
export interface ProductType extends SummaryProductType {
  /**
   * `0` if this type does not have subtypes; otherwise this holds the indicated number of direct subtypes.  This is a derived, immutable property. See also the *`apiture:children`* link on the `productSubtype` schema.
   * @type {number}
   * @memberof ProductType
   */
  subtypeCount?: number;
  /**
   * The date-time when this product type was created. This value is derived and immutable.
   * @type {Date}
   * @memberof ProductType
   */
  createdAt?: Date;
  /**
   * Embedded resources for this product type. This may contain the parent type, if any. _embedded may not appear if there are no embedded resources.
   * @type {any}
   * @memberof ProductType
   */
  _embedded?: any;
  /**
   * An optional map of name/value pairs which provide additional metadata about the product type.
   * @type {any}
   * @memberof ProductType
   */
  attributes?: any;
}

/**
 * Common fields of the product type resource.  This schema is version `v1.0.0`.
 * @export
 * @interface ProductTypeFields
 */
export interface ProductTypeFields extends ProductState {
  /**
   * The name of this product type.
   * @type {string}
   * @memberof ProductTypeFields
   */
  name?: string;
  /**
   * The text label for this product type. This field may be localized.
   * @type {string}
   * @memberof ProductTypeFields
   */
  label?: string;
  /**
   * A fuller description of this product type. This field may be localized.  The content is processed as  [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof ProductTypeFields
   */
  description?: string;
  /**
   * Indicates if this is a subtype. This is a derived, immutable property, based on whether the product type was created with a link to a parent type. See also the *`apiture:parent`* link on the `productSubtype` schema.
   * @type {boolean}
   * @memberof ProductTypeFields
   */
  subtype?: boolean;
}

/**
 * Collection of product types. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).  This schema is version `v1.0.0`.
 * @export
 * @interface ProductTypes
 */
export interface ProductTypes extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ProductTypes
   */
  _embedded?: any;
}

/**
 * Collection of products. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).  This schema is version `v1.0.0`.
 * @export
 * @interface Products
 */
export interface Products extends Collection {
  /**
   * Embedded objects
   * @type {any}
   * @memberof Products
   */
  _embedded?: any;
}

/**
 * The interest rate of the account. For deposit accounts, this is the rate of return; for loan accounts, this is the interest rate charged on balances. Rates can be absolute, such as \"1.40\" to indicate 1.4%, which is expressed as  `{ \"value\" : \"1.40\" }`, or relative to a benchmark, such as U.S. Prime Rate + 0.5% which is expressed as `{ \"benchmark\" : \"prime\", \"value\" : \"0.50\" }`.  This schema is version `v1.0.0`.
 * @export
 * @interface Rate
 */
export interface Rate {
  /**
   * The rate, expressed as an decimal percentage string in order to represent the rate exactly. This number must have 2 to four decimal points, i.e. '2.00' or '0.50' or '1.015', but not `2` or `.5`. (Regular expression pattern: `-?\\d{1,3}+\\.\\d{2,4}`)
   * @type {string}
   * @memberof Rate
   */
  value?: string;
  /**
   * An optional base benchmark that the rate is relative to. If omitted, the rate is fixed. Otherwise the rate is added to the benchmark rate. Values may be (but are not limited to):  * *`primeUS`* - the [U.S. Prime rate](https://en.wikipedia.org/wiki/Prime_rate)  * *`treasuryUS`* - The [U.S. Treasury rate](https://www.treasury.gov/resource-center/data-chart-center/interest-rates/Pages/TextView.aspx?data=yieldAll)  * *`libor`* - the [London Inter-bank Offered Rates](https://en.wikipedia.org/wiki/Libor) rate
   * @type {string}
   * @memberof Rate
   */
  benchmark?: string;
  /**
   * The period at which interest compounds.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. The default is `\"P0D\"` (continuous).
   * @type {string}
   * @memberof Rate
   */
  compoundPeriod?: string;
  /**
   * Indicates how interest is accrued according to the `compoundPeriod`.
   * @type {AccrualType}
   * @memberof Rate
   */
  accrualType?: AccrualType;
  /**
   * The period at which the rate is adjusted or recomputed to account for differences in the benchmark rate.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days; The default is `\"P1D\"` (daily).
   * @type {string}
   * @memberof Rate
   */
  adjustmentPeriod?: string;
  /**
   * The interest rate type.
   * @type {InterestRateType}
   * @memberof Rate
   */
  type?: InterestRateType;
}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * A text label and optional description.
 * @export
 * @interface SimpleLabel
 */
export interface SimpleLabel {
  /**
   * A label or title which may be used as labels or other UI controls which present a value.
   * @type {string}
   * @memberof SimpleLabel
   */
  label: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof SimpleLabel
   */
  description?: string;
}

/**
 * Summary representation of a product resource in products collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. This representation omits the `attributes` of the full representation.  This schema is version `v1.0.0`.
 * @export
 * @interface SummaryProduct
 */
export interface SummaryProduct extends AbstractResource, ProductFields, RevisionEffectiveInterval {
  /**
   * The unique identifier for this product resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryProduct
   */
  _id?: string;
  /**
   * The product type name, which is derived from the linked product type.
   * @type {string}
   * @memberof SummaryProduct
   */
  type?: string;
  /**
   * The product subtype name, which is derived from the linked product subtype. This is a derived, immutable property.
   * @type {string}
   * @memberof SummaryProduct
   */
  subtype?: string;
  /**
   *
   * @type {TimeDeposit}
   * @memberof SummaryProduct
   */
  timeDeposit?: TimeDeposit;
  /**
   *
   * @type {Constraints}
   * @memberof SummaryProduct
   */
  constraints?: Constraints;
}

/**
 * Summary representation of a product type resource in product types collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. This representation omits the `attributes` of the full representation.  This schema is version `v1.0.0`.
 * @export
 * @interface SummaryProductType
 */
export interface SummaryProductType extends ProductTypeFields, AbstractResource {
  /**
   * The unique identifier for this product type resource. This is an opaque string.
   * @type {string}
   * @memberof SummaryProductType
   */
  _id?: string;
}

/**
 * Properties of time deposit products, primarily Certificate of Deposit products.  This schema is version `v1.0.0`.
 * @export
 * @interface TimeDeposit
 */
export interface TimeDeposit {
  /**
   *
   * @type {MaturityPolicy}
   * @memberof TimeDeposit
   */
  maturityPolicy?: MaturityPolicy;
  /**
   * The minimum maturity term offered by this product, for products such as certificates of deposits. See also `maximumTerm` For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  minimumTerm?: string;
  /**
   * The maximum maturity term offered by this product, for products such as certificates of deposits. If omitted, there is no fixed term (not all product types impose a term). For example, Some CD products may be opened with a flexible term such as 31 to 181 days, expressed as `minimumTerm: P31D, maximumTerm: P181D` For fixed-term products, `minimmumTerm` and `maximumTerm` should be the same.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days. For example, the values `P30D`, `P6M`, `P2Y` indicate a term of 30 days, six months, and two years, respectively.
   * @type {string}
   * @memberof TimeDeposit
   */
  maximumTerm?: string;
  /**
   * The time period in which additional deposits may be made to a CD after it has rolled over after maturity. This value applies only if the `depositsAllowed` is `duringGracePeriod`. This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the term in the number of years/months/days.
   * @type {string}
   * @memberof TimeDeposit
   */
  fees?: string;
}

/**
 * A string which defines a transaction type allowed for an account.   * *`credit`* : Credits may be posted to this account, such as transfer funds _to_ this external account.   * *`debit`* : Debits may be posted to this account, such as transfer funds _from_ this external account. Labels and descriptions for the enumeration values are in the `transactionType` key in the response of the `getLabels` operation.  <strong><code>transactionType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named transactionType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `transactionType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>debit</code></strong></td><td>A transaction which descreases an account's balance</td>     </tr> <tr>     <td><strong><code>credit</code></strong></td><td>A transaction which increases an accounts's balance</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum TransactionType {
  Debit = 'debit',
  Credit = 'credit',
}

/**
 * An array which lists which transaction types are allowed for an account.  This schema is version `v1.0.0`.
 * @export
 * @interface TransactionTypes
 */
export interface TransactionTypes {}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:   * *`apiture:product`* : links to the collection of products   * *`apiture:productTypes`* : links to the collection of product types
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:   * *`apiture:product`* : links to the collection of products   * *`apiture:productTypes`* : links to the collection of product types
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<LabelGroups> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. This API returns the following links:   * *`apiture:product`* : links to the collection of products   * *`apiture:productTypes`* : links to the collection of product types
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. This API returns the following links:   * *`apiture:product`* : links to the collection of products   * *`apiture:productTypes`* : links to the collection of product types
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LabelGroups}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AccountVerificationLetterTemplateApi - axios parameter creator
 * @export
 */
export const AccountVerificationLetterTemplateApiAxiosParamCreator = function(
  configuration?: SdkConfiguration,
) {
  return {
    /**
     * Return a representation of account verification letter template for this product. This is a Mustache template. The content is [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) with Mustache template variables for replaceable text.  The variables in the template are:   * `{accountOwnerName}` - The account owner's full name   * `{accountOwnerAddress}` - The account owner's address   * `{businessName}` - The bussiness name   * `{businessAddress}` - The business' address   * `{today}` - Today's date   * `{product}` - The account's product name   * `{productType}` - The account's product type name   * `{productApy}` - The product APY   * `{routingNumber}` - The routing number   * `{accountNumber}` - The account number   * `{maturityDate}` - The maturity date   * `{openingDate}` - The opening date   * `{AccountBalance}` - The account balance   This template is used to format the account verification letter in the `createVerificationLetter` operation in the Accounts API.
     * @summary Fetch an account verification letter template
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVerificationLetterTemplate(
      productId: string,
      headers?: { Accept?: string },
      options: any = {},
    ): RequestArgs {
      const { Accept } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling getVerificationLetterTemplate.',
        );
      }
      const localVarPath = `/products/{productId}/verificationLetterTemplate`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept !== undefined && Accept !== null) {
        localVarHeaderParameter['Accept'] = String(Accept);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set or replace the account verification letter template for this product.
     * @summary Update this account verification letter template
     * @param {string} body The [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text (with Mustache variables) defining the template for the verification letter.
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {string} [headers.Content_Type] The media type of the request body representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateVerificationLetterTemplate(
      body: string,
      productId: string,
      headers?: { Accept?: string; Content_Type?: string },
      options: any = {},
    ): RequestArgs {
      const { Accept, Content_Type } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling updateVerificationLetterTemplate.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateVerificationLetterTemplate.',
        );
      }
      const localVarPath = `/products/{productId}/verificationLetterTemplate`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept !== undefined && Accept !== null) {
        localVarHeaderParameter['Accept'] = String(Accept);
      }

      if (Content_Type !== undefined && Content_Type !== null) {
        localVarHeaderParameter['Content-Type'] = String(Content_Type);
      }

      localVarHeaderParameter['Content-Type'] = 'text/markdown';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AccountVerificationLetterTemplateApi - functional programming interface
 * @export
 */
export const AccountVerificationLetterTemplateApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a representation of account verification letter template for this product. This is a Mustache template. The content is [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) with Mustache template variables for replaceable text.  The variables in the template are:   * `{accountOwnerName}` - The account owner's full name   * `{accountOwnerAddress}` - The account owner's address   * `{businessName}` - The bussiness name   * `{businessAddress}` - The business' address   * `{today}` - Today's date   * `{product}` - The account's product name   * `{productType}` - The account's product type name   * `{productApy}` - The product APY   * `{routingNumber}` - The routing number   * `{accountNumber}` - The account number   * `{maturityDate}` - The maturity date   * `{openingDate}` - The opening date   * `{AccountBalance}` - The account balance   This template is used to format the account verification letter in the `createVerificationLetter` operation in the Accounts API.
     * @summary Fetch an account verification letter template
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVerificationLetterTemplate(
      productId: string,
      headers?: { Accept?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = AccountVerificationLetterTemplateApiAxiosParamCreator(
        configuration,
      ).getVerificationLetterTemplate(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set or replace the account verification letter template for this product.
     * @summary Update this account verification letter template
     * @param {string} body The [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text (with Mustache variables) defining the template for the verification letter.
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {string} [headers.Content_Type] The media type of the request body representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateVerificationLetterTemplate(
      body: string,
      productId: string,
      headers?: { Accept?: string; Content_Type?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = AccountVerificationLetterTemplateApiAxiosParamCreator(
        configuration,
      ).updateVerificationLetterTemplate(
        body ? body : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AccountVerificationLetterTemplateApi - factory interface
 * @export
 */
export const AccountVerificationLetterTemplateApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a representation of account verification letter template for this product. This is a Mustache template. The content is [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) with Mustache template variables for replaceable text.  The variables in the template are:   * `{accountOwnerName}` - The account owner's full name   * `{accountOwnerAddress}` - The account owner's address   * `{businessName}` - The bussiness name   * `{businessAddress}` - The business' address   * `{today}` - Today's date   * `{product}` - The account's product name   * `{productType}` - The account's product type name   * `{productApy}` - The product APY   * `{routingNumber}` - The routing number   * `{accountNumber}` - The account number   * `{maturityDate}` - The maturity date   * `{openingDate}` - The opening date   * `{AccountBalance}` - The account balance   This template is used to format the account verification letter in the `createVerificationLetter` operation in the Accounts API.
     * @summary Fetch an account verification letter template
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVerificationLetterTemplate(productId: string, headers?: { Accept?: string }, options?: any) {
      return AccountVerificationLetterTemplateApiFp(configuration).getVerificationLetterTemplate(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set or replace the account verification letter template for this product.
     * @summary Update this account verification letter template
     * @param {string} body The [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text (with Mustache variables) defining the template for the verification letter.
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {string} [headers.Content_Type] The media type of the request body representation. Only &#x60;text/markdown&#x60; is currently supported.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateVerificationLetterTemplate(
      body: string,
      productId: string,
      headers?: { Accept?: string; Content_Type?: string },
      options?: any,
    ) {
      return AccountVerificationLetterTemplateApiFp(configuration).updateVerificationLetterTemplate(
        body ? body : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AccountVerificationLetterTemplateApi - object-oriented interface
 * @export
 * @class AccountVerificationLetterTemplateApi
 * @extends {BaseAPI}
 */
export class AccountVerificationLetterTemplateApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a representation of account verification letter template for this product. This is a Mustache template. The content is [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) with Mustache template variables for replaceable text.  The variables in the template are:   * `{accountOwnerName}` - The account owner's full name   * `{accountOwnerAddress}` - The account owner's address   * `{businessName}` - The bussiness name   * `{businessAddress}` - The business' address   * `{today}` - Today's date   * `{product}` - The account's product name   * `{productType}` - The account's product type name   * `{productApy}` - The product APY   * `{routingNumber}` - The routing number   * `{accountNumber}` - The account number   * `{maturityDate}` - The maturity date   * `{openingDate}` - The opening date   * `{AccountBalance}` - The account balance   This template is used to format the account verification letter in the `createVerificationLetter` operation in the Accounts API.
   * @summary Fetch an account verification letter template
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof AccountVerificationLetterTemplateApi
   */
  public getVerificationLetterTemplate(
    productId: string,
    headers?: { Accept?: string },
    options?: any,
  ) {
    return AccountVerificationLetterTemplateApiFp(this.configuration).getVerificationLetterTemplate(
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set or replace the account verification letter template for this product.
   * @summary Update this account verification letter template
   * @param {string} body The [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) text (with Mustache variables) defining the template for the verification letter.
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept] The media type of the desired response representation. Only &#x60;text/markdown&#x60; is currently supported.
   * @param {string} [headers.Content_Type] The media type of the request body representation. Only &#x60;text/markdown&#x60; is currently supported.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof AccountVerificationLetterTemplateApi
   */
  public updateVerificationLetterTemplate(
    body: string,
    productId: string,
    headers?: { Accept?: string; Content_Type?: string },
    options?: any,
  ) {
    return AccountVerificationLetterTemplateApiFp(
      this.configuration,
    ).updateVerificationLetterTemplate(
      body ? body : null,
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ProductApi - axios parameter creator
 * @export
 */
export const ProductApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a product that is eligible to be activated. Only product types which are `pending` or `inactive` may be activated. <p> This `POST` operation is invoked from the `apiture:activate` link on a product. <p> This changes the `state` to `active`.
     * @summary Activate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { product } = query;
      const { If_Match } = headers;

      // verify required parameter 'product' is not null or undefined
      if (product === null || product === undefined) {
        throw new RequiredError(
          'product',
          'Required parameter product was null or undefined when calling activateProduct.',
        );
      }
      const localVarPath = `/activeProducts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (product !== undefined) {
        localVarQueryParameter['product'] = product;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new product from the given name, label, description, and product subtype. The request must contain links to an existing product subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product to activate it.
     * @summary Create a new product
     * @param {CreateProduct} CreateProduct The data necessary to create a new product.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product, pass the URI of the original product. Fields in the request body will override the values copied from the existing product. The new name must be passed in the body, since names must be unique.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProduct(
      CreateProduct: CreateProduct,
      query?: { copyOf?: string },
      options: any = {},
    ): RequestArgs {
      const { copyOf } = query;

      // verify required parameter 'CreateProduct' is not null or undefined
      if (CreateProduct === null || CreateProduct === undefined) {
        throw new RequiredError(
          'CreateProduct',
          'Required parameter CreateProduct was null or undefined when calling createProduct.',
        );
      }
      const localVarPath = `/products`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (copyOf !== undefined) {
        localVarQueryParameter['copyOf'] = copyOf;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateProduct' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateProduct || {})
        : CreateProduct || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate a product that is eligible to be deactivated. <p> Only products which are `pending` or `active` and which are not in use by any `pending`, `active` or `inactive` accounts types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { product } = query;
      const { If_Match } = headers;

      // verify required parameter 'product' is not null or undefined
      if (product === null || product === undefined) {
        throw new RequiredError(
          'product',
          'Required parameter product was null or undefined when calling deactivateProduct.',
        );
      }
      const localVarPath = `/inactiveProducts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (product !== undefined) {
        localVarQueryParameter['product'] = product;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this product resource and any resources that are owned by it. A product may only be deleted if its `state` is `pending`.
     * @summary Delete this product resource
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProduct(
      productId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling deleteProduct.',
        );
      }
      const localVarPath = `/products/{productId}`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product resource.  This resource also maintains immutable revisions; see the `getProductRevisions` and `getProductRevision` operations. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch a representation of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProduct(
      productId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling getProduct.',
        );
      }
      const localVarPath = `/products/{productId}`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this product resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers are strings in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevision(
      productId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling getProductRevision.',
        );
      }
      // verify required parameter 'revisionId' is not null or undefined
      if (revisionId === null || revisionId === undefined) {
        throw new RequiredError(
          'revisionId',
          'Required parameter revisionId was null or undefined when calling getProductRevision.',
        );
      }
      const localVarPath = `/products/{productId}/revisions/{revisionId}`
        .replace(`{${'productId'}}`, encodeURIComponent(String(productId)))
        .replace(`{${'revisionId'}}`, encodeURIComponent(String(revisionId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product revisions
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevisions(
      productId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling getProductRevisions.',
        );
      }
      const localVarPath = `/products/{productId}/revisions`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of products. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of products
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.code] Subset the products or product types collection to those whose &#x60;code&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;B2001&#x60; matches only items whose &#x60;type&#x60; is &#x60;B2001&#x60;, but &#x60;?type&#x3D;B2001|B3002&#x60; matches items whose &#x60;type&#x60; is &#x60;B2001&#x60; or &#x60;B3002&#x60;. This is combined with an implicit &#x60;and&#x60; with &#x60;?state&#x60; &#x60;?filter&#x60; if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.category] Subset the products or product types collection to those whose &#x60;category&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?category&#x3D;Savings&#x60; matches only items whose &#x60;category&#x60; is &#x60;Savings&#x60;, but &#x60;?category&#x3D;Savings|Checking&#x60; matches items whose &#x60;type&#x60; is &#x60;Savings&#x60; or &#x60;Checking&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'personal' | 'business'} [query.target] Subset the products or product types collection to those whose &#x60;target&#x60; matches this value (&#x60;personal&#x60; or &#x60;business&#x60;). For example, &#x60;?target&#x3D;personal&#x60; matches only items whose &#x60;target&#x60; is &#x60;personal&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.ifxType] Subset the products collection to those whose &#x60;ifxType&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?ifxType&#x3D;SDA&#x60; matches only items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60;; &#x60;?ifxType&#x3D;SDA|DDA&#x60; matches items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60; or &#x60;DDA&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.openable] If true, filter only by products whose &#x60;state&#x60; is &#x60;active&#x60; and &#x60;newAccountAvailability&#x60; is &#x60;available&#x60;. For example, &#x60;?openable&#x3D;true&#x60; is equivalent to &#x60;?state&#x3D;active&amp;newAccountAvailability&#x3D;available&#x60; .
     * @param {'available' | 'notAvailable'} [query.newAccountAvailability] Subset the result to only those whose &#x60;newAccountAvailability&#x60; property matches this value.
     * @param {string} [query.productType] Subset the result to only products that use the product type identified by this value. The value is the &#x60;_id&#x60; of a product type instance. (This query parameter is used to implement the *&#x60;apiture:products&#x60;* link relation on a product type resource.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProducts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        code?: string;
        category?: string;
        state?: string;
        target?: 'personal' | 'business';
        ifxType?: string;
        filter?: string;
        q?: string;
        openable?: boolean;
        newAccountAvailability?: 'available' | 'notAvailable';
        productType?: string;
      },
      options: any = {},
    ): RequestArgs {
      const {
        start,
        limit,
        sortBy,
        name,
        type,
        code,
        category,
        state,
        target,
        ifxType,
        filter,
        q,
        openable,
        newAccountAvailability,
        productType,
      } = query;

      const localVarPath = `/products`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (code !== undefined) {
        localVarQueryParameter['code'] = code;
      }

      if (category !== undefined) {
        localVarQueryParameter['category'] = category;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (target !== undefined) {
        localVarQueryParameter['target'] = target;
      }

      if (ifxType !== undefined) {
        localVarQueryParameter['ifxType'] = ifxType;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (openable !== undefined) {
        localVarQueryParameter['openable'] = openable;
      }

      if (newAccountAvailability !== undefined) {
        localVarQueryParameter['newAccountAvailability'] = newAccountAvailability;
      }

      if (productType !== undefined) {
        localVarQueryParameter['productType'] = productType;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Marks an active product as ineligible for new account opening. Users may not open new accounts with this product, thus the product is \"locked\". <p> This `POST` operation is invoked from the `apiture:lock` link on a product. <p> This changes the `newAccountAvailability` to `notAvailable`.
     * @summary Marks an active product as ineligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { product } = query;
      const { If_Match } = headers;

      // verify required parameter 'product' is not null or undefined
      if (product === null || product === undefined) {
        throw new RequiredError(
          'product',
          'Required parameter product was null or undefined when calling lockProduct.',
        );
      }
      const localVarPath = `/lockedProducts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (product !== undefined) {
        localVarQueryParameter['product'] = product;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this product. This creates a new product revision. Fields which are omitted are not updated. The new name, if any, must not be in use by another product (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling patchProduct.',
        );
      }
      // verify required parameter 'Product' is not null or undefined
      if (Product === null || Product === undefined) {
        throw new RequiredError(
          'Product',
          'Required parameter Product was null or undefined when calling patchProduct.',
        );
      }
      const localVarPath = `/products/{productId}`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Product' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Product || {})
        : Product || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove a product that is eligible to be removed. <p> Only products which are `active` or `inactive` _and_ which are not used by any non-closed accounts may be removed. <p> This `POST` operation is invoked from the `apiture:remove` link on a product when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other products.
     * @summary Remove a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { product } = query;
      const { If_Match } = headers;

      // verify required parameter 'product' is not null or undefined
      if (product === null || product === undefined) {
        throw new RequiredError(
          'product',
          'Required parameter product was null or undefined when calling removeProduct.',
        );
      }
      const localVarPath = `/removedProducts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (product !== undefined) {
        localVarQueryParameter['product'] = product;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Marks an active product as eligible for new account opening. <p> This `POST` operation is invoked from the `apiture:unlock` link on a product. <p> This changes the `newAccountAvailability` to `available`.
     * @summary Marks an active product as eligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    unlockProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { product } = query;
      const { If_Match } = headers;

      // verify required parameter 'product' is not null or undefined
      if (product === null || product === undefined) {
        throw new RequiredError(
          'product',
          'Required parameter product was null or undefined when calling unlockProduct.',
        );
      }
      const localVarPath = `/unlockedProducts`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (product !== undefined) {
        localVarQueryParameter['product'] = product;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this product. This creates a new product revision. The new name, if any, must not be in use by another product  (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productId' is not null or undefined
      if (productId === null || productId === undefined) {
        throw new RequiredError(
          'productId',
          'Required parameter productId was null or undefined when calling updateProduct.',
        );
      }
      // verify required parameter 'Product' is not null or undefined
      if (Product === null || Product === undefined) {
        throw new RequiredError(
          'Product',
          'Required parameter Product was null or undefined when calling updateProduct.',
        );
      }
      const localVarPath = `/products/{productId}`.replace(
        `{${'productId'}}`,
        encodeURIComponent(String(productId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'Product' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(Product || {})
        : Product || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ProductApi - functional programming interface
 * @export
 */
export const ProductApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a product that is eligible to be activated. Only product types which are `pending` or `inactive` may be activated. <p> This `POST` operation is invoked from the `apiture:activate` link on a product. <p> This changes the `state` to `active`.
     * @summary Activate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).activateProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new product from the given name, label, description, and product subtype. The request must contain links to an existing product subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product to activate it.
     * @summary Create a new product
     * @param {CreateProduct} CreateProduct The data necessary to create a new product.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product, pass the URI of the original product. Fields in the request body will override the values copied from the existing product. The new name must be passed in the body, since names must be unique.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProduct(
      CreateProduct: CreateProduct,
      query?: { copyOf?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Product> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).createProduct(
        CreateProduct ? CreateProduct : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate a product that is eligible to be deactivated. <p> Only products which are `pending` or `active` and which are not in use by any `pending`, `active` or `inactive` accounts types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).deactivateProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this product resource and any resources that are owned by it. A product may only be deleted if its `state` is `pending`.
     * @summary Delete this product resource
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProduct(
      productId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).deleteProduct(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product resource.  This resource also maintains immutable revisions; see the `getProductRevisions` and `getProductRevision` operations. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch a representation of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProduct(
      productId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Product> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).getProduct(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this product resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers are strings in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevision(
      productId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Product> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).getProductRevision(
        productId ? productId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product revisions
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevisions(
      productId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Products> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).getProductRevisions(
        productId ? productId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of products. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of products
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.code] Subset the products or product types collection to those whose &#x60;code&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;B2001&#x60; matches only items whose &#x60;type&#x60; is &#x60;B2001&#x60;, but &#x60;?type&#x3D;B2001|B3002&#x60; matches items whose &#x60;type&#x60; is &#x60;B2001&#x60; or &#x60;B3002&#x60;. This is combined with an implicit &#x60;and&#x60; with &#x60;?state&#x60; &#x60;?filter&#x60; if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.category] Subset the products or product types collection to those whose &#x60;category&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?category&#x3D;Savings&#x60; matches only items whose &#x60;category&#x60; is &#x60;Savings&#x60;, but &#x60;?category&#x3D;Savings|Checking&#x60; matches items whose &#x60;type&#x60; is &#x60;Savings&#x60; or &#x60;Checking&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'personal' | 'business'} [query.target] Subset the products or product types collection to those whose &#x60;target&#x60; matches this value (&#x60;personal&#x60; or &#x60;business&#x60;). For example, &#x60;?target&#x3D;personal&#x60; matches only items whose &#x60;target&#x60; is &#x60;personal&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.ifxType] Subset the products collection to those whose &#x60;ifxType&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?ifxType&#x3D;SDA&#x60; matches only items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60;; &#x60;?ifxType&#x3D;SDA|DDA&#x60; matches items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60; or &#x60;DDA&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.openable] If true, filter only by products whose &#x60;state&#x60; is &#x60;active&#x60; and &#x60;newAccountAvailability&#x60; is &#x60;available&#x60;. For example, &#x60;?openable&#x3D;true&#x60; is equivalent to &#x60;?state&#x3D;active&amp;newAccountAvailability&#x3D;available&#x60; .
     * @param {'available' | 'notAvailable'} [query.newAccountAvailability] Subset the result to only those whose &#x60;newAccountAvailability&#x60; property matches this value.
     * @param {string} [query.productType] Subset the result to only products that use the product type identified by this value. The value is the &#x60;_id&#x60; of a product type instance. (This query parameter is used to implement the *&#x60;apiture:products&#x60;* link relation on a product type resource.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProducts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        code?: string;
        category?: string;
        state?: string;
        target?: 'personal' | 'business';
        ifxType?: string;
        filter?: string;
        q?: string;
        openable?: boolean;
        newAccountAvailability?: 'available' | 'notAvailable';
        productType?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Products> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).getProducts(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Marks an active product as ineligible for new account opening. Users may not open new accounts with this product, thus the product is \"locked\". <p> This `POST` operation is invoked from the `apiture:lock` link on a product. <p> This changes the `newAccountAvailability` to `notAvailable`.
     * @summary Marks an active product as ineligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).lockProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this product. This creates a new product revision. Fields which are omitted are not updated. The new name, if any, must not be in use by another product (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Product> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).patchProduct(
        Product ? Product : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove a product that is eligible to be removed. <p> Only products which are `active` or `inactive` _and_ which are not used by any non-closed accounts may be removed. <p> This `POST` operation is invoked from the `apiture:remove` link on a product when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other products.
     * @summary Remove a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).removeProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Marks an active product as eligible for new account opening. <p> This `POST` operation is invoked from the `apiture:unlock` link on a product. <p> This changes the `newAccountAvailability` to `available`.
     * @summary Marks an active product as eligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    unlockProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).unlockProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this product. This creates a new product revision. The new name, if any, must not be in use by another product  (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Product> {
      const localVarAxiosArgs = ProductApiAxiosParamCreator(configuration).updateProduct(
        Product ? Product : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ProductApi - factory interface
 * @export
 */
export const ProductApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate a product that is eligible to be activated. Only product types which are `pending` or `inactive` may be activated. <p> This `POST` operation is invoked from the `apiture:activate` link on a product. <p> This changes the `state` to `active`.
     * @summary Activate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProduct(query?: { product?: string }, headers?: { If_Match?: string }, options?: any) {
      return ProductApiFp(configuration).activateProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new product from the given name, label, description, and product subtype. The request must contain links to an existing product subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product to activate it.
     * @summary Create a new product
     * @param {CreateProduct} CreateProduct The data necessary to create a new product.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product, pass the URI of the original product. Fields in the request body will override the values copied from the existing product. The new name must be passed in the body, since names must be unique.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProduct(CreateProduct: CreateProduct, query?: { copyOf?: string }, options?: any) {
      return ProductApiFp(configuration).createProduct(
        CreateProduct ? CreateProduct : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate a product that is eligible to be deactivated. <p> Only products which are `pending` or `active` and which are not in use by any `pending`, `active` or `inactive` accounts types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProduct(
      query?: { product?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductApiFp(configuration).deactivateProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this product resource and any resources that are owned by it. A product may only be deleted if its `state` is `pending`.
     * @summary Delete this product resource
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProduct(productId: string, headers?: { If_Match?: string }, options?: any) {
      return ProductApiFp(configuration).deleteProduct(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product resource.  This resource also maintains immutable revisions; see the `getProductRevisions` and `getProductRevision` operations. The `Content-Location` response header, if present, identifies the equivalent revision.
     * @summary Fetch a representation of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProduct(productId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ProductApiFp(configuration).getProduct(
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this product resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers are strings in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevision(
      productId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ProductApiFp(configuration).getProductRevision(
        productId ? productId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product revisions
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductRevisions(
      productId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ProductApiFp(configuration).getProductRevisions(
        productId ? productId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of products. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of products
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.code] Subset the products or product types collection to those whose &#x60;code&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;B2001&#x60; matches only items whose &#x60;type&#x60; is &#x60;B2001&#x60;, but &#x60;?type&#x3D;B2001|B3002&#x60; matches items whose &#x60;type&#x60; is &#x60;B2001&#x60; or &#x60;B3002&#x60;. This is combined with an implicit &#x60;and&#x60; with &#x60;?state&#x60; &#x60;?filter&#x60; if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.category] Subset the products or product types collection to those whose &#x60;category&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?category&#x3D;Savings&#x60; matches only items whose &#x60;category&#x60; is &#x60;Savings&#x60;, but &#x60;?category&#x3D;Savings|Checking&#x60; matches items whose &#x60;type&#x60; is &#x60;Savings&#x60; or &#x60;Checking&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {'personal' | 'business'} [query.target] Subset the products or product types collection to those whose &#x60;target&#x60; matches this value (&#x60;personal&#x60; or &#x60;business&#x60;). For example, &#x60;?target&#x3D;personal&#x60; matches only items whose &#x60;target&#x60; is &#x60;personal&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.ifxType] Subset the products collection to those whose &#x60;ifxType&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?ifxType&#x3D;SDA&#x60; matches only items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60;; &#x60;?ifxType&#x3D;SDA|DDA&#x60; matches items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60; or &#x60;DDA&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {boolean} [query.openable] If true, filter only by products whose &#x60;state&#x60; is &#x60;active&#x60; and &#x60;newAccountAvailability&#x60; is &#x60;available&#x60;. For example, &#x60;?openable&#x3D;true&#x60; is equivalent to &#x60;?state&#x3D;active&amp;newAccountAvailability&#x3D;available&#x60; .
     * @param {'available' | 'notAvailable'} [query.newAccountAvailability] Subset the result to only those whose &#x60;newAccountAvailability&#x60; property matches this value.
     * @param {string} [query.productType] Subset the result to only products that use the product type identified by this value. The value is the &#x60;_id&#x60; of a product type instance. (This query parameter is used to implement the *&#x60;apiture:products&#x60;* link relation on a product type resource.)
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProducts(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        code?: string;
        category?: string;
        state?: string;
        target?: 'personal' | 'business';
        ifxType?: string;
        filter?: string;
        q?: string;
        openable?: boolean;
        newAccountAvailability?: 'available' | 'notAvailable';
        productType?: string;
      },
      options?: any,
    ) {
      return ProductApiFp(configuration).getProducts(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Marks an active product as ineligible for new account opening. Users may not open new accounts with this product, thus the product is \"locked\". <p> This `POST` operation is invoked from the `apiture:lock` link on a product. <p> This changes the `newAccountAvailability` to `notAvailable`.
     * @summary Marks an active product as ineligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockProduct(query?: { product?: string }, headers?: { If_Match?: string }, options?: any) {
      return ProductApiFp(configuration).lockProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this product. This creates a new product revision. Fields which are omitted are not updated. The new name, if any, must not be in use by another product (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductApiFp(configuration).patchProduct(
        Product ? Product : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove a product that is eligible to be removed. <p> Only products which are `active` or `inactive` _and_ which are not used by any non-closed accounts may be removed. <p> This `POST` operation is invoked from the `apiture:remove` link on a product when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other products.
     * @summary Remove a product
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProduct(query?: { product?: string }, headers?: { If_Match?: string }, options?: any) {
      return ProductApiFp(configuration).removeProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Marks an active product as eligible for new account opening. <p> This `POST` operation is invoked from the `apiture:unlock` link on a product. <p> This changes the `newAccountAvailability` to `available`.
     * @summary Marks an active product as eligible for new account opening
     * @param {Object} [query] Query object
     * @param {string} [query.product] A server-supplied value which identifies the product instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    unlockProduct(query?: { product?: string }, headers?: { If_Match?: string }, options?: any) {
      return ProductApiFp(configuration).unlockProduct(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this product. This creates a new product revision. The new name, if any, must not be in use by another product  (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
     * @summary Update this product
     * @param {Product} Product
     * @param {string} productId The unique identifier of this product. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProduct(
      Product: Product,
      productId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductApiFp(configuration).updateProduct(
        Product ? Product : null,
        productId ? productId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ProductApi - object-oriented interface
 * @export
 * @class ProductApi
 * @extends {BaseAPI}
 */
export class ProductApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate a product that is eligible to be activated. Only product types which are `pending` or `inactive` may be activated. <p> This `POST` operation is invoked from the `apiture:activate` link on a product. <p> This changes the `state` to `active`.
   * @summary Activate a product
   * @param {Object} [query] Query object
   * @param {string} [query.product] A server-supplied value which identifies the product instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductApi
   */
  public activateProduct(
    query?: { product?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).activateProduct(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new product from the given name, label, description, and product subtype. The request must contain links to an existing product subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product to activate it.
   * @summary Create a new product
   * @param {CreateProduct} CreateProduct The data necessary to create a new product.
   * @param {Object} [query] Query object
   * @param {string} [query.copyOf] To make a copy of an existing product, pass the URI of the original product. Fields in the request body will override the values copied from the existing product. The new name must be passed in the body, since names must be unique.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Product}
   * @memberof ProductApi
   */
  public createProduct(CreateProduct: CreateProduct, query?: { copyOf?: string }, options?: any) {
    return ProductApiFp(this.configuration).createProduct(
      CreateProduct ? CreateProduct : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate a product that is eligible to be deactivated. <p> Only products which are `pending` or `active` and which are not in use by any `pending`, `active` or `inactive` accounts types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
   * @summary Deactivate a product
   * @param {Object} [query] Query object
   * @param {string} [query.product] A server-supplied value which identifies the product instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductApi
   */
  public deactivateProduct(
    query?: { product?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).deactivateProduct(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this product resource and any resources that are owned by it. A product may only be deleted if its `state` is `pending`.
   * @summary Delete this product resource
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ProductApi
   */
  public deleteProduct(productId: string, headers?: { If_Match?: string }, options?: any) {
    return ProductApiFp(this.configuration).deleteProduct(
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product resource.  This resource also maintains immutable revisions; see the `getProductRevisions` and `getProductRevision` operations. The `Content-Location` response header, if present, identifies the equivalent revision.
   * @summary Fetch a representation of this product
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Product}
   * @memberof ProductApi
   */
  public getProduct(productId: string, headers?: { If_None_Match?: string }, options?: any) {
    return ProductApiFp(this.configuration).getProduct(
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this product resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
   * @summary Fetch a representation of an immutable revision of this product
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers are strings in [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Product}
   * @memberof ProductApi
   */
  public getProductRevision(
    productId: string,
    revisionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).getProductRevision(
      productId ? productId : null,
      revisionId ? revisionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of product revisions
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first product revision item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of product representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Products}
   * @memberof ProductApi
   */
  public getProductRevisions(
    productId: string,
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).getProductRevisions(
      productId ? productId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of products. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of products
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first product in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of product representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.code] Subset the products or product types collection to those whose &#x60;code&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;B2001&#x60; matches only items whose &#x60;type&#x60; is &#x60;B2001&#x60;, but &#x60;?type&#x3D;B2001|B3002&#x60; matches items whose &#x60;type&#x60; is &#x60;B2001&#x60; or &#x60;B3002&#x60;. This is combined with an implicit &#x60;and&#x60; with &#x60;?state&#x60; &#x60;?filter&#x60; if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.category] Subset the products or product types collection to those whose &#x60;category&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?category&#x3D;Savings&#x60; matches only items whose &#x60;category&#x60; is &#x60;Savings&#x60;, but &#x60;?category&#x3D;Savings|Checking&#x60; matches items whose &#x60;type&#x60; is &#x60;Savings&#x60; or &#x60;Checking&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {'personal' | 'business'} [query.target] Subset the products or product types collection to those whose &#x60;target&#x60; matches this value (&#x60;personal&#x60; or &#x60;business&#x60;). For example, &#x60;?target&#x3D;personal&#x60; matches only items whose &#x60;target&#x60; is &#x60;personal&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.ifxType] Subset the products collection to those whose &#x60;ifxType&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?ifxType&#x3D;SDA&#x60; matches only items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60;; &#x60;?ifxType&#x3D;SDA|DDA&#x60; matches items whose &#x60;ifxType&#x60; is &#x60;SDA&#x60; or &#x60;DDA&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {boolean} [query.openable] If true, filter only by products whose &#x60;state&#x60; is &#x60;active&#x60; and &#x60;newAccountAvailability&#x60; is &#x60;available&#x60;. For example, &#x60;?openable&#x3D;true&#x60; is equivalent to &#x60;?state&#x3D;active&amp;newAccountAvailability&#x3D;available&#x60; .
   * @param {'available' | 'notAvailable'} [query.newAccountAvailability] Subset the result to only those whose &#x60;newAccountAvailability&#x60; property matches this value.
   * @param {string} [query.productType] Subset the result to only products that use the product type identified by this value. The value is the &#x60;_id&#x60; of a product type instance. (This query parameter is used to implement the *&#x60;apiture:products&#x60;* link relation on a product type resource.)
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Products}
   * @memberof ProductApi
   */
  public getProducts(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      name?: string;
      type?: string;
      code?: string;
      category?: string;
      state?: string;
      target?: 'personal' | 'business';
      ifxType?: string;
      filter?: string;
      q?: string;
      openable?: boolean;
      newAccountAvailability?: 'available' | 'notAvailable';
      productType?: string;
    },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).getProducts(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Marks an active product as ineligible for new account opening. Users may not open new accounts with this product, thus the product is \"locked\". <p> This `POST` operation is invoked from the `apiture:lock` link on a product. <p> This changes the `newAccountAvailability` to `notAvailable`.
   * @summary Marks an active product as ineligible for new account opening
   * @param {Object} [query] Query object
   * @param {string} [query.product] A server-supplied value which identifies the product instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductApi
   */
  public lockProduct(query?: { product?: string }, headers?: { If_Match?: string }, options?: any) {
    return ProductApiFp(this.configuration).lockProduct(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this product. This creates a new product revision. Fields which are omitted are not updated. The new name, if any, must not be in use by another product (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
   * @summary Update this product
   * @param {Product} Product
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Product}
   * @memberof ProductApi
   */
  public patchProduct(
    Product: Product,
    productId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).patchProduct(
      Product ? Product : null,
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove a product that is eligible to be removed. <p> Only products which are `active` or `inactive` _and_ which are not used by any non-closed accounts may be removed. <p> This `POST` operation is invoked from the `apiture:remove` link on a product when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other products.
   * @summary Remove a product
   * @param {Object} [query] Query object
   * @param {string} [query.product] A server-supplied value which identifies the product instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductApi
   */
  public removeProduct(
    query?: { product?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).removeProduct(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Marks an active product as eligible for new account opening. <p> This `POST` operation is invoked from the `apiture:unlock` link on a product. <p> This changes the `newAccountAvailability` to `available`.
   * @summary Marks an active product as eligible for new account opening
   * @param {Object} [query] Query object
   * @param {string} [query.product] A server-supplied value which identifies the product instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductApi
   */
  public unlockProduct(
    query?: { product?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).unlockProduct(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this product. This creates a new product revision. The new name, if any, must not be in use by another product  (whether active or inactive). Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProducts`, `/inactiveProducts`, `/removedProducts`. </p> <p> The product `code` may not be changed if the current `state` is not `pending`. </p>
   * @summary Update this product
   * @param {Product} Product
   * @param {string} productId The unique identifier of this product. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Product}
   * @memberof ProductApi
   */
  public updateProduct(
    Product: Product,
    productId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductApiFp(this.configuration).updateProduct(
      Product ? Product : null,
      productId ? productId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ProductTypeApi - axios parameter creator
 * @export
 */
export const ProductTypeApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a product type that is eligible to be activated. <p> Only product types which are `pending` or `inactive` may be activated. This `POST` operation is invoked from the `apiture:activate` link on a product type. <p> This changes the `state` to `active`.
     * @summary Activate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { productType } = query;
      const { If_Match } = headers;

      // verify required parameter 'productType' is not null or undefined
      if (productType === null || productType === undefined) {
        throw new RequiredError(
          'productType',
          'Required parameter productType was null or undefined when calling activateProductType.',
        );
      }
      const localVarPath = `/activeProductTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (productType !== undefined) {
        localVarQueryParameter['productType'] = productType;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new product type or subtype. The request may include a parent type in order to create a subtype. The parent type may not be a subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product type to activate it.
     * @summary Create a new product type
     * @param {CreateProductType} CreateProductType The data necessary to create a new product type.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product type, pass the URI of the original product type. Fields in the request body will override the values copied from the existing product type. The new name must be passed in the body, since names must be unique. A new unique &#x60;code&#x60; will be assigned to the copy.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProductType(
      CreateProductType: CreateProductType,
      query?: { copyOf?: string },
      options: any = {},
    ): RequestArgs {
      const { copyOf } = query;

      // verify required parameter 'CreateProductType' is not null or undefined
      if (CreateProductType === null || CreateProductType === undefined) {
        throw new RequiredError(
          'CreateProductType',
          'Required parameter CreateProductType was null or undefined when calling createProductType.',
        );
      }
      const localVarPath = `/productTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (copyOf !== undefined) {
        localVarQueryParameter['copyOf'] = copyOf;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateProductType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateProductType || {})
        : CreateProductType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate a product type that is eligible to be deactivated. <p> Only product types which are `pending` or `active` and which are not in use by any `pending` or `active` products or accounts, and which are not the parent type of `pending` or `active`  product types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product type when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { productType } = query;
      const { If_Match } = headers;

      // verify required parameter 'productType' is not null or undefined
      if (productType === null || productType === undefined) {
        throw new RequiredError(
          'productType',
          'Required parameter productType was null or undefined when calling deactivateProductType.',
        );
      }
      const localVarPath = `/inactiveProductTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (productType !== undefined) {
        localVarQueryParameter['productType'] = productType;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this product type resource and any resources that are owned by it. A product type may only be deleted if its `state` is `pending`, and it is not in use by a product.
     * @summary Delete this product type resource
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProductType(
      productTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productTypeId' is not null or undefined
      if (productTypeId === null || productTypeId === undefined) {
        throw new RequiredError(
          'productTypeId',
          'Required parameter productTypeId was null or undefined when calling deleteProductType.',
        );
      }
      const localVarPath = `/productTypes/{productTypeId}`.replace(
        `{${'productTypeId'}}`,
        encodeURIComponent(String(productTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product type resource. See the description of the `productType` model schema for the links that may be found in a product type representation.
     * @summary Fetch a representation of this product type.
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductType(
      productTypeId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'productTypeId' is not null or undefined
      if (productTypeId === null || productTypeId === undefined) {
        throw new RequiredError(
          'productTypeId',
          'Required parameter productTypeId was null or undefined when calling getProductType.',
        );
      }
      const localVarPath = `/productTypes/{productTypeId}`.replace(
        `{${'productTypeId'}}`,
        encodeURIComponent(String(productTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product types. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product type in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {boolean} [query.subtype] Subset the product types collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.parent] Subset the product types to only those subtypes whose parent type is named by its product type URI. This implements the *&#x60;apiture:children&#x60;* link relation on a product type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        subtype?: boolean;
        state?: string;
        filter?: string;
        q?: string;
        parent?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, name, type, subtype, state, filter, q, parent } = query;

      const localVarPath = `/productTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (subtype !== undefined) {
        localVarQueryParameter['subtype'] = subtype;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (parent !== undefined) {
        localVarQueryParameter['parent'] = parent;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this product type. Fields which are omitted are not updated. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productTypeId' is not null or undefined
      if (productTypeId === null || productTypeId === undefined) {
        throw new RequiredError(
          'productTypeId',
          'Required parameter productTypeId was null or undefined when calling patchProductType.',
        );
      }
      // verify required parameter 'ProductType' is not null or undefined
      if (ProductType === null || ProductType === undefined) {
        throw new RequiredError(
          'ProductType',
          'Required parameter ProductType was null or undefined when calling patchProductType.',
        );
      }
      const localVarPath = `/productTypes/{productTypeId}`.replace(
        `{${'productTypeId'}}`,
        encodeURIComponent(String(productTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ProductType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ProductType || {})
        : ProductType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove a product type that is eligible to be removed.  <p> Only product types which are `active` or `inactive` and which are not in use by any `pending`, `active` or `inactive` products or accounts, and which are not the parent type of pending, active, or inactive product types may be removed. This operation is invoked from the `apiture:remove` link on a product type when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product type will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other product types.
     * @summary Remove a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { productType } = query;
      const { If_Match } = headers;

      // verify required parameter 'productType' is not null or undefined
      if (productType === null || productType === undefined) {
        throw new RequiredError(
          'productType',
          'Required parameter productType was null or undefined when calling removeProductType.',
        );
      }
      const localVarPath = `/removedProductTypes`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (productType !== undefined) {
        localVarQueryParameter['productType'] = productType;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this product type. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to `POST` the product type URI to one of the paths, `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'productTypeId' is not null or undefined
      if (productTypeId === null || productTypeId === undefined) {
        throw new RequiredError(
          'productTypeId',
          'Required parameter productTypeId was null or undefined when calling updateProductType.',
        );
      }
      // verify required parameter 'ProductType' is not null or undefined
      if (ProductType === null || ProductType === undefined) {
        throw new RequiredError(
          'ProductType',
          'Required parameter ProductType was null or undefined when calling updateProductType.',
        );
      }
      const localVarPath = `/productTypes/{productTypeId}`.replace(
        `{${'productTypeId'}}`,
        encodeURIComponent(String(productTypeId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
                'admin/read',
                'admin/write',
                'admin/delete',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'ProductType' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(ProductType || {})
        : ProductType || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ProductTypeApi - functional programming interface
 * @export
 */
export const ProductTypeApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a product type that is eligible to be activated. <p> Only product types which are `pending` or `inactive` may be activated. This `POST` operation is invoked from the `apiture:activate` link on a product type. <p> This changes the `state` to `active`.
     * @summary Activate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).activateProductType(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new product type or subtype. The request may include a parent type in order to create a subtype. The parent type may not be a subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product type to activate it.
     * @summary Create a new product type
     * @param {CreateProductType} CreateProductType The data necessary to create a new product type.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product type, pass the URI of the original product type. Fields in the request body will override the values copied from the existing product type. The new name must be passed in the body, since names must be unique. A new unique &#x60;code&#x60; will be assigned to the copy.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProductType(
      CreateProductType: CreateProductType,
      query?: { copyOf?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).createProductType(
        CreateProductType ? CreateProductType : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate a product type that is eligible to be deactivated. <p> Only product types which are `pending` or `active` and which are not in use by any `pending` or `active` products or accounts, and which are not the parent type of `pending` or `active`  product types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product type when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(
        configuration,
      ).deactivateProductType(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this product type resource and any resources that are owned by it. A product type may only be deleted if its `state` is `pending`, and it is not in use by a product.
     * @summary Delete this product type resource
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProductType(
      productTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).deleteProductType(
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product type resource. See the description of the `productType` model schema for the links that may be found in a product type representation.
     * @summary Fetch a representation of this product type.
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductType(
      productTypeId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).getProductType(
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product types. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product type in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {boolean} [query.subtype] Subset the product types collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.parent] Subset the product types to only those subtypes whose parent type is named by its product type URI. This implements the *&#x60;apiture:children&#x60;* link relation on a product type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        subtype?: boolean;
        state?: string;
        filter?: string;
        q?: string;
        parent?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductTypes> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).getProductTypes(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this product type. Fields which are omitted are not updated. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).patchProductType(
        ProductType ? ProductType : null,
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove a product type that is eligible to be removed.  <p> Only product types which are `active` or `inactive` and which are not in use by any `pending`, `active` or `inactive` products or accounts, and which are not the parent type of pending, active, or inactive product types may be removed. This operation is invoked from the `apiture:remove` link on a product type when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product type will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other product types.
     * @summary Remove a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).removeProductType(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this product type. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to `POST` the product type URI to one of the paths, `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProductType> {
      const localVarAxiosArgs = ProductTypeApiAxiosParamCreator(configuration).updateProductType(
        ProductType ? ProductType : null,
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ProductTypeApi - factory interface
 * @export
 */
export const ProductTypeApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate a product type that is eligible to be activated. <p> Only product types which are `pending` or `inactive` may be activated. This `POST` operation is invoked from the `apiture:activate` link on a product type. <p> This changes the `state` to `active`.
     * @summary Activate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).activateProductType(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new product type or subtype. The request may include a parent type in order to create a subtype. The parent type may not be a subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product type to activate it.
     * @summary Create a new product type
     * @param {CreateProductType} CreateProductType The data necessary to create a new product type.
     * @param {Object} [query] Query object
     * @param {string} [query.copyOf] To make a copy of an existing product type, pass the URI of the original product type. Fields in the request body will override the values copied from the existing product type. The new name must be passed in the body, since names must be unique. A new unique &#x60;code&#x60; will be assigned to the copy.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createProductType(
      CreateProductType: CreateProductType,
      query?: { copyOf?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).createProductType(
        CreateProductType ? CreateProductType : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate a product type that is eligible to be deactivated. <p> Only product types which are `pending` or `active` and which are not in use by any `pending` or `active` products or accounts, and which are not the parent type of `pending` or `active`  product types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product type when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
     * @summary Deactivate a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).deactivateProductType(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this product type resource and any resources that are owned by it. A product type may only be deleted if its `state` is `pending`, and it is not in use by a product.
     * @summary Delete this product type resource
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteProductType(productTypeId: string, headers?: { If_Match?: string }, options?: any) {
      return ProductTypeApiFp(configuration).deleteProductType(
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product type resource. See the description of the `productType` model schema for the links that may be found in a product type representation.
     * @summary Fetch a representation of this product type.
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductType(productTypeId: string, headers?: { If_None_Match?: string }, options?: any) {
      return ProductTypeApiFp(configuration).getProductType(
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product types. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of product types
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first product type in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of product type representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {boolean} [query.subtype] Subset the product types collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {string} [query.parent] Subset the product types to only those subtypes whose parent type is named by its product type URI. This implements the *&#x60;apiture:children&#x60;* link relation on a product type.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getProductTypes(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        name?: string;
        type?: string;
        subtype?: boolean;
        state?: string;
        filter?: string;
        q?: string;
        parent?: string;
      },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).getProductTypes(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this product type. Fields which are omitted are not updated. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).patchProductType(
        ProductType ? ProductType : null,
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove a product type that is eligible to be removed.  <p> Only product types which are `active` or `inactive` and which are not in use by any `pending`, `active` or `inactive` products or accounts, and which are not the parent type of pending, active, or inactive product types may be removed. This operation is invoked from the `apiture:remove` link on a product type when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product type will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other product types.
     * @summary Remove a product type
     * @param {Object} [query] Query object
     * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeProductType(
      query?: { productType?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).removeProductType(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this product type. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to `POST` the product type URI to one of the paths, `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
     * @summary Update this product type
     * @param {ProductType} ProductType
     * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateProductType(
      ProductType: ProductType,
      productTypeId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ProductTypeApiFp(configuration).updateProductType(
        ProductType ? ProductType : null,
        productTypeId ? productTypeId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ProductTypeApi - object-oriented interface
 * @export
 * @class ProductTypeApi
 * @extends {BaseAPI}
 */
export class ProductTypeApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate a product type that is eligible to be activated. <p> Only product types which are `pending` or `inactive` may be activated. This `POST` operation is invoked from the `apiture:activate` link on a product type. <p> This changes the `state` to `active`.
   * @summary Activate a product type
   * @param {Object} [query] Query object
   * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public activateProductType(
    query?: { productType?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).activateProductType(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new product type or subtype. The request may include a parent type in order to create a subtype. The parent type may not be a subtype. The `name` must be unique and the `state` may not be `removed`. `POST` to the `apiture:activate` link after creating a product type to activate it.
   * @summary Create a new product type
   * @param {CreateProductType} CreateProductType The data necessary to create a new product type.
   * @param {Object} [query] Query object
   * @param {string} [query.copyOf] To make a copy of an existing product type, pass the URI of the original product type. Fields in the request body will override the values copied from the existing product type. The new name must be passed in the body, since names must be unique. A new unique &#x60;code&#x60; will be assigned to the copy.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public createProductType(
    CreateProductType: CreateProductType,
    query?: { copyOf?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).createProductType(
      CreateProductType ? CreateProductType : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate a product type that is eligible to be deactivated. <p> Only product types which are `pending` or `active` and which are not in use by any `pending` or `active` products or accounts, and which are not the parent type of `pending` or `active`  product types may be deactivated. <p> This `POST` operation is invoked from the `apiture:deactivate` link on a product type when it is eligible to be deactivated. <p> This changes the `state` to `inactive`.
   * @summary Deactivate a product type
   * @param {Object} [query] Query object
   * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public deactivateProductType(
    query?: { productType?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).deactivateProductType(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this product type resource and any resources that are owned by it. A product type may only be deleted if its `state` is `pending`, and it is not in use by a product.
   * @summary Delete this product type resource
   * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ProductTypeApi
   */
  public deleteProductType(productTypeId: string, headers?: { If_Match?: string }, options?: any) {
    return ProductTypeApiFp(this.configuration).deleteProductType(
      productTypeId ? productTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this product type resource. See the description of the `productType` model schema for the links that may be found in a product type representation.
   * @summary Fetch a representation of this product type.
   * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public getProductType(
    productTypeId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).getProductType(
      productTypeId ? productTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of product types. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of product types
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first product type in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of product type representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.name] Subset the products or product types collection to those with this &#x60;name&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the products or product types collection to those with this exact &#x60;type&#x60; value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {boolean} [query.subtype] Subset the product types collection to those with this exact &#x60;subtype&#x60; value. For example, &#x60;?subtype&#x3D;true&#x60; will limit the response to only product types which are subtypes. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.state] Subset the products or product types collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {string} [query.parent] Subset the product types to only those subtypes whose parent type is named by its product type URI. This implements the *&#x60;apiture:children&#x60;* link relation on a product type.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductTypes}
   * @memberof ProductTypeApi
   */
  public getProductTypes(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      name?: string;
      type?: string;
      subtype?: boolean;
      state?: string;
      filter?: string;
      q?: string;
      parent?: string;
    },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).getProductTypes(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this product type. Fields which are omitted are not updated. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to  `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
   * @summary Update this product type
   * @param {ProductType} ProductType
   * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public patchProductType(
    ProductType: ProductType,
    productTypeId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).patchProductType(
      ProductType ? ProductType : null,
      productTypeId ? productTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove a product type that is eligible to be removed.  <p> Only product types which are `active` or `inactive` and which are not in use by any `pending`, `active` or `inactive` products or accounts, and which are not the parent type of pending, active, or inactive product types may be removed. This operation is invoked from the `apiture:remove` link on a product type when it is eligible to be removed. <p> This changes the `state` to `removed`. <p> Removing a product type will append the timestamp with the format \"` (Removed yyyy-mm-ddTHH:MM:SSZ)`\" to the name, so that the previous name may be used for other product types.
   * @summary Remove a product type
   * @param {Object} [query] Query object
   * @param {string} [query.productType] A server-supplied value which identifies the product type instance.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public removeProductType(
    query?: { productType?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).removeProductType(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this product type. Changes to the `state` follow the rules described in this API's description. <p> To change the state of a product type,  use the `apiture:activate`, `apiture:deactivate`, or `apiture:remove` links on the resource to `POST` the product type URI to one of the paths, `/activeProductTypes`, `/inactiveProductTypes`, `/removedProductTypes`. </p>
   * @summary Update this product type
   * @param {ProductType} ProductType
   * @param {string} productTypeId The unique identifier of this product type. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ProductType}
   * @memberof ProductTypeApi
   */
  public updateProductType(
    ProductType: ProductType,
    productTypeId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ProductTypeApiFp(this.configuration).updateProductType(
      ProductType ? ProductType : null,
      productTypeId ? productTypeId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
