// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Transfers
 * Clients can use the Transfers API to schedule transfer requests to move funds from one account to another. Transfers are one-time transfers or recurring transfers, based on the transfer's [`schedule`](#schema-schedule). To schedule a new transfer, use the [`createScheduledTransfer`](#op-createScheduledTransfer) operation. Use the [`getScheduledTransfers`](#op-getScheduledTransfers) operation to list the user's scheduled transfers. Scheduled transfers which have been processed are automatically removed from `/scheduledTransfers`. The [`getPastTransfers`](#op-getPastTransfers) operation returns the history of processed or canceled transfers.
 *
 * OpenAPI spec version: 0.12.8
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/transfers'.replace(/\/+$/, '');

export const API_VERSION = '0.12.8';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * Different representations of an account number.
 * @export
 * @interface AccountNumbers
 */
export interface AccountNumbers {
  /**
   * A partial account number that does not contain all the digits of the full account number. This masked number appears in statements or in user experience presentation. It is sufficient for a user to differentiate this account from other accounts they hold, but is not sufficient for initiating transfers, etc. The first character is the mask character and is repeated; this does not indicate that the full account number is the same as the mask length. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  masked?: string;
  /**
   * The full account number. This value only appears when `?unmasked=true` is passed on the `GET` request. Not included in the summary representation of the account that is included in account collection responses. This value is derived and immutable.
   * @type {string}
   * @memberof AccountNumbers
   */
  full?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Represents the configuration for various services.
 * @export
 * @interface Configuration
 */
export interface Configuration {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Configuration
   */
  _links?: { [key: string]: Link };
}

/**
 * Represents a configuration group.
 * @export
 * @interface ConfigurationGroup
 */
export interface ConfigurationGroup extends ConfigurationGroupSummary {
  /**
   * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
   * @type {{ [key: string]: ConfigurationSchemaValue; }}
   * @memberof ConfigurationGroup
   */
  schema?: { [key: string]: ConfigurationSchemaValue };
  /**
   * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
   * @type {{ [key: string]: ConfigurationValue; }}
   * @memberof ConfigurationGroup
   */
  values?: { [key: string]: ConfigurationValue };
}

/**
 * A summary of the data contained within a configuration group resource.
 * @export
 * @interface ConfigurationGroupSummary
 */
export interface ConfigurationGroupSummary extends AbstractResource {
  /**
   * The name of this configuration group, must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  name?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  description?: string;
}

/**
 * Collection of configuration groups. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ConfigurationGroups
 */
export interface ConfigurationGroups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ConfigurationGroups
   */
  _embedded?: any;
}

/**
 * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
 * @export
 * @interface ConfigurationSchema
 */
export interface ConfigurationSchema {
  [key: string]: ConfigurationSchemaValue;
}

/**
 * The data associated with this configuration schema.
 * @export
 * @interface ConfigurationSchemaValue
 */
export interface ConfigurationSchemaValue {}

/**
 * The data associated with this configuration.
 * @export
 * @interface ConfigurationValue
 */
export interface ConfigurationValue {}

/**
 * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
 * @export
 * @interface ConfigurationValues
 */
export interface ConfigurationValues {
  [key: string]: ConfigurationValue;
}

/**
 * Representation used to schedule a new transfer. The request includes the amount of the transfer and the schedule in the body, and the source and target accounts in the request's `_links` via the link relations `apiture:source` and `apiture:target`, and the user who scheduled the transfer in the request's `_links` via the link relation `apiture:creator`.
 * @export
 * @interface CreateScheduledTransfer
 */
export interface CreateScheduledTransfer extends AbstractResource, TransferFields {}

/**
 * @export
 * @namespace CreateScheduledTransfer
 */
export namespace CreateScheduledTransfer {}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values. Labels and descriptions for the enumeration values are in the `ifxType` key in the response of the `getLabels` operation.  <strong><code>ifxType</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named ifxType)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  These enumeration values are further described by the [label group](https://developer.apiture.com/concepts/label-groups) named `ifxType` in the response from the [`getLabels`](#op-getLabels) operation.  <tr>     <td><strong><code>CCA</code></strong></td><td>Credit card account</td>     </tr> <tr>     <td><strong><code>CDA</code></strong></td><td>Certificate of deposit account (CD)</td>     </tr> <tr>     <td><strong><code>CLA</code></strong></td><td>Commercial loan account</td>     </tr> <tr>     <td><strong><code>CMA</code></strong></td><td>Cash management account</td>     </tr> <tr>     <td><strong><code>DDA</code></strong></td><td>Demand deposit account</td>     </tr> <tr>     <td><strong><code>EQU</code></strong></td><td>Home equity loan</td>     </tr> <tr>     <td><strong><code>GLA</code></strong></td><td>General ledger account</td>     </tr> <tr>     <td><strong><code>ILA</code></strong></td><td>Installment loan account</td>     </tr> <tr>     <td><strong><code>INV</code></strong></td><td>Investment account</td>     </tr> <tr>     <td><strong><code>IRA</code></strong></td><td>Individual retirement account</td>     </tr> <tr>     <td><strong><code>IRL</code></strong></td><td>Accounts held in Ireland</td>     </tr> <tr>     <td><strong><code>LOC</code></strong></td><td>Consumer line of credit</td>     </tr> <tr>     <td><strong><code>MLA</code></strong></td><td>Military Lending Account: Credit facility held by former US service member</td>     </tr> <tr>     <td><strong><code>MMA</code></strong></td><td>Money market account</td>     </tr> <tr>     <td><strong><code>PBA</code></strong></td><td>Packaged bank Account: Account with additional benefits that charges a fixed monthly fee.</td>     </tr> <tr>     <td><strong><code>PPA</code></strong></td><td>Private pension administrator</td>     </tr> <tr>     <td><strong><code>RWD</code></strong></td><td>Reward accounts</td>     </tr> <tr>     <td><strong><code>SDA</code></strong></td><td>Savings deposit account</td>     </tr> </table>   This schema is version `v1.0.0`.
 * @export
 * @enum {string}
 */
export enum IfxType {
  CCA = 'CCA',
  CDA = 'CDA',
  CLA = 'CLA',
  CMA = 'CMA',
  DDA = 'DDA',
  EQU = 'EQU',
  GLA = 'GLA',
  ILA = 'ILA',
  INV = 'INV',
  IRA = 'IRA',
  IRL = 'IRL',
  LOC = 'LOC',
  MLA = 'MLA',
  MMA = 'MMA',
  PBA = 'PBA',
  PPA = 'PPA',
  RWD = 'RWD',
  SDA = 'SDA',
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Represents a transfer that has been processed or canceled (one that is no longer scheduled).  If the `state` of the processed transfer is `failed`, the `_error` object will contain details of the failure, including a `message`. The `_error.type` field will be an identifier string, one of:  * **`insufficientFunds`** - the source account did not have sufficient  funds at the time the transfer was processed.  * **`frozenAccount`** - The source or target account was frozen  at the time the transfer was processed. The `_error.attributes.account`  will indicate which account, one of `source` or `target`.  * **`amountOutOfRange`** - The transfer amount was outside the  account minimum and maximum  at the time the transfer was processed. The `_error.attributes.minimum`  and `_error.attributes.maximum` will indicate the allowed range  (these values are positiveMoney/currency objects).  * **`inactiveAccount`** - The source or target account was inactive  at the time the transfer was processed. The `_error.attributes.account`  will indicate which account, one of `source` or `target`.  * **`invalidAccount`** - The source or target account was invalid  for some other reason at the time the transfer was processed.  The `_error.attributes.account` will indicate which account,  one of `source` or `target`.  * **`inactiveUser`** - The user account was inactive  at the time the transfer was processed.  * **`missingAccountNumber`** - The account number was missing  for the source or target account at the time the transfer was processed.  The `_error.attributes.account` will indicate which account,  one of `source` or `target`.
 * @export
 * @interface PastTransfer
 */
export interface PastTransfer extends AbstractResource, SummaryPastTransfer, TransferAttribution {
  /**
   * A unique transaction confirmation ID.
   * @type {string}
   * @memberof PastTransfer
   */
  confirmationId?: string;
  /**
   * The date/time when the transfer was completed.
   * @type {Date}
   * @memberof PastTransfer
   */
  completedAt?: Date;
}

/**
 * @export
 * @namespace PastTransfer
 */
export namespace PastTransfer {}

/**
 * Collection of past transfers. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface PastTransfers
 */
export interface PastTransfers extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof PastTransfers
   */
  _embedded?: any;
}

/**
 * An amount of money in a specific currency, supporting only positive amounts.
 * @export
 * @interface PositiveMoney
 */
export interface PositiveMoney {
  /**
   * The monetary value, supporting only positive amounts. The numeric value is  represented as a string so that it can be exact with no loss of precision.
   * @type {string}
   * @memberof PositiveMoney
   */
  value?: string;
  /**
   * The [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) for this monetary value. This is always upper case ASCII.
   * @type {string}
   * @memberof PositiveMoney
   */
  currency?: string;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * A definition for a one-time or recurring scheduled transfer. Some financial institutions may limit scheduled transfers such that the transfer must be within 365 days.
 * @export
 * @interface Schedule
 */
export interface Schedule {
  /**
   * When the transfer occurs, or when a recurring transfer begins. This is a date-time in [RFC 3339](https://tools.ietf.org/html/rfc3339) `yyyy-mm-ddTHH:MM:SSZ` format. If present, the time portion is a *hint*; the financial institution may not be able to schedule events at specific times. If `start` is not provided, the current date will be used. If `start` is after the end of processing for the current day, the event may be scheduled for the next processing day.
   * @type {Date}
   * @memberof Schedule
   */
  start?: Date;
  /**
   * The `every` period indicates the interval at which the transfer recurs, such as every week, every month, every 3 months. If omitted or empty, this transfer is a one-time transfer.  `every` is **required** if either `maximumCount` is greater than 1 or if `end` is greater than `start`.  This value is an [ISO 8601 duration](https://en.wikipedia.org/wiki/ISO_8601#Durations) string of the form `P[n]Y[n]M[n]D` to specify the number of years/months/days between transfers. For example, use `P7D` to transfer every week, `P2M` to transfer every other month, `P4Y` to transfer every four years on the anniversary set by `start`. Time values in `every` are ignored but may be honored in the future. (That is, it is not possible to schedule a transfer every 8 hours; the minimum is `P1D`.) To specify semi-monthly or semi-annually, use `P0.5M` or `P0.5Y`. Fractional values are only allowed for month and year, and `0.5`  is the only allowed fractional value.  Some financial institutions may limit recurring transfers such that the period must be a year (`P1Y`, `P12M`, `P365D`) or less.  Scheduling may adjust transfer dates if `start` occurs near boundary dates which do occur not every year/month, such as `start: \"2018-01-31\", every: \"P1M\"`. For example, the next transfer may occur on the 30th for months which have only 30 days (Apr, Jun, Sep, Nov), or 29th or 28th for February. Actual transfer dates may also be adjusted to account for holidays or other days when processing does not occur.
   * @type {string}
   * @memberof Schedule
   */
  every?: string;
  /**
   * For a recurring transfer, this is the number of transfers which have been processed. It is a derived value and ignored on updates.
   * @type {number}
   * @memberof Schedule
   */
  count?: number;
  /**
   * If `true` for a monthly, recurring transfer, this value indicates that  all future transfers in the series should be executed on the _first_  processing day of the month.  The first transfer in the series executes  according to the optional `start` date, if supplied. This value is ignored  if included on non-monthly recurring transfer series.  It is an error if  both `first` and `last` are true.
   * @type {boolean}
   * @memberof Schedule
   */
  first?: boolean;
  /**
   * If `true` for a monthly, recurring transfer, this value indicates that  all future transfers in the series should be executed on the _last_  processing day of the month.  The first transfer in the series executes  according to the optional `start` date, if supplied. This value is ignored  if included on non-monthly recurring transfer series.  It is an error if  both `first` and `last` are true.
   * @type {boolean}
   * @memberof Schedule
   */
  last?: boolean;
  /**
   * The maximum number of transfers to perform for a recurring transfer. (Transfers in the recurrence will stop if the current date is beyond that set by `end`, even if fewer than `maximumCount` transfers have occurred). The `every` period is required if `maximumCount` or `end` is set. It is an error (422) if `maximumCount` is anything other than 0 or 1 and `every` is not set.  If a schedule contains both `end` and `maximumCount`, the _earliest_ will determine when the recurrence ends. Otherwise, the Transfers service will compute the other field.
   * @type {number}
   * @memberof Schedule
   */
  maximumCount?: number;
  /**
   * The optional date when the recurring transfer ends (inclusive). Transfers recur until the `maximumCount` of transfers are met _or_ the next transfer is _after_ the `end` date. (The earliest of `maximumCount` or `end` wins). If specified, `end` must be no earlier than `start`. This is a date in [RFC 3339](https://tools.ietf.org/html/rfc3339) `yyyy-mm-dd` format.   When scheduling a recurring transfer, the request should contain either `maximumCount` or `end`, but not both. The other field will be computed.
   * @type {string}
   * @memberof Schedule
   */
  end?: string;
}

/**
 * Representation of a transfer resource: a transfer of funds from one account to another.  A transfer consists of an amount, a source account, a target account, and a schedule which specifies a one-time transfer or a recurring transfer. In addition to the normal `self` link, The links for a transfer include:    * **`apiture:transactions`** - the collection of completed transactions associated with this transfer.   * **`apiture:source`** - The source account where funds will be debited.   * **`apiture:target`** - The target account where funds will be credited.   * **`apiture:cancel`** - Cancel a transfer; this link is only   available if the transfer may be canceled.   * **`apiture:suspend`** - Suspend a transfer; this link is only   available if the transfer may be suspended.   * **`apiture:suspend`** - Resume a suspended transfer; this link is only   available if the transfer is suspended.   * **`apiture:creator`** - The user who scheduled the transfer  The `_embedded` object contains `transactions`, which contains the first page of transactions matching this transfer, and the summary representations of the  `source` and `target` accounts.
 * @export
 * @interface ScheduledTransfer
 */
export interface ScheduledTransfer extends UpdateScheduledTransfer, TransferAttribution {}

/**
 * @export
 * @namespace ScheduledTransfer
 */
export namespace ScheduledTransfer {}

/**
 * Collection of scheduled transfers. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ScheduledTransfers
 */
export interface ScheduledTransfers extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ScheduledTransfers
   */
  _embedded?: any;
}

/**
 * Summary representation of a past transfer resource. The summary includes the transfer ID, description, amount, state, and schedule, and the `_links` indicate the source and target accounts. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. For transfers which have failed, the `_error` object will describe the error circumstances.
 * @export
 * @interface SummaryPastTransfer
 */
export interface SummaryPastTransfer extends SummaryScheduledTransfer {}

/**
 * @export
 * @namespace SummaryPastTransfer
 */
export namespace SummaryPastTransfer {}

/**
 * Summary representation of a scheduled transfer resource. The summary includes the transfer ID, description, amount, state, and schedule, and the `_links` indicate the source and target accounts. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects. For transfers which have failed, the `_error` object will describe the error circumstances.
 * @export
 * @interface SummaryScheduledTransfer
 */
export interface SummaryScheduledTransfer extends AbstractResource, TransferFields {
  /**
   * The state of the transfer. This is a _derived_ and _immutable_ value. The Transfers service processing updates the `state`. The `state` can be one of the following:     * *`scheduled`* -   A transfer is `scheduled` after a new one-time transfer is   approved; it is scheduled to occur in the future.   * *`recurring`* -   A transfer is `recurring` after a new recurring transfer is   approved; it is scheduled to start in the future.   * *`pendingApproval`* -   The source or target account is an external account which has   not been verified. The financial institution may review   the transfer and approve or deny it (the state will change   to `scheduled` or `failed`).   * *`processing`* -   A transfer which has been begun and is currently being processed. A   processing transfer can be modified as long as the transfer cutoff time   has not passed.  Once the cutoff time passes, the transfer cannot   be modified (the amount or schedule may not be changed).   To change a recurring transfer after the cutoff time, wait for the   state to change back to `recurring`.   * *`suspended`* -   A scheduled recurring transfer which is temporarily suspended or   paused. No further transfer of funds will occur until it   is resumed. If it is resumed, any missed transfers will not be performed.   * *`canceled`* -   A transfer which has been canceled. No further transfer of funds   will occur.  Canceled transfers cannot be restarted; create a new   one instead, or suspend/resume them instead of canceling.   A canceled transfer   cannot be modified. **Note**: There is no way to cancel specific   transfers within a recurring transfer; instead, suspend the   transfer and resume it after the desired date has passed.   * *`failed`* -   A transfer which failed. The `_error` will indicate the cause. A   completed transfer cannot be modified.   * *`completed`* -   A transfer which has completed successfully. A completed transfer   cannot be modified.   The client may change state in a limited number of ways: suspending a scheduled or recurring transaction via `POST` to the `/suspendedScheduledTransfers`; resuming a suspended recurring transaction via `POST` to the `/resumedScheduledTransfers`; canceling a scheduled transaction via `POST` to the `/canceledScheduledTransfers`. These operations are available with the `apiture:suspend`, `apiture:resume`, `apiture:cancel` links, respectively, on an instance. canceled by `POST`ing to `/canceledTransfers`. No request body is used on these operations.
   * @type {string}
   * @memberof SummaryScheduledTransfer
   */
  state?: SummaryScheduledTransfer.StateEnum;
  /**
   * The unique identifier for this transfer resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryScheduledTransfer
   */
  _id?: string;
}

/**
 * @export
 * @namespace SummaryScheduledTransfer
 */
export namespace SummaryScheduledTransfer {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Scheduled = 'scheduled',
    Recurring = 'recurring',
    Processing = 'processing',
    Suspended = 'suspended',
    Completed = 'completed',
    Canceled = 'canceled',
    Failed = 'failed',
  }
}

/**
 * **Note**: This model schema is deprecated and only used by deprecated operations. See scheduledTransfer instead.  Representation of a transfer resource: a transfer of funds from one account to another.
 * @export
 * @interface Transfer
 */
export interface Transfer extends ScheduledTransfer {}

/**
 * @export
 * @namespace Transfer
 */
export namespace Transfer {}

/**
 * Summary properties of the source and target account for a transfer.
 * @export
 * @interface TransferAccount
 */
export interface TransferAccount extends AbstractResource {
  /**
   * The title of the account. Traditionally, this is the name of the account holder. This field is deprecated and will be removed in a future release; use `title` instead.
   * @type {string}
   * @memberof TransferAccount
   */
  accountTitle?: string;
  /**
   * The title of the account. Traditionally, this is the name of the account holder.
   * @type {string}
   * @memberof TransferAccount
   */
  title?: string;
  /**
   * The name of the financial institution.
   * @type {string}
   * @memberof TransferAccount
   */
  institutionName?: string;
  /**
   * The account routing number which identifies the financial institution. The full routing number and full account number are required to fully identify the account.
   * @type {string}
   * @memberof TransferAccount
   */
  routingNumber?: string;
  /**
   * The account numbers for this account
   * @type {AccountNumbers}
   * @memberof TransferAccount
   */
  accountNumbers?: AccountNumbers;
  /**
   * A code which identifies the product type. This is one of the [IFX AcctType](https://ifxforum.org) values.
   * @type {IfxType}
   * @memberof TransferAccount
   */
  ifxType?: IfxType;
}

/**
 * Fields of transfers which are derived, used to build other schemas.
 * @export
 * @interface TransferAttribution
 */
export interface TransferAttribution {
  /**
   * The user who created/scheduled the transfer.
   * @type {string}
   * @memberof TransferAttribution
   */
  createdBy?: string;
  /**
   * The [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time when the transfer was scheduled/created.
   * @type {Date}
   * @memberof TransferAttribution
   */
  createdAt?: Date;
  /**
   * The user who last modified the scheduled transfer.
   * @type {string}
   * @memberof TransferAttribution
   */
  modifiedBy?: string;
  /**
   * The [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time when the transfer was last modified.
   * @type {Date}
   * @memberof TransferAttribution
   */
  modifiedAt?: Date;
  /**
   * Summary properties of the source account for a transfer
   * @type {TransferAccount}
   * @memberof TransferAttribution
   */
  sourceAccount?: TransferAccount;
  /**
   * Summary properties of the target account for a transfer
   * @type {TransferAccount}
   * @memberof TransferAttribution
   */
  targetAccount?: TransferAccount;
}

/**
 * Fields of the transfer resource, used to build other model schema.
 * @export
 * @interface TransferFields
 */
export interface TransferFields {
  /**
   * The amount of the transfer. For a transfer, the amount must be positive. The funding account must have sufficient available funds. Financial institutions may impose an upper limit on the amount in a transfer which may be lower than the available balance.
   * @type {PositiveMoney}
   * @memberof TransferFields
   */
  amount?: PositiveMoney;
  /**
   * A description of this transfer.
   * @type {string}
   * @memberof TransferFields
   */
  description?: string;
  /**
   * Describes when the transfer is scheduled to occur.
   * @type {Schedule}
   * @memberof TransferFields
   */
  schedule?: Schedule;
  /**
   * The type of transfer.  An `internal` transfer is one where both the source and target account reside within the current financial institution. `ach` (Automated Clearinghouse) is for standard cross-institution, U.S. only transfers. `ach` transfers are typically processed in batches. `wire` transfers (not implemented in this release), can be processed faster (they may not depend on batch processing) and can also involve financial institution outside the U.S. However, wire transfers have higher fees.  This field is optional, but immutable after being set. The default is `ach` if either the source or target account is external, and `internal` if both accounts are internal. It is an error to set the type to `ach` or `wire` for transfers between internal accounts, or to set `type` to `internal` if either the source or target account is external.
   * @type {string}
   * @memberof TransferFields
   */
  type?: TransferFields.TypeEnum;
  /**
   * If true, the transfer is for funding a new account. Initial funding transfers have different transfer limits and schedule validation. This field is immutable after creating a transfer. This must be false for recurring transfers.
   * @type {boolean}
   * @memberof TransferFields
   */
  initialFunding?: boolean;
  /**
   * The transfer may be visible or hidden. Some transfers are _micro-deposit_ ACH transfers into a local account from an external account as part of external account verification. These transfers are _hidden_ from the user: the user may only see the transfer amounts by viewing their external account (via that external financial institution). Hidden transfers are by default omitted from the `/scheduledTransfers` and `/pastTransfers` collections. Financial institution administrators, however, can view hidden transfers.
   * @type {string}
   * @memberof TransferFields
   */
  visibility?: TransferFields.VisibilityEnum;
  /**
   * The confirmation id that the transfer request was received for processing.
   * @type {string}
   * @memberof TransferFields
   */
  confirmationId?: string;
  /**
   * Additional unstructured application metadata about the transfer.
   * @type {Attributes}
   * @memberof TransferFields
   */
  attributes?: Attributes;
}

/**
 * @export
 * @namespace TransferFields
 */
export namespace TransferFields {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    Internal = 'internal',
    Ach = 'ach',
    Wire = 'wire',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum VisibilityEnum {
    Visible = 'visible',
    Hidden = 'hidden',
  }
}

/**
 * Representation used to update or patch an existing scheduled transfer. The representation includes the transfer ID, description, amount, state, and schedule, and the `_links` indicate the source and target accounts. An update to a transfer ignores the `_embedded` object.
 * @export
 * @interface UpdateScheduledTransfer
 */
export interface UpdateScheduledTransfer extends SummaryScheduledTransfer {}

/**
 * @export
 * @namespace UpdateScheduledTransfer
 */
export namespace UpdateScheduledTransfer {}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API.
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API.
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * ConfigurationApi - axios parameter creator
 * @export
 */
export const ConfigurationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options: any = {}): RequestArgs {
      const localVarPath = `/configurations`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroup.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupSchema.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/schema`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to the individual values` of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/configurations/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual `values` of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).  This operation is reserved for administrators.
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this set of values. This operation is reserved for administrators.
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: ConfigurationValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConfigurationApi - functional programming interface
 * @export
 */
export const ConfigurationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Configuration> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(configuration).getConfiguration(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroup> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to the individual values` of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroups> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroups(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual `values` of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).  This operation is reserved for administrators.
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this set of values. This operation is reserved for administrators.
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConfigurationApi - factory interface
 * @export
 */
export const ConfigurationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Returns the configuration for this API
     * @summary Configuration definition for this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfiguration(options?: any) {
      return ConfigurationApiFp(configuration).getConfiguration(options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(groupName: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to the individual values` of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroups(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual `values` of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).  This operation is reserved for administrators.
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this set of values. This operation is reserved for administrators.
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConfigurationApi - object-oriented interface
 * @export
 * @class ConfigurationApi
 * @extends {BaseAPI}
 */
export class ConfigurationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Returns the configuration for this API
   * @summary Configuration definition for this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Configuration}
   * @memberof ConfigurationApi
   */
  public getConfiguration(options?: any) {
    return ConfigurationApiFp(this.configuration).getConfiguration(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
   * @summary Fetch a representation of this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroup}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroup(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroup(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
   * @summary Fetch the schema for this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupSchema(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupSchema(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single value associated with this configuration group. This provides convenient access to the individual values` of the configuration group.  The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To update a specific value, use `PUT /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
   * @summary Fetch a single value associated with the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValue(
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a representation of this configuration group values resource.
   * @summary Fetch the values for the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValues(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValues(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of configuration groups
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroups}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroups(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroups(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single value associated with this configuration group. This provides convenient access to individual `values` of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent.  The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`.   Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }`   To fetch specific value, use `GET /transfers/configurations/groups/{groupName}/values/{valueName}` (operation `getConfigurationGroupValue`).  This operation is reserved for administrators.
   * @summary Update a single value associated with the specified configuration group
   * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValue(
    body: string,
    groupName: string,
    valueName: string,
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValue(
      body ? body : null,
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this set of values. This operation is reserved for administrators.
   * @summary Update the values for the specified configuration group
   * @param {{ [key: string]: ConfigurationValue; }} request_body
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValue}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValues(
    request_body: { [key: string]: ConfigurationValue },
    groupName: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValues(
      request_body ? request_body : null,
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * PastTransferApi - axios parameter creator
 * @export
 */
export const PastTransferApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource.
     * @summary Fetch a representation of this past transfer
     * @param {string} pastTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfer(
      pastTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { unmasked } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'pastTransferId' is not null or undefined
      if (pastTransferId === null || pastTransferId === undefined) {
        throw new RequiredError(
          'pastTransferId',
          'Required parameter pastTransferId was null or undefined when calling getPastTransfer.',
        );
      }
      const localVarPath = `/pastTransfers/{pastTransferId}`.replace(
        `{${'pastTransferId'}}`,
        encodeURIComponent(String(pastTransferId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of past transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Past transfers are transfers which have been processed or canceled.
     * @summary Return a collection of past transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options: any = {},
    ): RequestArgs {
      const {
        start,
        limit,
        sortBy,
        filter,
        q,
        state,
        name,
        account,
        sourceAccount,
        targetAccount,
      } = query;

      const localVarPath = `/pastTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state) {
        localVarQueryParameter['state'] = state.join(COLLECTION_FORMATS['csv']);
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (sourceAccount !== undefined) {
        localVarQueryParameter['sourceAccount'] = sourceAccount;
      }

      if (targetAccount !== undefined) {
        localVarQueryParameter['targetAccount'] = targetAccount;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PastTransferApi - functional programming interface
 * @export
 */
export const PastTransferApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource.
     * @summary Fetch a representation of this past transfer
     * @param {string} pastTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfer(
      pastTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<PastTransfer> {
      const localVarAxiosArgs = PastTransferApiAxiosParamCreator(configuration).getPastTransfer(
        pastTransferId ? pastTransferId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of past transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Past transfers are transfers which have been processed or canceled.
     * @summary Return a collection of past transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<PastTransfers> {
      const localVarAxiosArgs = PastTransferApiAxiosParamCreator(configuration).getPastTransfers(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PastTransferApi - factory interface
 * @export
 */
export const PastTransferApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource.
     * @summary Fetch a representation of this past transfer
     * @param {string} pastTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfer(
      pastTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return PastTransferApiFp(configuration).getPastTransfer(
        pastTransferId ? pastTransferId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of past transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Past transfers are transfers which have been processed or canceled.
     * @summary Return a collection of past transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPastTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options?: any,
    ) {
      return PastTransferApiFp(configuration).getPastTransfers(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PastTransferApi - object-oriented interface
 * @export
 * @class PastTransferApi
 * @extends {BaseAPI}
 */
export class PastTransferApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource.
   * @summary Fetch a representation of this past transfer
   * @param {string} pastTransferId The unique identifier of this scheduled transfer. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {PastTransfer}
   * @memberof PastTransferApi
   */
  public getPastTransfer(
    pastTransferId: string,
    query?: { unmasked?: boolean },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return PastTransferApiFp(this.configuration).getPastTransfer(
      pastTransferId ? pastTransferId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of past transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.  Past transfers are transfers which have been processed or canceled.
   * @summary Return a collection of past transfers
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
   * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
   * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {PastTransfers}
   * @memberof PastTransferApi
   */
  public getPastTransfers(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: Array<
        'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'
      >;
      name?: string;
      account?: string;
      sourceAccount?: string;
      targetAccount?: string;
    },
    options?: any,
  ) {
    return PastTransferApiFp(this.configuration).getPastTransfers(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ScheduledTransferApi - axios parameter creator
 * @export
 */
export const ScheduledTransferApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * `POST` the URI of a scheduled transfer to cancel it. This cancels all future recurring transfers. Any transfers that would have occurred on future dates will be canceled. This operation is only valid on scheduled transfers which are in the `scheduled`, `recurring`, or `suspended` state. It may also be allowed if the transfer state is `processing`  and the optional cutoff time has not passed.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:cancel`* link, The link will be present if the transfer can be canceled.
     * @summary Cancel a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { scheduledTransfer, scheduledTransferUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'scheduledTransfer' is not null or undefined
      if (scheduledTransfer === null || scheduledTransfer === undefined) {
        throw new RequiredError(
          'scheduledTransfer',
          'Required parameter scheduledTransfer was null or undefined when calling cancelScheduledTransfer.',
        );
      }
      const localVarPath = `/canceledScheduledTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (scheduledTransfer !== undefined) {
        localVarQueryParameter['scheduledTransfer'] = scheduledTransfer;
      }

      if (scheduledTransferUri !== undefined) {
        localVarQueryParameter['scheduledTransferUri'] = scheduledTransferUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * This operation adds either a new one-time or a recurring transfer, depending on the content of the embedded `schedule`.  The request includes the amount of the transfer in the body, and the source and target accounts in the request's `_links` via the link relations `apiture:source` and `apiture:target`. The accounts must be active and available for transfers and the amount must be in the allowed transfer range.  If the request's transfer date (`schedule.start`) is the current day, the financial institution is processing transfers on that day, and the time is _before_ the financial institution's transfer processing cutoff time, internal transfers will be processed as soon as possible and the transfer `state` will change to `processing` and then `completed`. If the request's transfer date (`schedule.start`) is the current day and the time is _past_ the cutoff time, the transfer will be processed on the _next_ processing day. The cutoff time is available as `cutoffTime` via this service's `basic` configuration values `GET /transfers/configurations/groups/basic/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/basic/schema`.  If the transfer is scheduled for a future date that  is _not_ a valid transfer processing day, the request fails with a 400 error. The holidays and other non-processing days are available via this service's `calendar` configuration values `GET /transfers/configurations/groups/calendar/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/calendar/schema`.  The service will reject duplicate requests, defined by a request that exactly matches an existing transfer (same `amount`, `schedule`, `description`, source and target accounts), returning a *409 Conflict* status. To schedule a duplicate transfer with the same amount, schedule, and accounts, change at least the `description`.  Scheduled transfers will be deleted automatically at some point after they have completed (typically 7 days), up until which they are available with a `state` of `completed` if successful or `failed` if not.
     * @summary Create a new scheduled transfer request
     * @param {CreateScheduledTransfer} CreateScheduledTransfer The data necessary to create a new transfer.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createScheduledTransfer(
      CreateScheduledTransfer: CreateScheduledTransfer,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'CreateScheduledTransfer' is not null or undefined
      if (CreateScheduledTransfer === null || CreateScheduledTransfer === undefined) {
        throw new RequiredError(
          'CreateScheduledTransfer',
          'Required parameter CreateScheduledTransfer was null or undefined when calling createScheduledTransfer.',
        );
      }
      const localVarPath = `/scheduledTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateScheduledTransfer' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateScheduledTransfer || {})
        : CreateScheduledTransfer || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this transfer. Any processing transfers may complete; future scheduled transfers, if this is a recurring transfer, will be canceled. After deleting a transfer, there is no direct access to the transactions or transaction errors.
     * @summary Delete this scheduled transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteScheduledTransfer(
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'scheduledTransferId' is not null or undefined
      if (scheduledTransferId === null || scheduledTransferId === undefined) {
        throw new RequiredError(
          'scheduledTransferId',
          'Required parameter scheduledTransferId was null or undefined when calling deleteScheduledTransfer.',
        );
      }
      const localVarPath = `/scheduledTransfers/{scheduledTransferId}`.replace(
        `{${'scheduledTransferId'}}`,
        encodeURIComponent(String(scheduledTransferId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request.
     * @summary Fetch a representation of this transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfer(
      scheduledTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { unmasked } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'scheduledTransferId' is not null or undefined
      if (scheduledTransferId === null || scheduledTransferId === undefined) {
        throw new RequiredError(
          'scheduledTransferId',
          'Required parameter scheduledTransferId was null or undefined when calling getScheduledTransfer.',
        );
      }
      const localVarPath = `/scheduledTransfers/{scheduledTransferId}`.replace(
        `{${'scheduledTransferId'}}`,
        encodeURIComponent(String(scheduledTransferId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (unmasked !== undefined) {
        localVarQueryParameter['unmasked'] = unmasked;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of scheduled transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options: any = {},
    ): RequestArgs {
      const {
        start,
        limit,
        sortBy,
        filter,
        q,
        state,
        name,
        account,
        sourceAccount,
        targetAccount,
      } = query;

      const localVarPath = `/scheduledTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state) {
        localVarQueryParameter['state'] = state.join(COLLECTION_FORMATS['csv']);
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (account !== undefined) {
        localVarQueryParameter['account'] = account;
      }

      if (sourceAccount !== undefined) {
        localVarQueryParameter['sourceAccount'] = sourceAccount;
      }

      if (targetAccount !== undefined) {
        localVarQueryParameter['targetAccount'] = targetAccount;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this transfer. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. If the `state` of the transfer allows, this operation may change the `description`, `amount`, and `schedule`; the source and target accounts and `_embedded` objects may not be changed. In the schedule, the user may not changed the `count`. The user may not change the `state`.  This update operation is subject to the same constraints defined in the `createTransfer` (`POST /transfers/transfers`) operation.
     * @summary Update this scheduled transfer
     * @param {UpdateScheduledTransfer} UpdateScheduledTransfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchScheduledTransfer(
      UpdateScheduledTransfer: UpdateScheduledTransfer,
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'scheduledTransferId' is not null or undefined
      if (scheduledTransferId === null || scheduledTransferId === undefined) {
        throw new RequiredError(
          'scheduledTransferId',
          'Required parameter scheduledTransferId was null or undefined when calling patchScheduledTransfer.',
        );
      }
      // verify required parameter 'UpdateScheduledTransfer' is not null or undefined
      if (UpdateScheduledTransfer === null || UpdateScheduledTransfer === undefined) {
        throw new RequiredError(
          'UpdateScheduledTransfer',
          'Required parameter UpdateScheduledTransfer was null or undefined when calling patchScheduledTransfer.',
        );
      }
      const localVarPath = `/scheduledTransfers/{scheduledTransferId}`.replace(
        `{${'scheduledTransferId'}}`,
        encodeURIComponent(String(scheduledTransferId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateScheduledTransfer' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateScheduledTransfer || {})
        : UpdateScheduledTransfer || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * `POST` the URI of a suspended scheduled transfer to resume it. This enables future recurring transfers. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates. See also the `extendSchedule` query parameter on this operation. This operation is only valid on scheduled transfers which are in the `suspended` state.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:resume`* link, The link will be present if the transfer can be resumed.
     * @summary Resume a suspended scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {boolean} [query.extendSchedule] If true, the &#x60;schedule.end&#x60; will be extended if necessary so that the &#x60;maximumCount&#x60; number of transfers will be made (based on the periods in &#x60;every&#x60;).  The default value (&#x60;false&#x60;) prevents processing transfers that the user may not expect based on the original schedule. (The user may still update the &#x60;schedule.end&#x60; via &#x60;PATCH&#x60; to the scheduled transfer.)
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    resumeScheduledTransfer(
      query?: {
        scheduledTransfer?: string;
        scheduledTransferUri?: string;
        extendSchedule?: boolean;
      },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { scheduledTransfer, scheduledTransferUri, extendSchedule } = query;
      const { If_Match } = headers;

      // verify required parameter 'scheduledTransfer' is not null or undefined
      if (scheduledTransfer === null || scheduledTransfer === undefined) {
        throw new RequiredError(
          'scheduledTransfer',
          'Required parameter scheduledTransfer was null or undefined when calling resumeScheduledTransfer.',
        );
      }
      const localVarPath = `/resumedScheduledTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (scheduledTransfer !== undefined) {
        localVarQueryParameter['scheduledTransfer'] = scheduledTransfer;
      }

      if (scheduledTransferUri !== undefined) {
        localVarQueryParameter['scheduledTransferUri'] = scheduledTransferUri;
      }

      if (extendSchedule !== undefined) {
        localVarQueryParameter['extendSchedule'] = extendSchedule;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Suspend a scheduled recurring transfer. This disables future recurring transfers until the scheduled transfer is either resumed or canceled. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates.  Use the `apiture:resume` or `apiture:cancel` links on the instance to resume or cancel the remaining transfers. This operation is only valid on scheduled transfers which are in `recurring` state, and only if the underlying bank core support suspending transfers.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:suspend`* link. The service includes the *`apiture:suspend`* link in the scheduled recurring transfer _if and only if_ the user may suspend the transfer _and_ if the banking core allows suspending. If the banking core does not allow suspending a recurring transfer, the user should instead [`cancel`](#op-cancelScheduledTransfer) the transfer and create a new one.  A client can check if the institution supports suspending transfers by accessing the `suspendScheduledTransfersEnabled` property in the `basic` [`getConfigurationGroupValue`](#op-getConfigurationGroupValue).
     * @summary Suspend a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    suspendScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { scheduledTransfer, scheduledTransferUri } = query;
      const { If_Match } = headers;

      // verify required parameter 'scheduledTransfer' is not null or undefined
      if (scheduledTransfer === null || scheduledTransfer === undefined) {
        throw new RequiredError(
          'scheduledTransfer',
          'Required parameter scheduledTransfer was null or undefined when calling suspendScheduledTransfer.',
        );
      }
      const localVarPath = `/suspendedScheduledTransfers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'banking/read',
                'banking/write',
                'banking/delete',
                'banking/readBalance',
                'banking/full',
                'admin/read',
                'admin/write',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (scheduledTransfer !== undefined) {
        localVarQueryParameter['scheduledTransfer'] = scheduledTransfer;
      }

      if (scheduledTransferUri !== undefined) {
        localVarQueryParameter['scheduledTransferUri'] = scheduledTransferUri;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ScheduledTransferApi - functional programming interface
 * @export
 */
export const ScheduledTransferApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * `POST` the URI of a scheduled transfer to cancel it. This cancels all future recurring transfers. Any transfers that would have occurred on future dates will be canceled. This operation is only valid on scheduled transfers which are in the `scheduled`, `recurring`, or `suspended` state. It may also be allowed if the transfer state is `processing`  and the optional cutoff time has not passed.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:cancel`* link, The link will be present if the transfer can be canceled.
     * @summary Cancel a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).cancelScheduledTransfer(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * This operation adds either a new one-time or a recurring transfer, depending on the content of the embedded `schedule`.  The request includes the amount of the transfer in the body, and the source and target accounts in the request's `_links` via the link relations `apiture:source` and `apiture:target`. The accounts must be active and available for transfers and the amount must be in the allowed transfer range.  If the request's transfer date (`schedule.start`) is the current day, the financial institution is processing transfers on that day, and the time is _before_ the financial institution's transfer processing cutoff time, internal transfers will be processed as soon as possible and the transfer `state` will change to `processing` and then `completed`. If the request's transfer date (`schedule.start`) is the current day and the time is _past_ the cutoff time, the transfer will be processed on the _next_ processing day. The cutoff time is available as `cutoffTime` via this service's `basic` configuration values `GET /transfers/configurations/groups/basic/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/basic/schema`.  If the transfer is scheduled for a future date that  is _not_ a valid transfer processing day, the request fails with a 400 error. The holidays and other non-processing days are available via this service's `calendar` configuration values `GET /transfers/configurations/groups/calendar/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/calendar/schema`.  The service will reject duplicate requests, defined by a request that exactly matches an existing transfer (same `amount`, `schedule`, `description`, source and target accounts), returning a *409 Conflict* status. To schedule a duplicate transfer with the same amount, schedule, and accounts, change at least the `description`.  Scheduled transfers will be deleted automatically at some point after they have completed (typically 7 days), up until which they are available with a `state` of `completed` if successful or `failed` if not.
     * @summary Create a new scheduled transfer request
     * @param {CreateScheduledTransfer} CreateScheduledTransfer The data necessary to create a new transfer.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createScheduledTransfer(
      CreateScheduledTransfer: CreateScheduledTransfer,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).createScheduledTransfer(
        CreateScheduledTransfer ? CreateScheduledTransfer : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this transfer. Any processing transfers may complete; future scheduled transfers, if this is a recurring transfer, will be canceled. After deleting a transfer, there is no direct access to the transactions or transaction errors.
     * @summary Delete this scheduled transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteScheduledTransfer(
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).deleteScheduledTransfer(
        scheduledTransferId ? scheduledTransferId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request.
     * @summary Fetch a representation of this transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfer(
      scheduledTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).getScheduledTransfer(
        scheduledTransferId ? scheduledTransferId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of scheduled transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfers> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).getScheduledTransfers(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this transfer. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. If the `state` of the transfer allows, this operation may change the `description`, `amount`, and `schedule`; the source and target accounts and `_embedded` objects may not be changed. In the schedule, the user may not changed the `count`. The user may not change the `state`.  This update operation is subject to the same constraints defined in the `createTransfer` (`POST /transfers/transfers`) operation.
     * @summary Update this scheduled transfer
     * @param {UpdateScheduledTransfer} UpdateScheduledTransfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchScheduledTransfer(
      UpdateScheduledTransfer: UpdateScheduledTransfer,
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Transfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).patchScheduledTransfer(
        UpdateScheduledTransfer ? UpdateScheduledTransfer : null,
        scheduledTransferId ? scheduledTransferId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * `POST` the URI of a suspended scheduled transfer to resume it. This enables future recurring transfers. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates. See also the `extendSchedule` query parameter on this operation. This operation is only valid on scheduled transfers which are in the `suspended` state.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:resume`* link, The link will be present if the transfer can be resumed.
     * @summary Resume a suspended scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {boolean} [query.extendSchedule] If true, the &#x60;schedule.end&#x60; will be extended if necessary so that the &#x60;maximumCount&#x60; number of transfers will be made (based on the periods in &#x60;every&#x60;).  The default value (&#x60;false&#x60;) prevents processing transfers that the user may not expect based on the original schedule. (The user may still update the &#x60;schedule.end&#x60; via &#x60;PATCH&#x60; to the scheduled transfer.)
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    resumeScheduledTransfer(
      query?: {
        scheduledTransfer?: string;
        scheduledTransferUri?: string;
        extendSchedule?: boolean;
      },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).resumeScheduledTransfer(query ? query : {}, headers ? headers : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Suspend a scheduled recurring transfer. This disables future recurring transfers until the scheduled transfer is either resumed or canceled. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates.  Use the `apiture:resume` or `apiture:cancel` links on the instance to resume or cancel the remaining transfers. This operation is only valid on scheduled transfers which are in `recurring` state, and only if the underlying bank core support suspending transfers.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:suspend`* link. The service includes the *`apiture:suspend`* link in the scheduled recurring transfer _if and only if_ the user may suspend the transfer _and_ if the banking core allows suspending. If the banking core does not allow suspending a recurring transfer, the user should instead [`cancel`](#op-cancelScheduledTransfer) the transfer and create a new one.  A client can check if the institution supports suspending transfers by accessing the `suspendScheduledTransfersEnabled` property in the `basic` [`getConfigurationGroupValue`](#op-getConfigurationGroupValue).
     * @summary Suspend a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    suspendScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ScheduledTransfer> {
      const localVarAxiosArgs = ScheduledTransferApiAxiosParamCreator(
        configuration,
      ).suspendScheduledTransfer(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ScheduledTransferApi - factory interface
 * @export
 */
export const ScheduledTransferApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * `POST` the URI of a scheduled transfer to cancel it. This cancels all future recurring transfers. Any transfers that would have occurred on future dates will be canceled. This operation is only valid on scheduled transfers which are in the `scheduled`, `recurring`, or `suspended` state. It may also be allowed if the transfer state is `processing`  and the optional cutoff time has not passed.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:cancel`* link, The link will be present if the transfer can be canceled.
     * @summary Cancel a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).cancelScheduledTransfer(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * This operation adds either a new one-time or a recurring transfer, depending on the content of the embedded `schedule`.  The request includes the amount of the transfer in the body, and the source and target accounts in the request's `_links` via the link relations `apiture:source` and `apiture:target`. The accounts must be active and available for transfers and the amount must be in the allowed transfer range.  If the request's transfer date (`schedule.start`) is the current day, the financial institution is processing transfers on that day, and the time is _before_ the financial institution's transfer processing cutoff time, internal transfers will be processed as soon as possible and the transfer `state` will change to `processing` and then `completed`. If the request's transfer date (`schedule.start`) is the current day and the time is _past_ the cutoff time, the transfer will be processed on the _next_ processing day. The cutoff time is available as `cutoffTime` via this service's `basic` configuration values `GET /transfers/configurations/groups/basic/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/basic/schema`.  If the transfer is scheduled for a future date that  is _not_ a valid transfer processing day, the request fails with a 400 error. The holidays and other non-processing days are available via this service's `calendar` configuration values `GET /transfers/configurations/groups/calendar/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/calendar/schema`.  The service will reject duplicate requests, defined by a request that exactly matches an existing transfer (same `amount`, `schedule`, `description`, source and target accounts), returning a *409 Conflict* status. To schedule a duplicate transfer with the same amount, schedule, and accounts, change at least the `description`.  Scheduled transfers will be deleted automatically at some point after they have completed (typically 7 days), up until which they are available with a `state` of `completed` if successful or `failed` if not.
     * @summary Create a new scheduled transfer request
     * @param {CreateScheduledTransfer} CreateScheduledTransfer The data necessary to create a new transfer.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createScheduledTransfer(CreateScheduledTransfer: CreateScheduledTransfer, options?: any) {
      return ScheduledTransferApiFp(configuration).createScheduledTransfer(
        CreateScheduledTransfer ? CreateScheduledTransfer : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this transfer. Any processing transfers may complete; future scheduled transfers, if this is a recurring transfer, will be canceled. After deleting a transfer, there is no direct access to the transactions or transaction errors.
     * @summary Delete this scheduled transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteScheduledTransfer(
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).deleteScheduledTransfer(
        scheduledTransferId ? scheduledTransferId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request.
     * @summary Fetch a representation of this transfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfer(
      scheduledTransferId: string,
      query?: { unmasked?: boolean },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).getScheduledTransfer(
        scheduledTransferId ? scheduledTransferId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of scheduled transfers
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getScheduledTransfers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: Array<
          | 'scheduled'
          | 'recurring'
          | 'processing'
          | 'suspended'
          | 'completed'
          | 'canceled'
          | 'failed'
        >;
        name?: string;
        account?: string;
        sourceAccount?: string;
        targetAccount?: string;
      },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).getScheduledTransfers(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this transfer. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. If the `state` of the transfer allows, this operation may change the `description`, `amount`, and `schedule`; the source and target accounts and `_embedded` objects may not be changed. In the schedule, the user may not changed the `count`. The user may not change the `state`.  This update operation is subject to the same constraints defined in the `createTransfer` (`POST /transfers/transfers`) operation.
     * @summary Update this scheduled transfer
     * @param {UpdateScheduledTransfer} UpdateScheduledTransfer
     * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchScheduledTransfer(
      UpdateScheduledTransfer: UpdateScheduledTransfer,
      scheduledTransferId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).patchScheduledTransfer(
        UpdateScheduledTransfer ? UpdateScheduledTransfer : null,
        scheduledTransferId ? scheduledTransferId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * `POST` the URI of a suspended scheduled transfer to resume it. This enables future recurring transfers. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates. See also the `extendSchedule` query parameter on this operation. This operation is only valid on scheduled transfers which are in the `suspended` state.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:resume`* link, The link will be present if the transfer can be resumed.
     * @summary Resume a suspended scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {boolean} [query.extendSchedule] If true, the &#x60;schedule.end&#x60; will be extended if necessary so that the &#x60;maximumCount&#x60; number of transfers will be made (based on the periods in &#x60;every&#x60;).  The default value (&#x60;false&#x60;) prevents processing transfers that the user may not expect based on the original schedule. (The user may still update the &#x60;schedule.end&#x60; via &#x60;PATCH&#x60; to the scheduled transfer.)
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    resumeScheduledTransfer(
      query?: {
        scheduledTransfer?: string;
        scheduledTransferUri?: string;
        extendSchedule?: boolean;
      },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).resumeScheduledTransfer(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Suspend a scheduled recurring transfer. This disables future recurring transfers until the scheduled transfer is either resumed or canceled. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates.  Use the `apiture:resume` or `apiture:cancel` links on the instance to resume or cancel the remaining transfers. This operation is only valid on scheduled transfers which are in `recurring` state, and only if the underlying bank core support suspending transfers.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:suspend`* link. The service includes the *`apiture:suspend`* link in the scheduled recurring transfer _if and only if_ the user may suspend the transfer _and_ if the banking core allows suspending. If the banking core does not allow suspending a recurring transfer, the user should instead [`cancel`](#op-cancelScheduledTransfer) the transfer and create a new one.  A client can check if the institution supports suspending transfers by accessing the `suspendScheduledTransfersEnabled` property in the `basic` [`getConfigurationGroupValue`](#op-getConfigurationGroupValue).
     * @summary Suspend a scheduled transfer
     * @param {Object} [query] Query object
     * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
     * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    suspendScheduledTransfer(
      query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ScheduledTransferApiFp(configuration).suspendScheduledTransfer(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ScheduledTransferApi - object-oriented interface
 * @export
 * @class ScheduledTransferApi
 * @extends {BaseAPI}
 */
export class ScheduledTransferApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * `POST` the URI of a scheduled transfer to cancel it. This cancels all future recurring transfers. Any transfers that would have occurred on future dates will be canceled. This operation is only valid on scheduled transfers which are in the `scheduled`, `recurring`, or `suspended` state. It may also be allowed if the transfer state is `processing`  and the optional cutoff time has not passed.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:cancel`* link, The link will be present if the transfer can be canceled.
   * @summary Cancel a scheduled transfer
   * @param {Object} [query] Query object
   * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
   * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfer}
   * @memberof ScheduledTransferApi
   */
  public cancelScheduledTransfer(
    query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).cancelScheduledTransfer(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * This operation adds either a new one-time or a recurring transfer, depending on the content of the embedded `schedule`.  The request includes the amount of the transfer in the body, and the source and target accounts in the request's `_links` via the link relations `apiture:source` and `apiture:target`. The accounts must be active and available for transfers and the amount must be in the allowed transfer range.  If the request's transfer date (`schedule.start`) is the current day, the financial institution is processing transfers on that day, and the time is _before_ the financial institution's transfer processing cutoff time, internal transfers will be processed as soon as possible and the transfer `state` will change to `processing` and then `completed`. If the request's transfer date (`schedule.start`) is the current day and the time is _past_ the cutoff time, the transfer will be processed on the _next_ processing day. The cutoff time is available as `cutoffTime` via this service's `basic` configuration values `GET /transfers/configurations/groups/basic/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/basic/schema`.  If the transfer is scheduled for a future date that  is _not_ a valid transfer processing day, the request fails with a 400 error. The holidays and other non-processing days are available via this service's `calendar` configuration values `GET /transfers/configurations/groups/calendar/values`; those values are defined by the JSON schema `GET /transfers/configurations/groups/calendar/schema`.  The service will reject duplicate requests, defined by a request that exactly matches an existing transfer (same `amount`, `schedule`, `description`, source and target accounts), returning a *409 Conflict* status. To schedule a duplicate transfer with the same amount, schedule, and accounts, change at least the `description`.  Scheduled transfers will be deleted automatically at some point after they have completed (typically 7 days), up until which they are available with a `state` of `completed` if successful or `failed` if not.
   * @summary Create a new scheduled transfer request
   * @param {CreateScheduledTransfer} CreateScheduledTransfer The data necessary to create a new transfer.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfer}
   * @memberof ScheduledTransferApi
   */
  public createScheduledTransfer(CreateScheduledTransfer: CreateScheduledTransfer, options?: any) {
    return ScheduledTransferApiFp(this.configuration).createScheduledTransfer(
      CreateScheduledTransfer ? CreateScheduledTransfer : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this transfer. Any processing transfers may complete; future scheduled transfers, if this is a recurring transfer, will be canceled. After deleting a transfer, there is no direct access to the transactions or transaction errors.
   * @summary Delete this scheduled transfer
   * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof ScheduledTransferApi
   */
  public deleteScheduledTransfer(
    scheduledTransferId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).deleteScheduledTransfer(
      scheduledTransferId ? scheduledTransferId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this transfer resource. To also receive the full account number when fetching an account, include the `?unmasked=true` option. When linking an external account, the full account number should be in the `accountNumbers.full` property in the request.
   * @summary Fetch a representation of this transfer
   * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {boolean} [query.unmasked] When requesting a transfer, the full account number of the source and target accounts is not included in the response by default, for security reasons. Include this query parameter, with a value of &#x60;true&#x60;, to request that the response body includes the full account number. Such requests are auditable.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfer}
   * @memberof ScheduledTransferApi
   */
  public getScheduledTransfer(
    scheduledTransferId: string,
    query?: { unmasked?: boolean },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).getScheduledTransfer(
      scheduledTransferId ? scheduledTransferId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of transfers. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of scheduled transfers
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first transfer item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of transfer representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {Array<'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'>} [query.state] Subset the transfers collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the transfers collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.account] Filter the result to transfers from or to the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of an external or internal account. This parameter is ignored if both &#x60;?sourceAccount&#x3D;&#x60; and &#x60;?targetAccount&#x3D;&#x60; are supplied. For security purposes, note that this is not the same as the account number.
   * @param {string} [query.sourceAccount] Filter the result to transfers _from_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the source external or internal account. For security purposes, note that this is not the same as the account number.
   * @param {string} [query.targetAccount] Filter the result to transfers _to_ the account named by this parameter. The value is the &#x60;_id&#x60; (not the account number) of the target external or internal account. For security purposes, note that this is not the same as the account number.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfers}
   * @memberof ScheduledTransferApi
   */
  public getScheduledTransfers(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: Array<
        'scheduled' | 'recurring' | 'processing' | 'suspended' | 'completed' | 'canceled' | 'failed'
      >;
      name?: string;
      account?: string;
      sourceAccount?: string;
      targetAccount?: string;
    },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).getScheduledTransfers(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this transfer. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included. If the `state` of the transfer allows, this operation may change the `description`, `amount`, and `schedule`; the source and target accounts and `_embedded` objects may not be changed. In the schedule, the user may not changed the `count`. The user may not change the `state`.  This update operation is subject to the same constraints defined in the `createTransfer` (`POST /transfers/transfers`) operation.
   * @summary Update this scheduled transfer
   * @param {UpdateScheduledTransfer} UpdateScheduledTransfer
   * @param {string} scheduledTransferId The unique identifier of this scheduled transfer. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Transfer}
   * @memberof ScheduledTransferApi
   */
  public patchScheduledTransfer(
    UpdateScheduledTransfer: UpdateScheduledTransfer,
    scheduledTransferId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).patchScheduledTransfer(
      UpdateScheduledTransfer ? UpdateScheduledTransfer : null,
      scheduledTransferId ? scheduledTransferId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * `POST` the URI of a suspended scheduled transfer to resume it. This enables future recurring transfers. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates. See also the `extendSchedule` query parameter on this operation. This operation is only valid on scheduled transfers which are in the `suspended` state.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:resume`* link, The link will be present if the transfer can be resumed.
   * @summary Resume a suspended scheduled transfer
   * @param {Object} [query] Query object
   * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
   * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
   * @param {boolean} [query.extendSchedule] If true, the &#x60;schedule.end&#x60; will be extended if necessary so that the &#x60;maximumCount&#x60; number of transfers will be made (based on the periods in &#x60;every&#x60;).  The default value (&#x60;false&#x60;) prevents processing transfers that the user may not expect based on the original schedule. (The user may still update the &#x60;schedule.end&#x60; via &#x60;PATCH&#x60; to the scheduled transfer.)
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfer}
   * @memberof ScheduledTransferApi
   */
  public resumeScheduledTransfer(
    query?: { scheduledTransfer?: string; scheduledTransferUri?: string; extendSchedule?: boolean },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).resumeScheduledTransfer(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Suspend a scheduled recurring transfer. This disables future recurring transfers until the scheduled transfer is either resumed or canceled. Any transfers that would have occurred on dates that passed while suspended will not be processed on those dates.  Use the `apiture:resume` or `apiture:cancel` links on the instance to resume or cancel the remaining transfers. This operation is only valid on scheduled transfers which are in `recurring` state, and only if the underlying bank core support suspending transfers.  This operation is invoked by submitting a `POST` to the `href` in the scheduled transfer's *`apiture:suspend`* link. The service includes the *`apiture:suspend`* link in the scheduled recurring transfer _if and only if_ the user may suspend the transfer _and_ if the banking core allows suspending. If the banking core does not allow suspending a recurring transfer, the user should instead [`cancel`](#op-cancelScheduledTransfer) the transfer and create a new one.  A client can check if the institution supports suspending transfers by accessing the `suspendScheduledTransfersEnabled` property in the `basic` [`getConfigurationGroupValue`](#op-getConfigurationGroupValue).
   * @summary Suspend a scheduled transfer
   * @param {Object} [query] Query object
   * @param {string} [query.scheduledTransfer] A server-generated key which identifies a scheduled transfer resource.
   * @param {string} [query.scheduledTransferUri] The URI of a scheduled transfer resource. This parameter is **deprecated** and will be removed in the next version. Use &#x60;?scheduledTransfer&#x3D;&#x60; instead.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ScheduledTransfer}
   * @memberof ScheduledTransferApi
   */
  public suspendScheduledTransfer(
    query?: { scheduledTransfer?: string; scheduledTransferUri?: string },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ScheduledTransferApiFp(this.configuration).suspendScheduledTransfer(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
