// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Users
 * The Users API provides operations to create and maintain online customers for the financial institution. A user represents a person who has registered for online digital banking. Each user resource contains contact information about them (their name, addresses, phone numbers, email addresses) as well as birthdate, government identification, citizenship, and other information that allows the financial institution to conform to regulations related to customers. Every user is uniquely identifiable by a system-generated unique identifier. Users can be created (never deleted) and the state of a user can be modified by authorized financial institution administrators. This API also maintains other banking information about a user, such as their funds transfer limits or other constraints. In addition to the basic operations to create and modify users, there are several actions supported for users. API [links](http://developer.apiture.com/docs/concepts/links) for these actions are described in the `user` schema.   * Lock - if someone attempts to log in with an incorrect password too many times,     the user is locked.     (`POST /lockedUsers?user={userId}`).     The user can be unlocked by resetting their password.     Unlocking a user is done by reactivating them     (`POST /activeUsers?user={userId}`).   * Deactivate - If the financial institution wishes to suspend a user's activity.     (`POST /inactiveUsers?user={userId}`).     Inactive users can be reactivated     (`POST /activeUsers?user={userId}`)`.   * Freeze - If the financial institution suspects fraudulent use of a user's account,     they can freeze a user.     (`POST /frozenUsers?user={userId}`).     Unfreezing a user is done by reactivating them     (`POST /activeUsers?user={userId}`)`.   * Remove - The financial institution can remove a user when they leave the financial institution.     (`POST /removedUsers?user={userId}`).     The user resource is retained rather than being deleted, so that other audit     and other information that references the user remains valid. This API also supports service configuration operations. ## Multi-factor authentication challenges To prevent account takeover attacks, some operations to update the user's profile require _multi-factor authentication_ (MFA). An MFA _challenge_ is a process to verify the user's identity through one or more additional authentication steps.  Some examples are the operations which change the user's preferred phone number:   1. `setPreferredPhoneNumber` operation   1. `createPhoneNumber` operation when the `?replaceId` names the current preferred phone number.   Both require an MFA challenge. When the client tries the operation without a valid redeemable `Apiture-Challenge` request header, the operation may fail with a 409 Conflict. The response body, defined by the `challengeErrorResponse` schema, contains a `challenge` resource which includes one or more _authenticators_. The client should start at least one of the authenticators, optionally allowing the user choose which ones to use, depending on how many authenticators are required.  When changing the user's preferred phone number, for example, the challenge may include an authenticator that sends a verification code to the user's email account. The user completes the authentication by entering the code in the client application. Once the authentication step has completed successfully, the client must pass the resource ID of the challenge resource in the `Apiture-Challenge` request header in order for the operation to update the user's profile information. Thus, these operations often require two tries: the first (without the `Apiture-Challenge` header), which fails with a 409 status but returns the challenge object, then after completing the challenges' authenticators, a second try, passing in the `Apiture-Challenge` header.
 *
 * OpenAPI spec version: 0.18.7
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/users'.replace(/\/+$/, '');

export const API_VERSION = '0.18.7';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * A postal address.
 * @export
 * @interface Address
 */
export interface Address {
  /**
   * The type of this address.
   * @type {AddressType}
   * @memberof Address
   */
  type: AddressType;
  /**
   * A text label, suitable for presentation to the end user. This is derived from `type` or from `otherType` if `type` is `other`
   * @type {string}
   * @memberof Address
   */
  label?: string;
  /**
   * The actual address type if `type` is `other`.
   * @type {string}
   * @memberof Address
   */
  otherType?: string;
  /**
   * The first street address line of the address, normally a house number and street name.
   * @type {string}
   * @memberof Address
   */
  addressLine1?: string;
  /**
   * The optional second street address line of the address.
   * @type {string}
   * @memberof Address
   */
  addressLine2?: string;
  /**
   * The name of the city or municipality.
   * @type {string}
   * @memberof Address
   */
  city?: string;
  /**
   * The mailing address region code, such as state in the US, or a province in Canada. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  regionCode?: string;
  /**
   * The mailing address postal code, such as a US Zip or Zip+4 code, or a Canadian postal code.
   * @type {string}
   * @memberof Address
   */
  postalCode?: string;
  /**
   * The [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code. This is normalized to uppercase.
   * @type {string}
   * @memberof Address
   */
  countryCode?: string;
  /**
   * An identifier for this address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all addresses within the `addresses` array.
   * @type {string}
   * @memberof Address
   */
  _id?: string;
}

/**
 * The type of a postal address.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `addressType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum AddressType {
  Unknown = 'unknown',
  Home = 'home',
  Prior = 'prior',
  Work = 'work',
  School = 'school',
  Mailing = 'mailing',
  Vacation = 'vacation',
  Shipping = 'shipping',
  Billing = 'billing',
  Headquarters = 'headquarters',
  Commercial = 'commercial',
  Site = 'site',
  Property = 'property',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A list of postal addresses and the preferred mailing address.
 * @export
 * @interface Addresses
 */
export interface Addresses {
  /**
   * An array of postal/mailing addresses.
   * @type {Array<Address>}
   * @memberof Addresses
   */
  addresses?: Array<Address>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array.
   * @type {string}
   * @memberof Addresses
   */
  preferredMailingAddressId?: string;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Representation of authenticators which verify a user's identity.   <h3 class='schema-links' id=\"authenticator-links\" >Links</h3>  Response and request bodies using this <strong><code>authenticator</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-retryAuthenticator'><strong><code>apiture:retry</code></strong></a></td><td>Retry an authenticator</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-startAuthenticator'><strong><code>apiture:start</code></strong></a></td><td>Start an authenticator</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-verifyAuthenticator'><strong><code>apiture:verify</code></strong></a></td><td>Verify a user's identity</td><td><code>POST</code></td> </tr>  <tr> <td><a href='#op-getChallenge'><strong><code>apiture:challenge</code></strong></a></td><td>Fetch a representation of this challenge</td><td><code>GET</code></td> </tr> </table>
 * @export
 * @interface Authenticator
 */
export interface Authenticator extends AbstractResource, AuthenticatorFields {
  /**
   * The unique identifier for this authenticator resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof Authenticator
   */
  _id?: string;
  /**
   * The user ID of the user who is requested to verify their identity.
   * @type {string}
   * @memberof Authenticator
   */
  userId?: string;
  /**
   * The state of this authenticator. This is derived and read-only.
   * @type {AuthenticatorState}
   * @memberof Authenticator
   */
  state?: AuthenticatorState;
  /**
   * The actual number of times a user has retried this authenticator.
   * @type {number}
   * @memberof Authenticator
   */
  retryCount?: number;
  /**
   * Data collected from the user that is used to verify this authenticator. This data conforms to the schema defined in the `type`. For example, for `sms`, the `attributes` must contains a `code`.
   * @type {any}
   * @memberof Authenticator
   */
  attributes?: any;
  /**
   * The time stamp when authenticator was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  createdAt?: Date;
  /**
   * The time stamp when authenticator was verified in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  verifiedAt?: Date;
  /**
   * The time stamp when the user failed to verify their identity verification (authentication) for this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  failedAt?: Date;
  /**
   * The time stamp when the this challenge expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Authenticator
   */
  expiresAt?: Date;
}

/**
 * Categories which help classify and organize different authenticator types:   * `knowledge` - Something you know, such as a password or   answers to personal questions.   * `biometric` - Something you are, such as   facial recognition or fingerprints.   * `device` - Something you have, such as a mobile phone   (for confirmation via a code sent via text message) or an electronic key.  <strong><code>authenticatorCategory</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named authenticatorCategory)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>knowledge</code></strong></td><td>Knowledge: Authenticate with information the user knows, such as a password or answers to personal questions.</td>     </tr> <tr>     <td><strong><code>biometric</code></strong></td><td>Biometric: Authenticate with physical characteristics of the user, such as fingerprints, voiceprint, or faceprint.</td>     </tr> <tr>     <td><strong><code>device</code></strong></td><td>Device: Authenticate with a device that the user has, such as a mobile phone or an electronic key.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum AuthenticatorCategory {
  Knowledge = 'knowledge',
  Biometric = 'biometric',
  Device = 'device',
}

/**
 * Common fields of an authenticator.
 * @export
 * @interface AuthenticatorFields
 */
export interface AuthenticatorFields {
  /**
   * The type of this authenticator. This must be one of the items in the `/authenticatorTypes` resource.
   * @type {AuthenticatorType}
   * @memberof AuthenticatorFields
   */
  type?: AuthenticatorType;
  /**
   * The maximum number of times the user may retry this authenticator. If `0`, the user must authenticate correctly on the first try. When an authenticator is retried, the client should `POST` to the `apiture:retry` link on the authenticators; absence of the link means the user cannot retry the authenticator. The default is `3`.
   * @type {number}
   * @memberof AuthenticatorFields
   */
  maximumRetries?: number;
}

/**
 * The state of a challenge authenticator resource.    * The `startAuthenticator` operation (link `apiture:start`) changes the state     from `pending` to `started`.   * The `retryAuthenticator` operation (link `apiture:retry`) changes the state     to `started` and is only allowed if the authenticator has more retries available.   * The `verifyAuthenticator` operation (link `apiture:verify`) validates     the `attributes` and changes the state     to `verified` if valid or     to `failed` if invalid.  <strong><code>authenticatorState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named authenticatorState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending: The authenticator is created but not yet started.</td>     </tr> <tr>     <td><strong><code>started</code></strong></td><td>Started: The user has started the authenticator.</td>     </tr> <tr>     <td><strong><code>verified</code></strong></td><td>Verified: The user corresponding verified the authenticator.</td>     </tr> <tr>     <td><strong><code>failed</code></strong></td><td>Failed: The user failed the authenticators criteria.</td>     </tr> <tr>     <td><strong><code>expired</code></strong></td><td>Expired: The authenticator expired before the user completed the criteria.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum AuthenticatorState {
  Pending = 'pending',
  Started = 'started',
  Verified = 'verified',
  Failed = 'failed',
  Expired = 'expired',
}

/**
 * An authenticator type description.
 * @export
 * @interface AuthenticatorType
 */
export interface AuthenticatorType {
  /**
   * The name of this authenticator; also the key in the `authenticatorTypes` object.
   * @type {string}
   * @memberof AuthenticatorType
   */
  name?: string;
  /**
   * A localized label or title which may be used labels or other UI controls which present a value.
   * @type {string}
   * @memberof AuthenticatorType
   */
  label?: string;
  /**
   * A more detailed localized description of an authenticator type.
   * @type {string}
   * @memberof AuthenticatorType
   */
  description?: string;
  /**
   * The actual natural language tag to which this authentication type description is associated, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1). If omitted, this serves as the _default_.
   * @type {string}
   * @memberof AuthenticatorType
   */
  language?: string;
  /**
   * The authentication category.
   * @type {AuthenticatorCategory}
   * @memberof AuthenticatorType
   */
  category?: AuthenticatorCategory;
  /**
   * The JSON schema which describe the `attributes` object for all authenticators of this type. For example, for `sms`, the schema defines a required `code` string.
   * @type {any}
   * @memberof AuthenticatorType
   */
  schema?: any;
}

/**
 * A resource which represents an identity verification challenge to a user. The user must verify one or more of the authentication methods defined in this challenge in order to proceed with a banking operation (such as scheduling a larger than normal transfer, adding a joint owner or authorized signer to an account, or changing their mailing address or mobile phone number).   <h3 class='schema-links' id=\"challenge-links\" >Links</h3>  Response and request bodies using this <strong><code>challenge</code></strong> schema may contain the following <a href='https://developer.apiture.com/docs/concepts/links'>links</a>:  <table> <tr>   <th>Rel</th><th>Summary</th><th>Method</th> </tr>  <tr> <td><a href='#op-redeemChallenge'><strong><code>apiture:redeem</code></strong></a></td><td>Redeem or use a challenge</td><td><code>POST</code></td> </tr> </table>
 * @export
 * @interface Challenge
 */
export interface Challenge extends AbstractResource, SummaryChallenge {
  /**
   * The unique identifier for this challenge resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof Challenge
   */
  _id?: string;
  /**
   * An array of authenticators with which the user can verify their identity. This is derived; the array and the authenticators are constructed in the `createChallenge` operation.
   * @type {Array<Authenticator>}
   * @memberof Challenge
   */
  authenticators?: Array<Authenticator>;
  /**
   * `true` if and only if the challenge may be redeemed. This is derived from the states of the challenge's authenticators; if the number of `verified` authenticators meets or exceeds the `minimumAuthenticatorCount`, the challenge becomes `verified` and may be redeemed via a `POST` to href in the challenge's `apiture:redeem` link.
   * @type {boolean}
   * @memberof Challenge
   */
  redeemable?: boolean;
  /**
   * The time stamp when challenge was verified in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  verifiedAt?: Date;
  /**
   * The time stamp when the user failed to verify their identity verification (authentication) for this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  failedAt?: Date;
  /**
   * The time stamp when the this challenge expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof Challenge
   */
  expiresAt?: Date;
  /**
   * The time stamps when a service or operation redeemed this challenge, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`). Item 0 is the time stamp the challenge was first redeemed, item 1 is the time stamp of the next redemption, and so on.
   * @type {Array<Date>}
   * @memberof Challenge
   */
  redemptionHistory?: Array<Date>;
  /**
   * An optional authentication code which is only returned in the challenge resource if both a) the platform assigned the `code` when [constructing the challenge](#op-createChallenge)), _and_ b) the user has successfully verified the challenge. The client must [re-fetch the verified challenge](#op-getChallenge) in order to access this property.
   * @type {string}
   * @memberof Challenge
   */
  code?: string;
}

/**
 * The operation error description with an embedded identity challenge.
 * @export
 * @interface ChallengeError
 */
export interface ChallengeError extends Error {
  /**
   * Embedded objects
   * @type {any}
   * @memberof ChallengeError
   */
  _embedded?: any;
}

/**
 * When an operation requires an additional identity verification challenge, it returns a 401 Unauthorized response status code and an error response with a challenge resource embedded in the `_error._embedded.challenge`. This informs the caller that they should verify the challenge via one or more of its `authenticators`, then retry the operation with the `Apiture-Challenge` header that references the challenge's `_id`.
 * @export
 * @interface ChallengeErrorResponse
 */
export interface ChallengeErrorResponse extends ErrorResponse {
  /**
   * The description of the error.
   * @type {ChallengeError}
   * @memberof ChallengeErrorResponse
   */
  _error?: ChallengeError;
}

/**
 * Properties of challenge objects.
 * @export
 * @interface ChallengeFields
 */
export interface ChallengeFields {
  /**
   * The reason the application or service has issued a challenge requesting the user verify their identity. This is for labeling or informational purposes.
   * @type {string}
   * @memberof ChallengeFields
   */
  reason?: string;
  /**
   * The URI of a resource that establishes the context in which the user is asked to authenticate their identity. For example, for this may be for a pending transfer, a user's mailing address, or an account if adding a joint owner.
   * @type {string}
   * @memberof ChallengeFields
   */
  contextUri?: string;
  /**
   * The user ID of the user who is requested to verify their identity. The default is the userID of the authenticated person creating the challenge.
   * @type {string}
   * @memberof ChallengeFields
   */
  userId?: string;
  /**
   * The minimum number of different authenticators the user must verify in order to satisfy the identity challenge. The default is 1.
   * @type {number}
   * @memberof ChallengeFields
   */
  minimumAuthenticatorCount?: number;
  /**
   * The maximum number of times the challenge may be used or redeemed. The default is 1.
   * @type {number}
   * @memberof ChallengeFields
   */
  maximumRedemptionCount?: number;
}

/**
 * The state of an identity challenge resource. This is derived based on the state of the challenge's authenticators.  <strong><code>challengeState</code></strong> strings may have one of the following [enumerated values](https://developer.apiture.com/concepts/label-groups#enumerations) values (described by the named challengeState)  <table> <tr>   <th>Value</th><th>Description</th> </tr>  <tr>     <td><strong><code>pending</code></strong></td><td>Pending: The challenge is created but not yet started.</td>     </tr> <tr>     <td><strong><code>started</code></strong></td><td>Started: The user has started the challenge and associated authenticator(s).</td>     </tr> <tr>     <td><strong><code>verified</code></strong></td><td>Verified: The user correctly verified the corresponding authenticator(s), marking the challenge as verified.</td>     </tr> <tr>     <td><strong><code>failed</code></strong></td><td>Failed: The challenge has failed, often because the user failed one or more of the authenticators.</td>     </tr> <tr>     <td><strong><code>redeemed</code></strong></td><td>Redeemed: The user has redeemed (used) the challenge.</td>     </tr> <tr>     <td><strong><code>expired</code></strong></td><td>Expired: The challenge has expired without being verified.</td>     </tr> </table>
 * @export
 * @enum {string}
 */
export enum ChallengeState {
  Pending = 'pending',
  Started = 'started',
  Verified = 'verified',
  Failed = 'failed',
  Redeemed = 'redeemed',
  Expired = 'expired',
}

/**
 * Representation used to describe the limits for check deposits.
 * @export
 * @interface CheckDepositConstraints
 */
export interface CheckDepositConstraints {
  /**
   * Indicates that the check deposit feature is enabled for the user.
   * @type {boolean}
   * @memberof CheckDepositConstraints
   */
  enabled?: boolean;
  /**
   * The string representation of the limit on the total amount of a check deposit per calendar month for a related user. The default is “50000.00”, although the default may be configurable by the financial institution.
   * @type {string}
   * @memberof CheckDepositConstraints
   */
  monthlyTotalAmountLimit?: string;
  /**
   * The string representation of the limit on the total number of a check per calendar month for a related user. The default is 1000, although the default may be configurable by the financial institution.
   * @type {number}
   * @memberof CheckDepositConstraints
   */
  monthlyTotalChecksLimit?: number;
}

/**
 * Citizenship or nationality status.
 * @export
 * @interface Citizenship
 */
export interface Citizenship {}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Represents a configuration group.
 * @export
 * @interface ConfigurationGroup
 */
export interface ConfigurationGroup extends ConfigurationGroupSummary {
  /**
   * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
   * @type {{ [key: string]: ConfigurationSchemaValue; }}
   * @memberof ConfigurationGroup
   */
  schema?: { [key: string]: ConfigurationSchemaValue };
  /**
   * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
   * @type {{ [key: string]: ConfigurationValue; }}
   * @memberof ConfigurationGroup
   */
  values?: { [key: string]: ConfigurationValue };
}

/**
 * A summary of the data contained within a configuration group resource.
 * @export
 * @interface ConfigurationGroupSummary
 */
export interface ConfigurationGroupSummary extends AbstractResource {
  /**
   * The name of this configuration group, must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  name?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof ConfigurationGroupSummary
   */
  description?: string;
}

/**
 * Collection of configuration groups. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface ConfigurationGroups
 */
export interface ConfigurationGroups extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof ConfigurationGroups
   */
  _embedded?: any;
}

/**
 * The schema which defines the name and types of the variables that are part of this configuration definition. Property names must be simple identifiers which follow the pattern `letter [letter | digit | - | _]*`.  This is implicitly a schema for `type: object` and contains the properties.   The `values` in a configuration conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
 * @export
 * @interface ConfigurationSchema
 */
export interface ConfigurationSchema {
  [key: string]: ConfigurationSchemaValue;
}

/**
 * The data associated with this configuration schema.
 * @export
 * @interface ConfigurationSchemaValue
 */
export interface ConfigurationSchemaValue {}

/**
 * The data associated with this configuration.
 * @export
 * @interface ConfigurationValue
 */
export interface ConfigurationValue {}

/**
 * The data values associated with this configuration group: the group's variable names and values. These values must conform to this item's `schema`.   *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`.   For example, multiple configurations may use the same schema that defines values `a`, `b`, and `c`, but each configuration may have their own unique values for `a`, `b`, and `c` which is separate from the schema.
 * @export
 * @interface ConfigurationValues
 */
export interface ConfigurationValues {
  [key: string]: ConfigurationValue;
}

/**
 * An Constraints description. The `attributes` field a required map of name/value  pairs which provide structured data about the constraint.
 * @export
 * @interface Constraints
 */
export interface Constraints extends AbstractResource, UpdateConstraints {}

/**
 * A person's name.
 * @export
 * @interface ContactName
 */
export interface ContactName {
  /**
   * The person's first name (or given name).
   * @type {string}
   * @memberof ContactName
   */
  firstName?: string;
  /**
   * The person's middle name.
   * @type {string}
   * @memberof ContactName
   */
  middleName?: string;
  /**
   * The person's last name (or surname).
   * @type {string}
   * @memberof ContactName
   */
  lastName?: string;
}

/**
 * Representation used to create a new user.
 * @export
 * @interface CreateUser
 */
export interface CreateUser extends AbstractResource, UserFields {}

/**
 * @export
 * @namespace CreateUser
 */
export namespace CreateUser {}

/**
 * A list of email addresses and the preferred email address.
 * @export
 * @interface EmailAddresses
 */
export interface EmailAddresses {
  /**
   * An array of email addresses.
   * @type {Array<TypedEmailAddress>}
   * @memberof EmailAddresses
   */
  emailAddresses?: Array<TypedEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.
   * @type {string}
   * @memberof EmailAddresses
   */
  preferredEmailAddressId?: string;
}

/**
 * The kind of email address.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `emailType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmailType {
  Unknown = 'unknown',
  Personal = 'personal',
  Work = 'work',
  School = 'school',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The employment status of a contact, located in `kycAnswers`.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `employmentStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum EmploymentStatus {
  Unknown = 'unknown',
  FullTime = 'fullTime',
  PartTime = 'partTime',
  PaidLeave = 'paidLeave',
  Retired = 'retired',
  Unemployed = 'unemployed',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * The type of association to a foreign political figure. This eumeration is described by the foreignPoliticalFigureAssociation value from the `getLabels` operation.
 * @export
 * @enum {string}
 */
export enum ForeignPoliticalFigureAssociation {
  Unknown = 'unknown',
  CloseAssociate = 'closeAssociate',
  FamilyMember = 'familyMember',
  None = 'none',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * Official identifying information associated with the contact.
 * @export
 * @interface Identification
 */
export interface Identification {
  /**
   * The value of this form of identification (the tax ID as a string, for example)
   * @type {string}
   * @memberof Identification
   */
  value: string;
  /**
   * The type of this form of identification.
   * @type {string}
   * @memberof Identification
   */
  type: Identification.TypeEnum;
  /**
   * The date when the form of identification expires, in [RFC 3339](https://tools.ietf.org/html/rfc3339) `YYYY-MM-DD` format.
   * @type {string}
   * @memberof Identification
   */
  expiration?: string;
}

/**
 * @export
 * @namespace Identification
 */
export namespace Identification {
  /**
   * @export
   * @enum {string}
   */
  export enum TypeEnum {
    TaxId = 'taxId',
    PassportNumber = 'passportNumber',
  }
}

/**
 * A contact with additional personally identifiable information data.
 * @export
 * @interface IdentifiedContact
 */
export interface IdentifiedContact extends SimpleContact, IdentifiedContactFields {}

/**
 * Properties which provide additional identification of a person.
 * @export
 * @interface IdentifiedContactFields
 */
export interface IdentifiedContactFields {
  /**
   * The contact's birth date in `YYYY-MM-DD` format.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  birthdate?: string;
  /**
   * This individual's citizenship or nationality status.
   * @type {Citizenship}
   * @memberof IdentifiedContactFields
   */
  citizenship?: Citizenship;
  /**
   * This individual's residency status.
   * @type {ResidencyStatus}
   * @memberof IdentifiedContactFields
   */
  residencyStatus?: ResidencyStatus;
  /**
   * The occupation of this individual.
   * @type {Occupation}
   * @memberof IdentifiedContactFields
   */
  occupation?: Occupation;
  /**
   * The actual occupation of this individual if their `occupation` is `other`. This is ignored if `occupation` is not `other`.
   * @type {string}
   * @memberof IdentifiedContactFields
   */
  otherOccupation?: string;
  /**
   * The number of years the person has been at their present home address.
   * @type {YearsAtAddress}
   * @memberof IdentifiedContactFields
   */
  yearsAtAddress?: YearsAtAddress;
}

/**
 * Data points on the identity verification process that tells if a user has passed, failed or expired the identity check.
 * @export
 * @interface IdentityVerification
 */
export interface IdentityVerification {
  /**
   * The name of the identity verification provider.
   * @type {string}
   * @memberof IdentityVerification
   */
  provider?: string;
  /**
   * The unique id for a session of the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  sessionId?: string;
  /**
   * The date-time when the provider ran identity verification. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) time stamp.
   * @type {Date}
   * @memberof IdentityVerification
   */
  scoredAt?: Date;
  /**
   * The indication if the user has passed or failed the identity verification process.
   * @type {string}
   * @memberof IdentityVerification
   */
  score?: IdentityVerification.ScoreEnum;
  /**
   * The identity verification status for this person.  This field is read-only and is derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record.
   * @type {string}
   * @memberof IdentityVerification
   */
  state?: IdentityVerification.StateEnum;
}

/**
 * @export
 * @namespace IdentityVerification
 */
export namespace IdentityVerification {
  /**
   * @export
   * @enum {string}
   */
  export enum ScoreEnum {
    Passed = 'passed',
    Failed = 'failed',
    Expired = 'expired',
  }
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Verified = 'verified',
    Unverified = 'unverified',
  }
}

/**
 * Answers to 'Know Your Customer' questions which allow financial institutions to conform to a customer identification program.
 * @export
 * @interface KycAnswers
 */
export interface KycAnswers {
  /**
   * `true` if the person is a citizen of the country in which the financial institution is doing business.
   * @type {boolean}
   * @memberof KycAnswers
   */
  citizen?: boolean;
  /**
   * `true` if the person is a permanent resident of the country in which the financial institution is doing business.
   * @type {boolean}
   * @memberof KycAnswers
   */
  permanentResident?: boolean;
  /**
   * `true` if the person is a subject to backup W-9 Tax Withholdings.
   * @type {boolean}
   * @memberof KycAnswers
   */
  w9Withholdings?: boolean;
  /**
   * The employment status of the person.
   * @type {EmploymentStatus}
   * @memberof KycAnswers
   */
  employmentStatus?: EmploymentStatus;
  /**
   * `true` if the person is a foreign senior political figure.
   * @type {boolean}
   * @memberof KycAnswers
   */
  foreignPoliticalFigure?: boolean;
  /**
   * If the person is a foreign senior political figure, this is the foreign country. This field is omitted if `foreignPoliticalFigure` is `false`.
   * @type {string}
   * @memberof KycAnswers
   */
  countryPoliticalFigure?: string;
  /**
   * `true` if the person is an immediate family member or a close associate of political figure.
   * @type {boolean}
   * @memberof KycAnswers
   */
  familyOfPoliticalFigure?: boolean;
  /**
   * If the person is a foreign senior political figure, this is the foreign country ISO 3166-1 country code. This field is omitted if `foreignPoliticalFigure` is `false`.
   * @type {string}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureCountry?: string;
  /**
   * The type of association to a foreign political figure.
   * @type {ForeignPoliticalFigureAssociation}
   * @memberof KycAnswers
   */
  foreignPoliticalFigureAssociation?: ForeignPoliticalFigureAssociation;
}

/**
 * A map that defines labels for the items in a group. This is a map from each item *name* &rarr; *a [`labelItem`](#schema-labelitem) object*. For example, consider a JSON response that includes a property named `revenueEstimate`; the values for `revenueEstimate` must be one of the items in the group named `estimatedAnnualRevenue`, with options ranging `under1Million`, to `over100Million`. The item name is used as the selected value in an Apiture representation, such as `{ ..., \"revenueEstimate\" : \"from10to100Million\" , ...}`, and the item with the name `from10to100Million` defines the presentation labels for that item, as well as other metadata about that choice: this is the range `[10000000.00,100000000.00)`.  This allows the client to let the user select a value from a list, such as the following derivde from the labels in the example:    * Unknown   * Under $1M   * $1M to $10M   * $10M to $100M   * $100M or more  Note that the `other` item is hidden from the selection list, as that item is marked as `hidden`. For items which define numeric ranges, a client may instead let the customer *directly* enter their estimated annual revenue as a number, such as 4,500,000.00. The client can then match that number to one of ranges in the items and set the `revenueEstimate` to the corresponding item's name: `{ ..., \"revenueEstimate\" : \"from1to10Million\", ... }`.
 * @export
 * @interface LabelGroup
 */
export interface LabelGroup {
  [key: string]: LabelItem;
}

/**
 * A set of named groups of labels, each of which contains multiple item labels.   The abbreviated example shows two groups, one named `structure` and one named `estimatedAnnualRevenue`. The first has items with names such as `corporation`, `llc` and `soleProprietorship`, with text labels for each in the default and in French. The second has items for estimated revenue *ranges* but no localized labels. For example, the item named `from1to10Million` has the `label` \"$1M to $10M\" and the range `[1000000.00,10000000.00)`.
 * @export
 * @interface LabelGroups
 */
export interface LabelGroups extends AbstractResource {
  /**
   * Groups of localized labels. This maps *group names* &rarr; [*a group of labels*](#schema-labelgroup) within that group.
   * @type {any}
   * @memberof LabelGroups
   */
  groups?: any;
}

/**
 * An item in a [`labelGroup`](#schema-labelgroup), with a set of `variants` which contains different localized labels for the item. Each ([`simpleLabel`](#schema-simpleLabel)) variant defines the presentation text label and optional description for a language. Items may also have a lookup `code` to map to external syststems, a numeric range, and a `hidden` boolean to indicate the item is normally hidden in the UI.
 * @export
 * @interface LabelItem
 */
export interface LabelItem extends SimpleLabel {
  /**
   * The language-specific variants of this label. The keys in this object are [RFC 7231](https://tools.ietf.org/html/rfc7231#section-3.1.3.1) language codes.
   * @type {{ [key: string]: SimpleLabel; }}
   * @memberof LabelItem
   */
  variants?: { [key: string]: SimpleLabel };
  /**
   * If the localized value is associated with an external standard or definition, this is a lookup code or key or URI for that value.
   * @type {string}
   * @memberof LabelItem
   */
  code?: string;
  /**
   * If `true`, this item is normally hidden from the User Interface.
   * @type {boolean}
   * @memberof LabelItem
   */
  hidden?: boolean;
  /**
   * The range of values, if the item describes a bounded numeric value. This is range notation such as `[min,max]`, `(exclusiveMin,max]`, `[min,exclusiveMax)`, or `(exclusiveMin,exclusiveMax)`. For example, `[0,100)` is the range greater than or equal to 0 and less than 100. If the *min* or *max* value are omitted, that end of the range is unbounded. For example, `(,1000.00)` means less than 1000.00 and `[20000.00,]` means 20000.00 or more. The ranges do not overlap or have gaps.
   * @type {string}
   * @memberof LabelItem
   */
  range?: string;
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Representation used to merge a set of users into a master user.
 * @export
 * @interface MergeUsers
 */
export interface MergeUsers {
  /**
   * Array of users to merge.
   * @type {Array<User>}
   * @memberof MergeUsers
   */
  items?: Array<User>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof MergeUsers
   */
  _links?: { [key: string]: Link };
}

/**
 * The person's occupation.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `occupation` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum Occupation {
  Unknown = 'unknown',
  ArchitectureAndEngineering = 'architectureAndEngineering',
  ArtsDesignEntertainmentSportsAndMedia = 'artsDesignEntertainmentSportsAndMedia',
  BuildingAndGroundsCleaningAndMaintenance = 'buildingAndGroundsCleaningAndMaintenance',
  BusinessAndFinancialOperations = 'businessAndFinancialOperations',
  CommunityAndSocialService = 'communityAndSocialService',
  ComputerAndMathematical = 'computerAndMathematical',
  ConstructionAndExtraction = 'constructionAndExtraction',
  EducationTrainingAndLibrary = 'educationTrainingAndLibrary',
  FarmingFishingAndForestry = 'farmingFishingAndForestry',
  FoodPreparationAndServingRelated = 'foodPreparationAndServingRelated',
  HealthcarePractitionersAndTechnical = 'healthcarePractitionersAndTechnical',
  HealthcareSupport = 'healthcareSupport',
  InstallationMaintenanceAndRepair = 'installationMaintenanceAndRepair',
  Legal = 'legal',
  LifePhysicalAndSciences = 'lifePhysicalAndSciences',
  Management = 'management',
  MilitarySpecific = 'militarySpecific',
  OfficeAndAdministrativeSupport = 'officeAndAdministrativeSupport',
  PersonalCareAndService = 'personalCareAndService',
  Production = 'production',
  ProtectiveServices = 'protectiveServices',
  SalesAndRelated = 'salesAndRelated',
  TransportationAndMaterialMoving = 'transportationAndMaterialMoving',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A phone number and its role.
 * @export
 * @interface PhoneNumber
 */
export interface PhoneNumber {
  /**
   * The type or role of this phone number.
   * @type {PhoneNumberType}
   * @memberof PhoneNumber
   */
  type: PhoneNumberType;
  /**
   * The phone number, as a string.
   * @type {string}
   * @memberof PhoneNumber
   */
  number: string;
  /**
   * A text label, suitable for presentation to the end user. This is also used if `type` is `other`.
   * @type {string}
   * @memberof PhoneNumber
   */
  label?: string;
  /**
   * An identifier for this phone number, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all phone numbers within the `phones` array.
   * @type {string}
   * @memberof PhoneNumber
   */
  _id?: string;
}

/**
 * The type or role of this phone number.  **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `phoneNumberType` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum PhoneNumberType {
  Unknown = 'unknown',
  Home = 'home',
  Work = 'work',
  Mobile = 'mobile',
  Fax = 'fax',
  Other = 'other',
}

/**
 * A list of phone numbers and the preferred phone number.
 * @export
 * @interface PhoneNumbers
 */
export interface PhoneNumbers {
  /**
   * An array of phone numbers.
   * @type {Array<PhoneNumber>}
   * @memberof PhoneNumbers
   */
  phones?: Array<PhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array.
   * @type {string}
   * @memberof PhoneNumbers
   */
  preferredPhoneId?: string;
}

/**
 * The contact's preferred method of communication.
 * @export
 * @enum {string}
 */
export enum PreferredContactMethod {
  Unknown = 'unknown',
  Sms = 'sms',
  Email = 'email',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * The state of an item (address, email address, or phone number) within the user's profile. New addresses, email addresses, or phone numbers start with the state `pending`, which means approval by the financial institution is pending. After they have been verified, the state becomes `approved`. Some normalizing or sanitizing of the value may occur when this happens (for example, a ZIP code may change to ZIP+4 format). `pending` items may not be assigned as the preferred item.
 * @export
 * @enum {string}
 */
export enum ProfileItemState {
  Pending = 'pending',
  Approved = 'approved',
}

/**
 * Residency status.   **Warning**: the `enum` list will be removed in a future release. and the values defined at runtime via the `residencyStatus` label group in the response from the [`getLabels`](#op-getLabels) operation.
 * @export
 * @enum {string}
 */
export enum ResidencyStatus {
  Unknown = 'unknown',
  Resident = 'resident',
  Nonresident = 'nonresident',
  ResidentAlien = 'residentAlien',
  NonresidentAlien = 'nonresidentAlien',
  Other = 'other',
  NotApplicable = 'notApplicable',
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Basic contact and identification information for a person, consisting of the name, mailing address, phone numbers, email addresses, and government identification.
 * @export
 * @interface SimpleContact
 */
export interface SimpleContact
  extends ContactName,
    Addresses,
    EmailAddresses,
    PhoneNumbers,
    SimpleContactFields {}

/**
 * Additional properties for a person or contact.
 * @export
 * @interface SimpleContactFields
 */
export interface SimpleContactFields {
  /**
   * A title or honorific prefix such as Dr. or Fr.
   * @type {string}
   * @memberof SimpleContactFields
   */
  prefix?: string;
  /**
   * A title or honorific suffix such as PhD or DDS.
   * @type {string}
   * @memberof SimpleContactFields
   */
  suffix?: string;
  /**
   * The contact's preferred name. This is how the contact's name is presented to the user in the interface. The default is the contact's `firstName`.
   * @type {string}
   * @memberof SimpleContactFields
   */
  preferredName?: string;
  /**
   * A collection of official identifying information associated with the contact.
   * @type {Array<Identification>}
   * @memberof SimpleContactFields
   */
  identification?: Array<Identification>;
  /**
   * The contact's preferred method of communication.
   * @type {PreferredContactMethod}
   * @memberof SimpleContactFields
   */
  preferredContactMethod?: PreferredContactMethod;
}

/**
 * A text label and optional description.
 * @export
 * @interface SimpleLabel
 */
export interface SimpleLabel {
  /**
   * A label or title which may be used as labels or other UI controls which present a value.
   * @type {string}
   * @memberof SimpleLabel
   */
  label: string;
  /**
   * A more detailed localized description of a localizable label.
   * @type {string}
   * @memberof SimpleLabel
   */
  description?: string;
}

/**
 * Summary representation of a challenge, used in the challenge collection.
 * @export
 * @interface SummaryChallenge
 */
export interface SummaryChallenge extends AbstractResource, ChallengeFields {
  /**
   * The unique identifier for this challenge resource. This is an immutable opaque string assigned upon creation.
   * @type {string}
   * @memberof SummaryChallenge
   */
  _id?: string;
  /**
   * How many times the challenge has been redeemed.
   * @type {number}
   * @memberof SummaryChallenge
   */
  redemptionCount?: number;
  /**
   * The state of this authenticator.
   * @type {ChallengeState}
   * @memberof SummaryChallenge
   */
  state?: ChallengeState;
  /**
   * The time stamp when challenge was created, in [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC date-time format (`YYYY-MM-DDThh:mm:ss.sssZ`).
   * @type {Date}
   * @memberof SummaryChallenge
   */
  createdAt?: Date;
}

/**
 * Summary representation of a user resource in user collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryUser
 */
export interface SummaryUser extends UserFields, AbstractResource {
  /**
   * The unique identifier for this user resource. This is an opaque string.
   * @type {string}
   * @memberof SummaryUser
   */
  _id?: string;
  /**
   * The unique customer number, also known as the Customer Identification File number or CIF number. This derived value is assigned to the user in the banking core. The `customerId` differs from the `_id` (which is the ID of the resource in the Users API).
   * @type {string}
   * @memberof SummaryUser
   */
  customerId?: string;
}

/**
 * @export
 * @namespace SummaryUser
 */
export namespace SummaryUser {}

/**
 * Representation used to describe the limits for transfers.
 * @export
 * @interface TransferConstraints
 */
export interface TransferConstraints {
  /**
   * The string representation of the limit on the amount of an individual credit transfer for a related user.
   * @type {string}
   * @memberof TransferConstraints
   */
  singleCreditLimit?: string;
  /**
   * The string representation of the limit on the amount of an individual debit transfer for a related user.
   * @type {string}
   * @memberof TransferConstraints
   */
  singleDebitLimit?: string;
  /**
   * The string representation of the limit on the total amount of credit transfers per calendar day for a related user.
   * @type {string}
   * @memberof TransferConstraints
   */
  dailyCreditLimit?: string;
  /**
   * The string representation of the limit on the total amount of debit transfers per calendar day for a related user.
   * @type {string}
   * @memberof TransferConstraints
   */
  dailyDebitLimit?: string;
}

/**
 * An email address and the email address type.
 * @export
 * @interface TypedEmailAddress
 */
export interface TypedEmailAddress {
  /**
   * The email address, such as `JohnBankCustomer@example.com`
   * @type {string}
   * @memberof TypedEmailAddress
   */
  value?: string;
  /**
   * The kind of email address.
   * @type {EmailType}
   * @memberof TypedEmailAddress
   */
  type?: EmailType;
  /**
   * An identifier for this email address, so that it can be referenced uniquely. The service will assign a unique `_id` if the client does not provide one. The `_id` must be unique across all email addresses within the `emailAddresses` array.
   * @type {string}
   * @memberof TypedEmailAddress
   */
  _id?: string;
}

/**
 * Representation used to update or patch a user's constraints.
 * @export
 * @interface UpdateConstraints
 */
export interface UpdateConstraints {
  /**
   * Constraints on the user's money transfers.
   * @type {TransferConstraints}
   * @memberof UpdateConstraints
   */
  transfers?: TransferConstraints;
  /**
   * Constraints on the user's remote check deposits.
   * @type {CheckDepositConstraints}
   * @memberof UpdateConstraints
   */
  checkDeposits?: CheckDepositConstraints;
}

/**
 * Representation of a user resource. A user may have the following links:   * *`self`*: A link to the user resource.   * *`apiture:remove`*: A link to remove the current user (via `POST`). This     link only exists if the user resource is not `removed` and if the caller is authorized to remove users.   * *`apiture:activate`*: A link to activate the current user (via `POST`). This     link only exists if the user resource is `inactive`, `locked`, or `frozen` and the caller is authorized to activate users.   * *`apiture:deactivate`*: A link to deactivate the current user (via `POST`). This     link only exists if the user resource is `active` or `locked` and the caller is authorized to deactivate users.   * *`apiture:lock`*: A link to lock the current user (via `POST`). This     link only exists if the user resource is `active` or `inactive` and the caller is authorized to lock users.   * *`apiture:freeze`*: A link to freeze the current user (via `POST`). This     link only exists if the user resource is `active` , `inactive` or `locked` and the caller is authorized to freeze users.   * *`apiture:merge`*: A link to merge the current user (or a collection of users) with a specified master user (via `POST`). This     link only exists if the user resource is `active`, `inactive`, or `locked` and the caller is authorized to merge users.
 * @export
 * @interface User
 */
export interface User extends SummaryUser {
  /**
   * The date-time when the user was created.
   * @type {Date}
   * @memberof User
   */
  createdAt?: Date;
  /**
   * The date-time when the user was last contacted. This is a computed, read-only field and will be ignored if specified as part of the request body. This is in [RFC 3396](https://tools.ietf.org/html/rfc3339) format: `YYYY-MM-DDThh:mm:ss.sssZ`
   * @type {Date}
   * @memberof User
   */
  lastContactedAt?: Date;
  /**
   * The date-time when the user last logged in. This is a computed, read-only field and will be ignored if specified as part of the request body. This is in [RFC 3396](https://tools.ietf.org/html/rfc3339) format: `YYYY-MM-DDThh:mm:ss.sssZ`
   * @type {Date}
   * @memberof User
   */
  lastLoggedInAt?: Date;
  /**
   * User preferences.
   * @type {UserPreferences}
   * @memberof User
   */
  preferences?: UserPreferences;
  /**
   * Additional unstructured application metadata about the user.
   * @type {Attributes}
   * @memberof User
   */
  attributes?: Attributes;
}

/**
 * @export
 * @namespace User
 */
export namespace User {}

/**
 * Representation of a user's address resource.
 * @export
 * @interface UserAddress
 */
export interface UserAddress extends Address, AbstractResource {
  /**
   * The state of this address. `pending` addresses require financial institution approval. Only `approved` addresses may be set as the preferred address.
   * @type {ProfileItemState}
   * @memberof UserAddress
   */
  state?: ProfileItemState;
}

/**
 * The list of the user's addresses.
 * @export
 * @interface UserAddresses
 */
export interface UserAddresses extends AbstractResource {
  /**
   * An array containing address items.
   * @type {Array<UserAddress>}
   * @memberof UserAddresses
   */
  items?: Array<UserAddress>;
}

/**
 * Representation of email address resources. An email address is immutable, although users can add new email addresses.
 * @export
 * @interface UserEmailAddress
 */
export interface UserEmailAddress extends TypedEmailAddress, AbstractResource {
  /**
   * The state of this email address. `pending` email addresses require financial institution approval. Only `approved` numbers may be set as the preferred email address.
   * @type {ProfileItemState}
   * @memberof UserEmailAddress
   */
  state?: ProfileItemState;
}

/**
 * The list of the user's email addresses.
 * @export
 * @interface UserEmailAddresses
 */
export interface UserEmailAddresses extends AbstractResource {
  /**
   * An array containing email address items.
   * @type {Array<UserEmailAddress>}
   * @memberof UserEmailAddresses
   */
  items?: Array<UserEmailAddress>;
}

/**
 * Fields for a user. (This fragment schema is used to build other schemas.)   To change user addresses, email addresses, and phone numbers, use operations on the sub-resources (`/users/{userId}/addresses`, `/users/{userId}/emailAddresses`, and `/users/{userId}/phoneNumbers`).
 * @export
 * @interface UserFields
 */
export interface UserFields
  extends IdentifiedContact,
    ContactName,
    SimpleContactFields,
    UserVerificationFields {
  /**
   * The unique username for the user.
   * @type {string}
   * @memberof UserFields
   */
  username?: string;
  /**
   * The state of this user record. The default is `active`.   * Users may not be deleted, but Users with a `state` of `active`, `inactive` or `locked`     may be removed by `POST`ing to the `/removedUsers` endpoint via the `apiture:remove`     endpoint. Removed users may not be reactivated.   * Users with a `state` of `active` or `locked` may be deactivated by `POST`ing to     the `/inactiveUsers` endpoint via the `apiture:deactivate` endpoint.   * Users with a `state` of `inactive` or `locked` may be activated by `POST`ing to     the `/activeUsers` endpoint via the `apiture:activate` endpoint.   * Users with a `state` of `active` or `inactive` may be locked by `POST`ing to     the `/lockedUsers` endpoint via the `apiture:lock` endpoint. A `state` of `locked`     indicates a user has entered the password incorrectly too many times.   * Users with a `state` of `active`, `inactive` or locked may be frozen by     `POST`ing to the `/frozenUsers` endpoint via the `apiture:freeze` endpoint.     A `state` of `frozen` indicates a user can no longer access online banking until     the financial institution re-activates the user.   * Users with a `state` of `active`, `inactive`, or `locked` may be     merged by `POST`ing to the `/mergedUsers` endpoint via the `apiture:merge` endpoint.     Merged users may not have their state changed.
   * @type {string}
   * @memberof UserFields
   */
  state?: UserFields.StateEnum;
  /**
   * An array of postal/mailing addresses. Add or delete addresses with the `createAddress` and `deleteAddress` operations.
   * @type {Array<UserAddress>}
   * @memberof UserFields
   */
  addresses?: Array<UserAddress>;
  /**
   * The preferred mailing address. This string is the `_id` of an address in the `addresses` array. This value is set with the `setPreferredMailingAddress` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredMailingAddressId?: string;
  /**
   * An array of phone numbers. Add or delete phoneNumbers with the `createPhoneNumber` and `deletePhoneNumber` operations.
   * @type {Array<UserPhoneNumber>}
   * @memberof UserFields
   */
  phoneNumbers?: Array<UserPhoneNumber>;
  /**
   * The ID of preferred phone number. This string is the `_id` of a phone number in the `phones` array. This value is set with the `setPreferredPhoneNumber` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredPhoneId?: string;
  /**
   * An array of email addresses. Add or delete email addresses with the `createEmailAddress` and `deleteEmailAddress` operations.
   * @type {Array<UserEmailAddress>}
   * @memberof UserFields
   */
  emailAddresses?: Array<UserEmailAddress>;
  /**
   * The preferred email address. This string is the `_id` of an email address in the `emailAddresses` array.  This value is set with the `setPreferredEmailAddress` operation.
   * @type {string}
   * @memberof UserFields
   */
  preferredEmailAddressId?: string;
}

/**
 * @export
 * @namespace UserFields
 */
export namespace UserFields {
  /**
   * @export
   * @enum {string}
   */
  export enum StateEnum {
    Active = 'active',
    Inactive = 'inactive',
    Locked = 'locked',
    Frozen = 'frozen',
    Merged = 'merged',
    Removed = 'removed',
  }
}

/**
 * Representation of phone number resources.
 * @export
 * @interface UserPhoneNumber
 */
export interface UserPhoneNumber extends PhoneNumber, AbstractResource {
  /**
   * The state of this phone number. `pending` numbers require financial institution approval. Only `approved` numbers may be set as the preferred phone number.
   * @type {ProfileItemState}
   * @memberof UserPhoneNumber
   */
  state?: ProfileItemState;
}

/**
 * The list of the user's phone numbers.
 * @export
 * @interface UserPhoneNumbers
 */
export interface UserPhoneNumbers extends AbstractResource {
  /**
   * An array containing phone number items.
   * @type {Array<UserPhoneNumber>}
   * @memberof UserPhoneNumbers
   */
  items?: Array<UserPhoneNumber>;
}

/**
 * User preferences for digital banking and applications.
 * @export
 * @interface UserPreferences
 */
export interface UserPreferences {
  /**
   * `true` if the user has not opted out of receiving SMS text messages from the financial institution for notification of banking or related activity. This value reflects the user's most recent opt in/opt out selection. Note: SMS may still be used for mult-factor authentication if `smsNotifications` is `false`.
   * @type {boolean}
   * @memberof UserPreferences
   */
  smsNotifications?: boolean;
  /**
   *
   * @type {AttributeValue}
   * @memberof UserPreferences
   */
  additionalProperties?: AttributeValue;
}

/**
 * Fields for recording the status of user verification for a financial institution's Customer Identification Program (CIP). (This fragment schema is used to build other schemas.)
 * @export
 * @interface UserVerificationFields
 */
export interface UserVerificationFields {
  /**
   * This user's answers Know Your Customer (KYC) questions.
   * @type {KycAnswers}
   * @memberof UserVerificationFields
   */
  kycAnswers?: KycAnswers;
  /**
   * The identity verification data for this person.  These fields are derived from the results of any identity verification processes executed against the personally identifiable information (PII) contained in this record.
   * @type {IdentityVerification}
   * @memberof UserVerificationFields
   */
  identityVerification?: IdentityVerification;
}

/**
 * Collection of users. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`).
 * @export
 * @interface Users
 */
export interface Users extends Collection {
  /**
   * Embedded objects.
   * @type {any}
   * @memberof Users
   */
  _embedded?: any;
}

/**
 * Categories for how long the person has been at their present home address.
 * @export
 * @enum {string}
 */
export enum YearsAtAddress {
  Unknown = 'unknown',
  OneOrFewer = 'oneOrFewer',
  Two = 'two',
  Three = 'three',
  FourOrMore = 'fourOrMore',
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:  * *`apiture:users`* : A link to the collection of all users.  * *`apiture:createUser`* : A link to create a new user (via `POST`)
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options: any = {}): RequestArgs {
      const { Accept_Language } = headers;

      const localVarPath = `/labels`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (Accept_Language !== undefined && Accept_Language !== null) {
        localVarHeaderParameter['Accept-Language'] = String(Accept_Language);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:  * *`apiture:users`* : A link to the collection of all users.  * *`apiture:createUser`* : A link to create a new user (via `POST`)
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(
      headers?: { Accept_Language?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<LabelGroups> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getLabels(
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links in the root response may include:  * *`apiture:users`* : A link to the collection of all users.  * *`apiture:createUser`* : A link to create a new user (via `POST`)
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
    /**
     * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
     * @summary Localized Labels
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getLabels(headers?: { Accept_Language?: string }, options?: any) {
      return APIApiFp(configuration).getLabels(headers ? headers : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. Links in the root response may include:  * *`apiture:users`* : A link to the collection of all users.  * *`apiture:createUser`* : A link to create a new user (via `POST`)
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a JSON object which defines labels for enumeration types defined by the schemas defined in this API.   The labels in the response may not all match the requested language; some may be in the default language (`en-us`).
   * @summary Localized Labels
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Accept_Language] The weighted language tags which indicate the user&#39;s preferred natural language for the localized labels in the response, as per [RFC 7231](https://tools.ietf.org/html/rfc7231#section-5.3.5).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {LabelGroups}
   * @memberof APIApi
   */
  public getLabels(headers?: { Accept_Language?: string }, options?: any) {
    return APIApiFp(this.configuration).getLabels(headers ? headers : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * AddressApi - axios parameter creator
 * @export
 */
export const AddressApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an address to the list of the user's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred mailing address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new address
     * @param {UserAddress} UserAddress The data necessary to create a new address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      UserAddress: UserAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling createAddress.',
        );
      }
      // verify required parameter 'UserAddress' is not null or undefined
      if (UserAddress === null || UserAddress === undefined) {
        throw new RequiredError(
          'UserAddress',
          'Required parameter UserAddress was null or undefined when calling createAddress.',
        );
      }
      const localVarPath = `/users/{userId}/addresses`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserAddress' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserAddress || {})
        : UserAddress || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the user's preferred address.
     * @summary Delete this address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(userId: string, addressId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling deleteAddress.',
        );
      }
      // verify required parameter 'addressId' is not null or undefined
      if (addressId === null || addressId === undefined) {
        throw new RequiredError(
          'addressId',
          'Required parameter addressId was null or undefined when calling deleteAddress.',
        );
      }
      const localVarPath = `/users/{userId}/addresses/{addressId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'addressId'}}`, encodeURIComponent(String(addressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      userId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getAddress.',
        );
      }
      // verify required parameter 'addressId' is not null or undefined
      if (addressId === null || addressId === undefined) {
        throw new RequiredError(
          'addressId',
          'Required parameter addressId was null or undefined when calling getAddress.',
        );
      }
      const localVarPath = `/users/{userId}/addresses/{addressId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'addressId'}}`, encodeURIComponent(String(addressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the user's addresses.
     * @summary Get user's addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(userId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getAddresses.',
        );
      }
      const localVarPath = `/users/{userId}/addresses`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the user's preferred mailing address. The user may set their preferred address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.   No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling setPreferredAddress.',
        );
      }
      const localVarPath = `/users/{userId}/preferredAddress`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * AddressApi - functional programming interface
 * @export
 */
export const AddressApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an address to the list of the user's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred mailing address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new address
     * @param {UserAddress} UserAddress The data necessary to create a new address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      UserAddress: UserAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserAddress> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).createAddress(
        UserAddress ? UserAddress : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the user's preferred address.
     * @summary Delete this address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(
      userId: string,
      addressId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).deleteAddress(
        userId ? userId : null,
        addressId ? addressId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      userId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserAddress> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).getAddress(
        userId ? userId : null,
        addressId ? addressId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the user's addresses.
     * @summary Get user's addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(
      userId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserAddresses> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).getAddresses(
        userId ? userId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the user's preferred mailing address. The user may set their preferred address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.   No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = AddressApiAxiosParamCreator(configuration).setPreferredAddress(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * AddressApi - factory interface
 * @export
 */
export const AddressApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add an address to the list of the user's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred mailing address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new address
     * @param {UserAddress} UserAddress The data necessary to create a new address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createAddress(
      UserAddress: UserAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).createAddress(
        UserAddress ? UserAddress : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this address. The address can only be deleted if it is _not_ the user's preferred address.
     * @summary Delete this address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteAddress(userId: string, addressId: string, options?: any) {
      return AddressApiFp(configuration).deleteAddress(
        userId ? userId : null,
        addressId ? addressId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
     * @summary Fetch a representation of this address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} addressId The unique identifier of this address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddress(
      userId: string,
      addressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).getAddress(
        userId ? userId : null,
        addressId ? addressId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the user's addresses.
     * @summary Get user's addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getAddresses(userId: string, options?: any) {
      return AddressApiFp(configuration).getAddresses(
        userId ? userId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the user's preferred mailing address. The user may set their preferred address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.   No changes are made if the specified address is already the preferred address.
     * @summary Set Preferred mailing Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return AddressApiFp(configuration).setPreferredAddress(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * AddressApi - object-oriented interface
 * @export
 * @class AddressApi
 * @extends {BaseAPI}
 */
export class AddressApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add an address to the list of the user's addresses. The new address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred mailing address. See _Multi-factor authentication challenges_ above.
   * @summary Create a new address
   * @param {UserAddress} UserAddress The data necessary to create a new address.
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing address to be _replaced_ with this new address instead of adding a new address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred mailing address the &#x60;preferredMailingAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing address matches &#x60;replaceId&#x60;, the new address is added to the list of addresses. Example: &#x60;?replaceId&#x3D;ha1&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserAddress}
   * @memberof AddressApi
   */
  public createAddress(
    UserAddress: UserAddress,
    userId: string,
    query?: { replaceId?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).createAddress(
      UserAddress ? UserAddress : null,
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this address. The address can only be deleted if it is _not_ the user's preferred address.
   * @summary Delete this address resource
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} addressId The unique identifier of this address. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof AddressApi
   */
  public deleteAddress(userId: string, addressId: string, options?: any) {
    return AddressApiFp(this.configuration).deleteAddress(
      userId ? userId : null,
      addressId ? addressId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this address resource.
   * @summary Fetch a representation of this address
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} addressId The unique identifier of this address. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserAddress}
   * @memberof AddressApi
   */
  public getAddress(
    userId: string,
    addressId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).getAddress(
      userId ? userId : null,
      addressId ? addressId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the user's addresses.
   * @summary Get user's addresses
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserAddresses}
   * @memberof AddressApi
   */
  public getAddresses(userId: string, options?: any) {
    return AddressApiFp(this.configuration).getAddresses(
      userId ? userId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the user's preferred mailing address. The user may set their preferred address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an address if that resource is eligible to be set as the preferred address.   No changes are made if the specified address is already the preferred address.
   * @summary Set Preferred mailing Address
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the address to assign as the preferred address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;ha1&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof AddressApi
   */
  public setPreferredAddress(
    userId: string,
    query?: { value?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return AddressApiFp(this.configuration).setPreferredAddress(
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * ConfigurationApi - axios parameter creator
 * @export
 */
export const ConfigurationApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroup.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupSchema.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/schema`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group. The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To update a specific value, use `PUT /users/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling getConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      const localVarPath = `/configurations/groups`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent. The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To fetch specific value, use `GET /users/configurations/groups/{groupName}/values/{valueName}`  (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      // verify required parameter 'body' is not null or undefined
      if (body === null || body === undefined) {
        throw new RequiredError(
          'body',
          'Required parameter body was null or undefined when calling updateConfigurationGroupValue.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values/{valueName}`
        .replace(`{${'groupName'}}`, encodeURIComponent(String(groupName)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'string' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(body || {}) : body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'groupName' is not null or undefined
      if (groupName === null || groupName === undefined) {
        throw new RequiredError(
          'groupName',
          'Required parameter groupName was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateConfigurationGroupValues.',
        );
      }
      const localVarPath = `/configurations/groups/{groupName}/values`.replace(
        `{${'groupName'}}`,
        encodeURIComponent(String(groupName)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: ConfigurationValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * ConfigurationApi - functional programming interface
 * @export
 */
export const ConfigurationApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroup> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group. The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To update a specific value, use `PUT /users/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<ConfigurationGroups> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).getConfigurationGroups(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent. The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To fetch specific value, use `GET /users/configurations/groups/{groupName}/values/{valueName}`  (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<string> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (
      axios?: AxiosInstance,
      basePath?: string,
    ) => AxiosPromise<{ [key: string]: ConfigurationSchemaValue }> {
      const localVarAxiosArgs = ConfigurationApiAxiosParamCreator(
        configuration,
      ).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * ConfigurationApi - factory interface
 * @export
 */
export const ConfigurationApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
     * @summary Fetch a representation of this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroup(groupName: string, headers?: { If_None_Match?: string }, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroup(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
     * @summary Fetch the schema for this configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupSchema(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupSchema(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group. The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To update a specific value, use `PUT /users/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
     * @summary Fetch a single value associated with the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValue(
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a representation of this configuration group values resource.
     * @summary Fetch the values for the specified configuration group
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroupValues(
      groupName: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroupValues(
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of configuration groups
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getConfigurationGroups(
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).getConfigurationGroups(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent. The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To fetch specific value, use `GET /users/configurations/groups/{groupName}/values/{valueName}`  (operation `getConfigurationGroupValue`).
     * @summary Update a single value associated with the specified configuration group
     * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
     * @param {string} groupName The unique name of this configuration group.
     * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValue(
      body: string,
      groupName: string,
      valueName: string,
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValue(
        body ? body : null,
        groupName ? groupName : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this set of values
     * @summary Update the values for the specified configuration group
     * @param {{ [key: string]: ConfigurationValue; }} request_body
     * @param {string} groupName The unique name of this configuration group.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateConfigurationGroupValues(
      request_body: { [key: string]: ConfigurationValue },
      groupName: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return ConfigurationApiFp(configuration).updateConfigurationGroupValues(
        request_body ? request_body : null,
        groupName ? groupName : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * ConfigurationApi - object-oriented interface
 * @export
 * @class ConfigurationApi
 * @extends {BaseAPI}
 */
export class ConfigurationApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group resource.
   * @summary Fetch a representation of this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroup}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroup(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroup(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this configuration group schema resource.
   * @summary Fetch the schema for this configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupSchema(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupSchema(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single value associated with this configuration group. This provides convenient access to individual values of the configuration group. The response is always a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To update a specific value, use `PUT /users/configurations/groups/{groupName}/values/{valueName}` (operation `updateConfigurationGroupValue`).
   * @summary Fetch a single value associated with the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValue(groupName: string, valueName: string, options?: any) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValue(
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a representation of this configuration group values resource.
   * @summary Fetch the values for the specified configuration group
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationValue}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroupValues(
    groupName: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroupValues(
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of configuration groups. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of configuration groups
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first configuration group item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of configuration group representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationGroups}
   * @memberof ConfigurationApi
   */
  public getConfigurationGroups(
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).getConfigurationGroups(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single value associated with this configuration group. This provides convenient access to individual values of the configuration group as defined in the configuration group's `schema`. The request body must conform to  the configuration group's schema for the named `{valueName}`. This operation is idempotent. The request body must be a JSON value which can be parsed with a strict JSON parser. The response may be  * a primitive number, boolean, or quoted JSON string.  * a JSON array.  * a JSON object.  * `null`. Examples:   * `\"a string configuration value\"`   * `120`   * `true`   * `null`   * `{ \"borderWidth\": 8, \"foregroundColor\": \"blue\" }` To fetch specific value, use `GET /users/configurations/groups/{groupName}/values/{valueName}`  (operation `getConfigurationGroupValue`).
   * @summary Update a single value associated with the specified configuration group
   * @param {string} body The request body must a valid JSON value and should be parsable with a JSON parser. The result may be a string, number, boolean, array, or object.
   * @param {string} groupName The unique name of this configuration group.
   * @param {string} valueName The unique name of a value in a configuration group. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {string}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValue(
    body: string,
    groupName: string,
    valueName: string,
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValue(
      body ? body : null,
      groupName ? groupName : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this set of values
   * @summary Update the values for the specified configuration group
   * @param {{ [key: string]: ConfigurationValue; }} request_body
   * @param {string} groupName The unique name of this configuration group.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {ConfigurationSchemaValue}
   * @memberof ConfigurationApi
   */
  public updateConfigurationGroupValues(
    request_body: { [key: string]: ConfigurationValue },
    groupName: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return ConfigurationApiFp(this.configuration).updateConfigurationGroupValues(
      request_body ? request_body : null,
      groupName ? groupName : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * EmailAddressApi - axios parameter creator
 * @export
 */
export const EmailAddressApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an email address to the list of the user's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred email address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new email address
     * @param {UserEmailAddress} UserEmailAddress The data necessary to create a new email address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      UserEmailAddress: UserEmailAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling createEmailAddress.',
        );
      }
      // verify required parameter 'UserEmailAddress' is not null or undefined
      if (UserEmailAddress === null || UserEmailAddress === undefined) {
        throw new RequiredError(
          'UserEmailAddress',
          'Required parameter UserEmailAddress was null or undefined when calling createEmailAddress.',
        );
      }
      const localVarPath = `/users/{userId}/emailAddresses`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserEmailAddress' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserEmailAddress || {})
        : UserEmailAddress || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the user's preferred email address.
     * @summary Delete this email address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(userId: string, emailAddressId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling deleteEmailAddress.',
        );
      }
      // verify required parameter 'emailAddressId' is not null or undefined
      if (emailAddressId === null || emailAddressId === undefined) {
        throw new RequiredError(
          'emailAddressId',
          'Required parameter emailAddressId was null or undefined when calling deleteEmailAddress.',
        );
      }
      const localVarPath = `/users/{userId}/emailAddresses/{emailAddressId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'emailAddressId'}}`, encodeURIComponent(String(emailAddressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      userId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getEmailAddress.',
        );
      }
      // verify required parameter 'emailAddressId' is not null or undefined
      if (emailAddressId === null || emailAddressId === undefined) {
        throw new RequiredError(
          'emailAddressId',
          'Required parameter emailAddressId was null or undefined when calling getEmailAddress.',
        );
      }
      const localVarPath = `/users/{userId}/emailAddresses/{emailAddressId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'emailAddressId'}}`, encodeURIComponent(String(emailAddressId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the user's email addresses.
     * @summary Get user's email addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(userId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getEmailAddresses.',
        );
      }
      const localVarPath = `/users/{userId}/emailAddresses`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the user's preferred email address. The user may set their preferred email address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredEmailAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.   No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling setPreferredEmailAddress.',
        );
      }
      const localVarPath = `/users/{userId}/preferredEmailAddress`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * EmailAddressApi - functional programming interface
 * @export
 */
export const EmailAddressApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add an email address to the list of the user's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred email address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new email address
     * @param {UserEmailAddress} UserEmailAddress The data necessary to create a new email address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      UserEmailAddress: UserEmailAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserEmailAddress> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).createEmailAddress(
        UserEmailAddress ? UserEmailAddress : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the user's preferred email address.
     * @summary Delete this email address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(
      userId: string,
      emailAddressId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).deleteEmailAddress(
        userId ? userId : null,
        emailAddressId ? emailAddressId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      userId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserEmailAddress> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).getEmailAddress(
        userId ? userId : null,
        emailAddressId ? emailAddressId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the user's email addresses.
     * @summary Get user's email addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(
      userId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserEmailAddresses> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(configuration).getEmailAddresses(
        userId ? userId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the user's preferred email address. The user may set their preferred email address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredEmailAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.   No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = EmailAddressApiAxiosParamCreator(
        configuration,
      ).setPreferredEmailAddress(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * EmailAddressApi - factory interface
 * @export
 */
export const EmailAddressApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add an email address to the list of the user's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred email address. See _Multi-factor authentication challenges_ above.
     * @summary Create a new email address
     * @param {UserEmailAddress} UserEmailAddress The data necessary to create a new email address.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createEmailAddress(
      UserEmailAddress: UserEmailAddress,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).createEmailAddress(
        UserEmailAddress ? UserEmailAddress : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this email address. The email address can only be deleted if it is _not_ the user's preferred email address.
     * @summary Delete this email address resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteEmailAddress(userId: string, emailAddressId: string, options?: any) {
      return EmailAddressApiFp(configuration).deleteEmailAddress(
        userId ? userId : null,
        emailAddressId ? emailAddressId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
     * @summary Fetch a representation of this email address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddress(
      userId: string,
      emailAddressId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).getEmailAddress(
        userId ? userId : null,
        emailAddressId ? emailAddressId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the user's email addresses.
     * @summary Get user's email addresses
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getEmailAddresses(userId: string, options?: any) {
      return EmailAddressApiFp(configuration).getEmailAddresses(
        userId ? userId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the user's preferred email address. The user may set their preferred email address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredEmailAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.   No changes are made if the specified email address is already the preferred email address.
     * @summary Set Preferred Email Address
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredEmailAddress(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return EmailAddressApiFp(configuration).setPreferredEmailAddress(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * EmailAddressApi - object-oriented interface
 * @export
 * @class EmailAddressApi
 * @extends {BaseAPI}
 */
export class EmailAddressApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add an email address to the list of the user's email addresses. The new email address will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred email address. See _Multi-factor authentication challenges_ above.
   * @summary Create a new email address
   * @param {UserEmailAddress} UserEmailAddress The data necessary to create a new email address.
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing email address to be _replaced_ with this new email address instead of adding a new email address, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred email address the &#x60;preferredEmailAddressId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing email address matches &#x60;replaceId&#x60;, the new email address is added to the list of email addresses. Example: &#x60;?replaceId&#x3D;e1&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserEmailAddress}
   * @memberof EmailAddressApi
   */
  public createEmailAddress(
    UserEmailAddress: UserEmailAddress,
    userId: string,
    query?: { replaceId?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).createEmailAddress(
      UserEmailAddress ? UserEmailAddress : null,
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this email address. The email address can only be deleted if it is _not_ the user's preferred email address.
   * @summary Delete this email address resource
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof EmailAddressApi
   */
  public deleteEmailAddress(userId: string, emailAddressId: string, options?: any) {
    return EmailAddressApiFp(this.configuration).deleteEmailAddress(
      userId ? userId : null,
      emailAddressId ? emailAddressId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this email address resource.
   * @summary Fetch a representation of this email address
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} emailAddressId The unique identifier of this email address. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserEmailAddress}
   * @memberof EmailAddressApi
   */
  public getEmailAddress(
    userId: string,
    emailAddressId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).getEmailAddress(
      userId ? userId : null,
      emailAddressId ? emailAddressId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the user's email addresses.
   * @summary Get user's email addresses
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserEmailAddresses}
   * @memberof EmailAddressApi
   */
  public getEmailAddresses(userId: string, options?: any) {
    return EmailAddressApiFp(this.configuration).getEmailAddresses(
      userId ? userId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the user's preferred email address. The user may set their preferred email address to an _approved_ address by passing its unique `_id` in the `value` query parameter. This updates the `preferredEmailAddressId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an email address if that resource is eligible to be set as the preferred email address.   No changes are made if the specified email address is already the preferred email address.
   * @summary Set Preferred Email Address
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the email address to assign as the preferred email address. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof EmailAddressApi
   */
  public setPreferredEmailAddress(
    userId: string,
    query?: { value?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return EmailAddressApiFp(this.configuration).setPreferredEmailAddress(
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * PhoneNumberApi - axios parameter creator
 * @export
 */
export const PhoneNumberApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add a phone number to the list of the user's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred phone number. See _Multi-factor authentication challenges_ above.
     * @summary Create a new phone number
     * @param {UserPhoneNumber} UserPhoneNumber The data necessary to create a new phone number.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneNumberId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      UserPhoneNumber: UserPhoneNumber,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { replaceId } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling createPhoneNumber.',
        );
      }
      // verify required parameter 'UserPhoneNumber' is not null or undefined
      if (UserPhoneNumber === null || UserPhoneNumber === undefined) {
        throw new RequiredError(
          'UserPhoneNumber',
          'Required parameter UserPhoneNumber was null or undefined when calling createPhoneNumber.',
        );
      }
      const localVarPath = `/users/{userId}/phoneNumbers`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (replaceId !== undefined) {
        localVarQueryParameter['replaceId'] = replaceId;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UserPhoneNumber' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UserPhoneNumber || {})
        : UserPhoneNumber || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the user's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(userId: string, phoneNumberId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling deletePhoneNumber.',
        );
      }
      // verify required parameter 'phoneNumberId' is not null or undefined
      if (phoneNumberId === null || phoneNumberId === undefined) {
        throw new RequiredError(
          'phoneNumberId',
          'Required parameter phoneNumberId was null or undefined when calling deletePhoneNumber.',
        );
      }
      const localVarPath = `/users/{userId}/phoneNumbers/{phoneNumberId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'phoneNumberId'}}`, encodeURIComponent(String(phoneNumberId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      userId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getPhoneNumber.',
        );
      }
      // verify required parameter 'phoneNumberId' is not null or undefined
      if (phoneNumberId === null || phoneNumberId === undefined) {
        throw new RequiredError(
          'phoneNumberId',
          'Required parameter phoneNumberId was null or undefined when calling getPhoneNumber.',
        );
      }
      const localVarPath = `/users/{userId}/phoneNumbers/{phoneNumberId}`
        .replace(`{${'userId'}}`, encodeURIComponent(String(userId)))
        .replace(`{${'phoneNumberId'}}`, encodeURIComponent(String(phoneNumberId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the list of the user's phone numbers
     * @summary Get user's phone numbers
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(userId: string, options: any = {}): RequestArgs {
      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getPhoneNumbers.',
        );
      }
      const localVarPath = `/users/{userId}/phoneNumbers`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Set the user's preferred phone number. The user may set their preferred phone number to an _approved_ number by passing its unique `_id` in the `value` query parameter. This updates the `preferredPhoneNumberId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.   No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options: any = {},
    ): RequestArgs {
      const { value } = query;
      const { Apiture_Challenge } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling setPreferredPhoneNumber.',
        );
      }
      const localVarPath = `/users/{userId}/preferredPhoneNumber`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (value !== undefined) {
        localVarQueryParameter['value'] = value;
      }

      if (Apiture_Challenge !== undefined && Apiture_Challenge !== null) {
        localVarHeaderParameter['Apiture-Challenge'] = String(Apiture_Challenge);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * PhoneNumberApi - functional programming interface
 * @export
 */
export const PhoneNumberApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Add a phone number to the list of the user's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred phone number. See _Multi-factor authentication challenges_ above.
     * @summary Create a new phone number
     * @param {UserPhoneNumber} UserPhoneNumber The data necessary to create a new phone number.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneNumberId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      UserPhoneNumber: UserPhoneNumber,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserPhoneNumber> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).createPhoneNumber(
        UserPhoneNumber ? UserPhoneNumber : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the user's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(
      userId: string,
      phoneNumberId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).deletePhoneNumber(
        userId ? userId : null,
        phoneNumberId ? phoneNumberId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      userId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserPhoneNumber> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).getPhoneNumber(
        userId ? userId : null,
        phoneNumberId ? phoneNumberId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the list of the user's phone numbers
     * @summary Get user's phone numbers
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(
      userId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<UserPhoneNumbers> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(configuration).getPhoneNumbers(
        userId ? userId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Set the user's preferred phone number. The user may set their preferred phone number to an _approved_ number by passing its unique `_id` in the `value` query parameter. This updates the `preferredPhoneNumberId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.   No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = PhoneNumberApiAxiosParamCreator(
        configuration,
      ).setPreferredPhoneNumber(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * PhoneNumberApi - factory interface
 * @export
 */
export const PhoneNumberApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Add a phone number to the list of the user's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred phone number. See _Multi-factor authentication challenges_ above.
     * @summary Create a new phone number
     * @param {UserPhoneNumber} UserPhoneNumber The data necessary to create a new phone number.
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneNumberId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createPhoneNumber(
      UserPhoneNumber: UserPhoneNumber,
      userId: string,
      query?: { replaceId?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).createPhoneNumber(
        UserPhoneNumber ? UserPhoneNumber : null,
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this phone number. The number can only be deleted if it is _not_ the user's preferred phone number.
     * @summary Delete this phone number resource
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deletePhoneNumber(userId: string, phoneNumberId: string, options?: any) {
      return PhoneNumberApiFp(configuration).deletePhoneNumber(
        userId ? userId : null,
        phoneNumberId ? phoneNumberId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
     * @summary Fetch a representation of this phone number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumber(
      userId: string,
      phoneNumberId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).getPhoneNumber(
        userId ? userId : null,
        phoneNumberId ? phoneNumberId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return the list of the user's phone numbers
     * @summary Get user's phone numbers
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getPhoneNumbers(userId: string, options?: any) {
      return PhoneNumberApiFp(configuration).getPhoneNumbers(
        userId ? userId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Set the user's preferred phone number. The user may set their preferred phone number to an _approved_ number by passing its unique `_id` in the `value` query parameter. This updates the `preferredPhoneNumberId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.   No changes are made if the specified phone number is already the preferred phone number.
     * @summary Set Preferred Phone Number
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
     * @param {Object} [headers] Headers object
     * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    setPreferredPhoneNumber(
      userId: string,
      query?: { value?: string },
      headers?: { Apiture_Challenge?: string },
      options?: any,
    ) {
      return PhoneNumberApiFp(configuration).setPreferredPhoneNumber(
        userId ? userId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * PhoneNumberApi - object-oriented interface
 * @export
 * @class PhoneNumberApi
 * @extends {BaseAPI}
 */
export class PhoneNumberApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Add a phone number to the list of the user's phone numbers. The new number will be `pending` until the financial institution has reviewed and approved it, after which it will become `approved`.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required if the `?replaceId` parameter is used and the profile item being replaced is the preferred phone number. See _Multi-factor authentication challenges_ above.
   * @summary Create a new phone number
   * @param {UserPhoneNumber} UserPhoneNumber The data necessary to create a new phone number.
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.replaceId] An optional &#x60;_id&#x60; of an existing phone number to be _replaced_ with this new phone number instead of adding a new phone number, once it has been approved. If &#x60;replaceId&#x60; matches the &#x60;_id&#x60; of the preferred phone number the &#x60;preferredPhoneNumberId&#x60; will also be updated to the value of &#x60;replaceId&#x60; once approved (the &#x60;Apiture-Challenge&#x60; header may be required also). If no existing phone number matches &#x60;replaceId&#x60;, the new phone number is added to the list of phone numbers. Example: &#x60;?replaceId&#x3D;p1&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserPhoneNumber}
   * @memberof PhoneNumberApi
   */
  public createPhoneNumber(
    UserPhoneNumber: UserPhoneNumber,
    userId: string,
    query?: { replaceId?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).createPhoneNumber(
      UserPhoneNumber ? UserPhoneNumber : null,
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this phone number. The number can only be deleted if it is _not_ the user's preferred phone number.
   * @summary Delete this phone number resource
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof PhoneNumberApi
   */
  public deletePhoneNumber(userId: string, phoneNumberId: string, options?: any) {
    return PhoneNumberApiFp(this.configuration).deletePhoneNumber(
      userId ? userId : null,
      phoneNumberId ? phoneNumberId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](http://developer.apiture.com/docs/concepts/hal) representation of this phone number resource.
   * @summary Fetch a representation of this phone number
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {string} phoneNumberId The unique identifier of this phone number. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserPhoneNumber}
   * @memberof PhoneNumberApi
   */
  public getPhoneNumber(
    userId: string,
    phoneNumberId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).getPhoneNumber(
      userId ? userId : null,
      phoneNumberId ? phoneNumberId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return the list of the user's phone numbers
   * @summary Get user's phone numbers
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {UserPhoneNumbers}
   * @memberof PhoneNumberApi
   */
  public getPhoneNumbers(userId: string, options?: any) {
    return PhoneNumberApiFp(this.configuration).getPhoneNumbers(
      userId ? userId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Set the user's preferred phone number. The user may set their preferred phone number to an _approved_ number by passing its unique `_id` in the `value` query parameter. This updates the `preferredPhoneNumberId` property of the user.   This operation may require the user to complete an additional authentication challenge as described in _Multi-factor authentication challenges_ above. A valid `Apiture-Challenge` request header may be required.   This operation is available via the `apiture:setAsPreferred` link on an phone number if that resource is eligible to be set as the preferred phone number.   No changes are made if the specified phone number is already the preferred phone number.
   * @summary Set Preferred Phone Number
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.value] The &#x60;_id&#x60; of the number to assign as the preferred phone number. If this query parameter exists, the request body, if any, is ignored. Example: &#x60;?value&#x3D;pe0&#x60;
   * @param {Object} [headers] Headers object
   * @param {string} [headers.Apiture_Challenge] The unique identifier of a Challenge resource which demonstrates the user has recently verified their identity. See the discussion of _Multi-factor authentication challenges_ above. The value must be the &#x60;_id&#x60; string of a valid, redeemable Challenge resource which matches the challenge context.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof PhoneNumberApi
   */
  public setPreferredPhoneNumber(
    userId: string,
    query?: { value?: string },
    headers?: { Apiture_Challenge?: string },
    options?: any,
  ) {
    return PhoneNumberApiFp(this.configuration).setPreferredPhoneNumber(
      userId ? userId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * UserApi - axios parameter creator
 * @export
 */
export const UserApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     *
     * @summary Create a new user
     * @param {CreateUser} CreateUser The data necessary to create a new user.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUser(CreateUser: CreateUser, options: any = {}): RequestArgs {
      // verify required parameter 'CreateUser' is not null or undefined
      if (CreateUser === null || CreateUser === undefined) {
        throw new RequiredError(
          'CreateUser',
          'Required parameter CreateUser was null or undefined when calling createUser.',
        );
      }
      const localVarPath = `/users`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateUser' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateUser || {})
        : CreateUser || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user resource.   This representation will contain links related to the current user as defined in the `user` schema.
     * @summary Fetch a representation of this user
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUser(userId: string, headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getUser.',
        );
      }
      const localVarPath = `/users/{userId}`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user's constraints resource. Constraints are limits and other values established for the user, such as single or daily transfer limits.
     * @summary Fetch a representation of this user's constraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUserConstraints(
      userId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling getUserConstraints.',
        );
      }
      const localVarPath = `/users/{userId}/constraints`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Use this endpoint to retrieve a [paginated](https://developer.apiture.com/docs/concepts/pagination), [sortable](https://developer.apiture.com/docs/concepts/sorting), [filterable](https://developer.apiture.com/docs/concepts/filtering), [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of users. An authenticated user will have access only to their User resource. The [links](https://developer.apiture.com/docs/concepts/links) in the response include collecton pagination links. Each resource in the `_embedded.items` array is a summary representation of a user; use the `getUser` opertion on the summary's `self` link to get the full representation of the user and all available links.
     * @summary Return a collection of users
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first user in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of user representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed'} [query.state] Subset the users collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the users collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.occupation] Subset the users collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, ?occupation&#x3D;officeAndAdministrativeSupport will match only items whose occupation is officeAndAdministrativeSupport; ?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving will match items whose occupation is officeAndAdministrativeSupport or transportationAndMaterialMoving. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUsers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed';
        customerId?: string;
        occupation?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, customerId, occupation } = query;

      const localVarPath = `/users`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (customerId !== undefined) {
        localVarQueryParameter['customerId'] = customerId;
      }

      if (occupation !== undefined) {
        localVarQueryParameter['occupation'] = occupation;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this user. Fields which are omitted are not updated.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUser(
      User: User,
      userId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling patchUser.',
        );
      }
      // verify required parameter 'User' is not null or undefined
      if (User === null || User === undefined) {
        throw new RequiredError(
          'User',
          'Required parameter User was null or undefined when calling patchUser.',
        );
      }
      const localVarPath = `/users/{userId}`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'User' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(User || {}) : User || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this  user's constraints, a user should not be able to change their own limits.  Fields which are omitted are not updated.
     * @summary Update this  user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling patchUserConstraints.',
        );
      }
      // verify required parameter 'UpdateConstraints' is not null or undefined
      if (UpdateConstraints === null || UpdateConstraints === undefined) {
        throw new RequiredError(
          'UpdateConstraints',
          'Required parameter UpdateConstraints was null or undefined when calling patchUserConstraints.',
        );
      }
      const localVarPath = `/users/{userId}/constraints`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateConstraints' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateConstraints || {})
        : UpdateConstraints || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this user.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUser(
      User: User,
      userId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling updateUser.',
        );
      }
      // verify required parameter 'User' is not null or undefined
      if (User === null || User === undefined) {
        throw new RequiredError(
          'User',
          'Required parameter User was null or undefined when calling updateUser.',
        );
      }
      const localVarPath = `/users/{userId}`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'User' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization ? JSON.stringify(User || {}) : User || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this user's constraints. This operation is performed by an admin. A user cannot change their own limits.
     * @summary Update this user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'userId' is not null or undefined
      if (userId === null || userId === undefined) {
        throw new RequiredError(
          'userId',
          'Required parameter userId was null or undefined when calling updateUserConstraints.',
        );
      }
      // verify required parameter 'UpdateConstraints' is not null or undefined
      if (UpdateConstraints === null || UpdateConstraints === undefined) {
        throw new RequiredError(
          'UpdateConstraints',
          'Required parameter UpdateConstraints was null or undefined when calling updateUserConstraints.',
        );
      }
      const localVarPath = `/users/{userId}/constraints`.replace(
        `{${'userId'}}`,
        encodeURIComponent(String(userId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateConstraints' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateConstraints || {})
        : UpdateConstraints || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * UserApi - functional programming interface
 * @export
 */
export const UserApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     *
     * @summary Create a new user
     * @param {CreateUser} CreateUser The data necessary to create a new user.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUser(
      CreateUser: CreateUser,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).createUser(
        CreateUser ? CreateUser : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user resource.   This representation will contain links related to the current user as defined in the `user` schema.
     * @summary Fetch a representation of this user
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUser(
      userId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).getUser(
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user's constraints resource. Constraints are limits and other values established for the user, such as single or daily transfer limits.
     * @summary Fetch a representation of this user's constraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUserConstraints(
      userId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Constraints> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).getUserConstraints(
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Use this endpoint to retrieve a [paginated](https://developer.apiture.com/docs/concepts/pagination), [sortable](https://developer.apiture.com/docs/concepts/sorting), [filterable](https://developer.apiture.com/docs/concepts/filtering), [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of users. An authenticated user will have access only to their User resource. The [links](https://developer.apiture.com/docs/concepts/links) in the response include collecton pagination links. Each resource in the `_embedded.items` array is a summary representation of a user; use the `getUser` opertion on the summary's `self` link to get the full representation of the user and all available links.
     * @summary Return a collection of users
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first user in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of user representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed'} [query.state] Subset the users collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the users collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.occupation] Subset the users collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, ?occupation&#x3D;officeAndAdministrativeSupport will match only items whose occupation is officeAndAdministrativeSupport; ?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving will match items whose occupation is officeAndAdministrativeSupport or transportationAndMaterialMoving. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUsers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed';
        customerId?: string;
        occupation?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Users> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).getUsers(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this user. Fields which are omitted are not updated.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUser(
      User: User,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).patchUser(
        User ? User : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this  user's constraints, a user should not be able to change their own limits.  Fields which are omitted are not updated.
     * @summary Update this  user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Constraints> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).patchUserConstraints(
        UpdateConstraints ? UpdateConstraints : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this user.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUser(
      User: User,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).updateUser(
        User ? User : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this user's constraints. This operation is performed by an admin. A user cannot change their own limits.
     * @summary Update this user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Constraints> {
      const localVarAxiosArgs = UserApiAxiosParamCreator(configuration).updateUserConstraints(
        UpdateConstraints ? UpdateConstraints : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * UserApi - factory interface
 * @export
 */
export const UserApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     *
     * @summary Create a new user
     * @param {CreateUser} CreateUser The data necessary to create a new user.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createUser(CreateUser: CreateUser, options?: any) {
      return UserApiFp(configuration).createUser(
        CreateUser ? CreateUser : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user resource.   This representation will contain links related to the current user as defined in the `user` schema.
     * @summary Fetch a representation of this user
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUser(userId: string, headers?: { If_None_Match?: string }, options?: any) {
      return UserApiFp(configuration).getUser(
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user's constraints resource. Constraints are limits and other values established for the user, such as single or daily transfer limits.
     * @summary Fetch a representation of this user's constraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUserConstraints(userId: string, headers?: { If_None_Match?: string }, options?: any) {
      return UserApiFp(configuration).getUserConstraints(
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Use this endpoint to retrieve a [paginated](https://developer.apiture.com/docs/concepts/pagination), [sortable](https://developer.apiture.com/docs/concepts/sorting), [filterable](https://developer.apiture.com/docs/concepts/filtering), [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of users. An authenticated user will have access only to their User resource. The [links](https://developer.apiture.com/docs/concepts/links) in the response include collecton pagination links. Each resource in the `_embedded.items` array is a summary representation of a user; use the `getUser` opertion on the summary's `self` link to get the full representation of the user and all available links.
     * @summary Return a collection of users
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first user in this page. The default, 0, represents the first page of the collection.
     * @param {number} [query.limit] The maximum number of user representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed'} [query.state] Subset the users collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.customerId] Subset the users collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.occupation] Subset the users collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, ?occupation&#x3D;officeAndAdministrativeSupport will match only items whose occupation is officeAndAdministrativeSupport; ?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving will match items whose occupation is officeAndAdministrativeSupport or transportationAndMaterialMoving. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getUsers(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?: 'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed';
        customerId?: string;
        occupation?: string;
      },
      options?: any,
    ) {
      return UserApiFp(configuration).getUsers(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a partial update of this user. Fields which are omitted are not updated.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUser(User: User, userId: string, headers?: { If_Match?: string }, options?: any) {
      return UserApiFp(configuration).patchUser(
        User ? User : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this  user's constraints, a user should not be able to change their own limits.  Fields which are omitted are not updated.
     * @summary Update this  user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return UserApiFp(configuration).patchUserConstraints(
        UpdateConstraints ? UpdateConstraints : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this user.
     * @summary Update this user
     * @param {User} User
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUser(User: User, userId: string, headers?: { If_Match?: string }, options?: any) {
      return UserApiFp(configuration).updateUser(
        User ? User : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this user's constraints. This operation is performed by an admin. A user cannot change their own limits.
     * @summary Update this user's constraints
     * @param {UpdateConstraints} UpdateConstraints
     * @param {string} userId The unique identifier of the user. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateUserConstraints(
      UpdateConstraints: UpdateConstraints,
      userId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return UserApiFp(configuration).updateUserConstraints(
        UpdateConstraints ? UpdateConstraints : null,
        userId ? userId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * UserApi - object-oriented interface
 * @export
 * @class UserApi
 * @extends {BaseAPI}
 */
export class UserApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   *
   * @summary Create a new user
   * @param {CreateUser} CreateUser The data necessary to create a new user.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserApi
   */
  public createUser(CreateUser: CreateUser, options?: any) {
    return UserApiFp(this.configuration).createUser(
      CreateUser ? CreateUser : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user resource.   This representation will contain links related to the current user as defined in the `user` schema.
   * @summary Fetch a representation of this user
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserApi
   */
  public getUser(userId: string, headers?: { If_None_Match?: string }, options?: any) {
    return UserApiFp(this.configuration).getUser(
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this user's constraints resource. Constraints are limits and other values established for the user, such as single or daily transfer limits.
   * @summary Fetch a representation of this user's constraints
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Constraints}
   * @memberof UserApi
   */
  public getUserConstraints(userId: string, headers?: { If_None_Match?: string }, options?: any) {
    return UserApiFp(this.configuration).getUserConstraints(
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Use this endpoint to retrieve a [paginated](https://developer.apiture.com/docs/concepts/pagination), [sortable](https://developer.apiture.com/docs/concepts/sorting), [filterable](https://developer.apiture.com/docs/concepts/filtering), [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of users. An authenticated user will have access only to their User resource. The [links](https://developer.apiture.com/docs/concepts/links) in the response include collecton pagination links. Each resource in the `_embedded.items` array is a summary representation of a user; use the `getUser` opertion on the summary's `self` link to get the full representation of the user and all available links.
   * @summary Return a collection of users
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first user in this page. The default, 0, represents the first page of the collection.
   * @param {number} [query.limit] The maximum number of user representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed'} [query.state] Subset the users collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.customerId] Subset the users collection to those whose &#x60;customerId&#x60; matches this value. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.occupation] Subset the users collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, ?occupation&#x3D;officeAndAdministrativeSupport will match only items whose occupation is officeAndAdministrativeSupport; ?occupation&#x3D;officeAndAdministrativeSupport|transportationAndMaterialMoving will match items whose occupation is officeAndAdministrativeSupport or transportationAndMaterialMoving. This is combined with an implicit and with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Users}
   * @memberof UserApi
   */
  public getUsers(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?: 'locked' | 'frozen' | 'merged' | 'active' | 'inactive' | 'removed';
      customerId?: string;
      occupation?: string;
    },
    options?: any,
  ) {
    return UserApiFp(this.configuration).getUsers(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a partial update of this user. Fields which are omitted are not updated.
   * @summary Update this user
   * @param {User} User
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserApi
   */
  public patchUser(User: User, userId: string, headers?: { If_Match?: string }, options?: any) {
    return UserApiFp(this.configuration).patchUser(
      User ? User : null,
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this  user's constraints, a user should not be able to change their own limits.  Fields which are omitted are not updated.
   * @summary Update this  user's constraints
   * @param {UpdateConstraints} UpdateConstraints
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Constraints}
   * @memberof UserApi
   */
  public patchUserConstraints(
    UpdateConstraints: UpdateConstraints,
    userId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return UserApiFp(this.configuration).patchUserConstraints(
      UpdateConstraints ? UpdateConstraints : null,
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this user.
   * @summary Update this user
   * @param {User} User
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserApi
   */
  public updateUser(User: User, userId: string, headers?: { If_Match?: string }, options?: any) {
    return UserApiFp(this.configuration).updateUser(
      User ? User : null,
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this user's constraints. This operation is performed by an admin. A user cannot change their own limits.
   * @summary Update this user's constraints
   * @param {UpdateConstraints} UpdateConstraints
   * @param {string} userId The unique identifier of the user. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Constraints}
   * @memberof UserApi
   */
  public updateUserConstraints(
    UpdateConstraints: UpdateConstraints,
    userId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return UserApiFp(this.configuration).updateUserConstraints(
      UpdateConstraints ? UpdateConstraints : null,
      userId ? userId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * UserActionsApi - axios parameter creator
 * @export
 */
export const UserActionsApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a user from an inactive state.   This operation is invoked from the `apiture:activate` link on a user resource when that user is eligible to be activated. This operation will fail if the user is frozen or locked unless an FI admin is invoking the operation.   This changes the `state` to `active`.
     * @summary Activate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { user } = query;
      const { If_Match } = headers;

      const localVarPath = `/activeUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Deactivate a user from an active state.   This operation is invoked from the `apiture:deactivate` link on a user resource when that user is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { user } = query;
      const { If_Match } = headers;

      const localVarPath = `/inactiveUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Freeze a user from an active, inactive or locked state. A state of frozen indicates that an admin has a concern of fraud.   This operation is invoked from the `apiture:freeze` link on a user resource when an admin user has suspicion of fraud. Only admin has access to freeze a user.  This changes the `state` to `frozen`.
     * @summary Freeze a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be frozen.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { user } = query;
      const { If_Match } = headers;

      const localVarPath = `/frozenUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Lock a user from an active or inactive state.   This operation is invoked from the `apiture:lock` link on a user resource when that user is eligible to be lock.   This changes the `state` to `locked`.
     * @summary Lock a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { user } = query;
      const { If_Match } = headers;

      const localVarPath = `/lockedUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Merge a collection of users from an active, inactive or locked state into the user specified via the `apiture:master` link.   This operation is invoked from the `apiture:merge` link on a user resource when that user is eligible to be merged.   This changes the `state` to `merged`.
     * @summary Merge a set of users
     * @param {MergeUsers} MergeUsers The data necessary to merge users.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    mergeUsers(MergeUsers: MergeUsers, options: any = {}): RequestArgs {
      // verify required parameter 'MergeUsers' is not null or undefined
      if (MergeUsers === null || MergeUsers === undefined) {
        throw new RequiredError(
          'MergeUsers',
          'Required parameter MergeUsers was null or undefined when calling mergeUsers.',
        );
      }
      const localVarPath = `/mergedUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'MergeUsers' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(MergeUsers || {})
        : MergeUsers || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Remove a user from active use.   This operation is invoked from the `apiture:remove` link on a user resource when that user is eligible to be removed.   This changes the `state` to `removed`.
     * @summary Remove a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { user } = query;
      const { If_Match } = headers;

      const localVarPath = `/removedUsers`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'profiles/read',
                'profiles/write',
                'profiles/delete',
                'profiles/readPii',
                'profiles/full',
                'admin/read',
                'admin/write',
                'admin/delete',
                'admin/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (user !== undefined) {
        localVarQueryParameter['user'] = user;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * UserActionsApi - functional programming interface
 * @export
 */
export const UserActionsApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Activate a user from an inactive state.   This operation is invoked from the `apiture:activate` link on a user resource when that user is eligible to be activated. This operation will fail if the user is frozen or locked unless an FI admin is invoking the operation.   This changes the `state` to `active`.
     * @summary Activate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).activateUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Deactivate a user from an active state.   This operation is invoked from the `apiture:deactivate` link on a user resource when that user is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).deactivateUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Freeze a user from an active, inactive or locked state. A state of frozen indicates that an admin has a concern of fraud.   This operation is invoked from the `apiture:freeze` link on a user resource when an admin user has suspicion of fraud. Only admin has access to freeze a user.  This changes the `state` to `frozen`.
     * @summary Freeze a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be frozen.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).freezeUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Lock a user from an active or inactive state.   This operation is invoked from the `apiture:lock` link on a user resource when that user is eligible to be lock.   This changes the `state` to `locked`.
     * @summary Lock a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).lockUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Merge a collection of users from an active, inactive or locked state into the user specified via the `apiture:master` link.   This operation is invoked from the `apiture:merge` link on a user resource when that user is eligible to be merged.   This changes the `state` to `merged`.
     * @summary Merge a set of users
     * @param {MergeUsers} MergeUsers The data necessary to merge users.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    mergeUsers(
      MergeUsers: MergeUsers,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).mergeUsers(
        MergeUsers ? MergeUsers : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Remove a user from active use.   This operation is invoked from the `apiture:remove` link on a user resource when that user is eligible to be removed.   This changes the `state` to `removed`.
     * @summary Remove a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeUser(
      query?: { user?: string },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<User> {
      const localVarAxiosArgs = UserActionsApiAxiosParamCreator(configuration).removeUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * UserActionsApi - factory interface
 * @export
 */
export const UserActionsApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Activate a user from an inactive state.   This operation is invoked from the `apiture:activate` link on a user resource when that user is eligible to be activated. This operation will fail if the user is frozen or locked unless an FI admin is invoking the operation.   This changes the `state` to `active`.
     * @summary Activate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    activateUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
      return UserActionsApiFp(configuration).activateUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Deactivate a user from an active state.   This operation is invoked from the `apiture:deactivate` link on a user resource when that user is eligible to be deactivated.   This changes the `state` to `inactive`.
     * @summary Deactivate a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deactivateUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
      return UserActionsApiFp(configuration).deactivateUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Freeze a user from an active, inactive or locked state. A state of frozen indicates that an admin has a concern of fraud.   This operation is invoked from the `apiture:freeze` link on a user resource when an admin user has suspicion of fraud. Only admin has access to freeze a user.  This changes the `state` to `frozen`.
     * @summary Freeze a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be frozen.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    freezeUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
      return UserActionsApiFp(configuration).freezeUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Lock a user from an active or inactive state.   This operation is invoked from the `apiture:lock` link on a user resource when that user is eligible to be lock.   This changes the `state` to `locked`.
     * @summary Lock a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    lockUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
      return UserActionsApiFp(configuration).lockUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Merge a collection of users from an active, inactive or locked state into the user specified via the `apiture:master` link.   This operation is invoked from the `apiture:merge` link on a user resource when that user is eligible to be merged.   This changes the `state` to `merged`.
     * @summary Merge a set of users
     * @param {MergeUsers} MergeUsers The data necessary to merge users.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    mergeUsers(MergeUsers: MergeUsers, options?: any) {
      return UserActionsApiFp(configuration).mergeUsers(
        MergeUsers ? MergeUsers : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Remove a user from active use.   This operation is invoked from the `apiture:remove` link on a user resource when that user is eligible to be removed.   This changes the `state` to `removed`.
     * @summary Remove a user
     * @param {Object} [query] Query object
     * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    removeUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
      return UserActionsApiFp(configuration).removeUser(
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * UserActionsApi - object-oriented interface
 * @export
 * @class UserActionsApi
 * @extends {BaseAPI}
 */
export class UserActionsApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Activate a user from an inactive state.   This operation is invoked from the `apiture:activate` link on a user resource when that user is eligible to be activated. This operation will fail if the user is frozen or locked unless an FI admin is invoking the operation.   This changes the `state` to `active`.
   * @summary Activate a user
   * @param {Object} [query] Query object
   * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public activateUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
    return UserActionsApiFp(this.configuration).activateUser(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Deactivate a user from an active state.   This operation is invoked from the `apiture:deactivate` link on a user resource when that user is eligible to be deactivated.   This changes the `state` to `inactive`.
   * @summary Deactivate a user
   * @param {Object} [query] Query object
   * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public deactivateUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
    return UserActionsApiFp(this.configuration).deactivateUser(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Freeze a user from an active, inactive or locked state. A state of frozen indicates that an admin has a concern of fraud.   This operation is invoked from the `apiture:freeze` link on a user resource when an admin user has suspicion of fraud. Only admin has access to freeze a user.  This changes the `state` to `frozen`.
   * @summary Freeze a user
   * @param {Object} [query] Query object
   * @param {string} [query.user] The ID or URI of an existing user which is eligible to be frozen.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public freezeUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
    return UserActionsApiFp(this.configuration).freezeUser(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Lock a user from an active or inactive state.   This operation is invoked from the `apiture:lock` link on a user resource when that user is eligible to be lock.   This changes the `state` to `locked`.
   * @summary Lock a user
   * @param {Object} [query] Query object
   * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public lockUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
    return UserActionsApiFp(this.configuration).lockUser(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Merge a collection of users from an active, inactive or locked state into the user specified via the `apiture:master` link.   This operation is invoked from the `apiture:merge` link on a user resource when that user is eligible to be merged.   This changes the `state` to `merged`.
   * @summary Merge a set of users
   * @param {MergeUsers} MergeUsers The data necessary to merge users.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public mergeUsers(MergeUsers: MergeUsers, options?: any) {
    return UserActionsApiFp(this.configuration).mergeUsers(
      MergeUsers ? MergeUsers : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Remove a user from active use.   This operation is invoked from the `apiture:remove` link on a user resource when that user is eligible to be removed.   This changes the `state` to `removed`.
   * @summary Remove a user
   * @param {Object} [query] Query object
   * @param {string} [query.user] The ID or URI of an existing user which is eligible to be removed.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If used, this must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {User}
   * @memberof UserActionsApi
   */
  public removeUser(query?: { user?: string }, headers?: { If_Match?: string }, options?: any) {
    return UserActionsApiFp(this.configuration).removeUser(
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
