// tslint:disable
/// <reference path="./custom.d.ts" />
/**
 * Workflow
 * The workflow API allows definition and execution of workflows. A _workflow_ is a set of tasks in a dependency graph, with state and business rules which connect and constrain the execution of the workflow tasks. Each workflow maintains some state. Each task in the workflow has entry criteria, input variables, and output variables. A task may be a composite task, built from another workflow. (This allows for reuse of such subflows.)   Each task and workflow has the following data:   * `domain`, `name`, `label`, `description` (descriptive information)  * A set of `values` (a map of name/value pairs) based on a `schema`  * A `state` field, one of `definition`, `pending`, `blocked`, `running`, `paused`, `failed`,    `completed`, `canceled`. The default state is `running` (or   `blocked` if no tasks are runnable)  * A `done` field is `true` if the state is one of those last three states.  * A list of `bindings` which connect workflow state `values` or the outputs    of previous tasks to the inputs of dependent tasks.   Some changes to the `state` of a workflow item is managed by the service. Clients can change some states via links in a task instance or workflow instance, via a `PUT` (operations `updateWorkflowValues`, `updateWorkflowValue`, `updateTaskValues` and `updateTaskValue`).   A workflow orchestrates a set of tasks and contains additional data:   * `dependencies`, which maps each task to a set of 0 or more    dependent tasks that trigger the task when they are `completed`.  * Entry criteria for each dependent task may also include a business    `rule` which must evaluate to `true`. The rules can access the    input values on the task as well as the workflow's values.    The default business rule tests that any dependent task is `completed`.  Tasks in a workflow which have no predecessor tasks and whose entry criteria rule evaluate to `true` may be run immediately.   Workflows are _static_: once a workflow has been created, tasks cannot be added or removed from the workflow and the task dependency graph may not be changed.  ## Workflow execution  Several operations change the execution state of workflow or task instances. Use the `startWorkflow`, `pauseWorkflow`, `cancelWorkflow`, `failWorkflow` operations to start a workflow, pause it, cancel it, or set it to a failed state. (Use `startWorkflow` to resume a paused workflow.) The `startTask`, `pauseTask`, `cancelTask`, `failTask` operations do the same for task instances. These operations are provided via links named `apiture:start`, `apiture:pause`, `apiture:cancel`, and `apiture:fail` in the `workflow` and `task` schemas, if the operations are available.   A workflow is `done` when the `state` of all its tasks are `done`, _or_ if the workflow has one or more _terminal_ tasks that are `done`, or if the workflow is in a `failed` state. If a terminal task completes, causing the workflow to complete, any remaining tasks are `canceled`. This allows business rules and flow to define the completion criteria, for example, three of four tasks completed instead all four.   ## Workflow and Task Definitions  Workflow _definitions_ are workflows with a `state` of `definition`; the tasks in a workflow definition are also tasks with `state` equal to `definition`. Definitions act as workflow templates: one creates new workflow instances by specifying an existing workflow definition. This also creates new task instances from each task definition. The workflow and all tasks' `state` is set to `blocked` with the exception of tasks that do not have dependent tasks (`initial` is `true`).   Workflow definitions may have cycles. That is, some tasks may be entered again, effectively restarting those tasks.  ## Workflow revisions  Workflow definitions and task definitions also retain a _revision history_, available in the definition's `revisions` collection. New revisions are created via a `POST` operation to a definition's `revisions` collection (see the `createWorkflowDefinitionRevision` and `createTaskDefinitionRevision` operations). Revisions are immutable copies of the resource which preserve or record the definition's data at the point in time that the revision was created. This allows preserving specific behavior of a workflow when after changing the definition.   For example, a specific revision of a workflow definition (using the revision URI, `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`) may be associated with other resources (such as banking products) so that the specific revision can be instantiated as a new workflow, rather than instantiating the currently active, revisionless definition found at `/workflowDefinitions/{workflowDefinitionId}`.   Revisions also support auditing: the immutable revision is a record of which workflow was used and its initial state. A workflow definition may reference either a specific revision of the embedded task definitions, or _revisionless_ task definitions; this determines which task definition (a specific revision or the most recent revision) is used for all the tasks in that workflow when that definition is used to create a new workflow instance. A reference to a revisionless task definition URL matches the URL pattern `/workflow/taskDefinitions/{taskDefinitionId}`; a task definition revision instance has a URL pattern `/workflow/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}` where revisionId is an [RFC 3339](https://tools.ietf.org/html/rfc3339) format timestamp:  `YYYY-MM-DDThh:mm:ss.sssZ`.   ## Error handling   If a workflow task fails, the service sets its `state` to `failed`. If the task has an `errorTask` defined, the workflow starts that task; it is included in the `/runningTasks`. The error task may be an interactive or hidden task. This allows the workflow to restart a sequence of tasks, for example, to let the user retry an operation that may fail. (The error task should be `restartable`.) The workflow may also define an `errorTask` which the workflow starts if the failed task does not define its own `errorTask`. If the error task is a terminal state, the workflow sets it's `state` to `failed`. The `errorTask` for a workflow or a workflow task is initialized from the same property of the workflow definition or a workflow task definition.
 *
 * OpenAPI spec version: 0.18.1
 * Contact: api@apiture.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import * as Url from 'url';
import { SdkConfiguration } from './configuration';
import globalAxios, { AxiosPromise, AxiosInstance } from 'axios';

const BASE_PATH = '/workflow'.replace(/\/+$/, '');

export const API_VERSION = '0.18.1';

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
  csv: ',',
  ssv: ' ',
  tsv: '\t',
  pipes: '|',
};

/**
 *
 * @export
 * @interface RequestArgs
 */
export interface RequestArgs {
  url: string;
  options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
  protected configuration?: SdkConfiguration;

  constructor(
    configuration?: SdkConfiguration,
    protected basePath: string = BASE_PATH,
    protected axios: AxiosInstance = globalAxios,
  ) {
    if (configuration) {
      this.configuration = { basePath: BASE_PATH, ...configuration };
    } else {
      this.configuration = { basePath: BASE_PATH };
    }

    this.parseHost();
  }

  public getBasePath() {
    return this.basePath;
  }

  private parseHost() {
    const hostUrl = this.configuration.host || '';
    let parsedUrl = hostUrl;
    if (hostUrl.indexOf('http://') < 0 && hostUrl.indexOf('https://') < 0) {
      parsedUrl = 'https://' + hostUrl;
    }
    this.basePath = parsedUrl + this.configuration.basePath || '';
  }

  public setAccessToken(newToken?: string) {
    if (typeof newToken === 'string') {
      this.configuration.accessToken = newToken;
    } else {
      throw new Error(`Expected string value, received ${newToken}/${typeof newToken}`);
    }
  }

  public setApiKey(newKey?: string) {
    if (typeof newKey === 'string') {
      this.configuration.apiKey = newKey;
    } else {
      throw new Error(`Expected string value, received ${newKey}/${typeof newKey}`);
    }
  }

  public setHost(newHost?: string) {
    if (typeof newHost === 'string') {
      this.configuration.host = newHost;
      this.parseHost();
    } else {
      throw new Error(`Expected string value, received ${newHost}/${typeof newHost}`);
    }
  }
}

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
  name: 'RequiredError' = 'RequiredError';
  constructor(public field: string, msg?: string) {
    super(msg);
  }
}

/**
 * An abstract schema used to define other request-only schemas. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation, minus the `_error` defined in `abstractResource`.
 * @export
 * @interface AbstractRequest
 */
export interface AbstractRequest {
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof AbstractRequest
   */
  _links?: { [key: string]: Link };
  /**
   * An optional map of nested resources, mapping each nested resource name to a nested resource representation.
   * @type {any}
   * @memberof AbstractRequest
   */
  _embedded?: any;
  /**
   * The URI of a [resource profile](https://developer.apiture.com/docs/concepts/profiles/) which describes the representation.
   * @type {string}
   * @memberof AbstractRequest
   */
  _profile?: string;
}

/**
 * An abstract schema used to define other schemas for request and response bodies. This is a [HAL](https://tools.ietf.org/html/draft-kelly-json-hal-08) resource representation. This model contains hypermedia `_links`, and either optional domain object data with `_profile` and optional `_embedded` objects, or an `_error` object. In responses, if the operation was successful, this object will not include the `_error`, but if the operation was a 4xx or 5xx error, this object will not include `_embedded` or any data fields, only `_error` and optionally `_links`.
 * @export
 * @interface AbstractResource
 */
export interface AbstractResource extends AbstractRequest {
  /**
   * An object which describes an error. This value is omitted if the operation succeeded without error.
   * @type {Error}
   * @memberof AbstractResource
   */
  _error?: Error;
}

/**
 * The data associated with this attribute.
 * @export
 * @interface AttributeValue
 */
export interface AttributeValue {}

/**
 * An optional map of name/value pairs which contains additional dynamic data about the resource.
 * @export
 * @interface Attributes
 */
export interface Attributes {
  [key: string]: AttributeValue;
}

/**
 * Binds (assigns) a source variable to one or more target destinations.   Each source or target is a compound name, either <code>_.<em>fieldName</em></code> to refer to an variable in the workflow's or task's `values`, or <code><em>taskName</em>.<em>fieldName</em></code> to refer to a variable in a task's `values`. The <em>fieldName</em> may in turn be a compound name if the value is an object type, or may include an array index if the referenced data value is an array.   For example, the binding  ```   { 'source' : '_.user',     'targets' : [ 'userForm1.user', 'jointUserForm1.spouse' ]   } ```  will initialize the value `user` in the `userForm1` task with the workflow item's `user` value, and initialize the value `spouse` field in the `jointUserForm1` task with the same value.
 * @export
 * @interface Binding
 */
export interface Binding {
  /**
   * The name of a value within the workflow's `values` (such as <code>_.<em>fieldName</em></code>) or within a task's `values` (such as <code><em>taskName</em>.<em>fieldName</em></code>).
   * @type {string}
   * @memberof Binding
   */
  source?: string;
  /**
   * The names of one or more `values` within the workflow (named <code>_.<em>fieldName</em></code>) or within a task (named <code><em>taskName</em>.<em>fieldName</em></code>) which will be bound to or assigned the value of the `source`.
   * @type {Array<string>}
   * @memberof Binding
   */
  targets?: Array<string>;
  /**
   * External targets bind source variables to an external resource.   For example, the external target  ```   { 'source' : 'userInformation.firstName',     'externalTargets' : [ { 'uri': '_.applicationUri', 'target': 'applicants[0].firstName'} ]   } ```  will update the resource located at the uri at `applicationUri` in the workflow's `values` and map the source value from the userInformation task values to the external resource's body  ``` {   'applicants': [{     'firstName': 'mySourceValue'   }] } ```
   * @type {Array<BindingExternalTargets>}
   * @memberof Binding
   */
  externalTargets?: Array<BindingExternalTargets>;
}

/**
 *
 * @export
 * @interface BindingExternalTargets
 */
export interface BindingExternalTargets {
  /**
   * The names of one or more `values` within the workflow (named <code>_.<em>fieldName</em></code>) or within a task (named <code><em>taskName</em>.<em>fieldName</em></code>) which contains the uri of the external resource to bind to.
   * @type {string}
   * @memberof BindingExternalTargets
   */
  uri?: string;
  /**
   * The name of one or more properties on the external resource which will be assigned the value of the `source`. This is used to map the `source` value to the proper object structure of the external resource.
   * @type {string}
   * @memberof BindingExternalTargets
   */
  target?: string;
}

/**
 * A collection of resources. This is an abstract model schema which is extended to define specific resource collections.
 * @export
 * @interface Collection
 */
export interface Collection extends AbstractResource {
  /**
   * The number of items in the collection. This value is _optional_ and may be omitted if the count is not computable efficiently. If a filter is applied to the collection (either implicitly or explicitly), the count, if present, indicates the number of items that satisfy the filter.
   * @type {number}
   * @memberof Collection
   */
  count?: number;
  /**
   * The start index of this page of items.
   * @type {number}
   * @memberof Collection
   */
  start?: number;
  /**
   * The maximum number of items per page.
   * @type {number}
   * @memberof Collection
   */
  limit?: number;
  /**
   * The name of the collection.
   * @type {string}
   * @memberof Collection
   */
  name?: string;
}

/**
 * Representation used to create a new task definition.
 * @export
 * @interface CreateTask
 */
export interface CreateTask extends TaskFields, FlowItem {}

/**
 * Representation used to create a new workflow definition. A workflow consists of one or more tasks, with dependencies and constraints. Each task can depend on one or more other tasks, with an optional constraint predicate which must evaluate to `true` when the dependent tasks have _completed_ (their `completed` field is `true`). The default constraint is that each dependent task has completed (its `completed` field is `true`, indicating it completed normally, it failed, or it was canceled).  The account application should be passed as the `apiture:application` link in `_links` in the request.   The `values` of each task in the workflows `_embedded.tasks` will also be available within the `values` of the workflow via the names in the `tasks` object. For example, if a workflow has tasks  ```     { 'a' : { ... task type c ... },       'b' : { ... task type c ... },       ... } ```  where tasks `a` and `b` both have `values` named `x`, `y` an `z`, these tasks will be available within the workflow's `values` as `a` and `b` and each of the tasks' `values` available via `a.x`, `a.y`, `a.z`, `b.x`, `b.y` and `b.z`, respectively. Thus, the `schema` and `values` from the workflow definition should not define any values whose name conflicts with the names in `tasks`.   *Note*: When creating workflow definition, the `_embedded` objects should be task *definitions*.
 * @export
 * @interface CreateWorkflow
 */
export interface CreateWorkflow extends FlowItem, WorkflowFields {}

/**
 * A dependency captures a workflow task dependency: each task within a workflow can depend on 0 or more other _dependent_ tasks, creating a (possibly cyclic) dependency graph. Associated with each dependency is a _rule_: an optional constraint predicate expression which must evaluate to `true` in order for the task to start. The default constraint is that the dependent tasks all be `completed` (normal completion). A `dependency` object is the value associated with a task's name within a workflow's `dependencies` object.
 * @export
 * @interface Dependency
 */
export interface Dependency {
  /**
   * The names of the tasks which must be `done` before this task can be run.
   * @type {Array<string>}
   * @memberof Dependency
   */
  dependents?: Array<string>;
  /**
   * A business rule expression which must evaluate to true for this dependency to succeed. If any dependency constraint evaluates to false, the node's state becomes `failed`, and the workflow state may also become `failed`.
   * @type {string}
   * @memberof Dependency
   */
  rule?: string;
}

/**
 * Describes an error in an API request or in a service called via the API.
 * @export
 * @interface Error
 */
export interface Error {
  /**
   * A localized message string describing the error condition.
   * @type {string}
   * @memberof Error
   */
  message: string;
  /**
   * A unique identifier for this error instance. This may be used as a correlation ID with the root cause error (i.e. this ID may be logged at the source of the error). This is is an opaque string.
   * @type {string}
   * @memberof Error
   */
  _id?: string;
  /**
   * The HTTP status code associate with this error.
   * @type {number}
   * @memberof Error
   */
  statusCode?: number;
  /**
   * An error identifier which indicates the category of error and associate it with API support documentation or which the UI tier can use to render an appropriate message or hint. This provides a finer level of granularity than the `statusCode`. For example, instead of just 400 Bad Request, the `type` may be much more specific. such as `integerValueNotInAllowedRange` or `numericValueExceedsMaximum` or `stringValueNotInAllowedSet`.
   * @type {string}
   * @memberof Error
   */
  type?: string;
  /**
   * An [RFC 3339](https://tools.ietf.org/html/rfc3339) UTC time stamp indicating when the error occurred.
   * @type {Date}
   * @memberof Error
   */
  occurredAt?: Date;
  /**
   * Informative values or constraints which describe the error. For example, for a value out of range error, the attributes may specify the `minimum` and `maximum` values. This allows clients to present error messages as they see fit (the API does not assume the client/presentation tier). The set of attributes varies by error `type`.
   * @type {Attributes}
   * @memberof Error
   */
  attributes?: Attributes;
  /**
   * An optional localized string which provides hints for how the user or client can resolve the error.
   * @type {string}
   * @memberof Error
   */
  remediation?: string;
  /**
   * An optional array of nested error objects. This property is not always present.
   * @type {Array<Error>}
   * @memberof Error
   */
  errors?: Array<Error>;
  /**
   * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
   * @type {{ [key: string]: Link; }}
   * @memberof Error
   */
  _links?: { [key: string]: Link };
}

/**
 * Describes an error response, typically returned on 4xx or 5xx errors from API operations. The `_error` object contains the error details.
 * @export
 * @interface ErrorResponse
 */
export interface ErrorResponse extends AbstractResource {}

/**
 * This schema defines core properties shared between workflows and tasks. It is used to define other model schemas for this API and is not used on its own to describe request and response bodies.
 * @export
 * @interface FlowItem
 */
export interface FlowItem extends FlowItemSummary {
  /**
   * The schema which defines the name and types of the variables that are part of this task definition. Property names must be simple identifiers consisting of alphanumeric characters, `-`, `_` following the pattern _`letter [letter | digit | '-' | '_']*`_ This is implicitly a schema for `type: object` and contains the properties.  The `values` in a task conform to the schema. The names and types are described with a subset of [JSON Schema Core](https://tools.ietf.org/html/draft-zyp-json-schema-04) and [JSON Schema Validation](https://tools.ietf.org/html/draft-fge-json-schema-validation-00) similar to that used to define schemas in [OpenAPI Specification 2.0](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#schemaObject).
   * @type {any}
   * @memberof FlowItem
   */
  schema?: any;
  /**
   * `interface` defines the input and output interface of the workflow or task. The `interface` maps a variable from the schema to an object which indicates if the variable is part of the inputs to the task or workflow or part of the outputs of the instance, or both. The `value` provides a default value which is used when creating the instance. The `value` must confirm to the schema for that variable.
   * @type {{ [key: string]: ModelInterface; }}
   * @memberof FlowItem
   */
  interface?: { [key: string]: ModelInterface };
  /**
   * `bindings` connects input and output `interface` variables of the workflow and the workflow tasks.  When the workflow starts, all workflow and task variables are first assigned to any default values as per their respective `interface` and `schema` defaults. Next, workflow and task `interface` inputs are assigned to the inputs of any tasks as per these `bindings`. When a task starts, any bindings for its inputs are assigned as per these bindings. Each binding defines a source and one or more targets that are assigned to the value named by the source.
   * @type {Array<Binding>}
   * @memberof FlowItem
   */
  bindings?: Array<Binding>;
  /**
   * The data associated with this flow item: the item's variable names and values. These values must conform to this item's `schema`. When a workflow or task runs, it may read and/or update these values as part of its processing.  When used in a workflow definition or task definition, the `values` define the default values for the variable that the workflow or task will take if the corresponding value is not bound via a workflow's `bindings`. That is, a definition's `values` are copied into the new workflow item's `values` when the item is instantiated from the definition.  *Note*: the `schema` may also contain `default` values which, if present, are used if a value is *not* set in the definition's `values`. (For example, multiple task definitions may use the same schema which defines values `a`, `b`, and `c`, but each task definition may have their own unique values for `a`, `b`, and `c` which is separate from the schema.)
   * @type {{ [key: string]: AttributeValue; }}
   * @memberof FlowItem
   */
  values?: { [key: string]: AttributeValue };
}

/**
 * The state of a workflow task or of a workflow.
 * @export
 * @enum {string}
 */
export enum FlowItemState {
  Definition = 'definition',
  Pending = 'pending',
  Blocked = 'blocked',
  Running = 'running',
  Paused = 'paused',
  Completed = 'completed',
  Failed = 'failed',
  Canceled = 'canceled',
}

/**
 * This schema defines core properties shared between workflow and task _summary_ representations. It is used to define other model schemas for this API and is not used on its own to describe request and response bodies.
 * @export
 * @interface FlowItemSummary
 */
export interface FlowItemSummary extends AbstractResource, RevisionEffectiveInterval {
  /**
   * The name of this resource. The combination of `domain` and `name` must be unique within the set of all resources of this type.
   * @type {string}
   * @memberof FlowItemSummary
   */
  name?: string;
  /**
   * A namespace for grouping related resources, to keep them separate from other resources. For example, a department or bank branch may define a *domain*, and all tasks or workflow instances they define will use that domain, so that they can avoid conflicting with task or workflow names in other domains. An API or service may define a domain for workflows and tasks that it defines. The combination of `domain` and `name` must be unique within the set of all resources of this type. It is a best practice to define domains with URIs.
   * @type {string}
   * @memberof FlowItemSummary
   */
  domain?: string;
  /**
   * The text label for this resource, suitable for presentation to the client.
   * @type {string}
   * @memberof FlowItemSummary
   */
  label?: string;
  /**
   * The full description for this resource, suitable for presentation in the tools for building/navigating the workflow. The content is processed as [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof FlowItemSummary
   */
  description?: string;
  /**
   * End-user instructions for this workflow item. The content is processed as [Github Flavored Markdown](https://help.github.com/articles/basic-writing-and-formatting-syntax/) and thus supports rich text.
   * @type {string}
   * @memberof FlowItemSummary
   */
  instructions?: string;
  /**
   * The text label for the revision of this resource, suitable for presentation to the client. This is used to differentiate between different revisions of the item. Clients should change this via the `PATCH` or `PUT` before creating the revision, since revisions are immutable and there is no way to change this label after the revision is created.
   * @type {string}
   * @memberof FlowItemSummary
   */
  revisionLabel?: string;
  /**
   * Indicates if a task or workflow has completed. (With the current set of state values, this is true when the `state` is one of `completed` or `failed` or `canceled`, although the set of states may change when new states are added.)
   * @type {boolean}
   * @memberof FlowItemSummary
   */
  done?: boolean;
  /**
   * Indicates if the workflow or task is restartable.
   * @type {boolean}
   * @memberof FlowItemSummary
   */
  restartable?: boolean;
  /**
   * An optional expression used in determining if the given task is restartable.
   * @type {string}
   * @memberof FlowItemSummary
   */
  restartableRule?: string;
  /**
   * An optional limit on the amount of times that the given task can be restarted.
   * @type {number}
   * @memberof FlowItemSummary
   */
  maxRestartCount?: number;
  /**
   * A running count of the amount of times that a given task has been restarted.
   * @type {number}
   * @memberof FlowItemSummary
   */
  restartCount?: number;
  /**
   * Can be used to include tasks in an optional task sequence object on the workflow.   This object contains an ordered list of tasks that have been completed during the workflow.  The UI may use this object to traverse the completed tasks.
   * @type {boolean}
   * @memberof FlowItemSummary
   */
  includeInTaskSequence?: boolean;
  /**
   * The state of a workflow or task.
   * @type {FlowItemState}
   * @memberof FlowItemSummary
   */
  state?: FlowItemState;
}

/**
 *
 * @export
 * @interface InlineResponse200
 */
export interface InlineResponse200 {
  /**
   * An optional map of name/value pairs which contains additional dynamic data about the resource.
   * @type {{ [key: string]: AttributeValue; }}
   * @memberof InlineResponse200
   */
  attributes?: { [key: string]: AttributeValue };
}

/**
 * Describes a hypermedia link within a `_links` object in HAL representations. In Apiture APIs, links are [HAL links](https://developer.apiture.com/docs/concepts/links), but Apiture APIs do not use the `name` or `hreflang` properties of HAL. Apiture links _may_ include a `method` property.
 * @export
 * @interface Link
 */
export interface Link {
  /**
   * The URI or URI template for the resource/operation this link refers to.
   * @type {string}
   * @memberof Link
   */
  href: string;
  /**
   * The media type for the resource.
   * @type {string}
   * @memberof Link
   */
  type?: string;
  /**
   * If true, the link's href is a [URI template](https://tools.ietf.org/html/rfc6570).
   * @type {boolean}
   * @memberof Link
   */
  templated?: boolean;
  /**
   * An optional human-readable localized title for the link.
   * @type {string}
   * @memberof Link
   */
  title?: string;
  /**
   * If present, the containing link is deprecated and the value is a URI which provides human-readable text information about the deprecation.
   * @type {string}
   * @memberof Link
   */
  deprecation?: string;
  /**
   * The URI of a profile document, a JSON document which describes the target resource/operation.
   * @type {string}
   * @memberof Link
   */
  profile?: string;
}

/**
 * An optional map of links, mapping each link relation to a link object. This model defines the `_links` object of HAL representations.
 * @export
 * @interface Links
 */
export interface Links {
  [key: string]: Link;
}

/**
 * Defines the input and output interface (subset of values) for  a task or workflow.
 * @export
 * @interface ModelInterface
 */
export interface ModelInterface {
  /**
   * `true` if the variable is an input to the task or workflow.
   * @type {any}
   * @memberof ModelInterface
   */
  input?: any;
  /**
   * `true` if the variable is an output of the task or workflow.
   * @type {any}
   * @memberof ModelInterface
   */
  output?: any;
  /**
   * `true` if the input variable is required. For a task, the workflow must bind the task's required inputs to a value, such as one of the variables in the workflow, or to an output variable of another task. (The schema types must match for such assignments.)
   * @type {any}
   * @memberof ModelInterface
   */
  required?: any;
}

/**
 * Summary representation of a task definition resource that contains an optional array of subtasks. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface NestableTask
 */
export interface NestableTask extends SummaryTask {
  /**
   * An optional array of summary task definitions.  Subtasks appear on nested workflows (tasks of `type: workflow`).
   * @type {Array<NestableTask>}
   * @memberof NestableTask
   */
  subtasks?: Array<NestableTask>;
}

/**
 * Time interval when a resource revision was effective and in use. This schema is used when composing other schemas.
 * @export
 * @interface RevisionEffectiveInterval
 */
export interface RevisionEffectiveInterval {
  /**
   * The date-time when this revision was created and became effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveStartAt?: Date;
  /**
   * The date-time when the another revision became effective and this revision ceased being effective. This is an [RFC 3339](https://tools.ietf.org/html/rfc3339) formatted date-time string `YYYY-MM-DDThh:mm:ss.sssZ`. This field is derived and immutable and is not present until the revision is no longer active.
   * @type {Date}
   * @memberof RevisionEffectiveInterval
   */
  effectiveEndAt?: Date;
}

/**
 * A HAL response, with hypermedia `_links` for the top-level resources and operations in API.
 * @export
 * @interface Root
 */
export interface Root extends AbstractResource {
  /**
   * This API's unique ID.
   * @type {string}
   * @memberof Root
   */
  _id?: string;
  /**
   * This API's name.
   * @type {string}
   * @memberof Root
   */
  name?: string;
  /**
   * This API's version.
   * @type {string}
   * @memberof Root
   */
  apiVersion?: string;
}

/**
 * Summary representation of a task definition resource in task definitions collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryTask
 */
export interface SummaryTask extends TaskFields {
  /**
   * The unique identifier for this task definition resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryTask
   */
  _id?: string;
}

/**
 * Summary representation of a workflow resource in workflows collections. This representation normally does not contain any `_embedded` objects. If needed, call the `GET` operation on the item's `self` link to get `_embedded` objects.
 * @export
 * @interface SummaryWorkflow
 */
export interface SummaryWorkflow extends FlowItemSummary {
  /**
   * The unique identifier for this workflow resource. This is an immutable opaque string.
   * @type {string}
   * @memberof SummaryWorkflow
   */
  _id?: string;
}

/**
 * Representation of a task definition resource. A definition (template) for creating new tasks in workflows.   A task instance (not a task definition) may have the following links:    * *`apiture:definition`* - links to the task definition.   * *`up`* - links to the workflow in which this task resides.   * *`apiture:pause`* - Pause the task with a `POST` to the `href` in this link.   * *`apiture:cancel`* - Cancel the task with a `POST` to the `href` in this link.   * *`apiture:start`* - Start or restart the task with a `POST` to the `href` in this link.   * *`apiture:fail`* - Stop the task and set its state to `failed` with a `POST` to the `href` in this link.
 * @export
 * @interface Task
 */
export interface Task extends TaskFields, FlowItem {
  /**
   * The unique identifier for this task resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Task
   */
  _id?: string;
  /**
   * The name of task to [start](#op-startTask) if this task fails. When the task fails, it [sets its state to `failed`](#op-failTask). If the value is `\"\"`, then the workflow does nothing if the task fails. If this is not set, the workflow will start the task named by the workflow's `errorTask`, if any, otherwise the workflow [sets its state to `failed`](#op-failWorkflow). type: string
   * @type {any}
   * @memberof Task
   */
  errorTask?: any;
}

/**
 * Common fields of the task resource used to build other model schemas.
 * @export
 * @interface TaskFields
 */
export interface TaskFields extends FlowItemSummary {
  /**
   * Describes the type of this task. This determines the behavior when the task is activated. Example task types are `form` (fill out a form), `choice` (select a value from a fixed set of choices), `select` (select one or more values from a dynamic set of choices), `rest` (perform a REST call), `compute` (compute output values based on the input values), `workflow` (a reusable set of subtasks). Task types are defined in the Workflow configuration.
   * @type {string}
   * @memberof TaskFields
   */
  type?: string;
  /**
   * Indicates if a task is an _initial_ task A initial task is one which has no task dependencies and thus can never be `blocked`. Initial tasks are started automatically when the workflow is started. <br> This is a derived property.
   * @type {boolean}
   * @memberof TaskFields
   */
  initial?: boolean;
  /**
   * Indicates if a task is a _terminal_ task A terminal task is one which no other task depends on. If a terminal state is reached (its entry criteria are satisfied), the workflow containing the task is also marked as `completed` or `failed`. <br> This is a derived property.
   * @type {boolean}
   * @memberof TaskFields
   */
  terminal?: boolean;
  /**
   * Whether the client should show or hide this task.
   * @type {TaskVisibility}
   * @memberof TaskFields
   */
  visibility?: TaskVisibility;
  /**
   * Indicates whether the client interacts with the task or not.
   * @type {TaskMode}
   * @memberof TaskFields
   */
  mode?: TaskMode;
}

/**
 * Indicates whether the client interacts with the task or not.   * *`interactive`* The task requires interaction with     the user, such as selecting a choice or filling out a form.   * *`automatic`* The task runs without interaction once     its prerequisites are satisfied.
 * @export
 * @enum {string}
 */
export enum TaskMode {
  Interactive = 'interactive',
  Automatic = 'automatic',
}

/**
 * Determines the visibility of the task in interactive (UI) clients.   * *`hidden`*: Presentation clients (UI) should not show     this task to the end user.   * *`visible`*: Presentation clients (UI) may show     this task to the end user.
 * @export
 * @enum {string}
 */
export enum TaskVisibility {
  Hidden = 'hidden',
  Visible = 'visible',
}

/**
 * Collection of tasks. The items in the collection are ordered in the `_embedded` object with name `items`.  The top-level `_links` object may contain pagination links  (`self`, `next`, `prev`, `first`, `last`, `collection`) as well  as the following:      * *`apiture:createTaskDefinition`* a POST     operation to create a task definition using the     `createTask` schema for the request.
 * @export
 * @interface Tasks
 */
export interface Tasks extends Collection {
  /**
   * Embedded task summary objects.
   * @type {any}
   * @memberof Tasks
   */
  _embedded?: any;
}

/**
 * Representation used to update or patch a task definition. Updates do not change the derived `state` field.
 * @export
 * @interface UpdateTask
 */
export interface UpdateTask extends Task {}

/**
 * Representation used to update or patch a workflow. Updates do not change the derived `state` field.
 * @export
 * @interface UpdateWorkflow
 */
export interface UpdateWorkflow extends Workflow {}

/**
 * Collection of visible tasks. The `visibility` of each task under `_embedded.items` will be `visible`.   If any of the tasks are of type `workflow`, their `visible` tasks will be included as well, nested inside that workflow task's `subTasks`.
 * @export
 * @interface VisibleTasks
 */
export interface VisibleTasks extends Collection {
  /**
   * Embedded task objects.
   * @type {any}
   * @memberof VisibleTasks
   */
  _embedded?: any;
}

/**
 * Representation of a workflow resource. A workflow instance based on a workflow definition.   A workflow instance (not a workflow definition) may have the following links:    * *`apiture:definition`* links to the task definition.   * *'apiture:pause` - Pause the workflow with a `POST` to the `href` in this link. Running tasks will also be paused.   * *'apiture:cancel` - Cancel the workflow with a `POST` to the `href` in this link. Running tasks will be canceled.   * *'apiture:start` - Start or restart the workflow with a `POST` to the `href` in this link.   * *'apiture:fail` - Stop the workflow and set its state to `failed` with a `POST` to the `href` in this link.
 * @export
 * @interface Workflow
 */
export interface Workflow extends FlowItem, WorkflowFields {
  /**
   * The unique identifier for this workflow resource. This is an immutable opaque string.
   * @type {string}
   * @memberof Workflow
   */
  _id?: string;
  /**
   * The date-time when the workflow was created. This is an [RFC 3369](https://tools.ietf.org/html/rfc3339) formatted date-time string, `YYYY-MM-DDThh:mm:ss.sssZ`. This is a derived field and is immutable.
   * @type {Date}
   * @memberof Workflow
   */
  createdAt?: Date;
  /**
   * The date-time when the workflow was updated. This is an [RFC 3369](https://tools.ietf.org/html/rfc3339) formatted date-time string, `YYYY-MM-DDThh:mm:ss.sssZ`. This is a derived field and is immutable.
   * @type {Date}
   * @memberof Workflow
   */
  updatedAt?: Date;
  /**
   * The name of a task to [start](#op-startTask) when a task fails and the failed task does not define its own `errorTask`. If the task is a `terminal` task, the workflow [sets its `state` to `failed`](#op-failTask). If the value is `\"\"`, then the workflow does nothing when a task fails. If not defined, the workflow state becomes `failed` if a task without an `errorTask` fails.
   * @type {string}
   * @memberof Workflow
   */
  errorTask?: string;
}

/**
 * Common properties used in `createWorkflow`, `updateWorkflow` and `workflow` which are not in the `summaryWorkflow` representation.
 * @export
 * @interface WorkflowFields
 */
export interface WorkflowFields {
  /**
   * The task dependency graph. This defines which tasks are prerequisite tasks for other task in the workflow. `dependencies` is a map structure. The key is the name of the task which depends on the others; the value is an array of `dependency` objects which define what named task depends on and what conditions must be met.
   * @type {{ [key: string]: Array<Dependency>; }}
   * @memberof WorkflowFields
   */
  dependencies?: { [key: string]: Array<Dependency> };
  /**
   * Nested objects within a workflow definition. When creating a workflow definition, the nested tasks should be task or task summary representations from `/taskDefinitions` (i.e. the task `state`  must be `definition`). These may be either revisionless task definitions or specific revisions of task definitions.
   * @type {any}
   * @memberof WorkflowFields
   */
  _embedded?: any;
}

/**
 * Collection of workflows. The items in the collection are ordered in the `_embedded` object with name `items`. The top-level `_links` object may contain pagination links (`self`, `next`, `prev`, `first`, `last`, `collection`) as well the following:      * *`apiture:createWorkflowDefinition`* - a POST operation to create a workflow definition using the     `createWorkflow` schema for the request.
 * @export
 * @interface Workflows
 */
export interface Workflows extends Collection {
  /**
   * Embedded workflow summary objects.
   * @type {any}
   * @memberof Workflows
   */
  _embedded?: any;
}

/**
 * APIApi - axios parameter creator
 * @export
 */
export const APIApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:workflowDefinitions`* - links to the collection of workflow definitions   * *`apiture:workflows`* - links to the collection of workflows   * *`apiture:taskDefinitions`* - links to the collection of workflow task definitions   * *`apiture:tasks`* - links to the collection of workflow tasks
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options: any = {}): RequestArgs {
      const localVarPath = `/`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options: any = {}): RequestArgs {
      const localVarPath = `/apiDoc`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * APIApi - functional programming interface
 * @export
 */
export const APIApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:workflowDefinitions`* - links to the collection of workflow definitions   * *`apiture:workflows`* - links to the collection of workflows   * *`apiture:taskDefinitions`* - links to the collection of workflow task definitions   * *`apiture:tasks`* - links to the collection of workflow tasks
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Root> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApi(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = APIApiAxiosParamCreator(configuration).getApiDoc(
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * APIApi - factory interface
 * @export
 */
export const APIApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:workflowDefinitions`* - links to the collection of workflow definitions   * *`apiture:workflows`* - links to the collection of workflows   * *`apiture:taskDefinitions`* - links to the collection of workflow task definitions   * *`apiture:tasks`* - links to the collection of workflow tasks
     * @summary Top-level resources and operations in this API
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApi(options?: any) {
      return APIApiFp(configuration).getApi(options ? options : {})(axios, basePath);
    },
    /**
     * Return the OpenAPI document that describes this API.
     * @summary Return API definition document
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getApiDoc(options?: any) {
      return APIApiFp(configuration).getApiDoc(options ? options : {})(axios, basePath);
    },
  };
};

/**
 * APIApi - object-oriented interface
 * @export
 * @class APIApi
 * @extends {BaseAPI}
 */
export class APIApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Return links to the top-level resources and operations in this API. Links included in this response include:    * *`apiture:workflowDefinitions`* - links to the collection of workflow definitions   * *`apiture:workflows`* - links to the collection of workflows   * *`apiture:taskDefinitions`* - links to the collection of workflow task definitions   * *`apiture:tasks`* - links to the collection of workflow tasks
   * @summary Top-level resources and operations in this API
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Root}
   * @memberof APIApi
   */
  public getApi(options?: any) {
    return APIApiFp(this.configuration).getApi(options ? options : {})(this.axios, this.basePath);
  }

  /**
   * Return the OpenAPI document that describes this API.
   * @summary Return API definition document
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof APIApi
   */
  public getApiDoc(options?: any) {
    return APIApiFp(this.configuration).getApiDoc(options ? options : {})(
      this.axios,
      this.basePath,
    );
  }
}

/**
 * TaskApi - axios parameter creator
 * @export
 */
export const TaskApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:cancel` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Cancel a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelTask(query?: { task?: string }, options: any = {}): RequestArgs {
      const { task } = query;

      // verify required parameter 'task' is not null or undefined
      if (task === null || task === undefined) {
        throw new RequiredError(
          'task',
          'Required parameter task was null or undefined when calling cancelTask.',
        );
      }
      const localVarPath = `/canceledTasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (task !== undefined) {
        localVarQueryParameter['task'] = task;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new task in the tasks collection.
     * @summary Create a new task
     * @param {CreateTask} CreateTask The data necessary to create a new task.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the task definition instance from which this new task will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTask(
      CreateTask: CreateTask,
      query?: { definition?: string },
      options: any = {},
    ): RequestArgs {
      const { definition } = query;

      // verify required parameter 'CreateTask' is not null or undefined
      if (CreateTask === null || CreateTask === undefined) {
        throw new RequiredError(
          'CreateTask',
          'Required parameter CreateTask was null or undefined when calling createTask.',
        );
      }
      const localVarPath = `/tasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (definition !== undefined) {
        localVarQueryParameter['definition'] = definition;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateTask' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateTask || {})
        : CreateTask || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this task resource and any resources that are owned by it.
     * @summary Delete this task resource
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTask(taskId: string, headers?: { If_Match?: string }, options: any = {}): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling deleteTask.',
        );
      }
      const localVarPath = `/tasks/{taskId}`.replace(
        `{${'taskId'}}`,
        encodeURIComponent(String(taskId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:fail` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Stop a workflow task and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failTask(query?: { task?: string }, options: any = {}): RequestArgs {
      const { task } = query;

      // verify required parameter 'task' is not null or undefined
      if (task === null || task === undefined) {
        throw new RequiredError(
          'task',
          'Required parameter task was null or undefined when calling failTask.',
        );
      }
      const localVarPath = `/failedTasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (task !== undefined) {
        localVarQueryParameter['task'] = task;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task resource.
     * @summary Fetch a representation of this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTask(taskId: string, headers?: { If_None_Match?: string }, options: any = {}): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling getTask.',
        );
      }
      const localVarPath = `/tasks/{taskId}`.replace(
        `{${'taskId'}}`,
        encodeURIComponent(String(taskId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single runtime value associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the task's `schema`.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Fetch a single runtime value associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValue(taskId: string, valueName: string, options: any = {}): RequestArgs {
      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling getTaskValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getTaskValue.',
        );
      }
      const localVarPath = `/tasks/{taskId}/values/{valueName}`
        .replace(`{${'taskId'}}`, encodeURIComponent(String(taskId)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.   Use the `PUT /tasks/{taskId}/values` operation to update the values, or to update a specific value, use `PUT /tasks/{taskId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValues(taskId: string, options: any = {}): RequestArgs {
      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling getTaskValues.',
        );
      }
      const localVarPath = `/tasks/{taskId}/values`.replace(
        `{${'taskId'}}`,
        encodeURIComponent(String(taskId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of tasks. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of tasks
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTasks(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, name, domain, type, label } = query;

      const localVarPath = `/tasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:pause` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Pause a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseTask(query?: { task?: string }, options: any = {}): RequestArgs {
      const { task } = query;

      // verify required parameter 'task' is not null or undefined
      if (task === null || task === undefined) {
        throw new RequiredError(
          'task',
          'Required parameter task was null or undefined when calling pauseTask.',
        );
      }
      const localVarPath = `/pausedTasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (task !== undefined) {
        localVarQueryParameter['task'] = task;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the task is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:start` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.           This operation is not allowed on a task definition.
     * @summary Start, restart, or resume a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startTask(query?: { task?: string }, options: any = {}): RequestArgs {
      const { task } = query;

      // verify required parameter 'task' is not null or undefined
      if (task === null || task === undefined) {
        throw new RequiredError(
          'task',
          'Required parameter task was null or undefined when calling startTask.',
        );
      }
      const localVarPath = `/runningTasks`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (task !== undefined) {
        localVarQueryParameter['task'] = task;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this task.
     * @summary Update this task
     * @param {UpdateTask} UpdateTask
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTask(
      UpdateTask: UpdateTask,
      taskId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling updateTask.',
        );
      }
      // verify required parameter 'UpdateTask' is not null or undefined
      if (UpdateTask === null || UpdateTask === undefined) {
        throw new RequiredError(
          'UpdateTask',
          'Required parameter UpdateTask was null or undefined when calling updateTask.',
        );
      }
      const localVarPath = `/tasks/{taskId}`.replace(
        `{${'taskId'}}`,
        encodeURIComponent(String(taskId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateTask' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateTask || {})
        : UpdateTask || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single runtime value associated with this task. This provides convenient access to individual `values` of the task as defined in the task's `schema`. The request body must conform to  the task's schema for the named `{valueName}`. This operation is idempotent.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValue(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling updateTaskValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateTaskValue.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateTaskValue.',
        );
      }
      const localVarPath = `/tasks/{taskId}/values/{valueName}`
        .replace(`{${'taskId'}}`, encodeURIComponent(String(taskId)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: AttributeValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs. This map only contains values defined in the task's `schema`.  The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the task's schema. This operation is idempotent.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValues(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'taskId' is not null or undefined
      if (taskId === null || taskId === undefined) {
        throw new RequiredError(
          'taskId',
          'Required parameter taskId was null or undefined when calling updateTaskValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateTaskValues.',
        );
      }
      const localVarPath = `/tasks/{taskId}/values`.replace(
        `{${'taskId'}}`,
        encodeURIComponent(String(taskId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: AttributeValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TaskApi - functional programming interface
 * @export
 */
export const TaskApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:cancel` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Cancel a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelTask(
      query?: { task?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).cancelTask(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new task in the tasks collection.
     * @summary Create a new task
     * @param {CreateTask} CreateTask The data necessary to create a new task.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the task definition instance from which this new task will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTask(
      CreateTask: CreateTask,
      query?: { definition?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).createTask(
        CreateTask ? CreateTask : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this task resource and any resources that are owned by it.
     * @summary Delete this task resource
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTask(
      taskId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).deleteTask(
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:fail` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Stop a workflow task and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failTask(
      query?: { task?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).failTask(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task resource.
     * @summary Fetch a representation of this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTask(
      taskId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).getTask(
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single runtime value associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the task's `schema`.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Fetch a single runtime value associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValue(
      taskId: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).getTaskValue(
        taskId ? taskId : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.   Use the `PUT /tasks/{taskId}/values` operation to update the values, or to update a specific value, use `PUT /tasks/{taskId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValues(
      taskId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).getTaskValues(
        taskId ? taskId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of tasks. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of tasks
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTasks(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Tasks> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).getTasks(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:pause` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Pause a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseTask(
      query?: { task?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).pauseTask(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the task is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:start` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.           This operation is not allowed on a task definition.
     * @summary Start, restart, or resume a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startTask(
      query?: { task?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).startTask(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this task.
     * @summary Update this task
     * @param {UpdateTask} UpdateTask
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTask(
      UpdateTask: UpdateTask,
      taskId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).updateTask(
        UpdateTask ? UpdateTask : null,
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single runtime value associated with this task. This provides convenient access to individual `values` of the task as defined in the task's `schema`. The request body must conform to  the task's schema for the named `{valueName}`. This operation is idempotent.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValue(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).updateTaskValue(
        request_body ? request_body : null,
        taskId ? taskId : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs. This map only contains values defined in the task's `schema`.  The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the task's schema. This operation is idempotent.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValues(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = TaskApiAxiosParamCreator(configuration).updateTaskValues(
        request_body ? request_body : null,
        taskId ? taskId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TaskApi - factory interface
 * @export
 */
export const TaskApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:cancel` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Cancel a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelTask(query?: { task?: string }, options?: any) {
      return TaskApiFp(configuration).cancelTask(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Create a new task in the tasks collection.
     * @summary Create a new task
     * @param {CreateTask} CreateTask The data necessary to create a new task.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the task definition instance from which this new task will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTask(CreateTask: CreateTask, query?: { definition?: string }, options?: any) {
      return TaskApiFp(configuration).createTask(
        CreateTask ? CreateTask : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this task resource and any resources that are owned by it.
     * @summary Delete this task resource
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTask(taskId: string, headers?: { If_Match?: string }, options?: any) {
      return TaskApiFp(configuration).deleteTask(
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:fail` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Stop a workflow task and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failTask(query?: { task?: string }, options?: any) {
      return TaskApiFp(configuration).failTask(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task resource.
     * @summary Fetch a representation of this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTask(taskId: string, headers?: { If_None_Match?: string }, options?: any) {
      return TaskApiFp(configuration).getTask(
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single runtime value associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the task's `schema`.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Fetch a single runtime value associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValue(taskId: string, valueName: string, options?: any) {
      return TaskApiFp(configuration).getTaskValue(
        taskId ? taskId : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.   Use the `PUT /tasks/{taskId}/values` operation to update the values, or to update a specific value, use `PUT /tasks/{taskId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this task
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskValues(taskId: string, options?: any) {
      return TaskApiFp(configuration).getTaskValues(
        taskId ? taskId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of tasks. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of tasks
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTasks(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ) {
      return TaskApiFp(configuration).getTasks(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:pause` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
     * @summary Pause a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseTask(query?: { task?: string }, options?: any) {
      return TaskApiFp(configuration).pauseTask(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the task is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:start` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.           This operation is not allowed on a task definition.
     * @summary Start, restart, or resume a workflow task
     * @param {Object} [query] Query object
     * @param {string} [query.task] A server-supplied value which identifies the task instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startTask(query?: { task?: string }, options?: any) {
      return TaskApiFp(configuration).startTask(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Perform a complete replacement of this task.
     * @summary Update this task
     * @param {UpdateTask} UpdateTask
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTask(
      UpdateTask: UpdateTask,
      taskId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return TaskApiFp(configuration).updateTask(
        UpdateTask ? UpdateTask : null,
        taskId ? taskId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update a single runtime value associated with this task. This provides convenient access to individual `values` of the task as defined in the task's `schema`. The request body must conform to  the task's schema for the named `{valueName}`. This operation is idempotent.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValue(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      valueName: string,
      options?: any,
    ) {
      return TaskApiFp(configuration).updateTaskValue(
        request_body ? request_body : null,
        taskId ? taskId : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs. This map only contains values defined in the task's `schema`.  The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the task's schema. This operation is idempotent.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
     * @summary Update the runtime values associated with this task
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} taskId The unique identifier of this task. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskValues(
      request_body: { [key: string]: AttributeValue },
      taskId: string,
      options?: any,
    ) {
      return TaskApiFp(configuration).updateTaskValues(
        request_body ? request_body : null,
        taskId ? taskId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TaskApi - object-oriented interface
 * @export
 * @class TaskApi
 * @extends {BaseAPI}
 */
export class TaskApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:cancel` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
   * @summary Cancel a workflow task
   * @param {Object} [query] Query object
   * @param {string} [query.task] A server-supplied value which identifies the task instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public cancelTask(query?: { task?: string }, options?: any) {
    return TaskApiFp(this.configuration).cancelTask(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Create a new task in the tasks collection.
   * @summary Create a new task
   * @param {CreateTask} CreateTask The data necessary to create a new task.
   * @param {Object} [query] Query object
   * @param {string} [query.definition] A server-supplied value which identifies the task definition instance from which this new task will be created. The request body is ignored when this parameter is used.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public createTask(CreateTask: CreateTask, query?: { definition?: string }, options?: any) {
    return TaskApiFp(this.configuration).createTask(
      CreateTask ? CreateTask : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this task resource and any resources that are owned by it.
   * @summary Delete this task resource
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof TaskApi
   */
  public deleteTask(taskId: string, headers?: { If_Match?: string }, options?: any) {
    return TaskApiFp(this.configuration).deleteTask(
      taskId ? taskId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:fail` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
   * @summary Stop a workflow task and mark it as failed
   * @param {Object} [query] Query object
   * @param {string} [query.task] A server-supplied value which identifies the task instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public failTask(query?: { task?: string }, options?: any) {
    return TaskApiFp(this.configuration).failTask(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task resource.
   * @summary Fetch a representation of this task
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public getTask(taskId: string, headers?: { If_None_Match?: string }, options?: any) {
    return TaskApiFp(this.configuration).getTask(
      taskId ? taskId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single runtime value associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the task's `schema`.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
   * @summary Fetch a single runtime value associated with this task
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof TaskApi
   */
  public getTaskValue(taskId: string, valueName: string, options?: any) {
    return TaskApiFp(this.configuration).getTaskValue(
      taskId ? taskId : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs.   Use the `PUT /tasks/{taskId}/values` operation to update the values, or to update a specific value, use `PUT /tasks/{taskId}/values/{valueName}`.
   * @summary Fetch the runtime values associated with this task
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof TaskApi
   */
  public getTaskValues(taskId: string, options?: any) {
    return TaskApiFp(this.configuration).getTaskValues(
      taskId ? taskId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of tasks. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of tasks
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first task item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of task representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Tasks}
   * @memberof TaskApi
   */
  public getTasks(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?:
        | 'pending'
        | 'definition'
        | 'blocked'
        | 'removed'
        | 'running'
        | 'paused'
        | 'completed'
        | 'failed'
        | 'canceled';
      name?: string;
      domain?: string;
      type?: string;
      label?: string;
    },
    options?: any,
  ) {
    return TaskApiFp(this.configuration).getTasks(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:pause` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a task definition.
   * @summary Pause a workflow task
   * @param {Object} [query] Query object
   * @param {string} [query.task] A server-supplied value which identifies the task instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public pauseTask(query?: { task?: string }, options?: any) {
    return TaskApiFp(this.configuration).pauseTask(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the task is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?task=`. This operation is invoked from the `apiture:start` link on a task; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.           This operation is not allowed on a task definition.
   * @summary Start, restart, or resume a workflow task
   * @param {Object} [query] Query object
   * @param {string} [query.task] A server-supplied value which identifies the task instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public startTask(query?: { task?: string }, options?: any) {
    return TaskApiFp(this.configuration).startTask(query ? query : {}, options ? options : {})(
      this.axios,
      this.basePath,
    );
  }

  /**
   * Perform a complete replacement of this task.
   * @summary Update this task
   * @param {UpdateTask} UpdateTask
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskApi
   */
  public updateTask(
    UpdateTask: UpdateTask,
    taskId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TaskApiFp(this.configuration).updateTask(
      UpdateTask ? UpdateTask : null,
      taskId ? taskId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single runtime value associated with this task. This provides convenient access to individual `values` of the task as defined in the task's `schema`. The request body must conform to  the task's schema for the named `{valueName}`. This operation is idempotent.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
   * @summary Update the runtime values associated with this task
   * @param {{ [key: string]: AttributeValue; }} request_body
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof TaskApi
   */
  public updateTaskValue(
    request_body: { [key: string]: AttributeValue },
    taskId: string,
    valueName: string,
    options?: any,
  ) {
    return TaskApiFp(this.configuration).updateTaskValue(
      request_body ? request_body : null,
      taskId ? taskId : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update the runtime values associated with this task. This provides convenient access to the map of `values` of the task, including the inputs and outputs. This map only contains values defined in the task's `schema`.  The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the task's schema. This operation is idempotent.   To update a specific value, use `PUT /tasks/{taskId}/values/{valueName}` (operation `updateTaskValue`).
   * @summary Update the runtime values associated with this task
   * @param {{ [key: string]: AttributeValue; }} request_body
   * @param {string} taskId The unique identifier of this task. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof TaskApi
   */
  public updateTaskValues(
    request_body: { [key: string]: AttributeValue },
    taskId: string,
    options?: any,
  ) {
    return TaskApiFp(this.configuration).updateTaskValues(
      request_body ? request_body : null,
      taskId ? taskId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * TaskDefinitionApi - axios parameter creator
 * @export
 */
export const TaskDefinitionApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new task definition in the task definitions collection. The `state` of the new task will be set to `definition`.
     * @summary Create a new task definition
     * @param {CreateTask} CreateTask The data necessary to create a new task definition.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinition(CreateTask: CreateTask, options: any = {}): RequestArgs {
      // verify required parameter 'CreateTask' is not null or undefined
      if (CreateTask === null || CreateTask === undefined) {
        throw new RequiredError(
          'CreateTask',
          'Required parameter CreateTask was null or undefined when calling createTaskDefinition.',
        );
      }
      const localVarPath = `/taskDefinitions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateTask' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateTask || {})
        : CreateTask || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new immutable revision of this workflow task definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. This operation is ignored if the task definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the task definition.
     * @summary Create a new task definition revision
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinitionRevision(
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling createTaskDefinitionRevision.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}/revisions`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this task definition resource and any resources that are owned by it. The task definition may not be deleted if it or any of its revisions are in use by any tasks or workflows. Deleting a task definition also deletes all revisions.
     * @summary Delete this task definition resource
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTaskDefinition(
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling deleteTaskDefinition.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task definition resource. This resource is referred to as the `revisionless` task definition, in contrast to the explicit revision at `/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this task definition
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinition(
      taskDefinitionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling getTaskDefinition.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow task resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow task
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevision(
      taskDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling getTaskDefinitionRevision.',
        );
      }
      // verify required parameter 'revisionId' is not null or undefined
      if (revisionId === null || revisionId === undefined) {
        throw new RequiredError(
          'revisionId',
          'Required parameter revisionId was null or undefined when calling getTaskDefinitionRevision.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}`
        .replace(`{${'taskDefinitionId'}}`, encodeURIComponent(String(taskDefinitionId)))
        .replace(`{${'revisionId'}}`, encodeURIComponent(String(revisionId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow task revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The revisions collection shows the modification history of the workflow task definition. Revisions are immutable.
     * @summary Return a collection of workflow task definition revisions
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow task revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevisions(
      taskDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling getTaskDefinitionRevisions.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}/revisions`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of task definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of task definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, name, domain, type, label } = query;

      const localVarPath = `/taskDefinitions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this task definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling patchTaskDefinition.',
        );
      }
      // verify required parameter 'UpdateTask' is not null or undefined
      if (UpdateTask === null || UpdateTask === undefined) {
        throw new RequiredError(
          'UpdateTask',
          'Required parameter UpdateTask was null or undefined when calling patchTaskDefinition.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateTask' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateTask || {})
        : UpdateTask || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this task definition.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'taskDefinitionId' is not null or undefined
      if (taskDefinitionId === null || taskDefinitionId === undefined) {
        throw new RequiredError(
          'taskDefinitionId',
          'Required parameter taskDefinitionId was null or undefined when calling updateTaskDefinition.',
        );
      }
      // verify required parameter 'UpdateTask' is not null or undefined
      if (UpdateTask === null || UpdateTask === undefined) {
        throw new RequiredError(
          'UpdateTask',
          'Required parameter UpdateTask was null or undefined when calling updateTaskDefinition.',
        );
      }
      const localVarPath = `/taskDefinitions/{taskDefinitionId}`.replace(
        `{${'taskDefinitionId'}}`,
        encodeURIComponent(String(taskDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateTask' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateTask || {})
        : UpdateTask || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * TaskDefinitionApi - functional programming interface
 * @export
 */
export const TaskDefinitionApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new task definition in the task definitions collection. The `state` of the new task will be set to `definition`.
     * @summary Create a new task definition
     * @param {CreateTask} CreateTask The data necessary to create a new task definition.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinition(
      CreateTask: CreateTask,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).createTaskDefinition(
        CreateTask ? CreateTask : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new immutable revision of this workflow task definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. This operation is ignored if the task definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the task definition.
     * @summary Create a new task definition revision
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinitionRevision(
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).createTaskDefinitionRevision(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this task definition resource and any resources that are owned by it. The task definition may not be deleted if it or any of its revisions are in use by any tasks or workflows. Deleting a task definition also deletes all revisions.
     * @summary Delete this task definition resource
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTaskDefinition(
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).deleteTaskDefinition(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task definition resource. This resource is referred to as the `revisionless` task definition, in contrast to the explicit revision at `/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this task definition
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinition(
      taskDefinitionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(configuration).getTaskDefinition(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow task resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow task
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevision(
      taskDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).getTaskDefinitionRevision(
        taskDefinitionId ? taskDefinitionId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow task revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The revisions collection shows the modification history of the workflow task definition. Revisions are immutable.
     * @summary Return a collection of workflow task definition revisions
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow task revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevisions(
      taskDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Tasks> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).getTaskDefinitionRevisions(
        taskDefinitionId ? taskDefinitionId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of task definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of task definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Tasks> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).getTaskDefinitions(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this task definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).patchTaskDefinition(
        UpdateTask ? UpdateTask : null,
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this task definition.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Task> {
      const localVarAxiosArgs = TaskDefinitionApiAxiosParamCreator(
        configuration,
      ).updateTaskDefinition(
        UpdateTask ? UpdateTask : null,
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * TaskDefinitionApi - factory interface
 * @export
 */
export const TaskDefinitionApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new task definition in the task definitions collection. The `state` of the new task will be set to `definition`.
     * @summary Create a new task definition
     * @param {CreateTask} CreateTask The data necessary to create a new task definition.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinition(CreateTask: CreateTask, options?: any) {
      return TaskDefinitionApiFp(configuration).createTaskDefinition(
        CreateTask ? CreateTask : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new immutable revision of this workflow task definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. This operation is ignored if the task definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the task definition.
     * @summary Create a new task definition revision
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createTaskDefinitionRevision(
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).createTaskDefinitionRevision(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this task definition resource and any resources that are owned by it. The task definition may not be deleted if it or any of its revisions are in use by any tasks or workflows. Deleting a task definition also deletes all revisions.
     * @summary Delete this task definition resource
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteTaskDefinition(taskDefinitionId: string, headers?: { If_Match?: string }, options?: any) {
      return TaskDefinitionApiFp(configuration).deleteTaskDefinition(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task definition resource. This resource is referred to as the `revisionless` task definition, in contrast to the explicit revision at `/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this task definition
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinition(
      taskDefinitionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).getTaskDefinition(
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow task resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow task
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevision(
      taskDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).getTaskDefinitionRevision(
        taskDefinitionId ? taskDefinitionId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow task revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The revisions collection shows the modification history of the workflow task definition. Revisions are immutable.
     * @summary Return a collection of workflow task definition revisions
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow task revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow task representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitionRevisions(
      taskDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).getTaskDefinitionRevisions(
        taskDefinitionId ? taskDefinitionId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of task definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of task definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first task definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of task definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getTaskDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).getTaskDefinitions(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this task definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).patchTaskDefinition(
        UpdateTask ? UpdateTask : null,
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this task definition.
     * @summary Update this task definition
     * @param {UpdateTask} UpdateTask
     * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateTaskDefinition(
      UpdateTask: UpdateTask,
      taskDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return TaskDefinitionApiFp(configuration).updateTaskDefinition(
        UpdateTask ? UpdateTask : null,
        taskDefinitionId ? taskDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * TaskDefinitionApi - object-oriented interface
 * @export
 * @class TaskDefinitionApi
 * @extends {BaseAPI}
 */
export class TaskDefinitionApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new task definition in the task definitions collection. The `state` of the new task will be set to `definition`.
   * @summary Create a new task definition
   * @param {CreateTask} CreateTask The data necessary to create a new task definition.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public createTaskDefinition(CreateTask: CreateTask, options?: any) {
    return TaskDefinitionApiFp(this.configuration).createTaskDefinition(
      CreateTask ? CreateTask : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new immutable revision of this workflow task definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. This operation is ignored if the task definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the task definition.
   * @summary Create a new task definition revision
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public createTaskDefinitionRevision(
    taskDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).createTaskDefinitionRevision(
      taskDefinitionId ? taskDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this task definition resource and any resources that are owned by it. The task definition may not be deleted if it or any of its revisions are in use by any tasks or workflows. Deleting a task definition also deletes all revisions.
   * @summary Delete this task definition resource
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof TaskDefinitionApi
   */
  public deleteTaskDefinition(
    taskDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).deleteTaskDefinition(
      taskDefinitionId ? taskDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this task definition resource. This resource is referred to as the `revisionless` task definition, in contrast to the explicit revision at `/taskDefinitions/{taskDefinitionId}/revisions/{revisionId}`.
   * @summary Fetch a representation of this task definition
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public getTaskDefinition(
    taskDefinitionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).getTaskDefinition(
      taskDefinitionId ? taskDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow task resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
   * @summary Fetch a representation of an immutable revision of this workflow task
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public getTaskDefinitionRevision(
    taskDefinitionId: string,
    revisionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).getTaskDefinitionRevision(
      taskDefinitionId ? taskDefinitionId : null,
      revisionId ? revisionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow task revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links. The revisions collection shows the modification history of the workflow task definition. Revisions are immutable.
   * @summary Return a collection of workflow task definition revisions
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first workflow task revision item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of workflow task representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Tasks}
   * @memberof TaskDefinitionApi
   */
  public getTaskDefinitionRevisions(
    taskDefinitionId: string,
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).getTaskDefinitionRevisions(
      taskDefinitionId ? taskDefinitionId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of task definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of task definitions
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first task definition item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of task definition representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Tasks}
   * @memberof TaskDefinitionApi
   */
  public getTaskDefinitions(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?:
        | 'pending'
        | 'definition'
        | 'blocked'
        | 'removed'
        | 'running'
        | 'paused'
        | 'completed'
        | 'failed'
        | 'canceled';
      name?: string;
      domain?: string;
      type?: string;
      label?: string;
    },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).getTaskDefinitions(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this task definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this task definition
   * @param {UpdateTask} UpdateTask
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public patchTaskDefinition(
    UpdateTask: UpdateTask,
    taskDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).patchTaskDefinition(
      UpdateTask ? UpdateTask : null,
      taskDefinitionId ? taskDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this task definition.
   * @summary Update this task definition
   * @param {UpdateTask} UpdateTask
   * @param {string} taskDefinitionId The unique identifier of this task definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Task}
   * @memberof TaskDefinitionApi
   */
  public updateTaskDefinition(
    UpdateTask: UpdateTask,
    taskDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return TaskDefinitionApiFp(this.configuration).updateTaskDefinition(
      UpdateTask ? UpdateTask : null,
      taskDefinitionId ? taskDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * WorkflowApi - axios parameter creator
 * @export
 */
export const WorkflowApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:cancel` link on a workflow; the link is present if the operation is allowed. This operation will also cancel all `running` or `paused` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Cancel a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelWorkflow(query?: { workflow?: string }, options: any = {}): RequestArgs {
      const { workflow } = query;

      // verify required parameter 'workflow' is not null or undefined
      if (workflow === null || workflow === undefined) {
        throw new RequiredError(
          'workflow',
          'Required parameter workflow was null or undefined when calling cancelWorkflow.',
        );
      }
      const localVarPath = `/canceledWorkflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (workflow !== undefined) {
        localVarQueryParameter['workflow'] = workflow;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new workflow instance from a workflow definition.  The workflow is started automatically upon creation; and initial tasks (those with no input dependencies) will be started. Thus, the state of the new workflow may be `running` or `blocked` depending on the initial tasks.
     * @summary Create a new workflow
     * @param {CreateWorkflow} CreateWorkflow The data necessary to create a new workflow.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the workflow definition instance from which this new workflow will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflow(
      CreateWorkflow: CreateWorkflow,
      query?: { definition?: string },
      options: any = {},
    ): RequestArgs {
      const { definition } = query;

      // verify required parameter 'CreateWorkflow' is not null or undefined
      if (CreateWorkflow === null || CreateWorkflow === undefined) {
        throw new RequiredError(
          'CreateWorkflow',
          'Required parameter CreateWorkflow was null or undefined when calling createWorkflow.',
        );
      }
      const localVarPath = `/workflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (definition !== undefined) {
        localVarQueryParameter['definition'] = definition;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateWorkflow' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateWorkflow || {})
        : CreateWorkflow || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this workflow resource and any resources that are owned by it.
     * @summary Delete this workflow resource
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflow(
      workflowId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling deleteWorkflow.',
        );
      }
      const localVarPath = `/workflows/{workflowId}`.replace(
        `{${'workflowId'}}`,
        encodeURIComponent(String(workflowId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:fail` link on a workflow; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a workflow definition.
     * @summary Stop a workflow and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failWorkflow(query?: { workflow?: string }, options: any = {}): RequestArgs {
      const { workflow } = query;

      // verify required parameter 'workflow' is not null or undefined
      if (workflow === null || workflow === undefined) {
        throw new RequiredError(
          'workflow',
          'Required parameter workflow was null or undefined when calling failWorkflow.',
        );
      }
      const localVarPath = `/failedWorkflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (workflow !== undefined) {
        localVarQueryParameter['workflow'] = workflow;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a collection of visible tasks for the given workflow. The result reflects the nested structure of the workflow and any tasks that are embedded inside nested workflows.
     * @summary Fetch an ordered representation of the visible tasks within this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVisibleTasks(
      workflowId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling getVisibleTasks.',
        );
      }
      const localVarPath = `/workflows/{workflowId}/visibleTasks`.replace(
        `{${'workflowId'}}`,
        encodeURIComponent(String(workflowId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow resource.
     * @summary Fetch a representation of this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.embed] The resources to embed within the &#x60;_embedded&#x60; object.  This is a comma separated list which can include any of the following options:   * *&#x60;tasks&#x60;* - A list of summary tasks specific to this workflow     instance.   * *&#x60;nextInteractiveTask&#x60;* - The next visible and running task within     this workflow instance.  &#x60;tasks&#x60; will be embedded by default even if no &#x60;embed&#x60; query parameters are specified.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflow(
      workflowId: string,
      query?: { embed?: string },
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { embed } = query;
      const { If_None_Match } = headers;

      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling getWorkflow.',
        );
      }
      const localVarPath = `/workflows/{workflowId}`.replace(
        `{${'workflowId'}}`,
        encodeURIComponent(String(workflowId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (embed !== undefined) {
        localVarQueryParameter['embed'] = embed;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch a single runtime value associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}` (operation `updateWorkflowValue`).
     * @summary Fetch a single runtime value associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValue(workflowId: string, valueName: string, options: any = {}): RequestArgs {
      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling getWorkflowValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling getWorkflowValue.',
        );
      }
      const localVarPath = `/workflows/{workflowId}/values/{valueName}`
        .replace(`{${'workflowId'}}`, encodeURIComponent(String(workflowId)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Fetch the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   Use the `PUT /workflows/{workflowId}/values` operation to update the values, or to update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValues(workflowId: string, options: any = {}): RequestArgs {
      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling getWorkflowValues.',
        );
      }
      const localVarPath = `/workflows/{workflowId}/values`.replace(
        `{${'workflowId'}}`,
        encodeURIComponent(String(workflowId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflows. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflows
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflows(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, name, domain, type, label } = query;

      const localVarPath = `/workflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:pause` link on a workflow; the link is present if the operation is allowed. This operation will also pause all `running` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Pause a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseWorkflow(query?: { workflow?: string }, options: any = {}): RequestArgs {
      const { workflow } = query;

      // verify required parameter 'workflow' is not null or undefined
      if (workflow === null || workflow === undefined) {
        throw new RequiredError(
          'workflow',
          'Required parameter workflow was null or undefined when calling pauseWorkflow.',
        );
      }
      const localVarPath = `/pausedWorkflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (workflow !== undefined) {
        localVarQueryParameter['workflow'] = workflow;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the workflow is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:start` link on a workflow; the link is present if the operation is allowed. This operation is not allowed on a workflow definition.
     * @summary Start, restart, or resume a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startWorkflow(query?: { workflow?: string }, options: any = {}): RequestArgs {
      const { workflow } = query;

      // verify required parameter 'workflow' is not null or undefined
      if (workflow === null || workflow === undefined) {
        throw new RequiredError(
          'workflow',
          'Required parameter workflow was null or undefined when calling startWorkflow.',
        );
      }
      const localVarPath = `/runningWorkflows`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (workflow !== undefined) {
        localVarQueryParameter['workflow'] = workflow;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update a single runtime value associated with this workflow. This provides convenient access to individual `values` of the workflow as defined in the workflow's `schema`. The request body must conform to the workflow's schema for the named `{valueName}`. This operation is idempotent.
     * @summary Update a single runtime value associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValue(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      valueName: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling updateWorkflowValue.',
        );
      }
      // verify required parameter 'valueName' is not null or undefined
      if (valueName === null || valueName === undefined) {
        throw new RequiredError(
          'valueName',
          'Required parameter valueName was null or undefined when calling updateWorkflowValue.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateWorkflowValue.',
        );
      }
      const localVarPath = `/workflows/{workflowId}/values/{valueName}`
        .replace(`{${'workflowId'}}`, encodeURIComponent(String(workflowId)))
        .replace(`{${'valueName'}}`, encodeURIComponent(String(valueName)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: AttributeValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Update the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`. This operation is idempotent. The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the workflow's schema.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValues(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      options: any = {},
    ): RequestArgs {
      // verify required parameter 'workflowId' is not null or undefined
      if (workflowId === null || workflowId === undefined) {
        throw new RequiredError(
          'workflowId',
          'Required parameter workflowId was null or undefined when calling updateWorkflowValues.',
        );
      }
      // verify required parameter 'request_body' is not null or undefined
      if (request_body === null || request_body === undefined) {
        throw new RequiredError(
          'request_body',
          'Required parameter request_body was null or undefined when calling updateWorkflowValues.',
        );
      }
      const localVarPath = `/workflows/{workflowId}/values`.replace(
        `{${'workflowId'}}`,
        encodeURIComponent(String(workflowId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'{ [key: string]: AttributeValue; }' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(request_body || {})
        : request_body || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * WorkflowApi - functional programming interface
 * @export
 */
export const WorkflowApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:cancel` link on a workflow; the link is present if the operation is allowed. This operation will also cancel all `running` or `paused` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Cancel a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelWorkflow(
      query?: { workflow?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).cancelWorkflow(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new workflow instance from a workflow definition.  The workflow is started automatically upon creation; and initial tasks (those with no input dependencies) will be started. Thus, the state of the new workflow may be `running` or `blocked` depending on the initial tasks.
     * @summary Create a new workflow
     * @param {CreateWorkflow} CreateWorkflow The data necessary to create a new workflow.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the workflow definition instance from which this new workflow will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflow(
      CreateWorkflow: CreateWorkflow,
      query?: { definition?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).createWorkflow(
        CreateWorkflow ? CreateWorkflow : null,

        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this workflow resource and any resources that are owned by it.
     * @summary Delete this workflow resource
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflow(
      workflowId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).deleteWorkflow(
        workflowId ? workflowId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:fail` link on a workflow; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a workflow definition.
     * @summary Stop a workflow and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failWorkflow(
      query?: { workflow?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).failWorkflow(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a collection of visible tasks for the given workflow. The result reflects the nested structure of the workflow and any tasks that are embedded inside nested workflows.
     * @summary Fetch an ordered representation of the visible tasks within this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVisibleTasks(
      workflowId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<VisibleTasks> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).getVisibleTasks(
        workflowId ? workflowId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow resource.
     * @summary Fetch a representation of this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.embed] The resources to embed within the &#x60;_embedded&#x60; object.  This is a comma separated list which can include any of the following options:   * *&#x60;tasks&#x60;* - A list of summary tasks specific to this workflow     instance.   * *&#x60;nextInteractiveTask&#x60;* - The next visible and running task within     this workflow instance.  &#x60;tasks&#x60; will be embedded by default even if no &#x60;embed&#x60; query parameters are specified.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflow(
      workflowId: string,
      query?: { embed?: string },
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).getWorkflow(
        workflowId ? workflowId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch a single runtime value associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}` (operation `updateWorkflowValue`).
     * @summary Fetch a single runtime value associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValue(
      workflowId: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).getWorkflowValue(
        workflowId ? workflowId : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Fetch the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   Use the `PUT /workflows/{workflowId}/values` operation to update the values, or to update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValues(
      workflowId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<any> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).getWorkflowValues(
        workflowId ? workflowId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflows. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflows
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflows(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflows> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).getWorkflows(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:pause` link on a workflow; the link is present if the operation is allowed. This operation will also pause all `running` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Pause a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseWorkflow(
      query?: { workflow?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).pauseWorkflow(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the workflow is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:start` link on a workflow; the link is present if the operation is allowed. This operation is not allowed on a workflow definition.
     * @summary Start, restart, or resume a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startWorkflow(
      query?: { workflow?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).startWorkflow(
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update a single runtime value associated with this workflow. This provides convenient access to individual `values` of the workflow as defined in the workflow's `schema`. The request body must conform to the workflow's schema for the named `{valueName}`. This operation is idempotent.
     * @summary Update a single runtime value associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValue(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      valueName: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).updateWorkflowValue(
        request_body ? request_body : null,
        workflowId ? workflowId : null,
        valueName ? valueName : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Update the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`. This operation is idempotent. The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the workflow's schema.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValues(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200> {
      const localVarAxiosArgs = WorkflowApiAxiosParamCreator(configuration).updateWorkflowValues(
        request_body ? request_body : null,
        workflowId ? workflowId : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * WorkflowApi - factory interface
 * @export
 */
export const WorkflowApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:cancel` link on a workflow; the link is present if the operation is allowed. This operation will also cancel all `running` or `paused` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Cancel a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    cancelWorkflow(query?: { workflow?: string }, options?: any) {
      return WorkflowApiFp(configuration).cancelWorkflow(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new workflow instance from a workflow definition.  The workflow is started automatically upon creation; and initial tasks (those with no input dependencies) will be started. Thus, the state of the new workflow may be `running` or `blocked` depending on the initial tasks.
     * @summary Create a new workflow
     * @param {CreateWorkflow} CreateWorkflow The data necessary to create a new workflow.
     * @param {Object} [query] Query object
     * @param {string} [query.definition] A server-supplied value which identifies the workflow definition instance from which this new workflow will be created. The request body is ignored when this parameter is used.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflow(CreateWorkflow: CreateWorkflow, query?: { definition?: string }, options?: any) {
      return WorkflowApiFp(configuration).createWorkflow(
        CreateWorkflow ? CreateWorkflow : null,

        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this workflow resource and any resources that are owned by it.
     * @summary Delete this workflow resource
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflow(workflowId: string, headers?: { If_Match?: string }, options?: any) {
      return WorkflowApiFp(configuration).deleteWorkflow(
        workflowId ? workflowId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:fail` link on a workflow; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a workflow definition.
     * @summary Stop a workflow and mark it as failed
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    failWorkflow(query?: { workflow?: string }, options?: any) {
      return WorkflowApiFp(configuration).failWorkflow(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Return a collection of visible tasks for the given workflow. The result reflects the nested structure of the workflow and any tasks that are embedded inside nested workflows.
     * @summary Fetch an ordered representation of the visible tasks within this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getVisibleTasks(workflowId: string, headers?: { If_None_Match?: string }, options?: any) {
      return WorkflowApiFp(configuration).getVisibleTasks(
        workflowId ? workflowId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow resource.
     * @summary Fetch a representation of this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {string} [query.embed] The resources to embed within the &#x60;_embedded&#x60; object.  This is a comma separated list which can include any of the following options:   * *&#x60;tasks&#x60;* - A list of summary tasks specific to this workflow     instance.   * *&#x60;nextInteractiveTask&#x60;* - The next visible and running task within     this workflow instance.  &#x60;tasks&#x60; will be embedded by default even if no &#x60;embed&#x60; query parameters are specified.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflow(
      workflowId: string,
      query?: { embed?: string },
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return WorkflowApiFp(configuration).getWorkflow(
        workflowId ? workflowId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch a single runtime value associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}` (operation `updateWorkflowValue`).
     * @summary Fetch a single runtime value associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValue(workflowId: string, valueName: string, options?: any) {
      return WorkflowApiFp(configuration).getWorkflowValue(
        workflowId ? workflowId : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Fetch the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   Use the `PUT /workflows/{workflowId}/values` operation to update the values, or to update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Fetch the runtime values associated with this workflow
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowValues(workflowId: string, options?: any) {
      return WorkflowApiFp(configuration).getWorkflowValues(
        workflowId ? workflowId : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflows. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflows
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflows(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ) {
      return WorkflowApiFp(configuration).getWorkflows(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:pause` link on a workflow; the link is present if the operation is allowed. This operation will also pause all `running` tasks in the workflow. This operation is not allowed on a workflow definition.
     * @summary Pause a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    pauseWorkflow(query?: { workflow?: string }, options?: any) {
      return WorkflowApiFp(configuration).pauseWorkflow(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the workflow is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:start` link on a workflow; the link is present if the operation is allowed. This operation is not allowed on a workflow definition.
     * @summary Start, restart, or resume a workflow
     * @param {Object} [query] Query object
     * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    startWorkflow(query?: { workflow?: string }, options?: any) {
      return WorkflowApiFp(configuration).startWorkflow(query ? query : {}, options ? options : {})(
        axios,
        basePath,
      );
    },
    /**
     * Update a single runtime value associated with this workflow. This provides convenient access to individual `values` of the workflow as defined in the workflow's `schema`. The request body must conform to the workflow's schema for the named `{valueName}`. This operation is idempotent.
     * @summary Update a single runtime value associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValue(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      valueName: string,
      options?: any,
    ) {
      return WorkflowApiFp(configuration).updateWorkflowValue(
        request_body ? request_body : null,
        workflowId ? workflowId : null,
        valueName ? valueName : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Update the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`. This operation is idempotent. The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the workflow's schema.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
     * @summary Update the runtime values associated with this workflow
     * @param {{ [key: string]: AttributeValue; }} request_body
     * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowValues(
      request_body: { [key: string]: AttributeValue },
      workflowId: string,
      options?: any,
    ) {
      return WorkflowApiFp(configuration).updateWorkflowValues(
        request_body ? request_body : null,
        workflowId ? workflowId : null,

        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * WorkflowApi - object-oriented interface
 * @export
 * @class WorkflowApi
 * @extends {BaseAPI}
 */
export class WorkflowApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Change the `state` of a workflow to `canceled`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:cancel` link on a workflow; the link is present if the operation is allowed. This operation will also cancel all `running` or `paused` tasks in the workflow. This operation is not allowed on a workflow definition.
   * @summary Cancel a workflow
   * @param {Object} [query] Query object
   * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public cancelWorkflow(query?: { workflow?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).cancelWorkflow(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new workflow instance from a workflow definition.  The workflow is started automatically upon creation; and initial tasks (those with no input dependencies) will be started. Thus, the state of the new workflow may be `running` or `blocked` depending on the initial tasks.
   * @summary Create a new workflow
   * @param {CreateWorkflow} CreateWorkflow The data necessary to create a new workflow.
   * @param {Object} [query] Query object
   * @param {string} [query.definition] A server-supplied value which identifies the workflow definition instance from which this new workflow will be created. The request body is ignored when this parameter is used.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public createWorkflow(
    CreateWorkflow: CreateWorkflow,
    query?: { definition?: string },
    options?: any,
  ) {
    return WorkflowApiFp(this.configuration).createWorkflow(
      CreateWorkflow ? CreateWorkflow : null,

      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this workflow resource and any resources that are owned by it.
   * @summary Delete this workflow resource
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof WorkflowApi
   */
  public deleteWorkflow(workflowId: string, headers?: { If_Match?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).deleteWorkflow(
      workflowId ? workflowId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Change the `state` of a workflow to `failed`. This is allowed if the state is `running` or `paused`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:fail` link on a workflow; the link is present if the operation is allowed. This operation may also affect the state of the workflow in which the task instance resides.  This operation is not allowed on a workflow definition.
   * @summary Stop a workflow and mark it as failed
   * @param {Object} [query] Query object
   * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public failWorkflow(query?: { workflow?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).failWorkflow(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a collection of visible tasks for the given workflow. The result reflects the nested structure of the workflow and any tasks that are embedded inside nested workflows.
   * @summary Fetch an ordered representation of the visible tasks within this workflow
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {VisibleTasks}
   * @memberof WorkflowApi
   */
  public getVisibleTasks(workflowId: string, headers?: { If_None_Match?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).getVisibleTasks(
      workflowId ? workflowId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow resource.
   * @summary Fetch a representation of this workflow
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {string} [query.embed] The resources to embed within the &#x60;_embedded&#x60; object.  This is a comma separated list which can include any of the following options:   * *&#x60;tasks&#x60;* - A list of summary tasks specific to this workflow     instance.   * *&#x60;nextInteractiveTask&#x60;* - The next visible and running task within     this workflow instance.  &#x60;tasks&#x60; will be embedded by default even if no &#x60;embed&#x60; query parameters are specified.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public getWorkflow(
    workflowId: string,
    query?: { embed?: string },
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return WorkflowApiFp(this.configuration).getWorkflow(
      workflowId ? workflowId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch a single runtime value associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs.  This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}` (operation `updateWorkflowValue`).
   * @summary Fetch a single runtime value associated with this workflow
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof WorkflowApi
   */
  public getWorkflowValue(workflowId: string, valueName: string, options?: any) {
    return WorkflowApiFp(this.configuration).getWorkflowValue(
      workflowId ? workflowId : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Fetch the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`.   Use the `PUT /workflows/{workflowId}/values` operation to update the values, or to update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
   * @summary Fetch the runtime values associated with this workflow
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {any}
   * @memberof WorkflowApi
   */
  public getWorkflowValues(workflowId: string, options?: any) {
    return WorkflowApiFp(this.configuration).getWorkflowValues(
      workflowId ? workflowId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflows. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of workflows
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first workflow item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of workflow representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflows}
   * @memberof WorkflowApi
   */
  public getWorkflows(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?:
        | 'pending'
        | 'definition'
        | 'blocked'
        | 'removed'
        | 'running'
        | 'paused'
        | 'completed'
        | 'failed'
        | 'canceled';
      name?: string;
      domain?: string;
      type?: string;
      label?: string;
    },
    options?: any,
  ) {
    return WorkflowApiFp(this.configuration).getWorkflows(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Change the `state` of a workflow to `paused`. This is allowed if the state is `running`.  There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:pause` link on a workflow; the link is present if the operation is allowed. This operation will also pause all `running` tasks in the workflow. This operation is not allowed on a workflow definition.
   * @summary Pause a workflow
   * @param {Object} [query] Query object
   * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public pauseWorkflow(query?: { workflow?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).pauseWorkflow(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Change the `state` of a workflow to `running`. This is allowed if the state is `paused`. If the workflow is restartable, this is also allowed if the state is `failed`, `completed`, or `canceled`. There is no request body on this operation; the task is passed as a query parameter, `?workflow=`. This operation is invoked from the `apiture:start` link on a workflow; the link is present if the operation is allowed. This operation is not allowed on a workflow definition.
   * @summary Start, restart, or resume a workflow
   * @param {Object} [query] Query object
   * @param {string} [query.workflow] A server-supplied value which identifies the workflow instance.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowApi
   */
  public startWorkflow(query?: { workflow?: string }, options?: any) {
    return WorkflowApiFp(this.configuration).startWorkflow(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update a single runtime value associated with this workflow. This provides convenient access to individual `values` of the workflow as defined in the workflow's `schema`. The request body must conform to the workflow's schema for the named `{valueName}`. This operation is idempotent.
   * @summary Update a single runtime value associated with this workflow
   * @param {{ [key: string]: AttributeValue; }} request_body
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {string} valueName The unique identifier of a value in a workflow item. This is the name of the value in the &#x60;schema&#x60;. A &#x60;{valueName}&#x60; must be a simple identifier following the pattern _&#x60;letter [letter | digit | &#39;-&#39; | &#39;_&#39;]*&#x60;_
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof WorkflowApi
   */
  public updateWorkflowValue(
    request_body: { [key: string]: AttributeValue },
    workflowId: string,
    valueName: string,
    options?: any,
  ) {
    return WorkflowApiFp(this.configuration).updateWorkflowValue(
      request_body ? request_body : null,
      workflowId ? workflowId : null,
      valueName ? valueName : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Update the runtime values associated with this workflow. This provides convenient access to the map of `values` of the workflow, including the inputs and outputs. This map does **not** include the tasks and their values, or values from nested workflows; it only contains values defined in the workflow's `schema`. This operation is idempotent. The request body must include _all_ values obtained from the `GET` operation, and the values must conform to the workflow's schema.   To update a specific value, use `PUT /workflows/{workflowId}/values/{valueName}`.
   * @summary Update the runtime values associated with this workflow
   * @param {{ [key: string]: AttributeValue; }} request_body
   * @param {string} workflowId The unique identifier of this workflow. This is an opaque string.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {InlineResponse200}
   * @memberof WorkflowApi
   */
  public updateWorkflowValues(
    request_body: { [key: string]: AttributeValue },
    workflowId: string,
    options?: any,
  ) {
    return WorkflowApiFp(this.configuration).updateWorkflowValues(
      request_body ? request_body : null,
      workflowId ? workflowId : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }
}

/**
 * WorkflowDefinitionApi - axios parameter creator
 * @export
 */
export const WorkflowDefinitionApiAxiosParamCreator = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new workflow definition in the workflow definitions collection.
     * @summary Create a new workflow definition
     * @param {CreateWorkflow} CreateWorkflow A workflow definition. The &#x60;state&#x60; must be &#x60;definition&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinition(CreateWorkflow: CreateWorkflow, options: any = {}): RequestArgs {
      // verify required parameter 'CreateWorkflow' is not null or undefined
      if (CreateWorkflow === null || CreateWorkflow === undefined) {
        throw new RequiredError(
          'CreateWorkflow',
          'Required parameter CreateWorkflow was null or undefined when calling createWorkflowDefinition.',
        );
      }
      const localVarPath = `/workflowDefinitions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'CreateWorkflow' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(CreateWorkflow || {})
        : CreateWorkflow || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Create a new immutable revision of this workflow definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. It is recommended to update the workflow definition's `revisionLabel` _before_ calling this operation. This operation is ignored (it returns 204 No Content) if the workflow definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the workflow definition.
     * @summary Create a new workflow definition revision
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {'none' | 'taskRevisions'} [query.revisionPolicy] The &#x60;revisionPolicy&#x60; property determines how task definitions reference by this workflow definition are processed when creating a workflow definition revision. If &#x60;revisionPolicy&#x60; is &#x60;none&#x60;, then the task definitions referenced by this workflow definition are copied directly to the new workflow definition revision. With this policy, when instantiating a new workflow _&#x60;W&#x60;_ from the new workflow definitions revision, _&#x60;W&#x60;_ will use the _revisionless_ task definitions, unless the workflow definition already specifies an explicit task definition revisionless.  If &#x60;revisionPolicy&#x60; is &#x60;taskRevisions&#x60; (the default), then the new revision will explicitly link to (and optionally create) the latest _revisions_ of any task definitions embedded within  this workflow definition, even if the workflow definition refers to revisionless task definitions.  This effectively \&quot;snapshots\&quot; both the workflow definition and the task definitions in one operation. For example, if the workflow embeds task definitions &#x60;A&#x60; and &#x60;B&#x60; and &#x60;C&#x60; such that:    * A is already a reference to a specific revision &#x60;2018-10-10T10:10:10.10Z&#x60;   * B refers to a revisionless task definition _and_ &#x60;B&#x60; has _not_ been modified since the last revision &#x60;2018-10-20T20:20:20.000Z&#x60; was created;   * &#x60;C&#x60; refers to a revisionless task definition but &#x60;C&#x60; _has_ been modified since its last revision was created;  then creating new workflow definition revision with &#x60;?taskRevisions&#x3D;true&#x60; will first create a task definition revision for &#x60;C&#x60; (&#x60;2018-10-30T13:30:30.300Z&#x60;) and the new workflow definition revision will embed the existing revision &#x60;2018-10-10T10:10:10.10Z&#x60; of &#x60;A&#x60;, the existing revision &#x60;2018-10-20T20:20:20.000Z&#x60; of &#x60;B&#x60;, and the new revision &#x60;2018-10-30T13:30:30.300Z&#x60; of &#x60;C&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      query?: { revisionPolicy?: 'none' | 'taskRevisions' },
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { revisionPolicy } = query;
      const { If_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling createWorkflowDefinitionRevision.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}/revisions`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'POST' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (revisionPolicy !== undefined) {
        localVarQueryParameter['revisionPolicy'] = revisionPolicy;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Delete this workflow definition resource. The workflow definition may not be deleted if it or any of its revisions are in use by any tasks. Deleting a workflow definition also deletes all of its revisions.
     * @summary Delete this workflow definition resource
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling deleteWorkflowDefinition.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'DELETE' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow definition resource. This resource is referred to as the `revisionless` workflow definition, in contrast to the explicit revision at `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling getWorkflowDefinition.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow definition resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_None_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling getWorkflowDefinitionRevision.',
        );
      }
      // verify required parameter 'revisionId' is not null or undefined
      if (revisionId === null || revisionId === undefined) {
        throw new RequiredError(
          'revisionId',
          'Required parameter revisionId was null or undefined when calling getWorkflowDefinitionRevision.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`
        .replace(`{${'workflowDefinitionId'}}`, encodeURIComponent(String(workflowDefinitionId)))
        .replace(`{${'revisionId'}}`, encodeURIComponent(String(revisionId)));
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_None_Match !== undefined && If_None_Match !== null) {
        localVarHeaderParameter['If-None-Match'] = String(If_None_Match);
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definition revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definition revisions
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevisions(
      workflowDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q } = query;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling getWorkflowDefinitionRevisions.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}/revisions`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options: any = {},
    ): RequestArgs {
      const { start, limit, sortBy, filter, q, state, name, domain, type, label } = query;

      const localVarPath = `/workflowDefinitions`;
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'GET' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (start !== undefined) {
        localVarQueryParameter['start'] = start;
      }

      if (limit !== undefined) {
        localVarQueryParameter['limit'] = limit;
      }

      if (sortBy !== undefined) {
        localVarQueryParameter['sortBy'] = sortBy;
      }

      if (filter !== undefined) {
        localVarQueryParameter['filter'] = filter;
      }

      if (q !== undefined) {
        localVarQueryParameter['q'] = q;
      }

      if (state !== undefined) {
        localVarQueryParameter['state'] = state;
      }

      if (name !== undefined) {
        localVarQueryParameter['name'] = name;
      }

      if (domain !== undefined) {
        localVarQueryParameter['domain'] = domain;
      }

      if (type !== undefined) {
        localVarQueryParameter['type'] = type;
      }

      if (label !== undefined) {
        localVarQueryParameter['label'] = label;
      }

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a partial update of this workflow definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling patchWorkflowDefinition.',
        );
      }
      // verify required parameter 'UpdateWorkflow' is not null or undefined
      if (UpdateWorkflow === null || UpdateWorkflow === undefined) {
        throw new RequiredError(
          'UpdateWorkflow',
          'Required parameter UpdateWorkflow was null or undefined when calling patchWorkflowDefinition.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PATCH' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateWorkflow' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateWorkflow || {})
        : UpdateWorkflow || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
    /**
     * Perform a complete replacement of this workflow definition.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options: any = {},
    ): RequestArgs {
      const { If_Match } = headers;

      // verify required parameter 'workflowDefinitionId' is not null or undefined
      if (workflowDefinitionId === null || workflowDefinitionId === undefined) {
        throw new RequiredError(
          'workflowDefinitionId',
          'Required parameter workflowDefinitionId was null or undefined when calling updateWorkflowDefinition.',
        );
      }
      // verify required parameter 'UpdateWorkflow' is not null or undefined
      if (UpdateWorkflow === null || UpdateWorkflow === undefined) {
        throw new RequiredError(
          'UpdateWorkflow',
          'Required parameter UpdateWorkflow was null or undefined when calling updateWorkflowDefinition.',
        );
      }
      const localVarPath = `/workflowDefinitions/{workflowDefinitionId}`.replace(
        `{${'workflowDefinitionId'}}`,
        encodeURIComponent(String(workflowDefinitionId)),
      );
      const localVarUrlObj = Url.parse(localVarPath, true);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = Object.assign({ method: 'PUT' }, baseOptions, options);
      const localVarHeaderParameter = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      const localVarQueryParameter = {} as any;

      // authentication accessToken required
      // oauth required
      if (configuration && configuration.accessToken) {
        const localVarAccessTokenValue =
          typeof configuration.accessToken === 'function'
            ? configuration.accessToken('accessToken', [
                'data/read',
                'data/write',
                'data/delete',
                'data/full',
              ])
            : configuration.accessToken;
        localVarHeaderParameter['Authorization'] = 'Bearer ' + localVarAccessTokenValue;
      }

      // authentication apiKey required
      if (configuration && configuration.apiKey) {
        const localVarApiKeyValue =
          typeof configuration.apiKey === 'function'
            ? configuration.apiKey('API-Key')
            : configuration.apiKey;
        localVarHeaderParameter['API-Key'] = localVarApiKeyValue;
      }

      if (If_Match !== undefined && If_Match !== null) {
        localVarHeaderParameter['If-Match'] = String(If_Match);
      }

      localVarHeaderParameter['Content-Type'] = 'application/hal+json';

      localVarUrlObj.query = Object.assign(
        {},
        localVarUrlObj.query,
        localVarQueryParameter,
        options.query,
      );
      // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
      delete localVarUrlObj.search;
      localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);
      const needsSerialization =
        <any>'UpdateWorkflow' !== 'string' ||
        localVarRequestOptions.headers['Content-Type'] === 'application/json';
      localVarRequestOptions.data = needsSerialization
        ? JSON.stringify(UpdateWorkflow || {})
        : UpdateWorkflow || '';

      return {
        url: Url.format(localVarUrlObj),
        options: localVarRequestOptions,
      };
    },
  };
};

/**
 * WorkflowDefinitionApi - functional programming interface
 * @export
 */
export const WorkflowDefinitionApiFp = function(configuration?: SdkConfiguration) {
  return {
    /**
     * Create a new workflow definition in the workflow definitions collection.
     * @summary Create a new workflow definition
     * @param {CreateWorkflow} CreateWorkflow A workflow definition. The &#x60;state&#x60; must be &#x60;definition&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinition(
      CreateWorkflow: CreateWorkflow,
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).createWorkflowDefinition(
        CreateWorkflow ? CreateWorkflow : null,

        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Create a new immutable revision of this workflow definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. It is recommended to update the workflow definition's `revisionLabel` _before_ calling this operation. This operation is ignored (it returns 204 No Content) if the workflow definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the workflow definition.
     * @summary Create a new workflow definition revision
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {'none' | 'taskRevisions'} [query.revisionPolicy] The &#x60;revisionPolicy&#x60; property determines how task definitions reference by this workflow definition are processed when creating a workflow definition revision. If &#x60;revisionPolicy&#x60; is &#x60;none&#x60;, then the task definitions referenced by this workflow definition are copied directly to the new workflow definition revision. With this policy, when instantiating a new workflow _&#x60;W&#x60;_ from the new workflow definitions revision, _&#x60;W&#x60;_ will use the _revisionless_ task definitions, unless the workflow definition already specifies an explicit task definition revisionless.  If &#x60;revisionPolicy&#x60; is &#x60;taskRevisions&#x60; (the default), then the new revision will explicitly link to (and optionally create) the latest _revisions_ of any task definitions embedded within  this workflow definition, even if the workflow definition refers to revisionless task definitions.  This effectively \&quot;snapshots\&quot; both the workflow definition and the task definitions in one operation. For example, if the workflow embeds task definitions &#x60;A&#x60; and &#x60;B&#x60; and &#x60;C&#x60; such that:    * A is already a reference to a specific revision &#x60;2018-10-10T10:10:10.10Z&#x60;   * B refers to a revisionless task definition _and_ &#x60;B&#x60; has _not_ been modified since the last revision &#x60;2018-10-20T20:20:20.000Z&#x60; was created;   * &#x60;C&#x60; refers to a revisionless task definition but &#x60;C&#x60; _has_ been modified since its last revision was created;  then creating new workflow definition revision with &#x60;?taskRevisions&#x3D;true&#x60; will first create a task definition revision for &#x60;C&#x60; (&#x60;2018-10-30T13:30:30.300Z&#x60;) and the new workflow definition revision will embed the existing revision &#x60;2018-10-10T10:10:10.10Z&#x60; of &#x60;A&#x60;, the existing revision &#x60;2018-10-20T20:20:20.000Z&#x60; of &#x60;B&#x60;, and the new revision &#x60;2018-10-30T13:30:30.300Z&#x60; of &#x60;C&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      query?: { revisionPolicy?: 'none' | 'taskRevisions' },
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).createWorkflowDefinitionRevision(
        workflowDefinitionId ? workflowDefinitionId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Delete this workflow definition resource. The workflow definition may not be deleted if it or any of its revisions are in use by any tasks. Deleting a workflow definition also deletes all of its revisions.
     * @summary Delete this workflow definition resource
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Response> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).deleteWorkflowDefinition(
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow definition resource. This resource is referred to as the `revisionless` workflow definition, in contrast to the explicit revision at `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).getWorkflowDefinition(
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow definition resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).getWorkflowDefinitionRevision(
        workflowDefinitionId ? workflowDefinitionId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definition revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definition revisions
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevisions(
      workflowDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflows> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).getWorkflowDefinitionRevisions(
        workflowDefinitionId ? workflowDefinitionId : null,
        query ? query : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflows> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).getWorkflowDefinitions(query ? query : {}, options ? options : {});
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a partial update of this workflow definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).patchWorkflowDefinition(
        UpdateWorkflow ? UpdateWorkflow : null,
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
    /**
     * Perform a complete replacement of this workflow definition.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ): (axios?: AxiosInstance, basePath?: string) => AxiosPromise<Workflow> {
      const localVarAxiosArgs = WorkflowDefinitionApiAxiosParamCreator(
        configuration,
      ).updateWorkflowDefinition(
        UpdateWorkflow ? UpdateWorkflow : null,
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      );
      return (axios: AxiosInstance = globalAxios, basePath: string = BASE_PATH) => {
        const axiosRequestArgs = Object.assign(localVarAxiosArgs.options, {
          url: basePath + localVarAxiosArgs.url,
        });
        return axios.request(axiosRequestArgs);
      };
    },
  };
};

/**
 * WorkflowDefinitionApi - factory interface
 * @export
 */
export const WorkflowDefinitionApiFactory = function(
  configuration?: SdkConfiguration,
  basePath?: string,
  axios?: AxiosInstance,
) {
  return {
    /**
     * Create a new workflow definition in the workflow definitions collection.
     * @summary Create a new workflow definition
     * @param {CreateWorkflow} CreateWorkflow A workflow definition. The &#x60;state&#x60; must be &#x60;definition&#x60;.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinition(CreateWorkflow: CreateWorkflow, options?: any) {
      return WorkflowDefinitionApiFp(configuration).createWorkflowDefinition(
        CreateWorkflow ? CreateWorkflow : null,

        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Create a new immutable revision of this workflow definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. It is recommended to update the workflow definition's `revisionLabel` _before_ calling this operation. This operation is ignored (it returns 204 No Content) if the workflow definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the workflow definition.
     * @summary Create a new workflow definition revision
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {'none' | 'taskRevisions'} [query.revisionPolicy] The &#x60;revisionPolicy&#x60; property determines how task definitions reference by this workflow definition are processed when creating a workflow definition revision. If &#x60;revisionPolicy&#x60; is &#x60;none&#x60;, then the task definitions referenced by this workflow definition are copied directly to the new workflow definition revision. With this policy, when instantiating a new workflow _&#x60;W&#x60;_ from the new workflow definitions revision, _&#x60;W&#x60;_ will use the _revisionless_ task definitions, unless the workflow definition already specifies an explicit task definition revisionless.  If &#x60;revisionPolicy&#x60; is &#x60;taskRevisions&#x60; (the default), then the new revision will explicitly link to (and optionally create) the latest _revisions_ of any task definitions embedded within  this workflow definition, even if the workflow definition refers to revisionless task definitions.  This effectively \&quot;snapshots\&quot; both the workflow definition and the task definitions in one operation. For example, if the workflow embeds task definitions &#x60;A&#x60; and &#x60;B&#x60; and &#x60;C&#x60; such that:    * A is already a reference to a specific revision &#x60;2018-10-10T10:10:10.10Z&#x60;   * B refers to a revisionless task definition _and_ &#x60;B&#x60; has _not_ been modified since the last revision &#x60;2018-10-20T20:20:20.000Z&#x60; was created;   * &#x60;C&#x60; refers to a revisionless task definition but &#x60;C&#x60; _has_ been modified since its last revision was created;  then creating new workflow definition revision with &#x60;?taskRevisions&#x3D;true&#x60; will first create a task definition revision for &#x60;C&#x60; (&#x60;2018-10-30T13:30:30.300Z&#x60;) and the new workflow definition revision will embed the existing revision &#x60;2018-10-10T10:10:10.10Z&#x60; of &#x60;A&#x60;, the existing revision &#x60;2018-10-20T20:20:20.000Z&#x60; of &#x60;B&#x60;, and the new revision &#x60;2018-10-30T13:30:30.300Z&#x60; of &#x60;C&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    createWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      query?: { revisionPolicy?: 'none' | 'taskRevisions' },
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).createWorkflowDefinitionRevision(
        workflowDefinitionId ? workflowDefinitionId : null,
        query ? query : {},
        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Delete this workflow definition resource. The workflow definition may not be deleted if it or any of its revisions are in use by any tasks. Deleting a workflow definition also deletes all of its revisions.
     * @summary Delete this workflow definition resource
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    deleteWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).deleteWorkflowDefinition(
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow definition resource. This resource is referred to as the `revisionless` workflow definition, in contrast to the explicit revision at `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`.
     * @summary Fetch a representation of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinition(
      workflowDefinitionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).getWorkflowDefinition(
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow definition resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
     * @summary Fetch a representation of an immutable revision of this workflow definition
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevision(
      workflowDefinitionId: string,
      revisionId: string,
      headers?: { If_None_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).getWorkflowDefinitionRevision(
        workflowDefinitionId ? workflowDefinitionId : null,
        revisionId ? revisionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definition revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definition revisions
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition revision item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitionRevisions(
      workflowDefinitionId: string,
      query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).getWorkflowDefinitionRevisions(
        workflowDefinitionId ? workflowDefinitionId : null,
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
     * @summary Return a collection of workflow definitions
     * @param {Object} [query] Query object
     * @param {number} [query.start] The zero-based index of the first workflow definition item to include in this page. The default 0 denotes the beginning of the collection.
     * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
     * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
     * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
     * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    getWorkflowDefinitions(
      query?: {
        start?: number;
        limit?: number;
        sortBy?: string;
        filter?: string;
        q?: string;
        state?:
          | 'pending'
          | 'definition'
          | 'blocked'
          | 'removed'
          | 'running'
          | 'paused'
          | 'completed'
          | 'failed'
          | 'canceled';
        name?: string;
        domain?: string;
        type?: string;
        label?: string;
      },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).getWorkflowDefinitions(
        query ? query : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a partial update of this workflow definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    patchWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).patchWorkflowDefinition(
        UpdateWorkflow ? UpdateWorkflow : null,
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
    /**
     * Perform a complete replacement of this workflow definition.
     * @summary Update this workflow definition
     * @param {UpdateWorkflow} UpdateWorkflow
     * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
     * @param {Object} [headers] Headers object
     * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     **/
    updateWorkflowDefinition(
      UpdateWorkflow: UpdateWorkflow,
      workflowDefinitionId: string,
      headers?: { If_Match?: string },
      options?: any,
    ) {
      return WorkflowDefinitionApiFp(configuration).updateWorkflowDefinition(
        UpdateWorkflow ? UpdateWorkflow : null,
        workflowDefinitionId ? workflowDefinitionId : null,

        headers ? headers : {},
        options ? options : {},
      )(axios, basePath);
    },
  };
};

/**
 * WorkflowDefinitionApi - object-oriented interface
 * @export
 * @class WorkflowDefinitionApi
 * @extends {BaseAPI}
 */
export class WorkflowDefinitionApi extends BaseAPI {
  constructor(config?: SdkConfiguration) {
    super(config);
  }
  /**
   * Create a new workflow definition in the workflow definitions collection.
   * @summary Create a new workflow definition
   * @param {CreateWorkflow} CreateWorkflow A workflow definition. The &#x60;state&#x60; must be &#x60;definition&#x60;.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public createWorkflowDefinition(CreateWorkflow: CreateWorkflow, options?: any) {
    return WorkflowDefinitionApiFp(this.configuration).createWorkflowDefinition(
      CreateWorkflow ? CreateWorkflow : null,

      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Create a new immutable revision of this workflow definition. The revision is a snapshot of the content of the definition. This operation has no request body. The response body is the representation of the new _revision_. It is recommended to update the workflow definition's `revisionLabel` _before_ calling this operation. This operation is ignored (it returns 204 No Content) if the workflow definition has not changed since the last time the revision was created. Creating a revision does not alter the entity tag of the workflow definition.
   * @summary Create a new workflow definition revision
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {'none' | 'taskRevisions'} [query.revisionPolicy] The &#x60;revisionPolicy&#x60; property determines how task definitions reference by this workflow definition are processed when creating a workflow definition revision. If &#x60;revisionPolicy&#x60; is &#x60;none&#x60;, then the task definitions referenced by this workflow definition are copied directly to the new workflow definition revision. With this policy, when instantiating a new workflow _&#x60;W&#x60;_ from the new workflow definitions revision, _&#x60;W&#x60;_ will use the _revisionless_ task definitions, unless the workflow definition already specifies an explicit task definition revisionless.  If &#x60;revisionPolicy&#x60; is &#x60;taskRevisions&#x60; (the default), then the new revision will explicitly link to (and optionally create) the latest _revisions_ of any task definitions embedded within  this workflow definition, even if the workflow definition refers to revisionless task definitions.  This effectively \&quot;snapshots\&quot; both the workflow definition and the task definitions in one operation. For example, if the workflow embeds task definitions &#x60;A&#x60; and &#x60;B&#x60; and &#x60;C&#x60; such that:    * A is already a reference to a specific revision &#x60;2018-10-10T10:10:10.10Z&#x60;   * B refers to a revisionless task definition _and_ &#x60;B&#x60; has _not_ been modified since the last revision &#x60;2018-10-20T20:20:20.000Z&#x60; was created;   * &#x60;C&#x60; refers to a revisionless task definition but &#x60;C&#x60; _has_ been modified since its last revision was created;  then creating new workflow definition revision with &#x60;?taskRevisions&#x3D;true&#x60; will first create a task definition revision for &#x60;C&#x60; (&#x60;2018-10-30T13:30:30.300Z&#x60;) and the new workflow definition revision will embed the existing revision &#x60;2018-10-10T10:10:10.10Z&#x60; of &#x60;A&#x60;, the existing revision &#x60;2018-10-20T20:20:20.000Z&#x60; of &#x60;B&#x60;, and the new revision &#x60;2018-10-30T13:30:30.300Z&#x60; of &#x60;C&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public createWorkflowDefinitionRevision(
    workflowDefinitionId: string,
    query?: { revisionPolicy?: 'none' | 'taskRevisions' },
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).createWorkflowDefinitionRevision(
      workflowDefinitionId ? workflowDefinitionId : null,
      query ? query : {},
      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Delete this workflow definition resource. The workflow definition may not be deleted if it or any of its revisions are in use by any tasks. Deleting a workflow definition also deletes all of its revisions.
   * @summary Delete this workflow definition resource
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {}
   * @memberof WorkflowDefinitionApi
   */
  public deleteWorkflowDefinition(
    workflowDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).deleteWorkflowDefinition(
      workflowDefinitionId ? workflowDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this workflow definition resource. This resource is referred to as the `revisionless` workflow definition, in contrast to the explicit revision at `/workflowDefinitions/{workflowDefinitionId}/revisions/{revisionId}`.
   * @summary Fetch a representation of this workflow definition
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public getWorkflowDefinition(
    workflowDefinitionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).getWorkflowDefinition(
      workflowDefinitionId ? workflowDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return an immutable [HAL](https://developer.apiture.com/docs/concepts/hal) representation of this revision of this workflow definition resource. The revision may also have `prev` and `next` links to previous and/or next revisions, if they exist.
   * @summary Fetch a representation of an immutable revision of this workflow definition
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {string} revisionId The identifier for a revision of this resource. Revision identifiers use [RFC 3339](https://tools.ietf.org/html/rfc3339) format: &#x60;YYYY-MM-DDThh:mm:ss.sssZ&#x60;.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_None_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. If the resource&#39;s current entity tag matches, the &#x60;GET&#x60; will return 304 (Not Modified) and no response body, else the resource representation will be returned.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public getWorkflowDefinitionRevision(
    workflowDefinitionId: string,
    revisionId: string,
    headers?: { If_None_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).getWorkflowDefinitionRevision(
      workflowDefinitionId ? workflowDefinitionId : null,
      revisionId ? revisionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definition revisions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of workflow definition revisions
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first workflow definition revision item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. Revision collections are sorted by default in reverse chronological order (most recent revision first). See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflows}
   * @memberof WorkflowDefinitionApi
   */
  public getWorkflowDefinitionRevisions(
    workflowDefinitionId: string,
    query?: { start?: number; limit?: number; sortBy?: string; filter?: string; q?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).getWorkflowDefinitionRevisions(
      workflowDefinitionId ? workflowDefinitionId : null,
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Return a [paginated](https://developer.apiture.com/docs/concepts/pagination) [sortable](https://developer.apiture.com/docs/concepts/sorting) [filterable](https://developer.apiture.com/docs/concepts/filtering) [searchable](https://developer.apiture.com/docs/concepts/searchable) collection of workflow definitions. The [links](https://developer.apiture.com/docs/concepts/links) in the response include pagination links.
   * @summary Return a collection of workflow definitions
   * @param {Object} [query] Query object
   * @param {number} [query.start] The zero-based index of the first workflow definition item to include in this page. The default 0 denotes the beginning of the collection.
   * @param {number} [query.limit] The maximum number of workflow definition representations to return in this page.
   * @param {string} [query.sortBy] Optional sort criteria. See [sort criteria format](https://developer.apiture.com/docs/concepts/sorting), such as &#x60;?sortBy&#x3D;field1,-field2&#x60;.
   * @param {string} [query.filter] Optional filter criteria. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.q] Optional search string. See [searching](https://developer.apiture.com/docs/concepts/searching).
   * @param {'pending' | 'definition' | 'blocked' | 'removed' | 'running' | 'paused' | 'completed' | 'failed' | 'canceled'} [query.state] Subset the collection to those whose &#x60;state&#x60; matches this value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?state&#x3D;pending&#x60; matches only items whose &#x60;state&#x60; is &#x60;pending&#x60;; &#x60;?state&#x3D;removed|inactive&#x60; matches items whose &#x60;state&#x60; is &#x60;removed&#x60; or &#x60;inactive&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.name] Subset the collection to those with this name value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?name&#x3D;Bartell&#x60; will match only items whose name is &#x60;Bartell&#x60;; &#x60;?name&#x3D;Bartell|kirsten&#x60; will match items whose name is &#x60;Bartell&#x60; or &#x60;kirsten&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.domain] Subset the collection to those with this &#x60;domain&#x60; value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?domain&#x3D;http://api.apiture.com/acctApps&#x60; matches only items whose domain is &#x60;http://api.apiture.com/acctApps&#x60;; &#x60;?domain&#x3D;http://api.apiture.com/acctApps|http:/api.apiture.com/domains/tasks/forms&#x60; will match items  whose domain is &#x60;http://api.apiture.com/acctApps&#x60; or &#x60;http:/api.apiture.com/domains/tasks/forms&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.type] Subset the collection to those with this exact type value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?type&#x3D;Personal%20Savings&#x60; matches only items whose type is &#x60;Personal Savings&#x60;; &#x60;?type&#x3D;Personal%20Savings|Investment%20Account&#x60; matches items whose type is &#x60;Personal Savings&#x60; or &#x60;Investment Account&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {string} [query.label] Subset the collection to those with this label value. Use &#x60;|&#x60; to separate multiple values. For example, &#x60;?label&#x3D;Email%20Verification&#x60; matches only items whose label is &#x60;Email Verification&#x60;; &#x60;?label&#x3D;Email%20Verification|Account%20Verification&#x60; will match items whose label is &#x60;Email Verification&#x60; or &#x60;Account Verification&#x60;. This is combined with an implicit &#x60;and&#x60; with other filters if they are used. See [filtering](https://developer.apiture.com/docs/concepts/filtering).
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflows}
   * @memberof WorkflowDefinitionApi
   */
  public getWorkflowDefinitions(
    query?: {
      start?: number;
      limit?: number;
      sortBy?: string;
      filter?: string;
      q?: string;
      state?:
        | 'pending'
        | 'definition'
        | 'blocked'
        | 'removed'
        | 'running'
        | 'paused'
        | 'completed'
        | 'failed'
        | 'canceled';
      name?: string;
      domain?: string;
      type?: string;
      label?: string;
    },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).getWorkflowDefinitions(
      query ? query : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a partial update of this workflow definition. Fields which are omitted are not updated. Nested `_embedded` and `_links` are ignored if included.
   * @summary Update this workflow definition
   * @param {UpdateWorkflow} UpdateWorkflow
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public patchWorkflowDefinition(
    UpdateWorkflow: UpdateWorkflow,
    workflowDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).patchWorkflowDefinition(
      UpdateWorkflow ? UpdateWorkflow : null,
      workflowDefinitionId ? workflowDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }

  /**
   * Perform a complete replacement of this workflow definition.
   * @summary Update this workflow definition
   * @param {UpdateWorkflow} UpdateWorkflow
   * @param {string} workflowDefinitionId The unique identifier of this workflow definition. This is an opaque string.
   * @param {Object} [headers] Headers object
   * @param {string} [headers.If_Match] The entity tag that was returned in the &#x60;ETag&#x60; response. This must match the current entity tag of the resource.
   * @param {*} [options] Override http request option.
   * @throws {RequiredError}
   * @returns {Workflow}
   * @memberof WorkflowDefinitionApi
   */
  public updateWorkflowDefinition(
    UpdateWorkflow: UpdateWorkflow,
    workflowDefinitionId: string,
    headers?: { If_Match?: string },
    options?: any,
  ) {
    return WorkflowDefinitionApiFp(this.configuration).updateWorkflowDefinition(
      UpdateWorkflow ? UpdateWorkflow : null,
      workflowDefinitionId ? workflowDefinitionId : null,

      headers ? headers : {},
      options ? options : {},
    )(this.axios, this.basePath);
  }
}
